#--------------------------------------------------------------------
#FILE NAME  :   kovacic_tester.mpl
#
# Copyright (C) 2022, Nasser M. Abbasi. All rights reserved
# email: nma@12000.org
#
# Free software to use and modify in anyway as long as the above 
# copyright notice remains attached in the file
#
# Change history
#-----------------
# Oct 27, 2022.     Initial version
#
# Note that the latest version can alaways be obtained from the author
# web site at 
# http://12000.org/my_notes/my_paper_on_kovacic/paper.htm
#

#--------------------------------------------------------------------
# This module is for doing unit tests of
# kovacic class
#--------------------------------------------------------------------
kovacic_tester:=module()

global kovacic_class;

#--------------------------------------------------------------------
#  main API test
#--------------------------------------------------------------------
export unit_test_main_api:=proc()
local sol,ode,x::nothing,y::nothing,DATA::list;
local N::integer:=0;
local ODE::kovacic_class;
local item::list;
local f::symbol,r::symbol,z::symbol;
local u::symbol,v::symbol;
local res_from_odetest;

#keep track of COUNT which case uses. 1,2 or 3.
local cases_used_tally:=[0,0,0]; 
local case_used::integer;

#keep track of n used by case 3
local n_used_for_case_3_tally:=[0,0,0]; 
local n_used::integer;

#keep track of distribution of cases that meets neccessary conditions
local possible_cases_tally:=[0,0,0]; 
local possible_cases::list;
local number_failed::integer:=0;
local problems_failed:=Array(1..0);
local Z;

DATA :=[[157,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[158,diff(diff(y(x),x),x)-9*y(x) = 0,y(x)],
[159,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[160,diff(diff(y(x),x),x)+25*y(x) = 0,y(x)],
[161,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[162,diff(diff(y(x),x),x)+diff(y(x),x)-6*y(x) = 0,y(x)],
[163,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[164,diff(diff(y(x),x),x)-3*diff(y(x),x) = 0,y(x)],
[165,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[166,diff(diff(y(x),x),x)-10*diff(y(x),x)+25*y(x) = 0,y(x)],
[167,diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[168,diff(diff(y(x),x),x)+6*diff(y(x),x)+13*y(x) = 0,y(x)],
[169,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[170,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-6*y(x) = 0,y(x)],
[171,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[172,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[173,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[174,diff(diff(y(x),x),x)+2*diff(y(x),x)-15*y(x) = 0,y(x)],
[175,diff(diff(y(x),x),x)+5*diff(y(x),x) = 0,y(x)],
[176,2*diff(diff(y(x),x),x)+3*diff(y(x),x) = 0,y(x)],
[177,2*diff(diff(y(x),x),x)-diff(y(x),x)-y(x) = 0,y(x)],
[178,4*diff(diff(y(x),x),x)+8*diff(y(x),x)+3*y(x) = 0,y(x)],
[179,4*diff(diff(y(x),x),x)+4*diff(y(x),x)+y(x) = 0,y(x)],
[180,9*diff(diff(y(x),x),x)-12*diff(y(x),x)+4*y(x) = 0,y(x)],
[181,6*diff(diff(y(x),x),x)-7*diff(y(x),x)-20*y(x) = 0,y(x)],
[182,35*diff(diff(y(x),x),x)-diff(y(x),x)-12*y(x) = 0,y(x)],
[183,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[184,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-12*y(x) = 0,y(x)],
[185,4*x^2*diff(diff(y(x),x),x)+8*x*diff(y(x),x)-3*y(x) = 0,y(x)],
[186,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x) = 0,y(x)],
[187,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[188,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[189,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[190,diff(diff(y(x),x),x)-2*diff(y(x),x)-3*y(x) = 0,y(x)],
[191,diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[192,diff(diff(y(x),x),x)+2*y(x) = 0,y(x)],
[193,diff(diff(y(x),x),x)+2*y(x) = 0,y(x)],
[194,diff(diff(y(x),x),x)+2*y(x) = 0,y(x)],
[195,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[196,2*diff(diff(y(x),x),x)-3*diff(y(x),x) = 0,y(x)],
[197,diff(diff(y(x),x),x)+3*diff(y(x),x)-10*y(x) = 0,y(x)],
[198,2*diff(diff(y(x),x),x)-7*diff(y(x),x)+3*y(x) = 0,y(x)],
[199,diff(diff(y(x),x),x)+6*diff(y(x),x)+9*y(x) = 0,y(x)],
[200,diff(diff(y(x),x),x)+5*diff(y(x),x)+5*y(x) = 0,y(x)],
[201,4*diff(diff(y(x),x),x)-12*diff(y(x),x)+9*y(x) = 0,y(x)],
[202,diff(diff(y(x),x),x)-6*diff(y(x),x)+13*y(x) = 0,y(x)],
[203,diff(diff(y(x),x),x)+8*diff(y(x),x)+25*y(x) = 0,y(x)],
[204,diff(diff(y(x),x),x)-4*diff(y(x),x)+3*y(x) = 0,y(x)],
[205,9*diff(diff(y(x),x),x)+6*diff(y(x),x)+4*y(x) = 0,y(x)],
[206,diff(diff(y(x),x),x)-6*diff(y(x),x)+25*y(x) = 0,y(x)],
[207,diff(diff(y(x),x),x)-2*I*diff(y(x),x)+3*y(x) = 0,y(x)],
[208,diff(diff(y(x),x),x)-I*diff(y(x),x)+6*y(x) = 0,y(x)],
[209,diff(diff(y(x),x),x)+(-2*I*3^(1/2)+2)*y(x) = 0,y(x)],
[210,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+9*y(x) = 0,y(x)],
[211,x^2*diff(diff(y(x),x),x)+7*x*diff(y(x),x)+25*y(x) = 0,y(x)],
[212,1/2*diff(diff(x(t),t),t)+3*diff(x(t),t)+4*x(t) = 0,x(t)],
[213,3*diff(diff(x(t),t),t)+30*diff(x(t),t)+63*x(t) = 0,x(t)],
[214,diff(diff(x(t),t),t)+8*diff(x(t),t)+16*x(t) = 0,x(t)],
[215,2*diff(diff(x(t),t),t)+12*diff(x(t),t)+50*x(t) = 0,x(t)],
[216,4*diff(diff(x(t),t),t)+20*diff(x(t),t)+169*x(t) = 0,x(t)],
[217,2*diff(diff(x(t),t),t)+16*diff(x(t),t)+40*x(t) = 0,x(t)],
[218,diff(diff(x(t),t),t)+10*diff(x(t),t)+125*x(t) = 0,x(t)],
[219,diff(diff(y(x),x),x)+16*y(x) = 0,y(x)],
[220,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[221,diff(diff(y(x),x),x)-diff(y(x),x)-6*y(x) = 0,y(x)],
[222,4*diff(diff(y(x),x),x)+4*diff(y(x),x)+y(x) = 0,y(x)],
[223,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[224,2*diff(diff(y(x),x),x)+4*diff(y(x),x)+7*y(x) = 0,y(x)],
[225,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[226,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[227,diff(diff(y(x),x),x)+2*diff(y(x),x)-3*y(x) = 0,y(x)],
[228,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[229,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[230,diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[231,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[232,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[233,diff(diff(y(x),x),x)-6*diff(y(x),x)+13*y(x) = 0,y(x)],
[234,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[235,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[236,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[237,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[238,diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[239,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[240,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[241,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[242,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[243,diff(diff(y(x),x),x)-2*diff(y(x),x)-8*y(x) = 0,y(x)],
[244,diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[245,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[246,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[247,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[248,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[249,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[250,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[251,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[252,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[253,x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[254,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[255,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+3*y(x) = 0,y(x)],
[256,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[257,(x^2-1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[258,diff(diff(x(t),t),t)+9*x(t) = 0,x(t)],
[259,diff(diff(x(t),t),t)+4*x(t) = 0,x(t)],
[260,diff(diff(x(t),t),t)+100*x(t) = 0,x(t)],
[261,diff(diff(x(t),t),t)+25*x(t) = 0,x(t)],
[262,m*diff(diff(x(t),t),t)+k*x(t) = 0,x(t)],
[263,diff(diff(x(t),t),t)+4*diff(x(t),t)+4*x(t) = 0,x(t)],
[264,diff(diff(x(t),t),t)+3*diff(x(t),t)+5*x(t) = 0,x(t)],
[265,2*diff(diff(x(t),t),t)+2*diff(x(t),t)+x(t) = 0,x(t)],
[266,diff(diff(x(t),t),t)+3*diff(x(t),t)+3*x(t) = 0,x(t)],
[267,diff(diff(x(t),t),t)+4*diff(x(t),t)+5*x(t) = 0,x(t)],
[268,diff(diff(x(t),t),t)+6*diff(x(t),t)+13*x(t) = 0,x(t)],
[269,diff(diff(x(t),t),t)+6*diff(x(t),t)+13*x(t) = 0,x(t)],
[270,diff(diff(x(t),t),t)+2*diff(x(t),t)+26*x(t) = 0,x(t)],
[271,diff(diff(x(t),t),t)+8*diff(x(t),t)+25*x(t) = 0,x(t)],
[278,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-9*y(x) = 0,y(x)],
[279,4*diff(diff(y(x),x),x)-4*diff(y(x),x)+y(x) = 0,y(x)],
[280,x^2*diff(diff(y(x),x),x)+(-x^2-2*x)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[281,(x+1)*diff(diff(y(x),x),x)+(-x-2)*diff(y(x),x)+y(x) = 0,y(x)],
[282,(-x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[283,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[284,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[286,16*diff(diff(y(x),x),x) = 0,y(x)],
[287,3*diff(diff(y(x),x),x)-diff(y(x),x) = 0,y(x)],
[288,12*diff(diff(y(x),x),x)+4*diff(y(x),x) = 0,y(x)],
[289,3*diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[290,-16*diff(diff(y(x),x),x)+16*y(x) = 0,y(x)],
[291,18*diff(diff(y(x),x),x)+81*y(x) = 0,y(x)],
[292,11*diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[294,diff(diff(y(x),x),x)-diff(y(x),x)-y(x) = 0,y(x)],
[295,3*diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[296,-3*diff(diff(y(x),x),x)-2*diff(y(x),x) = 0,y(x)],
[297,2*diff(diff(y(x),x),x) = 0,y(x)],
[298,10*diff(diff(y(x),x),x)+25*diff(y(x),x) = 0,y(x)],
[299,3*diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[300,-diff(diff(y(x),x),x)-5*diff(y(x),x)-2*y(x) = 0,y(x)],
[302,diff(diff(y(x),x),x)-3*diff(y(x),x)-6*y(x) = 0,y(x)],
[303,3*diff(diff(y(x),x),x)+4*diff(y(x),x)-8*y(x) = 0,y(x)],
[304,-3*diff(diff(y(x),x),x)-5*diff(y(x),x)-2*y(x) = 0,y(x)],
[305,-5*diff(diff(y(x),x),x)+100*diff(y(x),x)-500*y(x) = 0,y(x)],
[307,-diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[308,6*x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x) = 0,y(x)],
[309,-x^2*diff(diff(y(x),x),x)+x*diff(y(x),x) = 0,y(x)],
[310,3*x^2*diff(diff(y(x),x),x)+x*diff(y(x),x) = 0,y(x)],
[311,-3*x^2*diff(diff(y(x),x),x)+x*diff(y(x),x) = 0,y(x)],
[312,6*x^2*diff(diff(y(x),x),x)+7*x*diff(y(x),x)+y(x) = 0,y(x)],
[402,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[403,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[404,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[405,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[410,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[411,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[412,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[413,diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[416,(x^2-1)*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[417,(x^2+2)*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[418,diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[419,(x^2+1)*diff(diff(y(x),x),x)+6*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[420,(x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x) = 0,y(x)],
[421,(x^2-1)*diff(diff(y(x),x),x)-6*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[422,(x^2+3)*diff(diff(y(x),x),x)-7*x*diff(y(x),x)+16*y(x) = 0,y(x)],
[423,(-x^2+2)*diff(diff(y(x),x),x)-x*diff(y(x),x)+16*y(x) = 0,y(x)],
[424,(x^2-1)*diff(diff(y(x),x),x)+8*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[425,3*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[426,5*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+10*y(x) = 0,y(x)],
[427,diff(diff(y(x),x),x)-x^2*diff(y(x),x)-3*x*y(x) = 0,y(x)],
[428,diff(diff(y(x),x),x)+x^2*diff(y(x),x)+2*x*y(x) = 0,y(x)],
[431,(x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[432,diff(diff(y(x),x),x)+x*diff(y(x),x)-2*y(x) = 0,y(x)],
[433,diff(diff(y(x),x),x)+(x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[434,(-x^2+2*x)*diff(diff(y(x),x),x)+(-6*x+6)*diff(y(x),x)-4*y(x) = 0,y(x)],
[435,(x^2-6*x+10)*diff(diff(y(x),x),x)+(-4*x+12)*diff(y(x),x)+6*y(x) = 0,y(x)],
[436,(4*x^2+16*x+17)*diff(diff(y(x),x),x)-8*y(x) = 0,y(x)],
[437,(x^2+6*x)*diff(diff(y(x),x),x)+(3*x+9)*diff(y(x),x)-3*y(x) = 0,y(x)],
[599,diff(diff(y(x),x),x)+2*diff(y(x),x)-3*y(x) = 0,y(x)],
[600,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[601,6*diff(diff(y(x),x),x)-diff(y(x),x)-y(x) = 0,y(x)],
[602,2*diff(diff(y(x),x),x)-3*diff(y(x),x)+y(x) = 0,y(x)],
[603,diff(diff(y(x),x),x)+5*diff(y(x),x) = 0,y(x)],
[604,4*diff(diff(y(x),x),x)-9*y(x) = 0,y(x)],
[605,diff(diff(y(x),x),x)-9*diff(y(x),x)+9*y(x) = 0,y(x)],
[606,diff(diff(y(x),x),x)-2*diff(y(x),x)-2*y(x) = 0,y(x)],
[607,diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[608,diff(diff(y(x),x),x)+4*diff(y(x),x)+3*y(x) = 0,y(x)],
[609,6*diff(diff(y(x),x),x)-5*diff(y(x),x)+y(x) = 0,y(x)],
[610,diff(diff(y(x),x),x)+3*diff(y(x),x) = 0,y(x)],
[611,diff(diff(y(x),x),x)+5*diff(y(x),x)+3*y(x) = 0,y(x)],
[612,2*diff(diff(y(x),x),x)+diff(y(x),x)-4*y(x) = 0,y(x)],
[613,diff(diff(y(x),x),x)+8*diff(y(x),x)-9*y(x) = 0,y(x)],
[614,4*diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[615,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[616,2*diff(diff(y(x),x),x)-3*diff(y(x),x)+y(x) = 0,y(x)],
[617,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[618,4*diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[621,2*diff(diff(y(x),x),x)+3*diff(y(x),x)-2*y(x) = 0,y(x)],
[622,diff(diff(y(x),x),x)+5*diff(y(x),x)+6*y(x) = 0,y(x)],
[623,diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[624,diff(diff(y(x),x),x)-2*diff(y(x),x)+6*y(x) = 0,y(x)],
[625,diff(diff(y(x),x),x)+2*diff(y(x),x)-8*y(x) = 0,y(x)],
[626,diff(diff(y(x),x),x)+2*diff(y(x),x)+2*y(x) = 0,y(x)],
[627,diff(diff(y(x),x),x)+6*diff(y(x),x)+13*y(x) = 0,y(x)],
[628,4*diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[629,diff(diff(y(x),x),x)+2*diff(y(x),x)+5/4*y(x) = 0,y(x)],
[630,9*diff(diff(y(x),x),x)+9*diff(y(x),x)-4*y(x) = 0,y(x)],
[631,diff(diff(y(x),x),x)+diff(y(x),x)+5/4*y(x) = 0,y(x)],
[632,diff(diff(y(x),x),x)+4*diff(y(x),x)+25/4*y(x) = 0,y(x)],
[633,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[634,diff(diff(y(x),x),x)+4*diff(y(x),x)+5*y(x) = 0,y(x)],
[635,diff(diff(y(x),x),x)-2*diff(y(x),x)+5*y(x) = 0,y(x)],
[636,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[637,diff(diff(y(x),x),x)+diff(y(x),x)+5/4*y(x) = 0,y(x)],
[638,diff(diff(y(x),x),x)+2*diff(y(x),x)+2*y(x) = 0,y(x)],
[639,diff(diff(u(x),x),x)-diff(u(x),x)+2*u(x) = 0,u(x)],
[640,5*diff(diff(u(x),x),x)+2*diff(u(x),x)+7*u(x) = 0,u(x)],
[641,diff(diff(y(x),x),x)+2*diff(y(x),x)+6*y(x) = 0,y(x)],
[643,t^2*diff(diff(y(t),t),t)+t*diff(y(t),t)+y(t) = 0,y(t)],
[644,t^2*diff(diff(y(t),t),t)+4*t*diff(y(t),t)+2*y(t) = 0,y(t)],
[645,t^2*diff(diff(y(t),t),t)+3*t*diff(y(t),t)+5/4*y(t) = 0,y(t)],
[646,t^2*diff(diff(y(t),t),t)-4*t*diff(y(t),t)-6*y(t) = 0,y(t)],
[647,t^2*diff(diff(y(t),t),t)-4*t*diff(y(t),t)+6*y(t) = 0,y(t)],
[648,t^2*diff(diff(y(t),t),t)-t*diff(y(t),t)+5*y(t) = 0,y(t)],
[649,t^2*diff(diff(y(t),t),t)+3*t*diff(y(t),t)-3*y(t) = 0,y(t)],
[650,t^2*diff(diff(y(t),t),t)+7*t*diff(y(t),t)+10*y(t) = 0,y(t)],
[652,t*diff(diff(y(t),t),t)+(t^2-1)*diff(y(t),t)+t^3*y(t) = 0,y(t)],
[653,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[654,9*diff(diff(y(x),x),x)+6*diff(y(x),x)+y(x) = 0,y(x)],
[655,4*diff(diff(y(x),x),x)-4*diff(y(x),x)-3*y(x) = 0,y(x)],
[656,4*diff(diff(y(x),x),x)+12*diff(y(x),x)+9*y(x) = 0,y(x)],
[657,diff(diff(y(x),x),x)-2*diff(y(x),x)+10*y(x) = 0,y(x)],
[658,diff(diff(y(x),x),x)-6*diff(y(x),x)+9*y(x) = 0,y(x)],
[659,4*diff(diff(y(x),x),x)+17*diff(y(x),x)+4*y(x) = 0,y(x)],
[660,16*diff(diff(y(x),x),x)+24*diff(y(x),x)+9*y(x) = 0,y(x)],
[661,25*diff(diff(y(x),x),x)-20*diff(y(x),x)+4*y(x) = 0,y(x)],
[662,2*diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[663,9*diff(diff(y(t),t),t)-12*diff(y(t),t)+4*y(t) = 0,y(t)],
[664,diff(diff(y(t),t),t)-6*diff(y(t),t)+9*y(t) = 0,y(t)],
[665,9*diff(diff(y(t),t),t)+6*diff(y(t),t)+82*y(t) = 0,y(t)],
[666,diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[667,4*diff(diff(y(t),t),t)+12*diff(y(t),t)+9*y(t) = 0,y(t)],
[668,diff(diff(y(t),t),t)-diff(y(t),t)+1/4*y(t) = 0,y(t)],
[669,t^2*diff(diff(y(t),t),t)-4*t*diff(y(t),t)+6*y(t) = 0,y(t)],
[670,t^2*diff(diff(y(t),t),t)+2*t*diff(y(t),t)-2*y(t) = 0,y(t)],
[671,t^2*diff(diff(y(t),t),t)+3*t*diff(y(t),t)+y(t) = 0,y(t)],
[672,t^2*diff(diff(y(t),t),t)+(-t^2-2*t)*diff(y(t),t)+(t+2)*y(t) = 0,y(t)],
[673,x*diff(diff(y(x),x),x)-diff(y(x),x)+4*x^3*y(x) = 0,y(x)],
[674,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[675,x^2*diff(diff(y(x),x),x)+(-x+3/16)*y(x) = 0,y(x)],
[676,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[677,t^2*diff(diff(y(t),t),t)-3*t*diff(y(t),t)+4*y(t) = 0,y(t)],
[678,t^2*diff(diff(y(t),t),t)+2*t*diff(y(t),t)+1/4*y(t) = 0,y(t)],
[679,2*t^2*diff(diff(y(t),t),t)-5*t*diff(y(t),t)+5*y(t) = 0,y(t)],
[680,t^2*diff(diff(y(t),t),t)+3*t*diff(y(t),t)+y(t) = 0,y(t)],
[681,4*t^2*diff(diff(y(t),t),t)-8*t*diff(y(t),t)+9*y(t) = 0,y(t)],
[682,t^2*diff(diff(y(t),t),t)+5*t*diff(y(t),t)+13*y(t) = 0,y(t)],
[683,diff(diff(y(t),t),t)-5*diff(y(t),t)+6*y(t) = 0,y(t)],
[684,diff(diff(y(t),t),t)-diff(y(t),t)-2*y(t) = 0,y(t)],
[685,diff(diff(y(t),t),t)+2*diff(y(t),t)+y(t) = 0,y(t)],
[686,4*diff(diff(y(t),t),t)-4*diff(y(t),t)+y(t) = 0,y(t)],
[687,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[688,diff(diff(y(t),t),t)+9*y(t) = 0,y(t)],
[689,diff(diff(y(t),t),t)+4*diff(y(t),t)+4*y(t) = 0,y(t)],
[690,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[691,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[692,diff(diff(y(t),t),t)-2*diff(y(t),t)+y(t) = 0,y(t)],
[693,diff(diff(y(t),t),t)-5*diff(y(t),t)+6*y(t) = 0,y(t)],
[694,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[695,t^2*diff(diff(y(t),t),t)-2*y(t) = 0,y(t)],
[696,t^2*diff(diff(y(t),t),t)+(-t^2-2*t)*diff(y(t),t)+(t+2)*y(t) = 0,y(t)],
[697,t*diff(diff(y(t),t),t)+(-t-1)*diff(y(t),t)+y(t) = 0,y(t)],
[698,(1-t)*diff(diff(y(t),t),t)+t*diff(y(t),t)-y(t) = 0,y(t)],
[699,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[700,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[701,t^2*diff(diff(y(t),t),t)-2*t*diff(y(t),t)+2*y(t) = 0,y(t)],
[702,t^2*diff(diff(y(t),t),t)+7*t*diff(y(t),t)+5*y(t) = 0,y(t)],
[703,t*diff(diff(y(t),t),t)+(-t-1)*diff(y(t),t)+y(t) = 0,y(t)],
[704,(1-t)*diff(diff(y(t),t),t)+t*diff(y(t),t)-y(t) = 0,y(t)],
[705,diff(diff(u(t),t),t)+2*u(t) = 0,u(t)],
[706,diff(diff(u(t),t),t)+1/4*diff(u(t),t)+2*u(t) = 0,u(t)],
[707,diff(diff(u(t),t),t)+1/8*diff(u(t),t)+4*u(t) = 0,u(t)],
[708,diff(diff(u(t),t),t)+1/8*diff(u(t),t)+4*u(t) = 0,u(t)],
[709,diff(diff(u(t),t),t)+1/8*diff(u(t),t)+4*u(t) = 0,u(t)],
[711,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[712,diff(diff(y(x),x),x)-x*diff(y(x),x)-y(x) = 0,y(x)],
[715,(x^2+2)*diff(diff(y(x),x),x)-x*diff(y(x),x)+4*y(x) = 0,y(x)],
[716,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[717,(x^2+1)*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[718,(-x^2+4)*diff(diff(y(x),x),x)+2*y(x) = 0,y(x)],
[719,(-x^2+3)*diff(diff(y(x),x),x)-3*x*diff(y(x),x)-y(x) = 0,y(x)],
[720,(1-x)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[721,2*diff(diff(y(x),x),x)+x*diff(y(x),x)+3*y(x) = 0,y(x)],
[722,diff(diff(y(x),x),x)-x*diff(y(x),x)-y(x) = 0,y(x)],
[723,(x^2+2)*diff(diff(y(x),x),x)-x*diff(y(x),x)+4*y(x) = 0,y(x)],
[724,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[725,(1-x)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[727,diff(diff(y(x),x),x)-x*diff(y(x),x)-y(x) = 0,y(x)],
[728,(x^2+2)*diff(diff(y(x),x),x)-x*diff(y(x),x)+4*y(x) = 0,y(x)],
[729,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[730,(-x^2+4)*diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[732,(1-x)*diff(diff(y(x),x),x)+x*diff(y(x),x)-2*y(x) = 0,y(x)],
[733,diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[814,diff(diff(y(t),t),t) = 0,y(t)],
[815,2*diff(diff(y(t),t),t)-diff(y(t),t)-2*y(t) = 0,y(t)],
[816,-diff(diff(y(x),x),x) = 0,y(x)],
[817,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[818,2*diff(diff(y(x),x),x)-diff(y(x),x)-3*y(x) = 0,y(x)],
[820,(2*t-3)*diff(diff(y(t),t),t)-t*diff(y(t),t)+y(t) = 0,y(t)],
[821,(-3*t^2-6*t)*diff(diff(y(t),t),t)+(6*t+6)*diff(y(t),t)-6*y(t) = 0,y(t)],
[822,-diff(diff(y(x),x),x)-diff(y(x),x)+y(x) = 0,y(x)],
[823,-3*diff(diff(y(x),x),x)+3*diff(y(x),x)+y(x) = 0,y(x)],
[824,4*diff(diff(y(x),x),x) = 0,y(x)],
[826,3*diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[827,-diff(diff(y(x),x),x) = 0,y(x)],
[828,-3*diff(diff(y(x),x),x)+2*diff(y(x),x) = 0,y(x)],
[830,2*diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[831,5*diff(diff(y(x),x),x)+6*diff(y(x),x)+2*y(x) = 0,y(x)],
[832,6*diff(diff(y(x),x),x)+30*diff(y(x),x)-36*y(x) = 0,y(x)],
[833,diff(diff(y(t),t),t)-diff(y(t),t)-6*y(t) = 0,y(t)],
[834,diff(diff(y(t),t),t)+3*diff(y(t),t)+2*y(t) = 0,y(t)],
[835,diff(diff(y(t),t),t)-2*diff(y(t),t)+2*y(t) = 0,y(t)],
[836,diff(diff(y(t),t),t)-2*diff(y(t),t)+4*y(t) = 0,y(t)],
[837,diff(diff(y(t),t),t)+2*diff(y(t),t)+5*y(t) = 0,y(t)],
[838,6*diff(diff(y(t),t),t)-4*diff(y(t),t)+y(t) = 0,y(t)],
[841,diff(diff(y(t),t),t)-2*diff(y(t),t)+2*y(t) = 0,y(t)],
[842,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[843,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[844,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[845,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[846,diff(diff(y(t),t),t)+2*diff(y(t),t)+2*y(t) = 0,y(t)],
[847,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[848,diff(diff(y(t),t),t)+3*diff(y(t),t)+2*y(t) = 0,y(t)],
[849,diff(diff(y(t),t),t)+diff(y(t),t)+5/4*y(t) = 0,y(t)],
[850,diff(diff(y(t),t),t)+diff(y(t),t)+5/4*y(t) = 0,y(t)],
[851,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[852,5*diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[853,diff(diff(u(t),t),t)+1/4*diff(u(t),t)+u(t) = 0,u(t)],
[854,diff(diff(u(t),t),t)+1/4*diff(u(t),t)+u(t) = 0,u(t)],
[855,diff(diff(u(t),t),t)+1/4*diff(u(t),t)+u(t) = 0,u(t)],
[856,diff(diff(y(t),t),t)+2*diff(y(t),t)+2*y(t) = 0,y(t)],
[857,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[858,diff(diff(y(t),t),t)+3*diff(y(t),t)+2*y(t) = 0,y(t)],
[859,diff(diff(y(t),t),t)+2*diff(y(t),t)+3*y(t) = 0,y(t)],
[860,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[861,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[862,diff(diff(y(t),t),t)+2*diff(y(t),t)+2*y(t) = 0,y(t)],
[864,diff(diff(y(t),t),t)+1/2*diff(y(t),t)+y(t) = 0,y(t)],
[865,diff(diff(y(t),t),t)+1/4*diff(y(t),t)+y(t) = 0,y(t)],
[866,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[867,diff(diff(y(t),t),t)+2*diff(y(t),t)+2*y(t) = 0,y(t)],
[868,diff(diff(y(t),t),t)+2*diff(y(t),t)+2*y(t) = 0,y(t)],
[1087,diff(diff(y(x),x),x)-7*diff(y(x),x)+10*y(x) = 0,y(x)],
[1088,diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[1089,diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[1090,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[1091,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[1092,(x^2-1)*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1093,diff(diff(y(x),x),x)-2*diff(y(x),x)-3*y(x) = 0,y(x)],
[1094,diff(diff(y(x),x),x)-6*diff(y(x),x)+9*y(x) = 0,y(x)],
[1096,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[1097,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[1099,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(-16*x^2+3)*y(x) = 0,y(x)],
[1100,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[1101,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[1104,(x^2-4)*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1106,(x^2-2*x)*diff(diff(y(x),x),x)+(-x^2+2)*diff(y(x),x)+(2*x-2)*y(x) = 0,y(x)],
[1107,(2*x+1)*diff(diff(y(x),x),x)-2*diff(y(x),x)+(-2*x-3)*y(x) = 0,y(x)],
[1108,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[1109,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[1110,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[1111,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[1112,4*x^2*diff(diff(y(x),x),x)+(-8*x^2+4*x)*diff(y(x),x)+(4*x^2-4*x-1)*y(x) = 0,y(x)],
[1113,diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[1114,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[1115,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[1116,x^2*diff(diff(y(x),x),x)+(2*x^2-2*x)*diff(y(x),x)+(x^2-2*x+2)*y(x) = 0,y(x)],
[1117,x^2*diff(diff(y(x),x),x)+(-2*x^2+x)*diff(y(x),x)+(x^2-x-1)*y(x) = 0,y(x)],
[1118,(1-2*x)*diff(diff(y(x),x),x)+2*diff(y(x),x)+(2*x-3)*y(x) = 0,y(x)],
[1119,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[1120,2*x*diff(diff(y(x),x),x)+(1+4*x)*diff(y(x),x)+(2*x+1)*y(x) = 0,y(x)],
[1121,x*diff(diff(y(x),x),x)+(-2*x-1)*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[1122,4*x^2*diff(diff(y(x),x),x)+(-4*x^2-4*x)*diff(y(x),x)+(2*x+3)*y(x) = 0,y(x)],
[1123,x^2*diff(diff(y(x),x),x)-5*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[1124,x*diff(diff(y(x),x),x)+(-2*x+2)*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[1125,x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[1127,4*x*diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[1128,x*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[1130,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[1131,x*diff(diff(y(x),x),x)+(-4*x-1)*diff(y(x),x)+(4*x+2)*y(x) = 0,y(x)],
[1133,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(-16*x^2+3)*y(x) = 0,y(x)],
[1134,(2*x^2+x)*diff(diff(y(x),x),x)+(-4*x^2+2)*diff(y(x),x)+(-4*x-4)*y(x) = 0,y(x)],
[1135,(x^2-2*x)*diff(diff(y(x),x),x)+(-x^2+2)*diff(y(x),x)+(2*x-2)*y(x) = 0,y(x)],
[1136,x*diff(diff(y(x),x),x)+(-4*x-1)*diff(y(x),x)+(4*x+2)*y(x) = 0,y(x)],
[1137,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[1138,(3*x-1)*diff(diff(y(x),x),x)+(-3*x-2)*diff(y(x),x)+(-6*x+8)*y(x) = 0,y(x)],
[1139,(x^2+2*x+1)*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+(-x^2-2*x+1)*y(x) = 0,y(x)],
[1140,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[1141,(x^2-4)*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1155,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[1156,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[1157,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[1158,diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[1159,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[1160,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[1161,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[1163,4*x^2*diff(diff(y(x),x),x)+(-8*x^2+4*x)*diff(y(x),x)+(4*x^2-4*x-1)*y(x) = 0,y(x)],
[1164,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[1165,x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[1166,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+3*y(x) = 0,y(x)],
[1167,(2*x+1)*diff(diff(y(x),x),x)-2*diff(y(x),x)+(-2*x-3)*y(x) = 0,y(x)],
[1169,x*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[1171,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[1172,x*diff(diff(y(x),x),x)-diff(y(x),x)-4*x^3*y(x) = 0,y(x)],
[1174,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(-16*x^2+3)*y(x) = 0,y(x)],
[1175,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2+3)*y(x) = 0,y(x)],
[1176,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(-x^2+2)*y(x) = 0,y(x)],
[1177,x^2*diff(diff(y(x),x),x)+(-2*x^2-2*x)*diff(y(x),x)+(x^2+2*x+2)*y(x) = 0,y(x)],
[1178,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)-3*y(x) = 0,y(x)],
[1179,x^2*diff(diff(y(x),x),x)+(-x^2-4*x)*diff(y(x),x)+(2*x+6)*y(x) = 0,y(x)],
[1180,x^2*diff(diff(y(x),x),x)+(-2*x^2-4*x)*diff(y(x),x)+(x^2+4*x+6)*y(x) = 0,y(x)],
[1181,x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(x^2+6)*y(x) = 0,y(x)],
[1182,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[1183,4*x^2*diff(diff(y(x),x),x)+(-4*x^2-4*x)*diff(y(x),x)+(2*x+3)*y(x) = 0,y(x)],
[1184,(3*x-1)*diff(diff(y(x),x),x)+(-3*x-2)*diff(y(x),x)+(-6*x+8)*y(x) = 0,y(x)],
[1185,(x^2-2*x+1)*diff(diff(y(x),x),x)+(-2*x+2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[1187,(x^2-2*x+1)*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1188,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[1189,(2*x^2+5*x+3)*diff(diff(y(x),x),x)+(2*x+4)*diff(y(x),x)-2*y(x) = 0,y(x)],
[1190,(x+2)*diff(diff(y(x),x),x)+x*diff(y(x),x)+3*y(x) = 0,y(x)],
[1199,(-x^3+x^2)*diff(diff(y(x),x),x)+(x^2+4*x)*diff(y(x),x)+(2-x)*y(x) = 0,y(x)],
[1200,(x^3+x^2)*diff(diff(y(x),x),x)+(2*x^2+x)*diff(y(x),x)+(-6*x-4)*y(x) = 0,y(x)],
[1202,(3*x^3+x^2)*diff(diff(y(x),x),x)+(x^3+12*x^2+2*x)*diff(y(x),x)+(2*x^2+6*x)*y(x) = 0,y(x)],
[1203,(2*x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3+4*x)*diff(y(x),x)+(-2*x^2+2)*y(x) = 0,y(x)],
[1204,(x^4+2*x^2)*diff(diff(y(x),x),x)+(2*x^3+10*x)*diff(y(x),x)+(-2*x^2+6)*y(x) = 0,y(x)],
[1205,(x^2+1)*diff(diff(y(x),x),x)+6*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[1206,(x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[1207,(x^2+1)*diff(diff(y(x),x),x)-8*x*diff(y(x),x)+20*y(x) = 0,y(x)],
[1208,(-x^2+1)*diff(diff(y(x),x),x)-8*x*diff(y(x),x)-12*y(x) = 0,y(x)],
[1209,(2*x^2+1)*diff(diff(y(x),x),x)+7*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1211,(-x^2+1)*diff(diff(y(x),x),x)-5*x*diff(y(x),x)-4*y(x) = 0,y(x)],
[1212,(x^2+1)*diff(diff(y(x),x),x)-10*x*diff(y(x),x)+28*y(x) = 0,y(x)],
[1213,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1215,(x^2+1)*diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[1216,(2*x^2+1)*diff(diff(y(x),x),x)-9*x*diff(y(x),x)-6*y(x) = 0,y(x)],
[1218,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[1219,diff(diff(y(x),x),x)+(-x+3)*diff(y(x),x)-y(x) = 0,y(x)],
[1220,(2*x^2-4*x+1)*diff(diff(y(x),x),x)+(10*x-10)*diff(y(x),x)+6*y(x) = 0,y(x)],
[1221,(2*x^2-8*x+11)*diff(diff(y(x),x),x)+(-16*x+32)*diff(y(x),x)+36*y(x) = 0,y(x)],
[1222,(3*x^2+6*x+5)*diff(diff(y(x),x),x)+(9*x+9)*diff(y(x),x)+3*y(x) = 0,y(x)],
[1223,(x^2-4)*diff(diff(y(x),x),x)-x*diff(y(x),x)-3*y(x) = 0,y(x)],
[1224,diff(diff(y(x),x),x)+(x-3)*diff(y(x),x)+3*y(x) = 0,y(x)],
[1227,(x^2-8*x+14)*diff(diff(y(x),x),x)+(-8*x+32)*diff(y(x),x)+20*y(x) = 0,y(x)],
[1228,(2*x^2+4*x+5)*diff(diff(y(x),x),x)+(-20*x-20)*diff(y(x),x)+60*y(x) = 0,y(x)],
[1229,(x^2+1)*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1232,(-2*x^3+1)*diff(diff(y(x),x),x)-10*x^2*diff(y(x),x)-8*x*y(x) = 0,y(x)],
[1233,(x^3+1)*diff(diff(y(x),x),x)+7*x^2*diff(y(x),x)+9*x*y(x) = 0,y(x)],
[1234,(-2*x^3+1)*diff(diff(y(x),x),x)+6*x^2*diff(y(x),x)+24*x*y(x) = 0,y(x)],
[1238,diff(diff(y(x),x),x)+x^6*diff(y(x),x)+7*x^5*y(x) = 0,y(x)],
[1240,(-x^6+1)*diff(diff(y(x),x),x)-12*x^5*diff(y(x),x)-30*x^4*y(x) = 0,y(x)],
[1241,diff(diff(y(x),x),x)+x^5*diff(y(x),x)+6*x^4*y(x) = 0,y(x)],
[1242,(1+3*x)*diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1243,(2*x^2+x+1)*diff(diff(y(x),x),x)+(2+8*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[1244,(-2*x^2+1)*diff(diff(y(x),x),x)+(2-6*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[1245,(3*x^2+x+1)*diff(diff(y(x),x),x)+(2+15*x)*diff(y(x),x)+12*y(x) = 0,y(x)],
[1246,(x+2)*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)+3*y(x) = 0,y(x)],
[1247,(x^2+3*x+3)*diff(diff(y(x),x),x)+(6+4*x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[1248,(x+4)*diff(diff(y(x),x),x)+(x+2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[1249,(2*x^2-3*x+2)*diff(diff(y(x),x),x)+(6*x-4)*diff(y(x),x)+2*y(x) = 0,y(x)],
[1250,(2*x^2+3*x)*diff(diff(y(x),x),x)+(10*x+10)*diff(y(x),x)+8*y(x) = 0,y(x)],
[1251,(x^2-x+1)*diff(diff(y(x),x),x)+(-1+4*x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[1252,(x+2)*diff(diff(y(x),x),x)+(x+2)*diff(y(x),x)+y(x) = 0,y(x)],
[1253,x^2*diff(diff(y(x),x),x)+(-6+7*x)*diff(y(x),x)+8*y(x) = 0,y(x)],
[1254,(2*x^2+x+1)*diff(diff(y(x),x),x)+(1+7*x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[1255,(x+3)*diff(diff(y(x),x),x)+(2*x+1)*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[1256,diff(diff(y(x),x),x)+3*x*diff(y(x),x)+(2*x^2+4)*y(x) = 0,y(x)],
[1257,(4*x+2)*diff(diff(y(x),x),x)-4*diff(y(x),x)+(-4*x-6)*y(x) = 0,y(x)],
[1268,(2*x^2+3*x+1)*diff(diff(y(x),x),x)+(6+8*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[1269,(6*x^2-5*x+1)*diff(diff(y(x),x),x)+(24*x-10)*diff(y(x),x)+12*y(x) = 0,y(x)],
[1270,(4*x^2-4*x+1)*diff(diff(y(x),x),x)+(16*x-8)*diff(y(x),x)+8*y(x) = 0,y(x)],
[1271,(x^2+4*x+4)*diff(diff(y(x),x),x)+(8+4*x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[1272,(3*x^2+8*x+4)*diff(diff(y(x),x),x)+(16+12*x)*diff(y(x),x)+6*y(x) = 0,y(x)],
[1274,diff(diff(y(x),x),x)-3*x*diff(y(x),x)+(2*x^2+5)*y(x) = 0,y(x)],
[1278,2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)+(2*x^2+4)*y(x) = 0,y(x)],
[1280,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[1281,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[1293,(x^3+3*x^2)*diff(diff(y(x),x),x)+(5*x^2+5*x)*diff(y(x),x)+(-1+4*x)*y(x) = 0,y(x)],
[1296,3*x^2*diff(diff(y(x),x),x)+(-4*x^3+2*x^2+2*x)*diff(y(x),x)+(-8*x^2+2*x)*y(x) = 0,y(x)],
[1299,(12*x^3+12*x^2)*diff(diff(y(x),x),x)+(3*x^3+35*x^2+11*x)*diff(y(x),x)+(5*x^2+10*x-1)*y(x) = 0,y(x)],
[1300,(10*x^4+x^3+5*x^2)*diff(diff(y(x),x),x)+(48*x^3+3*x^2+4*x)*diff(y(x),x)+(36*x^2+x)*y(x) = 0,y(x)],
[1302,(18*x^3+18*x^2)*diff(diff(y(x),x),x)+(3*x^3+33*x^2+15*x)*diff(y(x),x)+(5*x^2+2*x-1)*y(x) = 0,y(x)],
[1305,2*x^2*diff(diff(y(x),x),x)+(2*x^2+3*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[1306,(x^3+3*x^2)*diff(diff(y(x),x),x)+(4*x^2+5*x)*diff(y(x),x)+(2*x-1)*y(x) = 0,y(x)],
[1307,2*x^2*diff(diff(y(x),x),x)+(x^2+5*x)*diff(y(x),x)+(3*x-2)*y(x) = 0,y(x)],
[1308,3*x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)-y(x) = 0,y(x)],
[1309,2*x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+(1-2*x)*y(x) = 0,y(x)],
[1311,3*x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(-1-3*x)*y(x) = 0,y(x)],
[1312,(2*x^3+6*x^2)*diff(diff(y(x),x),x)+(5*x^2+x)*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[1313,(x^3+4*x^2)*diff(diff(y(x),x),x)+(3*x^2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[1314,2*x^2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[1315,(4*x^3+3*x^2)*diff(diff(y(x),x),x)+(18*x^2+5*x)*diff(y(x),x)+(12*x-1)*y(x) = 0,y(x)],
[1316,6*x^2*diff(diff(y(x),x),x)+(-x^2+10*x)*diff(y(x),x)+(-x-2)*y(x) = 0,y(x)],
[1318,(4*x^3+3*x^2)*diff(diff(y(x),x),x)+(4*x^2+11*x)*diff(y(x),x)+(-4*x-3)*y(x) = 0,y(x)],
[1319,(6*x^3+4*x^2)*diff(diff(y(x),x),x)+(11*x^2+4*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[1320,(x^3+2*x^2)*diff(diff(y(x),x),x)+(-5*x^2+5*x)*diff(y(x),x)+(8*x-2)*y(x) = 0,y(x)],
[1323,(-8*x^4+8*x^2)*diff(diff(y(x),x),x)+(-26*x^3+2*x)*diff(y(x),x)+(-9*x^2+1)*y(x) = 0,y(x)],
[1324,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3-4*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[1325,(x^3+3*x)*diff(diff(y(x),x),x)+(-x^2+2)*diff(y(x),x)-8*x*y(x) = 0,y(x)],
[1326,(-4*x^4+4*x^2)*diff(diff(y(x),x),x)+(-19*x^3+7*x)*diff(y(x),x)+(-14*x^2-1)*y(x) = 0,y(x)],
[1327,(-3*x^4+6*x^2)*diff(diff(y(x),x),x)+(-11*x^3+x)*diff(y(x),x)+(-5*x^2+1)*y(x) = 0,y(x)],
[1328,(2*x^4+4*x^2)*diff(diff(y(x),x),x)+(7*x^3-12*x)*diff(y(x),x)+(3*x^2+7)*y(x) = 0,y(x)],
[1329,(2*x^4+4*x^2)*diff(diff(y(x),x),x)+(7*x^3+4*x)*diff(y(x),x)+(3*x^2-1)*y(x) = 0,y(x)],
[1330,(4*x^4+2*x^2)*diff(diff(y(x),x),x)+(30*x^3+5*x)*diff(y(x),x)+(40*x^2-2)*y(x) = 0,y(x)],
[1332,(x^3+x)*diff(diff(y(x),x),x)+(7*x^2+4)*diff(y(x),x)+8*x*y(x) = 0,y(x)],
[1334,(2*x^4+2*x^2)*diff(diff(y(x),x),x)+(8*x^3+3*x)*diff(y(x),x)+(4*x^2-3)*y(x) = 0,y(x)],
[1335,9*x^2*diff(diff(y(x),x),x)+(3*x^3+9*x)*diff(y(x),x)+(5*x^2-1)*y(x) = 0,y(x)],
[1336,6*x^2*diff(diff(y(x),x),x)+(6*x^3+x)*diff(y(x),x)+(9*x^2+1)*y(x) = 0,y(x)],
[1338,(9*x^4+9*x^2)*diff(diff(y(x),x),x)+(39*x^3+9*x)*diff(y(x),x)+(25*x^2-1)*y(x) = 0,y(x)],
[1339,(4*x^4+4*x^2)*diff(diff(y(x),x),x)+(24*x^3+4*x)*diff(y(x),x)+(25*x^2-1)*y(x) = 0,y(x)],
[1340,(16*x^4+8*x^2)*diff(diff(y(x),x),x)+(68*x^3+10*x)*diff(y(x),x)+(30*x^2-1)*y(x) = 0,y(x)],
[1341,(2*x^3+2*x^2)*diff(diff(y(x),x),x)+(3*x^2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[1342,(12*x^4+6*x^2)*diff(diff(y(x),x),x)+(50*x^3+x)*diff(y(x),x)+(30*x^2+1)*y(x) = 0,y(x)],
[1343,(-84*x^3+28*x^2)*diff(diff(y(x),x),x)+(-63*x^2-35*x)*diff(y(x),x)+(63*x+14)*y(x) = 0,y(x)],
[1345,(-8*x^4+16*x^2)*diff(diff(y(x),x),x)+(-42*x^3+20*x)*diff(y(x),x)+(-35*x^2-2)*y(x) = 0,y(x)],
[1346,(4*x^4+12*x^3+4*x^2)*diff(diff(y(x),x),x)+(12*x^3+12*x^2-4*x)*diff(y(x),x)+(3*x^2-3*x+3)*y(x) = 0,y(x)],
[1347,(3*x^4+6*x^3+3*x^2)*diff(diff(y(x),x),x)+(11*x^3+10*x^2-x)*diff(y(x),x)+(5*x^2+1)*y(x) = 0,y(x)],
[1348,(4*x^4+8*x^3+12*x^2)*diff(diff(y(x),x),x)+(15*x^3+14*x^2-3*x)*diff(y(x),x)+(7*x^2+3)*y(x) = 0,y(x)],
[1349,(x^4-2*x^3+x^2)*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+(x+4)*y(x) = 0,y(x)],
[1350,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+5*x^2*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[1351,(-x^4+2*x^2)*diff(diff(y(x),x),x)+(-4*x^3-2*x)*diff(y(x),x)+(-2*x^2+2)*y(x) = 0,y(x)],
[1352,x^2*diff(diff(y(x),x),x)+(x^2-5*x)*diff(y(x),x)+(9-4*x)*y(x) = 0,y(x)],
[1354,(2*x^4+x^3+x^2)*diff(diff(y(x),x),x)+(7*x^3+6*x^2+3*x)*diff(y(x),x)+(-3*x^2+6*x+1)*y(x) = 0,y(x)],
[1355,(x^4+2*x^3+x^2)*diff(diff(y(x),x),x)+(4*x^3+3*x^2+x)*diff(y(x),x)+(2*x^2-x)*y(x) = 0,y(x)],
[1356,(4*x^4+4*x^3+4*x^2)*diff(diff(y(x),x),x)+(12*x^3+12*x^2)*diff(y(x),x)+(3*x^2+3*x+1)*y(x) = 0,y(x)],
[1357,(x^4+x^3+x^2)*diff(diff(y(x),x),x)+(2*x^3+4*x^2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[1358,9*x^2*diff(diff(y(x),x),x)+(-6*x^3+9*x^2+15*x)*diff(y(x),x)+(-14*x^2+12*x+1)*y(x) = 0,y(x)],
[1360,(2*x^3+x^2)*diff(diff(y(x),x),x)+(3*x^3+14*x^2+5*x)*diff(y(x),x)+(12*x^2+18*x+4)*y(x) = 0,y(x)],
[1362,16*x^2*diff(diff(y(x),x),x)+(8*x^3+4*x^2+24*x)*diff(y(x),x)+(18*x^2+5*x+1)*y(x) = 0,y(x)],
[1363,(9*x^3+9*x^2)*diff(diff(y(x),x),x)+(-3*x^3+33*x^2+15*x)*diff(y(x),x)+(-7*x^2+16*x+1)*y(x) = 0,y(x)],
[1365,(-72*x^3+36*x^2)*diff(diff(y(x),x),x)+(-216*x^2+24*x)*diff(y(x),x)+(1-70*x)*y(x) = 0,y(x)],
[1366,(x^3+x^2)*diff(diff(y(x),x),x)+(x^2-3*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[1367,(-2*x^3+x^2)*diff(diff(y(x),x),x)+(4*x^2-5*x)*diff(y(x),x)+(9-4*x)*y(x) = 0,y(x)],
[1369,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+(1-x)*y(x) = 0,y(x)],
[1372,(-4*x^3+x^2)*diff(diff(y(x),x),x)+(-18*x^2+3*x)*diff(y(x),x)+(1-12*x)*y(x) = 0,y(x)],
[1373,(2*x^3+x^2)*diff(diff(y(x),x),x)+(5*x^2+3*x)*diff(y(x),x)+(1-2*x)*y(x) = 0,y(x)],
[1374,(2*x^3+2*x^2)*diff(diff(y(x),x),x)+(x^2-6*x)*diff(y(x),x)+(8-x)*y(x) = 0,y(x)],
[1375,(2*x^3+x^2)*diff(diff(y(x),x),x)+(9*x^2+5*x)*diff(y(x),x)+(4+3*x)*y(x) = 0,y(x)],
[1376,(-2*x^3+x^2)*diff(diff(y(x),x),x)+(-4*x^2-5*x)*diff(y(x),x)+(9+4*x)*y(x) = 0,y(x)],
[1379,(-x^3+x^2)*diff(diff(y(x),x),x)+(x^2+7*x)*diff(y(x),x)+(9-x)*y(x) = 0,y(x)],
[1380,x^2*diff(diff(y(x),x),x)+(x^3-x)*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[1381,(x^4+x^2)*diff(diff(y(x),x),x)+(3*x^3-3*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[1382,4*x^2*diff(diff(y(x),x),x)+2*x^3*diff(y(x),x)+(3*x^2+1)*y(x) = 0,y(x)],
[1383,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3-x)*diff(y(x),x)+y(x) = 0,y(x)],
[1384,(2*x^4+4*x^2)*diff(diff(y(x),x),x)+7*x^3*diff(y(x),x)+(3*x^2+1)*y(x) = 0,y(x)],
[1385,(x^4+x^2)*diff(diff(y(x),x),x)+(4*x^3-x)*diff(y(x),x)+(2*x^2+1)*y(x) = 0,y(x)],
[1386,(4*x^4+16*x^2)*diff(diff(y(x),x),x)+(9*x^3+24*x)*diff(y(x),x)+(-9*x^2+1)*y(x) = 0,y(x)],
[1387,(3*x^4+9*x^2)*diff(diff(y(x),x),x)+(11*x^3+3*x)*diff(y(x),x)+(5*x^2+1)*y(x) = 0,y(x)],
[1389,9*x^2*diff(diff(y(x),x),x)+(6*x^3-21*x)*diff(y(x),x)+(2*x^2+25)*y(x) = 0,y(x)],
[1390,(2*x^4+x^2)*diff(diff(y(x),x),x)+(7*x^3+3*x)*diff(y(x),x)+(-3*x^2+1)*y(x) = 0,y(x)],
[1391,(x^4+x^2)*diff(diff(y(x),x),x)+(8*x^3+3*x)*diff(y(x),x)+(12*x^2+1)*y(x) = 0,y(x)],
[1392,x^2*diff(diff(y(x),x),x)+(x^3-x)*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[1396,(-2*x^3+x^2)*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+(1+4*x)*y(x) = 0,y(x)],
[1397,(x^2+x)*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)+y(x) = 0,y(x)],
[1398,(-x^3+x^2)*diff(diff(y(x),x),x)+(-2*x^2+3*x)*diff(y(x),x)+(2*x+1)*y(x) = 0,y(x)],
[1400,(-x^3+x^2)*diff(diff(y(x),x),x)+(5*x^2-3*x)*diff(y(x),x)+(4-5*x)*y(x) = 0,y(x)],
[1401,(x^4+x^2)*diff(diff(y(x),x),x)+(-9*x^3-x)*diff(y(x),x)+(25*x^2+1)*y(x) = 0,y(x)],
[1402,9*x^2*diff(diff(y(x),x),x)+(-3*x^3+3*x)*diff(y(x),x)+(7*x^2+1)*y(x) = 0,y(x)],
[1403,(x^3+x)*diff(diff(y(x),x),x)+(-x^2+1)*diff(y(x),x)-8*x*y(x) = 0,y(x)],
[1404,4*x^2*diff(diff(y(x),x),x)+(-2*x^3+8*x)*diff(y(x),x)+(7*x^2+1)*y(x) = 0,y(x)],
[1405,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+8*x^2*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[1406,(9*x^3+27*x^2)*diff(diff(y(x),x),x)+(21*x^2+9*x)*diff(y(x),x)+(4*x+3)*y(x) = 0,y(x)],
[1407,(-x^4+2*x^2)*diff(diff(y(x),x),x)+(-3*x^3-2*x)*diff(y(x),x)+(-x^2+2)*y(x) = 0,y(x)],
[1408,(16*x^4+16*x^2)*diff(diff(y(x),x),x)+(72*x^3+8*x)*diff(y(x),x)+(49*x^2+1)*y(x) = 0,y(x)],
[1409,(3*x^3+4*x^2)*diff(diff(y(x),x),x)+(3*x^2-4*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[1410,(4*x^4+12*x^3+4*x^2)*diff(diff(y(x),x),x)+(16*x^3+24*x^2)*diff(y(x),x)+(9*x^2+3*x+1)*y(x) = 0,y(x)],
[1411,(x^4-2*x^3+x^2)*diff(diff(y(x),x),x)+(3*x^3-2*x^2-x)*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[1412,(9*x^4+9*x^3+9*x^2)*diff(diff(y(x),x),x)+(39*x^3+21*x^2+3*x)*diff(y(x),x)+(25*x^2+4*x+1)*y(x) = 0,y(x)],
[1413,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+(7*x^2-4*x)*diff(y(x),x)+(3*x-5)*y(x) = 0,y(x)],
[1414,(-2*x^3+x^2)*diff(diff(y(x),x),x)+(-9*x^2+8*x)*diff(y(x),x)+(6-3*x)*y(x) = 0,y(x)],
[1415,(x^4+x^2)*diff(diff(y(x),x),x)+(10*x^3+3*x)*diff(y(x),x)+(14*x^2-15)*y(x) = 0,y(x)],
[1416,(-2*x^4+x^2)*diff(diff(y(x),x),x)+(-13*x^3+7*x)*diff(y(x),x)-14*x^2*y(x) = 0,y(x)],
[1419,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+(8*x^2+4*x)*diff(y(x),x)+(-1-3*x)*y(x) = 0,y(x)],
[1421,(6*x^3+4*x^2)*diff(diff(y(x),x),x)+(21*x^2+4*x)*diff(y(x),x)+(9*x-1)*y(x) = 0,y(x)],
[1422,x^2*diff(diff(y(x),x),x)+(x^2+2*x)*diff(y(x),x)+(3*x-2)*y(x) = 0,y(x)],
[1425,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+(32*x^2+12*x)*diff(y(x),x)+(49*x-5)*y(x) = 0,y(x)],
[1426,(x^3+x^2)*diff(diff(y(x),x),x)+(-10*x^2-3*x)*diff(y(x),x)+30*x*y(x) = 0,y(x)],
[1427,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(-3*x-9)*y(x) = 0,y(x)],
[1429,(x^2+x)*diff(diff(y(x),x),x)-4*diff(y(x),x)-2*y(x) = 0,y(x)],
[1430,(2*x^3+x^2)*diff(diff(y(x),x),x)+(13*x^2+9*x)*diff(y(x),x)+(7+5*x)*y(x) = 0,y(x)],
[1431,(8*x^3+4*x^2)*diff(diff(y(x),x),x)+(2*x^2-8*x)*diff(y(x),x)+(-5*x-7)*y(x) = 0,y(x)],
[1432,(3*x^3+9*x^2)*diff(diff(y(x),x),x)+(-x^2-15*x)*diff(y(x),x)-20*y(x) = 0,y(x)],
[1433,(x^3+x^2)*diff(diff(y(x),x),x)+(-10*x^2+x)*diff(y(x),x)+(10*x-9)*y(x) = 0,y(x)],
[1434,(x^3+x^2)*diff(diff(y(x),x),x)+3*x^2*diff(y(x),x)+(x-6)*y(x) = 0,y(x)],
[1435,(2*x^3+x^2)*diff(diff(y(x),x),x)+(-28*x^2-6*x)*diff(y(x),x)+(6+100*x)*y(x) = 0,y(x)],
[1436,(x^3+x^2)*diff(diff(y(x),x),x)+(-11*x^2-6*x)*diff(y(x),x)+(6+32*x)*y(x) = 0,y(x)],
[1437,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+(16*x^2+4*x)*diff(y(x),x)+(-27*x-49)*y(x) = 0,y(x)],
[1438,(2*x^3+x^2)*diff(diff(y(x),x),x)+(-8*x^2-9*x)*diff(y(x),x)-12*x*y(x) = 0,y(x)],
[1439,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3-7*x)*diff(y(x),x)+12*y(x) = 0,y(x)],
[1440,x^2*diff(diff(y(x),x),x)+(x^3-7*x)*diff(y(x),x)+12*y(x) = 0,y(x)],
[1442,x^2*diff(diff(y(x),x),x)+(2*x^3+x)*diff(y(x),x)+(10*x^2-1)*y(x) = 0,y(x)],
[1445,x^2*diff(diff(y(x),x),x)+(x^3+x)*diff(y(x),x)+(3*x^2-1)*y(x) = 0,y(x)],
[1446,x^2*diff(diff(y(x),x),x)+(-2*x^3+x)*diff(y(x),x)+(-8*x^2-4)*y(x) = 0,y(x)],
[1449,x^2*diff(diff(y(x),x),x)+(-2*x^3+x)*diff(y(x),x)+(4*x^2-4)*y(x) = 0,y(x)],
[1450,x^2*diff(diff(y(x),x),x)+(-3*x^3+x)*diff(y(x),x)+(12*x^2-4)*y(x) = 0,y(x)],
[1451,(x^4+x^2)*diff(diff(y(x),x),x)+(11*x^3+5*x)*diff(y(x),x)+24*x^2*y(x) = 0,y(x)],
[1452,(4*x^4+4*x^2)*diff(diff(y(x),x),x)+8*x*diff(y(x),x)+(x^2-35)*y(x) = 0,y(x)],
[1453,(x^4+x^2)*diff(diff(y(x),x),x)+(x^3-5*x)*diff(y(x),x)+(-25*x^2-7)*y(x) = 0,y(x)],
[1454,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3+5*x)*diff(y(x),x)-21*y(x) = 0,y(x)],
[1456,(4*x^4+4*x^2)*diff(diff(y(x),x),x)+(4*x^3+8*x)*diff(y(x),x)+(-x^2-15)*y(x) = 0,y(x)],
[1457,-x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[1458,-7*diff(diff(y(x),x),x)-diff(y(x),x)+6*y(x) = 0,y(x)],
[1459,-x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[1460,-x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[1461,-x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[1462,-x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[1463,diff(diff(y(x),x),x)-diff(y(x),x)-y(x) = 0,y(x)],
[1464,-3*diff(diff(y(x),x),x)+7*diff(y(x),x)-5*y(x) = 0,y(x)],
[1465,-3*diff(diff(y(x),x),x)+3*diff(y(x),x)-y(x) = 0,y(x)],
[1466,8*diff(diff(y(x),x),x)-9*y(x) = 0,y(x)],
[1467,-diff(diff(y(x),x),x)+16*diff(y(x),x)-16*y(x) = 0,y(x)],
[1468,3*diff(diff(y(x),x),x)-2*diff(y(x),x)-3*y(x) = 0,y(x)],
[1469,5*diff(diff(y(x),x),x)+9*diff(y(x),x)+5*y(x) = 0,y(x)],
[1470,-8*diff(diff(y(x),x),x)+5*diff(y(x),x)-y(x) = 0,y(x)],
[1471,27*diff(diff(y(x),x),x)+9*diff(y(x),x)+y(x) = 0,y(x)],
[1472,diff(diff(y(x),x),x) = 0,y(x)],
[1474,12*diff(diff(y(x),x),x)+36*y(x) = 0,y(x)],
[1475,-72*diff(diff(y(x),x),x)+81*y(x) = 0,y(x)],
[1476,7*diff(diff(y(x),x),x)+5*diff(y(x),x)+y(x) = 0,y(x)],
[1477,3*diff(diff(y(x),x),x)-13*diff(y(x),x)-6*y(x) = 0,y(x)],
[1478,7*diff(diff(y(x),x),x)-6*diff(y(x),x)+2*y(x) = 0,y(x)],
[1479,-2*diff(diff(y(x),x),x)+4*diff(y(x),x)-8*y(x) = 0,y(x)],
[1480,3*diff(diff(y(x),x),x)-diff(y(x),x)-3*y(x) = 0,y(x)],
[1481,-diff(diff(y(x),x),x)-diff(y(x),x)+y(x) = 0,y(x)],
[1483,-diff(diff(y(x),x),x)-7*diff(y(x),x)+5*y(x) = 0,y(x)],
[1484,-6*diff(diff(y(x),x),x)+12*diff(y(x),x)-8*y(x) = 0,y(x)],
[1485,-11*diff(diff(y(x),x),x)+12*diff(y(x),x)+9*y(x) = 0,y(x)],
[1486,-4*diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[1488,7*diff(diff(y(x),x),x)+6*diff(y(x),x)-8*y(x) = 0,y(x)],
[1489,-13*diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[1490,-2*diff(diff(y(x),x),x)-8*diff(y(x),x)-8*y(x) = 0,y(x)],
[1491,19*diff(diff(y(x),x),x)+32*diff(y(x),x)+12*y(x) = 0,y(x)],
[1497,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[1498,-6*diff(diff(y(x),x),x)+11*diff(y(x),x)-6*y(x) = 0,y(x)],
[1499,-2*diff(diff(y(x),x),x)-5*diff(y(x),x)+6*y(x) = 0,y(x)],
[1500,8*diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[1501,3*diff(diff(y(x),x),x)-diff(y(x),x)-3*y(x) = 0,y(x)],
[1502,3*diff(diff(y(x),x),x)-diff(y(x),x)-3*y(x) = 0,y(x)],
[1503,diff(diff(y(x),x),x)-2*y(x) = 0,y(x)],
[1504,8*diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[1505,-diff(diff(y(x),x),x)-diff(y(x),x)+y(x) = 0,y(x)],
[1506,-7*diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[1507,-5*diff(diff(y(x),x),x)+3*diff(y(x),x)+9*y(x) = 0,y(x)],
[1508,-7*diff(diff(y(x),x),x)+8*diff(y(x),x)+16*y(x) = 0,y(x)],
[1509,-12*diff(diff(y(x),x),x)+6*diff(y(x),x)-y(x) = 0,y(x)],
[1510,-3*diff(diff(y(x),x),x)-7*diff(y(x),x)+6*y(x) = 0,y(x)],
[1511,diff(diff(y(x),x),x)-3*diff(y(x),x)-2*y(x) = 0,y(x)],
[1512,24*diff(diff(y(x),x),x)+32*diff(y(x),x) = 0,y(x)],
[1513,-11*diff(diff(y(x),x),x)-9*diff(y(x),x)-2*y(x) = 0,y(x)],
[1515,6*diff(diff(y(x),x),x)-4*diff(y(x),x)+2*y(x) = 0,y(x)],
[1517,-2*diff(diff(y(x),x),x)-6*diff(y(x),x)-4*y(x) = 0,y(x)],
[1519,-5*diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[1520,-3*diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[1523,3*diff(diff(y(x),x),x)+diff(y(x),x)-y(x) = 0,y(x)],
[1524,3*diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[1525,18*diff(diff(y(x),x),x)-20*diff(y(x),x)+8*y(x) = 0,y(x)],
[1526,-diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[1527,diff(diff(y(x),x),x)-4*diff(y(x),x)-4*y(x) = 0,y(x)],
[1528,-diff(diff(y(x),x),x)+2*diff(y(x),x)-2*y(x) = 0,y(x)],
[1529,-2*diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[1530,3*diff(diff(y(x),x),x)+4*diff(y(x),x)+12*y(x) = 0,y(x)],
[1531,-diff(diff(y(x),x),x)+2*y(x) = 0,y(x)],
[1532,-7*diff(diff(y(x),x),x)+20*diff(y(x),x)-24*y(x) = 0,y(x)],
[1533,-6*diff(diff(y(x),x),x)+18*diff(y(x),x) = 0,y(x)],
[1534,-2*diff(diff(y(x),x),x)-8*diff(y(x),x)-8*y(x) = 0,y(x)],
[1535,2*diff(diff(y(x),x),x)+2*diff(y(x),x)-4*y(x) = 0,y(x)],
[1536,24*diff(diff(y(x),x),x)-32*diff(y(x),x)+15*y(x) = 0,y(x)],
[1537,13*diff(diff(y(x),x),x)+12*diff(y(x),x)+4*y(x) = 0,y(x)],
[1538,2*diff(diff(y(x),x),x)-2*diff(y(x),x)-4*y(x) = 0,y(x)],
[1539,13*diff(diff(y(x),x),x)-19*diff(y(x),x)+10*y(x) = 0,y(x)],
[1540,32*diff(diff(y(x),x),x)+64*diff(y(x),x)+39*y(x) = 0,y(x)],
[1541,13*diff(diff(y(x),x),x)-19*diff(y(x),x)+10*y(x) = 0,y(x)],
[1542,8*diff(diff(y(x),x),x)+8*diff(y(x),x)+4*y(x) = 0,y(x)],
[1543,32*diff(diff(y(x),x),x)-64*diff(y(x),x)+64*y(x) = 0,y(x)],
[1544,26*diff(diff(y(x),x),x)-40*diff(y(x),x)+25*y(x) = 0,y(x)],
[1545,-4*diff(diff(y(x),x),x)+5*diff(y(x),x)-2*y(x) = 0,y(x)],
[1546,-diff(diff(y(x),x),x)+diff(y(x),x)-y(x) = 0,y(x)],
[1548,-4*diff(diff(y(x),x),x)+9*diff(y(x),x)-10*y(x) = 0,y(x)],
[1549,3*diff(diff(y(x),x),x)+3*diff(y(x),x)+y(x) = 0,y(x)],
[1550,diff(diff(y(x),x),x)-diff(y(x),x)-y(x) = 0,y(x)],
[1551,-5*diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[1552,11*diff(diff(y(x),x),x)-14*diff(y(x),x)+10*y(x) = 0,y(x)],
[1553,-3*diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[1555,9*diff(diff(y(x),x),x)+7*diff(y(x),x)+2*y(x) = 0,y(x)],
[1556,7*diff(diff(y(x),x),x)-6*diff(y(x),x)+2*y(x) = 0,y(x)],
[1557,-diff(diff(y(x),x),x)-diff(y(x),x)+y(x) = 0,y(x)],
[1558,diff(diff(y(x),x),x)-2*y(x) = 0,y(x)],
[1559,-6*diff(diff(y(x),x),x)+11*diff(y(x),x)-6*y(x) = 0,y(x)],
[1560,2*diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[1561,-3*diff(diff(y(x),x),x)+3*diff(y(x),x)-y(x) = 0,y(x)],
[1562,-2*diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[1563,2*diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[1564,4*diff(diff(y(x),x),x)-2*diff(y(x),x) = 0,y(x)],
[1565,14*diff(diff(y(x),x),x)-20*diff(y(x),x)+25*y(x) = 0,y(x)],
[1566,-2*diff(diff(y(x),x),x)-5*diff(y(x),x)+6*y(x) = 0,y(x)],
[1567,-diff(diff(y(x),x),x)-diff(y(x),x)+y(x) = 0,y(x)],
[1569,2*diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[1570,2*diff(diff(y(x),x),x)+diff(y(x),x)+2*y(x) = 0,y(x)],
[1571,5*diff(diff(y(x),x),x)-2*diff(y(x),x) = 0,y(x)],
[1572,-3*x^2*diff(diff(y(x),x),x)+6*x*diff(y(x),x)-6*y(x) = 0,y(x)],
[1573,4*x^2*diff(diff(y(x),x),x)-5*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1574,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1575,72*x^2*diff(diff(y(x),x),x)-24*x*diff(y(x),x)+9*y(x) = 0,y(x)],
[1576,12*x^2*diff(diff(y(x),x),x)-24*x*diff(y(x),x)+24*y(x) = 0,y(x)],
[1577,2*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[1578,-2*x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-3*y(x) = 0,y(x)],
[1579,-5*x^2*diff(diff(y(x),x),x)+14*x*diff(y(x),x)-18*y(x) = 0,y(x)],
[1580,-6*x^2*diff(diff(y(x),x),x)+16*x*diff(y(x),x)-16*y(x) = 0,y(x)],
[1581,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1582,-x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[1583,23*x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[1584,-3*x^2*diff(diff(y(x),x),x)-6*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[1585,2*diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[1586,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1587,-5*diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[1588,2*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[1712,2*t^2*diff(diff(y(t),t),t)+3*t*diff(y(t),t)-y(t) = 0,y(t)],
[1713,2*t^2*diff(diff(y(t),t),t)+3*t*diff(y(t),t)-y(t) = 0,y(t)],
[1714,diff(diff(y(t),t),t)+t*diff(y(t),t)+y(t) = 0,y(t)],
[1715,diff(diff(y(t),t),t)+t*diff(y(t),t)+y(t) = 0,y(t)],
[1716,diff(diff(y(t),t),t)-y(t) = 0,y(t)],
[1717,6*diff(diff(y(t),t),t)-7*diff(y(t),t)+y(t) = 0,y(t)],
[1718,diff(diff(y(t),t),t)-3*diff(y(t),t)+y(t) = 0,y(t)],
[1719,3*diff(diff(y(t),t),t)+6*diff(y(t),t)+3*y(t) = 0,y(t)],
[1720,diff(diff(y(t),t),t)-3*diff(y(t),t)-4*y(t) = 0,y(t)],
[1721,2*diff(diff(y(t),t),t)+diff(y(t),t)-10*y(t) = 0,y(t)],
[1722,5*diff(diff(y(t),t),t)+5*diff(y(t),t)-y(t) = 0,y(t)],
[1723,diff(diff(y(t),t),t)-6*diff(y(t),t)+y(t) = 0,y(t)],
[1724,diff(diff(y(t),t),t)+5*diff(y(t),t)+6*y(t) = 0,y(t)],
[1726,t^2*diff(diff(y(t),t),t)+5*t*diff(y(t),t)-5*y(t) = 0,y(t)],
[1727,t^2*diff(diff(y(t),t),t)-t*diff(y(t),t)-2*y(t) = 0,y(t)],
[1728,diff(diff(y(t),t),t)+2*diff(y(t),t)+4*y(t) = 0,y(t)],
[1729,diff(diff(y(t),t),t)+diff(y(t),t)+y(t) = 0,y(t)],
[1730,2*diff(diff(y(t),t),t)+3*diff(y(t),t)+4*y(t) = 0,y(t)],
[1731,diff(diff(y(t),t),t)+2*diff(y(t),t)+3*y(t) = 0,y(t)],
[1732,4*diff(diff(y(t),t),t)-diff(y(t),t)+y(t) = 0,y(t)],
[1733,diff(diff(y(t),t),t)+diff(y(t),t)+2*y(t) = 0,y(t)],
[1734,diff(diff(y(t),t),t)+2*diff(y(t),t)+5*y(t) = 0,y(t)],
[1735,2*diff(diff(y(t),t),t)-diff(y(t),t)+3*y(t) = 0,y(t)],
[1736,3*diff(diff(y(t),t),t)-2*diff(y(t),t)+4*y(t) = 0,y(t)],
[1737,t^2*diff(diff(y(t),t),t)+t*diff(y(t),t)+y(t) = 0,y(t)],
[1738,t^2*diff(diff(y(t),t),t)+2*t*diff(y(t),t)+2*y(t) = 0,y(t)],
[1739,diff(diff(y(t),t),t)-6*diff(y(t),t)+9*y(t) = 0,y(t)],
[1740,4*diff(diff(y(t),t),t)-12*diff(y(t),t)+9*y(t) = 0,y(t)],
[1741,9*diff(diff(y(t),t),t)+6*diff(y(t),t)+y(t) = 0,y(t)],
[1742,4*diff(diff(y(t),t),t)-4*diff(y(t),t)+y(t) = 0,y(t)],
[1743,diff(diff(y(t),t),t)+2*diff(y(t),t)+y(t) = 0,y(t)],
[1744,9*diff(diff(y(t),t),t)-12*diff(y(t),t)+4*y(t) = 0,y(t)],
[1745,diff(diff(y(t),t),t)+(-2/(t^2+2*t-1)*t-2/(t^2+2*t-1))*diff(y(t),t)+2/(t^2+2*t-1)*y(t) = 0,y(t)],
[1746,diff(diff(y(t),t),t)-4*t*diff(y(t),t)+(4*t^2-2)*y(t) = 0,y(t)],
[1747,(-t^2+1)*diff(diff(y(t),t),t)-2*t*diff(y(t),t)+2*y(t) = 0,y(t)],
[1748,(t^2+1)*diff(diff(y(t),t),t)-2*t*diff(y(t),t)+2*y(t) = 0,y(t)],
[1749,(-t^2+1)*diff(diff(y(t),t),t)-2*t*diff(y(t),t)+6*y(t) = 0,y(t)],
[1750,(2*t+1)*diff(diff(y(t),t),t)+(-4*t-4)*diff(y(t),t)+4*y(t) = 0,y(t)],
[1751,t^2*diff(diff(y(t),t),t)+t*diff(y(t),t)+(t^2-1/4)*y(t) = 0,y(t)],
[1752,t^2*diff(diff(y(t),t),t)+3*t*diff(y(t),t)+y(t) = 0,y(t)],
[1753,t^2*diff(diff(y(t),t),t)-t*diff(y(t),t)+y(t) = 0,y(t)],
[1754,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[1755,diff(diff(y(t),t),t)-4*diff(y(t),t)+4*y(t) = 0,y(t)],
[1756,2*diff(diff(y(t),t),t)-3*diff(y(t),t)+y(t) = 0,y(t)],
[1757,diff(diff(y(t),t),t)-3*diff(y(t),t)+2*y(t) = 0,y(t)],
[1758,3*diff(diff(y(t),t),t)+4*diff(y(t),t)+y(t) = 0,y(t)],
[1759,diff(diff(y(t),t),t)+4*diff(y(t),t)+4*y(t) = 0,y(t)],
[1760,diff(diff(y(t),t),t)-3*diff(y(t),t)+2*y(t) = 0,y(t)],
[1761,diff(diff(y(t),t),t)-y(t) = 0,y(t)],
[1763,diff(diff(y(t),t),t)-2*t/(t^2+1)*diff(y(t),t)+2/(t^2+1)*y(t) = 0,y(t)],
[1765,diff(diff(y(t),t),t)+t*diff(y(t),t)+y(t) = 0,y(t)],
[1767,(t^2+2)*diff(diff(y(t),t),t)-t*diff(y(t),t)-3*y(t) = 0,y(t)],
[1769,(-t^2+2*t)*diff(diff(y(t),t),t)+(-6*t+6)*diff(y(t),t)-4*y(t) = 0,y(t)],
[1776,diff(diff(y(t),t),t)+t^3*diff(y(t),t)+3*t^2*y(t) = 0,y(t)],
[1777,diff(diff(y(t),t),t)+t^3*diff(y(t),t)+3*t^2*y(t) = 0,y(t)],
[1778,(-t+1)*diff(diff(y(t),t),t)+t*diff(y(t),t)+y(t) = 0,y(t)],
[1783,t^2*diff(diff(y(t),t),t)-5*t*diff(y(t),t)+9*y(t) = 0,y(t)],
[1784,t^2*diff(diff(y(t),t),t)+5*t*diff(y(t),t)-5*y(t) = 0,y(t)],
[1785,2*t^2*diff(diff(y(t),t),t)+3*t*diff(y(t),t)-y(t) = 0,y(t)],
[1786,(t^2-2*t+1)*diff(diff(y(t),t),t)+(-2*t+2)*diff(y(t),t)+2*y(t) = 0,y(t)],
[1787,t^2*diff(diff(y(t),t),t)+3*t*diff(y(t),t)+y(t) = 0,y(t)],
[1788,t^2*diff(diff(y(t),t),t)-t*diff(y(t),t)+y(t) = 0,y(t)],
[1789,(t^2-4*t+4)*diff(diff(y(t),t),t)+(5*t-10)*diff(y(t),t)+4*y(t) = 0,y(t)],
[1790,t^2*diff(diff(y(t),t),t)+t*diff(y(t),t)+y(t) = 0,y(t)],
[1791,t^2*diff(diff(y(t),t),t)-t*diff(y(t),t)+2*y(t) = 0,y(t)],
[1792,t^2*diff(diff(y(t),t),t)-3*t*diff(y(t),t)+4*y(t) = 0,y(t)],
[1799,2*t^2*diff(diff(y(t),t),t)+3*t*diff(y(t),t)+(-t-1)*y(t) = 0,y(t)],
[1800,2*t*diff(diff(y(t),t),t)+(1-2*t)*diff(y(t),t)-y(t) = 0,y(t)],
[1801,2*t*diff(diff(y(t),t),t)+(t+1)*diff(y(t),t)-2*y(t) = 0,y(t)],
[1802,2*t^2*diff(diff(y(t),t),t)-t*diff(y(t),t)+(t+1)*y(t) = 0,y(t)],
[1804,2*t^2*diff(diff(y(t),t),t)+(t^2-t)*diff(y(t),t)+y(t) = 0,y(t)],
[1806,t^2*diff(diff(y(t),t),t)+(-t^2+t)*diff(y(t),t)-y(t) = 0,y(t)],
[1807,t*diff(diff(y(t),t),t)+(-t^2-2)*diff(y(t),t)+t*y(t) = 0,y(t)],
[1808,t^2*diff(diff(y(t),t),t)+(-t^2+3*t)*diff(y(t),t)-t*y(t) = 0,y(t)],
[1809,t^2*diff(diff(y(t),t),t)+(t^2+t)*diff(y(t),t)-y(t) = 0,y(t)],
[1810,t*diff(diff(y(t),t),t)+(-4-t)*diff(y(t),t)+2*y(t) = 0,y(t)],
[1811,t^2*diff(diff(y(t),t),t)+(t^2-3*t)*diff(y(t),t)+3*y(t) = 0,y(t)],
[1813,t*diff(diff(y(t),t),t)+t*diff(y(t),t)+2*y(t) = 0,y(t)],
[1814,t*diff(diff(y(t),t),t)+(-t^2+1)*diff(y(t),t)+4*t*y(t) = 0,y(t)],
[1821,t^2*diff(diff(y(t),t),t)+(-t^2-t)*diff(y(t),t)+y(t) = 0,y(t)],
[2005,diff(diff(f(t),t),t)+2*diff(f(t),t)+5*f(t) = 0,f(t)],
[2006,diff(diff(f(t),t),t)+2*diff(f(t),t)+5*f(t) = 0,f(t)],
[2007,diff(diff(f(t),t),t)+6*diff(f(t),t)+9*f(t) = 0,f(t)],
[2008,diff(diff(f(t),t),t)+8*diff(f(t),t)+12*f(t) = 0,f(t)],
[2009,diff(diff(f(t),t),t)+8*diff(f(t),t)+12*f(t) = 0,f(t)],
[2010,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[2013,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[2014,(x^2+2*x+1)*diff(diff(y(x),x),x)+(3*x+3)*diff(y(x),x)+y(x) = 0,y(x)],
[2015,(x-2)*diff(diff(y(x),x),x)+3*diff(y(x),x)+4*y(x)/x^2 = 0,y(x)],
[2016,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[2017,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[2019,2*diff(diff(y(x),x),x) = 0,y(x)],
[2020,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+6)*y(x) = 0,y(x)],
[2022,4*z*diff(diff(y(z),z),z)+(-2*z+2)*diff(y(z),z)-y(z) = 0,y(z)],
[2023,z*diff(diff(y(z),z),z)-2*diff(y(z),z)+9*z^5*y(z) = 0,y(z)],
[2024,diff(diff(f(z),z),z)+(2*z-2)*diff(f(z),z)+4*f(z) = 0,f(z)],
[2025,z^2*diff(diff(y(z),z),z)-3/2*z*diff(y(z),z)+(z+1)*y(z) = 0,y(z)],
[2026,z*diff(diff(y(z),z),z)-2*diff(y(z),z)+z*y(z) = 0,y(z)],
[2027,diff(diff(y(z),z),z)-2*z*diff(y(z),z)-2*y(z) = 0,y(z)],
[2029,z*diff(diff(y(z),z),z)+(2*z-3)*diff(y(z),z)+4/z*y(z) = 0,y(z)],
[2034,(-z^2+1)*diff(diff(y(z),z),z)-z*diff(y(z),z)+m^2*y(z) = 0,y(z)],
[2078,diff(diff(y(x),x),x)-25*y(x) = 0,y(x)],
[2079,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[2080,diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[2083,diff(diff(y(x),x),x)+2*diff(y(x),x)+5*y(x) = 0,y(x)],
[2084,diff(diff(y(x),x),x)-9*y(x) = 0,y(x)],
[2085,x^2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)+3*y(x) = 0,y(x)],
[2086,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[2087,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+13*y(x) = 0,y(x)],
[2088,2*x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[2089,x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[2093,diff(diff(y(x),x),x)-diff(y(x),x)-6*y(x) = 0,y(x)],
[2094,diff(diff(y(x),x),x)+6*diff(y(x),x)+9*y(x) = 0,y(x)],
[2095,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[2096,x^2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[2104,diff(diff(y(x),x),x) = 0,y(x)],
[2105,diff(diff(y(x),x),x) = 0,y(x)],
[2107,diff(diff(y(x),x),x) = 0,y(x)],
[2109,diff(diff(y(x),x),x) = 0,y(x)],
[2110,diff(diff(y(x),x),x)+diff(y(x),x)-6*y(x) = 0,y(x)],
[2111,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)-8*y(x) = 0,y(x)],
[2112,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[2151,diff(diff(y(x),x),x)+1/x*diff(y(x),x) = 0,y(x)],
[2216,diff(diff(y(x),x),x)-2*diff(y(x),x)-3*y(x) = 0,y(x)],
[2217,diff(diff(y(x),x),x)+7*diff(y(x),x)+10*y(x) = 0,y(x)],
[2218,diff(diff(y(x),x),x)-36*y(x) = 0,y(x)],
[2219,diff(diff(y(x),x),x)+4*diff(y(x),x) = 0,y(x)],
[2220,-3*diff(diff(y(x),x),x)-diff(y(x),x)+3*y(x) = 0,y(x)],
[2221,3*diff(diff(y(x),x),x)-4*diff(y(x),x)-12*y(x) = 0,y(x)],
[2222,3*diff(diff(y(x),x),x)-18*diff(y(x),x)-40*y(x) = 0,y(x)],
[2223,-diff(diff(y(x),x),x)-2*diff(y(x),x) = 0,y(x)],
[2224,diff(diff(y(x),x),x)-10*diff(y(x),x)+8*y(x) = 0,y(x)],
[2225,-diff(diff(y(x),x),x)+2*diff(y(x),x) = 0,y(x)],
[2226,-13*diff(diff(y(x),x),x)+36*y(x) = 0,y(x)],
[2227,x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-8*y(x) = 0,y(x)],
[2228,2*x^2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)+y(x) = 0,y(x)],
[2229,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[2230,3*x^2*diff(diff(y(x),x),x)-6*x*diff(y(x),x) = 0,y(x)],
[2231,diff(diff(y(x),x),x)+diff(y(x),x)-6*y(x) = 0,y(x)],
[2232,diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[2233,2*diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[2234,diff(diff(y(x),x),x)-10*diff(y(x),x)+8*y(x) = 0,y(x)],
[2235,5*diff(diff(y(x),x),x)+6*diff(y(x),x) = 0,y(x)],
[2236,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[2237,diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[2238,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[2239,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[2240,diff(diff(y(x),x),x)+2*diff(y(x),x)+5*y(x) = 0,y(x)],
[2241,2*diff(diff(y(x),x),x)-5*diff(y(x),x)-6*y(x) = 0,y(x)],
[2242,-diff(diff(y(x),x),x)+diff(y(x),x)-y(x) = 0,y(x)],
[2243,3*diff(diff(y(x),x),x)+3*diff(y(x),x)+y(x) = 0,y(x)],
[2244,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[2245,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[2246,diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[2247,diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[2249,diff(diff(y(x),x),x)-4*diff(y(x),x)+6*y(x) = 0,y(x)],
[2250,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[2251,2740*diff(diff(y(x),x),x) = 0,y(x)],
[2252,diff(diff(y(x),x),x)+2*diff(y(x),x)-3*y(x) = 0,y(x)],
[2253,diff(diff(y(x),x),x)+6*y(x) = 0,y(x)],
[2254,diff(diff(y(x),x),x)-16*y(x) = 0,y(x)],
[2255,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[2256,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[2257,diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[2258,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[2259,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[2260,diff(diff(y(x),x),x)+2*diff(y(x),x)+2*y(x) = 0,y(x)],
[2261,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[2262,diff(diff(y(x),x),x)+2*diff(y(x),x)+5*y(x) = 0,y(x)],
[2263,diff(diff(y(x),x),x)-2*diff(y(x),x)+10*y(x) = 0,y(x)],
[2264,diff(diff(y(x),x),x)+16*y(x) = 0,y(x)],
[2265,diff(diff(y(x),x),x)-6*diff(y(x),x)+9*y(x) = 0,y(x)],
[2266,diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[2267,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[2268,diff(diff(y(x),x),x)+6*diff(y(x),x)+9*y(x) = 0,y(x)],
[2269,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[2270,diff(diff(y(x),x),x)-4*diff(y(x),x)+5*y(x) = 0,y(x)],
[2271,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[2272,diff(diff(y(x),x),x)-10*diff(y(x),x)+25*y(x) = 0,y(x)],
[2273,diff(diff(y(x),x),x)-6*diff(y(x),x)+13*y(x) = 0,y(x)],
[2274,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[2275,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[2276,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[2277,diff(diff(y(x),x),x)-2*m*diff(y(x),x)+m^2*y(x) = 0,y(x)],
[2278,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[2279,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[2280,diff(diff(y(x),x),x)+2*diff(y(x),x)+17*y(x) = 0,y(x)],
[2281,diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[2282,diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[2283,-3*diff(diff(y(x),x),x)+3*diff(y(x),x)-y(x) = 0,y(x)],
[2284,-6*diff(diff(y(x),x),x)+12*diff(y(x),x)-8*y(x) = 0,y(x)],
[2285,3*diff(diff(y(x),x),x)+3*diff(y(x),x)+y(x) = 0,y(x)],
[2286,-6*diff(diff(y(x),x),x)+9*diff(y(x),x) = 0,y(x)],
[2287,diff(diff(y(x),x),x)-9*y(x) = 0,y(x)],
[2288,diff(diff(y(x),x),x)+5*diff(y(x),x)+4*y(x) = 0,y(x)],
[2289,diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[2290,diff(diff(y(x),x),x)+4*diff(y(x),x)-12*y(x) = 0,y(x)],
[2291,diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[2292,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[2293,x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[2294,x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[2295,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+9*y(x) = 0,y(x)],
[2296,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+5*y(x) = 0,y(x)],
[2297,x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[2298,x^2*diff(diff(y(x),x),x)+6*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[2299,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[2300,x^2*diff(diff(y(x),x),x)+(-2*m*x+x)*diff(y(x),x)+m^2*y(x) = 0,y(x)],
[2301,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+5*y(x) = 0,y(x)],
[2302,t^2*diff(diff(y(t),t),t)+t*diff(y(t),t)+25*y(t) = 0,y(t)],
[2303,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[2304,x*diff(diff(y(x),x),x)+(1-2*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[2305,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[2306,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[2307,diff(diff(y(x),x),x)-1/x*diff(y(x),x)+4*x^2*y(x) = 0,y(x)],
[2308,4*x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2-1)*y(x) = 0,y(x)],
[2309,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[2310,x*diff(diff(y(x),x),x)+(-2*x-1)*diff(y(x),x)+2*y(x) = 0,y(x)],
[2311,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[2312,diff(diff(y(x),x),x)-6*diff(y(x),x)+9*y(x) = 0,y(x)],
[2313,diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[2314,4*x^2*diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[2315,3*diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[2316,11*diff(diff(y(x),x),x)+36*diff(y(x),x)+26*y(x) = 0,y(x)],
[2317,diff(diff(y(x),x),x)+6*diff(y(x),x)+9*y(x) = 0,y(x)],
[2318,diff(diff(y(x),x),x)+6*diff(y(x),x)+9*y(x) = 0,y(x)],
[2319,-6*diff(diff(y(x),x),x)+25*diff(y(x),x) = 0,y(x)],
[2320,-6*diff(diff(y(x),x),x)+25*diff(y(x),x) = 0,y(x)],
[2321,9*diff(diff(y(x),x),x)+24*diff(y(x),x)+16*y(x) = 0,y(x)],
[2322,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[2323,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[2324,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[2326,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[2327,diff(diff(y(x),x),x)+2*diff(y(x),x)-3*y(x) = 0,y(x)],
[2328,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[2329,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[2337,diff(diff(y(t),t),t)+diff(y(t),t)-2*y(t) = 0,y(t)],
[2338,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[2339,diff(diff(y(t),t),t)-3*diff(y(t),t)+2*y(t) = 0,y(t)],
[2340,diff(diff(y(t),t),t)-diff(y(t),t)-12*y(t) = 0,y(t)],
[2341,diff(diff(y(t),t),t)+diff(y(t),t)-2*y(t) = 0,y(t)],
[2342,diff(diff(y(t),t),t)-3*diff(y(t),t)+2*y(t) = 0,y(t)],
[2343,diff(diff(y(t),t),t)-2*diff(y(t),t) = 0,y(t)],
[2344,diff(diff(y(t),t),t)-y(t) = 0,y(t)],
[2345,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[2346,diff(diff(y(t),t),t)-diff(y(t),t)-6*y(t) = 0,y(t)],
[2347,diff(diff(y(t),t),t)-y(t) = 0,y(t)],
[2348,diff(diff(y(t),t),t)-9*y(t) = 0,y(t)],
[2349,diff(diff(y(t),t),t)-y(t) = 0,y(t)],
[2350,diff(diff(y(t),t),t)-diff(y(t),t)-2*y(t) = 0,y(t)],
[2351,diff(diff(y(t),t),t)+5*diff(y(t),t)+4*y(t) = 0,y(t)],
[2352,diff(diff(y(t),t),t)+5*diff(y(t),t)+4*y(t) = 0,y(t)],
[2353,diff(diff(y(t),t),t)-3*diff(y(t),t)+2*y(t) = 0,y(t)],
[2354,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[2355,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[2356,diff(diff(y(t),t),t)+9*y(t) = 0,y(t)],
[2357,diff(diff(y(t),t),t)-y(t) = 0,y(t)],
[2365,diff(diff(y(t),t),t)-y(t) = 0,y(t)],
[2366,diff(diff(y(t),t),t)-diff(y(t),t)-2*y(t) = 0,y(t)],
[2367,diff(diff(y(t),t),t)-4*y(t) = 0,y(t)],
[2368,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[2369,diff(diff(y(t),t),t)+3*diff(y(t),t)+2*y(t) = 0,y(t)],
[2370,diff(diff(y(t),t),t)+diff(y(t),t)-6*y(t) = 0,y(t)],
[2371,diff(diff(y(t),t),t)+4*diff(y(t),t)+5*y(t) = 0,y(t)],
[2372,diff(diff(y(t),t),t)-2*diff(y(t),t)+5*y(t) = 0,y(t)],
[2379,diff(diff(y(t),t),t)-3*diff(y(t),t)+2*y(t) = 0,y(t)],
[2380,diff(diff(y(t),t),t)-4*y(t) = 0,y(t)],
[2381,diff(diff(y(t),t),t)+2*diff(y(t),t)+5*y(t) = 0,y(t)],
[2382,diff(diff(y(t),t),t)-4*diff(y(t),t)+13*y(t) = 0,y(t)],
[2383,diff(diff(y(t),t),t)+4*diff(y(t),t)+3*y(t) = 0,y(t)],
[2384,diff(diff(y(t),t),t)+6*diff(y(t),t)+13*y(t) = 0,y(t)],
[2385,diff(diff(y(t),t),t)+9*y(t) = 0,y(t)],
[2386,diff(diff(y(t),t),t)+16*y(t) = 0,y(t)],
[2387,diff(diff(y(t),t),t)+2*diff(y(t),t)+5*y(t) = 0,y(t)],
[2388,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[2389,diff(diff(y(x),x),x)+2*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[2390,diff(diff(y(x),x),x)-2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[2391,diff(diff(y(x),x),x)-x^2*diff(y(x),x)-2*x*y(x) = 0,y(x)],
[2393,diff(diff(y(x),x),x)+x*diff(y(x),x)+3*y(x) = 0,y(x)],
[2394,diff(diff(y(x),x),x)-x^2*diff(y(x),x)-3*x*y(x) = 0,y(x)],
[2396,(x^2-3)*diff(diff(y(x),x),x)-3*x*diff(y(x),x)-5*y(x) = 0,y(x)],
[2397,(x^2+1)*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[2398,(-4*x^2+1)*diff(diff(y(x),x),x)-20*x*diff(y(x),x)-16*y(x) = 0,y(x)],
[2399,(x^2-1)*diff(diff(y(x),x),x)-6*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[2401,diff(diff(y(x),x),x)+x*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[2404,(2*x^2+1)*diff(diff(y(x),x),x)+7*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[2405,4*diff(diff(y(x),x),x)+x*diff(y(x),x)+4*y(x) = 0,y(x)],
[2407,diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[2414,4*x*diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[2417,6*x^2*diff(diff(y(x),x),x)+(18*x^2+x)*diff(y(x),x)+(1+12*x)*y(x) = 0,y(x)],
[2420,3*x^2*diff(diff(y(x),x),x)+(-x^2-8*x)*diff(y(x),x)+6*y(x) = 0,y(x)],
[2421,2*x^2*diff(diff(y(x),x),x)+(-2*x^2-x)*diff(y(x),x)+(8*x-2)*y(x) = 0,y(x)],
[2423,3*x^2*diff(diff(y(x),x),x)+(3*x^2+7*x)*diff(y(x),x)+(1+6*x)*y(x) = 0,y(x)],
[2426,4*x^2*diff(diff(y(x),x),x)-4*x^2*diff(y(x),x)+(2*x+1)*y(x) = 0,y(x)],
[2427,x^2*diff(diff(y(x),x),x)+(-2*x^2+3*x)*diff(y(x),x)+(1-2*x)*y(x) = 0,y(x)],
[2428,x^2*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+(4-x)*y(x) = 0,y(x)],
[2429,x^2*diff(diff(y(x),x),x)+(-x^2+3*x)*diff(y(x),x)+y(x) = 0,y(x)],
[2432,x^2*diff(diff(y(x),x),x)+(-2*x*5^(1/2)+x)*diff(y(x),x)+(19/4-3*x^2)*y(x) = 0,y(x)],
[2435,x^2*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+x*y(x) = 0,y(x)],
[2436,x^2*diff(diff(y(x),x),x)+(x^2-3*x)*diff(y(x),x)+(4-x)*y(x) = 0,y(x)],
[2439,x^2*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+(-x-2)*y(x) = 0,y(x)],
[2440,x^2*diff(diff(y(x),x),x)+2*x^2*diff(y(x),x)+(x-3/4)*y(x) = 0,y(x)],
[2444,(x^3+x^2)*diff(diff(y(x),x),x)+x^2*diff(y(x),x)-2*y(x) = 0,y(x)],
[2447,x^2*diff(diff(y(x),x),x)+(x^3+6*x)*diff(y(x),x)+6*y(x) = 0,y(x)],
[2448,x^2*diff(diff(y(x),x),x)+(-x^2+x)*diff(y(x),x)-y(x) = 0,y(x)],
[2452,x^2*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[2453,x^2*diff(diff(y(x),x),x)-x^2*diff(y(x),x)-2*y(x) = 0,y(x)],
[2454,x^2*diff(diff(y(x),x),x)-x^2*diff(y(x),x)+(-3*x-2)*y(x) = 0,y(x)],
[2455,x^2*diff(diff(y(x),x),x)+(-x^2+5*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[2456,4*x^2*diff(diff(y(x),x),x)+(-4*x^2+4*x)*diff(y(x),x)+(2*x-9)*y(x) = 0,y(x)],
[2457,x^2*diff(diff(y(x),x),x)+(2*x^2+4*x)*diff(y(x),x)+(2*x+2)*y(x) = 0,y(x)],
[2458,x^2*diff(diff(y(x),x),x)+(x^2-x)*diff(y(x),x)+(1-x)*y(x) = 0,y(x)],
[2459,4*x^2*diff(diff(y(x),x),x)+(8*x^2+4*x)*diff(y(x),x)+(-1+4*x)*y(x) = 0,y(x)],
[2461,x*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[2462,x^2*diff(diff(y(x),x),x)+(x^2+4*x)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[2463,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-9/4)*y(x) = 0,y(x)],
[2467,(-x^2+1)*diff(diff(y(x),x),x)-6*x*diff(y(x),x)-4*y(x) = 0,y(x)],
[2469,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[2470,2*x*diff(diff(y(x),x),x)+(-10*x+5)*diff(y(x),x)-5*y(x) = 0,y(x)],
[2472,(4*x^2+1)*diff(diff(y(x),x),x)-8*y(x) = 0,y(x)],
[2473,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[2475,x^2*diff(diff(y(x),x),x)+3/2*x*diff(y(x),x)+(-1/2*x-1/2)*y(x) = 0,y(x)],
[2733,-2*diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[2734,diff(diff(y(x),x),x)+9*diff(y(x),x)+9*y(x) = 0,y(x)],
[2735,diff(diff(y(x),x),x)-diff(y(x),x)-y(x) = 0,y(x)],
[2739,18*diff(diff(y(x),x),x)+81*y(x) = 0,y(x)],
[2740,-4*diff(diff(y(x),x),x)+16*y(x) = 0,y(x)],
[2741,2*diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[2742,5*diff(diff(y(x),x),x)+5*diff(y(x),x)-6*y(x) = 0,y(x)],
[2745,diff(diff(y(x),x),x)+6*diff(y(x),x)+10*y(x) = 0,y(x)],
[2746,diff(diff(y(x),x),x)-8*diff(y(x),x)+17*y(x) = 0,y(x)],
[2747,diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[2748,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[2749,diff(diff(y(x),x),x)+2*diff(y(x),x)+2*y(x) = 0,y(x)],
[2751,-2*diff(diff(y(x),x),x)+4*diff(y(x),x)-8*y(x) = 0,y(x)],
[2752,-4*diff(diff(y(x),x),x)+3*diff(y(x),x) = 0,y(x)],
[2753,2*diff(diff(y(x),x),x) = 0,y(x)],
[2754,5*diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[4064,diff(diff(y(x),x),x)+2*diff(y(x),x) = 0,y(x)],
[4065,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4066,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4067,6*diff(diff(y(x),x),x)-11*diff(y(x),x)+4*y(x) = 0,y(x)],
[4068,diff(diff(y(x),x),x)+2*diff(y(x),x)-y(x) = 0,y(x)],
[4069,diff(diff(y(x),x),x)-10*diff(y(x),x)-6*y(x) = 0,y(x)],
[4070,-4*diff(diff(y(x),x),x)+4*diff(y(x),x) = 0,y(x)],
[4071,diff(diff(y(x),x),x)-4*diff(y(x),x)-2*y(x) = 0,y(x)],
[4073,diff(diff(y(x),x),x)-2*k*diff(y(x),x)-2*y(x) = 0,y(x)],
[4076,diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[4077,5*diff(diff(y(x),x),x)+diff(y(x),x)-y(x) = 0,y(x)],
[4078,-6*diff(diff(y(x),x),x)+12*diff(y(x),x)-8*y(x) = 0,y(x)],
[4081,-2*diff(diff(y(x),x),x) = 0,y(x)],
[4082,-11*diff(diff(y(x),x),x)-12*diff(y(x),x)+36*y(x) = 0,y(x)],
[4083,-37*diff(diff(y(x),x),x)+4*diff(y(x),x)+5*y(x) = 0,y(x)],
[4084,-8*diff(diff(y(x),x),x)+36*y(x) = 0,y(x)],
[4085,diff(diff(y(x),x),x)-2*diff(y(x),x)+5*y(x) = 0,y(x)],
[4086,diff(diff(y(x),x),x)-diff(y(x),x)+y(x) = 0,y(x)],
[4087,5*diff(diff(y(x),x),x)+6*y(x) = 0,y(x)],
[4088,diff(diff(y(x),x),x)-4*diff(y(x),x)+20*y(x) = 0,y(x)],
[4089,4*diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[4091,4*diff(diff(y(x),x),x) = 0,y(x)],
[4093,diff(diff(y(x),x),x) = 0,y(x)],
[4094,diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[4095,diff(diff(y(x),x),x)-2*diff(y(x),x)+5*y(x) = 0,y(x)],
[4096,diff(diff(y(x),x),x)-4*diff(y(x),x)+20*y(x) = 0,y(x)],
[4097,5*diff(diff(y(x),x),x)+diff(y(x),x)-y(x) = 0,y(x)],
[4098,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4099,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4100,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4101,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4102,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4103,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4104,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[4105,diff(diff(y(x),x),x)-2*diff(y(x),x)-8*y(x) = 0,y(x)],
[4106,diff(diff(y(x),x),x)-3*diff(y(x),x) = 0,y(x)],
[4107,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[4108,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[4109,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4110,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[4111,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[4112,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4113,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4114,diff(diff(y(x),x),x)+diff(y(x),x)-6*y(x) = 0,y(x)],
[4115,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4116,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4117,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4118,diff(diff(y(x),x),x)-5*diff(y(x),x)-6*y(x) = 0,y(x)],
[4119,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[4120,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[4121,diff(diff(y(x),x),x)-5*diff(y(x),x)+6*y(x) = 0,y(x)],
[4122,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4123,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4124,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4125,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4126,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4127,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4128,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4129,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[4130,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4131,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[4132,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4133,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4134,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[4135,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4136,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4137,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4138,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[4139,diff(diff(y(x),x),x)-2/x*diff(y(x),x)+2*y(x)/x^2 = 0,y(x)],
[4140,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[4141,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[4142,2*x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-y(x) = 0,y(x)],
[4146,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x) = 0,y(x)],
[4147,x*diff(diff(y(x),x),x)-diff(y(x),x) = 0,y(x)],
[4157,(x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x) = 0,y(x)],
[4162,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x) = 0,y(x)],
[4163,x*diff(diff(y(x),x),x)-diff(y(x),x) = 0,y(x)],
[4174,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[4193,x^4*diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[4194,x^2*diff(diff(y(x),x),x)+(2*x^2+x)*diff(y(x),x)-4*y(x) = 0,y(x)],
[4195,(-x^2+x)*diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4196,(4*x^3-14*x^2-2*x)*diff(diff(y(x),x),x)+(-6*x^2+7*x-1)*diff(y(x),x)+(6*x-1)*y(x) = 0,y(x)],
[4197,x^2*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[4198,x^2*diff(diff(y(x),x),x)-x^2*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[4200,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(x-9)*y(x) = 0,y(x)],
[4207,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(3*x-1)*y(x) = 0,y(x)],
[4211,x^2*diff(diff(y(x),x),x)+(-x^2-4*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[4215,2*x^2*diff(diff(y(x),x),x)+(-3*x-2)*diff(y(x),x)+(2-1/x)*y(x) = 0,y(x)],
[4216,(-x^2+x)*diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4217,(-x^2+x)*diff(diff(y(x),x),x)+(3/2-2*x)*diff(y(x),x)-1/4*y(x) = 0,y(x)],
[4218,(-2*x^2+2*x)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[4219,(-2*x^2+2*x)*diff(diff(y(x),x),x)+(1-11*x)*diff(y(x),x)-10*y(x) = 0,y(x)],
[4220,(-x^2+x)*diff(diff(y(x),x),x)+(-2/3*x+1/3)*diff(y(x),x)+20/9*y(x) = 0,y(x)],
[4221,(-2*x^2+2*x)*diff(diff(y(x),x),x)+diff(y(x),x)+4*y(x) = 0,y(x)],
[4222,4*diff(diff(y(x),x),x)+(-3/(-x^2+1)^2*x^2+6/(-x^2+1)^2)*y(x) = 0,y(x)],
[4232,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(-x^2-1/4)*y(x) = 0,y(x)],
[4234,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-25/4)*y(x) = 0,y(x)],
[4235,diff(diff(y(x),x),x)+q*diff(y(x),x)-2*y(x)/x^2 = 0,y(x)],
[4239,x*diff(diff(y(x),x),x)+3*diff(y(x),x)+4*x^3*y(x) = 0,y(x)],
[4283,diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[4284,diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[4285,diff(diff(y(x),x),x)+9*diff(y(x),x) = 0,y(x)],
[4286,diff(diff(y(x),x),x)+2*diff(y(x),x)+2*y(x) = 0,y(x)],
[4287,diff(diff(y(x),x),x)-2*diff(y(x),x)+6*y(x) = 0,y(x)],
[4288,diff(diff(y(x),x),x)+16*y(x) = 0,y(x)],
[4289,diff(diff(y(x),x),x)-5*diff(y(x),x)+6*y(x) = 0,y(x)],
[4290,diff(diff(y(x),x),x)+5*diff(y(x),x) = 0,y(x)],
[4291,diff(diff(y(x),x),x)-4*diff(y(x),x)+13*y(x) = 0,y(x)],
[4292,2*diff(diff(y(x),x),x)+diff(y(x),x)-y(x) = 0,y(x)],
[4293,diff(diff(y(x),x),x)+(1+2*I)*diff(y(x),x)+(-1+I)*y(x) = 0,y(x)],
[4294,diff(diff(y(x),x),x)+(1+2*I)*diff(y(x),x)+(-1+I)*y(x) = 0,y(x)],
[4296,diff(diff(y(x),x),x)-6*diff(y(x),x) = 0,y(x)],
[4297,3*diff(diff(y(x),x),x)-9*diff(y(x),x)-5*y(x) = 0,y(x)],
[4299,diff(diff(y(x),x),x)-4*diff(y(x),x) = 0,y(x)],
[4300,diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[4301,diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[4302,diff(diff(y(x),x),x)-2*diff(y(x),x)-3*y(x) = 0,y(x)],
[4303,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4304,diff(diff(y(x),x),x)+6*diff(y(x),x)+9*y(x) = 0,y(x)],
[4305,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[4306,diff(diff(y(x),x),x)-16*y(x) = 0,y(x)],
[4307,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[4308,diff(diff(y(x),x),x)-6*diff(y(x),x)+9*y(x) = 0,y(x)],
[4309,diff(diff(y(x),x),x)+2*diff(y(x),x)+10*y(x) = 0,y(x)],
[4310,diff(diff(y(x),x),x)+4*diff(y(x),x)+12*y(x) = 0,y(x)],
[4311,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4312,diff(diff(y(x),x),x)+8*diff(y(x),x)+25*y(x) = 0,y(x)],
[4313,5*diff(diff(y(x),x),x)+12*diff(y(x),x)+20*y(x) = 0,y(x)],
[4314,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[4315,diff(diff(y(x),x),x)+16*y(x) = 0,y(x)],
[4316,diff(diff(y(x),x),x)+2*diff(y(x),x)+17*y(x) = 0,y(x)],
[4317,4*diff(diff(y(x),x),x)+4*diff(y(x),x)+5*y(x) = 0,y(x)],
[4318,diff(diff(y(x),x),x)+4*diff(y(x),x)+8*y(x) = 0,y(x)],
[4319,5*diff(diff(y(x),x),x)+6*diff(y(x),x)+2*y(x) = 0,y(x)],
[4320,2*diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[4321,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4322,diff(diff(y(x),x),x)-6*diff(y(x),x)+9*y(x) = 0,y(x)],
[4323,diff(diff(y(x),x),x)-2*diff(y(x),x)-3*y(x) = 0,y(x)],
[4324,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4325,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4326,diff(diff(y(x),x),x)-5*diff(y(x),x)+6*y(x) = 0,y(x)],
[4327,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4328,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4329,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[4330,diff(diff(y(x),x),x)-2*diff(y(x),x) = 0,y(x)],
[4335,diff(diff(y(x),x),x)+2*x*diff(y(x),x) = 0,y(x)],
[4340,x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-3*y(x) = 0,y(x)],
[4341,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[4342,x^2*diff(diff(y(x),x),x)+7*x*diff(y(x),x)+9*y(x) = 0,y(x)],
[4343,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+6*y(x) = 0,y(x)],
[4344,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-16*y(x) = 0,y(x)],
[4345,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[4346,x^2*diff(diff(y(x),x),x)-5*x*diff(y(x),x)+9*y(x) = 0,y(x)],
[4347,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[4348,x^2*diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4349,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[4350,(-x^3+2*x^2)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[4351,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[4352,x*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[4353,3*x*diff(diff(y(x),x),x)+(-6*x+2)*diff(y(x),x)+(3*x-2)*y(x) = 0,y(x)],
[4354,x^2*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)-y(x) = 0,y(x)],
[4355,(x^2+x)*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)+y(x) = 0,y(x)],
[4358,2*diff(diff(y(x),x),x)+2*diff(y(x),x) = 0,y(x)],
[4359,diff(diff(r(t),t),t)-6*diff(r(t),t)+9*r(t) = 0,r(t)],
[4361,diff(diff(y(x),x),x)+2*diff(y(x),x)+2*y(x) = 0,y(x)],
[4363,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[4367,x*diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[4368,diff(diff(y(x),x),x)+4*diff(y(x),x)+5*y(x) = 0,y(x)],
[4369,diff(diff(y(x),x),x)+4*diff(y(x),x)+5*y(x) = 0,y(x)],
[4370,diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[4371,diff(diff(y(x),x),x)-5*diff(y(x),x)+6*y(x) = 0,y(x)],
[4375,diff(diff(y(x),x),x)-2*diff(y(x),x)+5*y(x) = 0,y(x)],
[4377,13*diff(diff(y(x),x),x)-18*diff(y(x),x)+36*y(x) = 0,y(x)],
[4382,diff(diff(y(x),x),x)+diff(y(x),x)-6*y(x) = 0,y(x)],
[4390,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[4391,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[4392,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4393,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4394,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4395,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4396,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+3*y(x) = 0,y(x)],
[4397,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+3*y(x) = 0,y(x)],
[4398,(x^2+2*x)*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[4399,(x^2+2*x)*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[4400,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[4401,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[4402,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-2)*y(x) = 0,y(x)],
[4403,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-2)*y(x) = 0,y(x)],
[4507,diff(diff(y(x),x),x)+(x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[4508,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4510,(2*x-3)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[4512,diff(diff(y(x),x),x)-x*diff(y(x),x)-3*y(x) = 0,y(x)],
[4520,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[4530,diff(diff(z(x),x),x)+x*diff(z(x),x)+z(x) = 0,z(x)],
[4532,(x^2+1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[4533,diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[4534,(-x^2+1)*diff(diff(y(x),x),x)-diff(y(x),x)+y(x) = 0,y(x)],
[4538,-diff(diff(x(t),t),t)+diff(x(t),t)-x(t) = 0,x(t)],
[4539,diff(diff(x(t),t),t)+42*diff(x(t),t)+x(t) = 0,x(t)],
[4541,-3*diff(diff(x(t),t),t)-9*diff(x(t),t)-5*x(t) = 0,x(t)],
[4543,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[4544,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4545,diff(diff(y(x),x),x)+16*y(x) = 0,y(x)],
[4546,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4556,(x^3+2*x^2+x)*diff(diff(y(x),x),x)+(-x^2+1)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[4557,(-x^2+x)*diff(diff(y(x),x),x)+(2-4*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[4558,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-9*y(x) = 0,y(x)],
[4559,x*diff(diff(y(x),x),x)+1/2*diff(y(x),x)+2*y(x) = 0,y(x)],
[4560,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[4561,2*x*diff(diff(y(x),x),x)-diff(y(x),x)+2*y(x) = 0,y(x)],
[4562,x*diff(diff(y(x),x),x)+x*diff(y(x),x)-2*y(x) = 0,y(x)],
[4563,(x^3-2*x^2+x)*diff(diff(y(x),x),x)-2*y(x) = 0,y(x)],
[4628,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[4629,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[4630,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[4631,diff(diff(y(x),x),x)+25*y(x) = 0,y(x)],
[4632,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4633,diff(diff(y(x),x),x)+4*diff(y(x),x)+5*y(x) = 0,y(x)],
[4634,3*diff(diff(y(x),x),x)-2*diff(y(x),x)-y(x) = 0,y(x)],
[4635,diff(diff(y(x),x),x)-6*diff(y(x),x)+8*y(x) = 0,y(x)],
[4636,2*diff(diff(y(x),x),x)-7*diff(y(x),x)-4*y(x) = 0,y(x)],
[4637,diff(diff(y(x),x),x)-6*diff(y(x),x)+9*y(x) = 0,y(x)],
[4638,diff(diff(y(x),x),x)-5*diff(y(x),x)+6*y(x) = 0,y(x)],
[4639,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[4640,diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[4641,diff(diff(y(x),x),x)-diff(y(x),x)+10*y(x) = 0,y(x)],
[4642,diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[4643,diff(diff(y(x),x),x)-4*diff(y(x),x)+3*y(x) = 0,y(x)],
[4644,diff(diff(y(x),x),x)-2*diff(y(x),x)+3*y(x) = 0,y(x)],
[4645,diff(diff(y(x),x),x)-9*y(x) = 0,y(x)],
[4646,diff(diff(x(t),t),t)+4*diff(x(t),t)+3*x(t) = 0,x(t)],
[4647,diff(diff(y(t),t),t)+4*diff(y(t),t)+5*y(t) = 0,y(t)],
[4648,diff(diff(x(t),t),t)-3*diff(x(t),t)+2*x(t) = 0,x(t)],
[4649,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4650,diff(diff(y(x),x),x)+6*diff(y(x),x)+10*y(x) = 0,y(x)],
[4651,diff(diff(x(t),t),t)+2*diff(x(t),t)+2*x(t) = 0,x(t)],
[4652,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[4653,1/2*diff(diff(x(t),t),t)+48*x(t) = 0,x(t)],
[4654,diff(diff(x(t),t),t)+5*diff(x(t),t)+6*x(t) = 0,x(t)],
[4655,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[4656,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[4657,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[4658,diff(diff(y(t),t),t)-6*diff(y(t),t)+25*y(t) = 0,y(t)],
[4659,diff(diff(y(t),t),t)-6*diff(y(t),t)+25*y(t) = 0,y(t)],
[4660,diff(diff(y(t),t),t)-6*diff(y(t),t)+25*y(t) = 0,y(t)],
[4661,-6*diff(diff(y(x),x),x)+11*diff(y(x),x)-6*y(x) = 0,y(x)],
[4662,diff(diff(y(x),x),x) = 0,y(x)],
[4663,diff(diff(y(x),x),x)-5*y(x) = 0,y(x)],
[4667,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4668,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4669,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4670,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4671,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4675,-3*diff(diff(y(x),x),x)+3*diff(y(x),x)-y(x) = 0,y(x)],
[4677,-3*diff(diff(y(x),x),x)+2*diff(y(x),x) = 0,y(x)],
[4678,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4679,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[4680,diff(diff(x(t),t),t)+4*x(t) = 0,x(t)],
[4681,t^2*diff(diff(y(t),t),t)-2*t*diff(y(t),t)+2*y(t) = 0,y(t)],
[4684,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4685,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4686,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[4687,diff(diff(y(x),x),x)-60*diff(y(x),x)-900*y(x) = 0,y(x)],
[4688,diff(diff(y(x),x),x)-7*diff(y(x),x) = 0,y(x)],
[4689,diff(diff(y(x),x),x)+1/x*diff(y(x),x)-y(x)/x^2 = 0,y(x)],
[4690,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x) = 0,y(x)],
[4695,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4696,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4697,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4698,diff(diff(y(x),x),x)+2*diff(y(x),x)-3*y(x) = 0,y(x)],
[4699,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4700,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[4701,diff(diff(y(x),x),x)+2*diff(y(x),x)+5*y(x) = 0,y(x)],
[4702,diff(diff(y(x),x),x)+5*diff(y(x),x)-3*y(x) = 0,y(x)],
[4705,-3*diff(diff(y(x),x),x)+3*diff(y(x),x)-y(x) = 0,y(x)],
[4706,diff(diff(x(t),t),t)+4*diff(x(t),t)+4*x(t) = 0,x(t)],
[4707,diff(diff(q(t),t),t)+9*diff(q(t),t)+14*q(t) = 0,q(t)],
[4711,diff(diff(y(x),x),x)-2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[4712,diff(diff(y(x),x),x)+x^2*diff(y(x),x)+2*x*y(x) = 0,y(x)],
[4715,(x^2-1)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[4717,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+x^2*y(x) = 0,y(x)],
[4718,(-x^3+2*x)*diff(diff(y(x),x),x)+(x^3+3*x^2-2*x-2)*diff(y(x),x)+(-x^2-4*x-2)*y(x) = 0,y(x)],
[4719,(x^3+x^2)*diff(diff(y(x),x),x)+(-2*x^2-x)*diff(y(x),x)+(2*x+1)*y(x) = 0,y(x)],
[4720,(-4*x^3-2*x^2)*diff(diff(y(x),x),x)+(10*x^2+4*x)*diff(y(x),x)+(-12*x-4)*y(x) = 0,y(x)],
[4721,(-4*x^4-2*x^2)*diff(diff(y(x),x),x)+(10*x^3+4*x)*diff(y(x),x)+(-12*x^2-4)*y(x) = 0,y(x)],
[4722,(-2*x^3+4*x^2)*diff(diff(y(x),x),x)+(x^2-4*x)*diff(y(x),x)+(3-x)*y(x) = 0,y(x)],
[4723,(-x^3+x^2)*diff(diff(y(x),x),x)+(5*x^2-4*x)*diff(y(x),x)+(6-9*x)*y(x) = 0,y(x)],
[4724,x*diff(diff(y(x),x),x)+(4*x^2+1)*diff(y(x),x)+(4*x^3+4*x)*y(x) = 0,y(x)],
[4727,(x^2-3*x+2)*diff(diff(y(x),x),x)+(4*x-6)*diff(y(x),x)+2*y(x) = 0,y(x)],
[4728,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[4729,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[4730,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[4732,(x^2+2*x)*diff(diff(y(x),x),x)+(2*x+2)*diff(y(x),x)-2*y(x) = 0,y(x)],
[4735,(-x^2+x)*diff(diff(y(x),x),x)-3*x*diff(y(x),x)-y(x) = 0,y(x)],
[4736,2*x*diff(diff(y(x),x),x)-diff(y(x),x)+x^2*y(x) = 0,y(x)],
[4739,(x^2+2*x)*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)-4*y(x) = 0,y(x)],
[4740,x*diff(diff(y(x),x),x)+(1/2-x)*diff(y(x),x)-y(x) = 0,y(x)],
[4744,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[4750,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4755,(-x^2+1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+p^2*y(x) = 0,y(x)],
[4756,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[4761,x^2*diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4763,x^2*diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4766,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)-y(x) = 0,y(x)],
[4771,x^2*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+x^2*y(x) = 0,y(x)],
[4772,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4777,x^2*diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4779,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[4782,(x^2-2*x+10)*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[4783,(x^2-2*x+10)*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[4787,diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[4789,diff(diff(y(x),x),x)+2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[4790,(x-1)*diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[4791,(x+2)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[4792,diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)-y(x) = 0,y(x)],
[4793,(x^2+1)*diff(diff(y(x),x),x)-6*y(x) = 0,y(x)],
[4794,(x^2+2)*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-y(x) = 0,y(x)],
[4795,(x^2-1)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[4796,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[4797,(x+1)*diff(diff(y(x),x),x)+(x-2)*diff(y(x),x)+y(x) = 0,y(x)],
[4798,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[4799,(x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x) = 0,y(x)],
[4802,diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[4815,x^2*diff(diff(y(x),x),x)+(5/3*x+x^2)*diff(y(x),x)-1/3*y(x) = 0,y(x)],
[4817,2*x*diff(diff(y(x),x),x)-diff(y(x),x)+2*y(x) = 0,y(x)],
[4821,3*x*diff(diff(y(x),x),x)+(-x+2)*diff(y(x),x)-y(x) = 0,y(x)],
[4823,2*x*diff(diff(y(x),x),x)+(-2*x-3)*diff(y(x),x)+y(x) = 0,y(x)],
[4826,2*x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+(2*x-1)*y(x) = 0,y(x)],
[4827,x*diff(diff(y(x),x),x)+2*diff(y(x),x)-x*y(x) = 0,y(x)],
[4828,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[4829,x*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[4831,x*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)-y(x) = 0,y(x)],
[4833,x*diff(diff(y(x),x),x)+(x-6)*diff(y(x),x)-3*y(x) = 0,y(x)],
[4834,(x^2-x)*diff(diff(y(x),x),x)+3*diff(y(x),x)-2*y(x) = 0,y(x)],
[4837,x^2*diff(diff(y(x),x),x)+(3*x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[4840,4*x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2-25)*y(x) = 0,y(x)],
[4845,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(36*x^2-1/4)*y(x) = 0,y(x)],
[4852,x^2*diff(diff(y(x),x),x)+(x^2-2)*y(x) = 0,y(x)],
[4854,x*diff(diff(y(x),x),x)+3*diff(y(x),x)+x^3*y(x) = 0,y(x)],
[4858,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4859,x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[4860,16*x^2*diff(diff(y(x),x),x)+32*x*diff(y(x),x)+(x^4-12)*y(x) = 0,y(x)],
[4862,2*x*diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[4863,diff(diff(y(x),x),x)-x*diff(y(x),x)-y(x) = 0,y(x)],
[4865,diff(diff(y(x),x),x)-x^2*diff(y(x),x)+x*y(x) = 0,y(x)],
[4866,x*diff(diff(y(x),x),x)+(-x-2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[4868,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[4873,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4876,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[4878,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-2)*y(x) = 0,y(x)],
[4881,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+30*y(x) = 0,y(x)],
[4883,(x^2-4*x+4)*diff(diff(y(x),x),x)+(x+2)*diff(y(x),x)-y(x) = 0,y(x)],
[4884,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[4886,x*diff(diff(y(x),x),x)+(2*x+1)*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[4890,(2*x^2-2*x)*diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[4891,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+4*x*y(x) = 0,y(x)],
[4892,x*diff(diff(y(x),x),x)+(2-2*x)*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[4893,x^2*diff(diff(y(x),x),x)+6*x*diff(y(x),x)+(4*x^2+6)*y(x) = 0,y(x)],
[4894,x*diff(diff(y(x),x),x)+(1-2*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[4895,(-2*x^2+2*x)*diff(diff(y(x),x),x)+(-6*x-1)*diff(y(x),x)-2*y(x) = 0,y(x)],
[4896,(-x^2+x)*diff(diff(y(x),x),x)+(1/2+2*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[4898,(4*t^2-12*t+8)*diff(diff(y(t),t),t)-2*diff(y(t),t)+y(t) = 0,y(t)],
[4899,(2*t^2-10*t+12)*diff(diff(y(t),t),t)+(2*t-3)*diff(y(t),t)-8*y(t) = 0,y(t)],
[4900,(3*t^2+3*t)*diff(diff(y(t),t),t)+t*diff(y(t),t)-y(t) = 0,y(t)],
[4904,x^2*diff(diff(y(x),x),x)+(1/4*x+3/16)*y(x) = 0,y(x)],
[4905,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(1/4*x^2-1/4)*y(x) = 0,y(x)],
[4916,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[4917,x*diff(diff(y(x),x),x)+(1-2*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[4918,(x^2-2*x+1)*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)-35*y(x) = 0,y(x)],
[4919,(16*x^2+32*x+16)*diff(diff(y(x),x),x)+3*y(x) = 0,y(x)],
[4922,x*diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[4923,x*diff(diff(y(x),x),x)+3*diff(y(x),x)+4*x^3*y(x) = 0,y(x)],
[4928,diff(diff(y(t),t),t)-diff(y(t),t)-6*y(t) = 0,y(t)],
[4929,diff(diff(y(t),t),t)+9*y(t) = 0,y(t)],
[4930,diff(diff(y(t),t),t)-1/4*y(t) = 0,y(t)],
[4931,diff(diff(y(t),t),t)-6*diff(y(t),t)+5*y(t) = 0,y(t)],
[4932,diff(diff(y(t),t),t)+7*diff(y(t),t)+12*y(t) = 0,y(t)],
[4933,diff(diff(y(t),t),t)-4*diff(y(t),t)+4*y(t) = 0,y(t)],
[4934,diff(diff(y(t),t),t)-4*diff(y(t),t)+3*y(t) = 0,y(t)],
[4935,diff(diff(y(t),t),t)+1/25*y(t) = 0,y(t)],
[4936,diff(diff(y(t),t),t)+3*diff(y(t),t)+9/4*y(t) = 0,y(t)],
[4937,diff(diff(y(t),t),t)-2*diff(y(t),t)-3*y(t) = 0,y(t)],
[4939,diff(diff(y(t),t),t)+2*diff(y(t),t)+5*y(t) = 0,y(t)],
[4940,diff(diff(y(t),t),t)+3*diff(y(t),t)-4*y(t) = 0,y(t)],
[4941,9*diff(diff(y(t),t),t)-6*diff(y(t),t)+y(t) = 0,y(t)],
[4942,diff(diff(y(t),t),t)+6*diff(y(t),t)+8*y(t) = 0,y(t)],
[4943,diff(diff(y(t),t),t)+10*diff(y(t),t)+24*y(t) = 0,y(t)],
[4944,diff(diff(y(t),t),t)+9*y(t) = 0,y(t)],
[4945,diff(diff(y(t),t),t)+3*diff(y(t),t)+2*y(t) = 0,y(t)],
[4946,diff(diff(y(t),t),t)+diff(y(t),t)-2*y(t) = 0,y(t)],
[4947,diff(diff(y(t),t),t)+3*diff(y(t),t)+2*y(t) = 0,y(t)],
[4948,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[4949,diff(diff(y(t),t),t)+2*diff(y(t),t)+5*y(t) = 0,y(t)],
[4950,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[4951,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[4952,diff(diff(y(t),t),t)+16*y(t) = 0,y(t)],
[4953,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[4954,diff(diff(y(t),t),t)+4*diff(y(t),t)+5*y(t) = 0,y(t)],
[4955,4*diff(diff(y(t),t),t)+24*diff(y(t),t)+37*y(t) = 0,y(t)],
[4956,diff(diff(y(t),t),t)+3*diff(y(t),t)+2*y(t) = 0,y(t)],
[4957,diff(diff(y(t),t),t)+4*diff(y(t),t)+5*y(t) = 0,y(t)],
[4958,diff(diff(y(t),t),t)+5*diff(y(t),t)+6*y(t) = 0,y(t)],
[4959,diff(diff(y(t),t),t)+5*diff(y(t),t)+6*y(t) = 0,y(t)],
[4960,diff(diff(y(t),t),t)+2*diff(y(t),t)+5*y(t) = 0,y(t)],
[5057,diff(diff(y(x),x),x)+2*diff(y(x),x)-y(x) = 0,y(x)],
[5058,diff(diff(y(x),x),x)+1/x*diff(y(x),x)-y(x)/x^2 = 0,y(x)],
[5059,(x^2+1)*diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[5062,(-x^4+x^2)*diff(diff(y(x),x),x)+(-2*x^3+2*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[5063,(-x^2+1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[5066,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[5067,-x^2*diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5068,(x^2+1)*diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[5069,diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[5070,x*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[5071,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[5072,x^3*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[5073,(x^2+x)*diff(diff(y(x),x),x)+(x+2)*diff(y(x),x)-y(x) = 0,y(x)],
[5074,2*x*diff(diff(y(x),x),x)+(x-2)*diff(y(x),x)-y(x) = 0,y(x)],
[5077,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[5078,(-x^2+1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+1/4*y(x) = 0,y(x)],
[5096,diff(diff(y(x),x),x)-2*diff(y(x),x)-3*y(x) = 0,y(x)],
[5097,diff(diff(s(t),t),t)+2*diff(s(t),t)+s(t) = 0,s(t)],
[5098,diff(diff(y(x),x),x)-2*diff(y(x),x)+5*y(x) = 0,y(x)],
[5099,diff(diff(y(x),x),x)-2*diff(y(x),x)-3*y(x) = 0,y(x)],
[5100,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[5101,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5102,diff(diff(y(x),x),x)+2*x^2*diff(y(x),x)+(x^4+2*x-1)*y(x) = 0,y(x)],
[5103,p*x^2*diff(diff(u(x),x),x)+q*x*diff(u(x),x)+r*u(x) = 0,u(x)],
[5106,diff(diff(y(x),x),x)-x/(-x^2+1)*diff(y(x),x)+y(x)/(-x^2+1) = 0,y(x)],
[5108,-3*diff(diff(y(t),t),t)+3*diff(y(t),t)-y(t) = 0,y(t)],
[5109,2*diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[5110,-diff(diff(y(t),t),t)-diff(y(t),t)+y(t) = 0,y(t)],
[5113,3*diff(diff(y(x),x),x)-4*diff(y(x),x)-4*y(x) = 0,y(x)],
[5114,diff(diff(u(x),x),x)+(-2*x-1)*diff(u(x),x)+(x^2+x-1)*u(x) = 0,u(x)],
[5115,diff(diff(y(x),x),x)+6*diff(y(x),x)+9*y(x) = 0,y(x)],
[5116,diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[5117,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[5118,6*diff(diff(y(x),x),x)+11*diff(y(x),x)+6*y(x) = 0,y(x)],
[5119,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5120,diff(diff(y(x),x),x)-4*diff(y(x),x)+3*y(x) = 0,y(x)],
[5121,diff(diff(y(x),x),x)+2*diff(y(x),x)+(1+2/(3*x+1)^2)*y(x) = 0,y(x)],
[5124,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[5125,diff(diff(y(x),x),x)+2/x*diff(y(x),x)-2*y(x)/(x+1)^2 = 0,y(x)],
[5133,-diff(diff(y(x),x),x) = 0,y(x)],
[5160,diff(diff(y(x),x),x) = 0,y(x)],
[5164,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[5165,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5168,diff(diff(y(x),x),x) = 0,y(x)],
[5191,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[5192,3*diff(diff(y(x),x),x)+2*y(x) = 0,y(x)],
[5193,diff(diff(y(x),x),x)+16*y(x) = 0,y(x)],
[5194,diff(diff(y(x),x),x) = 0,y(x)],
[5195,diff(diff(y(x),x),x)+2*I*diff(y(x),x)+y(x) = 0,y(x)],
[5196,diff(diff(y(x),x),x)-4*diff(y(x),x)+5*y(x) = 0,y(x)],
[5197,diff(diff(y(x),x),x)+(-1+3*I)*diff(y(x),x)-3*I*y(x) = 0,y(x)],
[5198,diff(diff(y(x),x),x)+diff(y(x),x)-6*y(x) = 0,y(x)],
[5199,diff(diff(y(x),x),x)+diff(y(x),x)-6*y(x) = 0,y(x)],
[5200,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5201,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5202,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5203,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5204,diff(diff(y(x),x),x)-2*diff(y(x),x)-3*y(x) = 0,y(x)],
[5205,diff(diff(y(x),x),x)+(1+4*I)*diff(y(x),x)+y(x) = 0,y(x)],
[5206,diff(diff(y(x),x),x)+(-1+3*I)*diff(y(x),x)-3*I*y(x) = 0,y(x)],
[5207,diff(diff(y(x),x),x)+10*y(x) = 0,y(x)],
[5208,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5209,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[5210,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5211,diff(diff(y(x),x),x)+2*I*diff(y(x),x)+y(x) = 0,y(x)],
[5212,diff(diff(y(x),x),x)-4*diff(y(x),x)+5*y(x) = 0,y(x)],
[5213,diff(diff(y(x),x),x)-7*diff(y(x),x)+6*y(x) = 0,y(x)],
[5214,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5215,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5216,4*diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[5217,6*diff(diff(y(x),x),x)+5*diff(y(x),x)-6*y(x) = 0,y(x)],
[5221,-5*diff(diff(y(x),x),x)+6*diff(y(x),x) = 0,y(x)],
[5222,-I*diff(diff(y(x),x),x)+4*diff(y(x),x)-4*I*y(x) = 0,y(x)],
[5223,5*diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5226,-3*I*diff(diff(y(x),x),x)-3*diff(y(x),x)+I*y(x) = 0,y(x)],
[5229,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5230,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[5233,-5*diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5235,-I*diff(diff(y(x),x),x)+diff(y(x),x)-I*y(x) = 0,y(x)],
[5236,diff(diff(y(x),x),x)-2*I*diff(y(x),x)-y(x) = 0,y(x)],
[5241,6*diff(diff(y(x),x),x)-4*diff(y(x),x)+y(x) = 0,y(x)],
[5243,diff(diff(y(x),x),x)-2*I*diff(y(x),x)-y(x) = 0,y(x)],
[5244,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5245,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5246,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[5247,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[5248,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[5249,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5250,diff(diff(y(x),x),x)+I*diff(y(x),x)+2*y(x) = 0,y(x)],
[5252,3*diff(diff(y(x),x),x)+3*diff(y(x),x)+y(x) = 0,y(x)],
[5253,diff(diff(y(x),x),x)+1/x*diff(y(x),x)-y(x)/x^2 = 0,y(x)],
[5254,diff(diff(y(x),x),x)+1/x*diff(y(x),x)-y(x)/x^2 = 0,y(x)],
[5255,(9*x^2-6*x+1)*diff(diff(y(x),x),x)+(9*x-3)*diff(y(x),x)-9*y(x) = 0,y(x)],
[5256,x^2*diff(diff(y(x),x),x)-7*x*diff(y(x),x)+15*y(x) = 0,y(x)],
[5257,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[5258,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-2)*y(x) = 0,y(x)],
[5259,x*diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[5260,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5261,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5262,-3*x^2*diff(diff(y(x),x),x)+6*x*diff(y(x),x)-6*y(x) = 0,y(x)],
[5263,x^2*diff(diff(y(x),x),x)-2*y(x) = 0,y(x)],
[5264,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[5265,x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[5266,diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[5270,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5278,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-6*y(x) = 0,y(x)],
[5279,2*x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[5280,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[5281,x^2*diff(diff(y(x),x),x)-5*x*diff(y(x),x)+9*y(x) = 0,y(x)],
[5282,2*x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[5283,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+4*y(x) = 0,y(x)],
[5284,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+5*y(x) = 0,y(x)],
[5285,x^2*diff(diff(y(x),x),x)+(-I*x-2*x)*diff(y(x),x)+3*I*y(x) = 0,y(x)],
[5286,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*Pi*y(x) = 0,y(x)],
[5287,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)-y(x) = 0,y(x)],
[5291,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5294,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[5304,x^2*diff(diff(y(x),x),x)+2*x^2*diff(y(x),x)-2*y(x) = 0,y(x)],
[5306,x^2*diff(diff(y(x),x),x)+(-2*x^2-2*x)*diff(y(x),x)+(2*x+2)*y(x) = 0,y(x)],
[5308,x^2*diff(diff(y(x),x),x)-2*x^2*diff(y(x),x)+(4*x-2)*y(x) = 0,y(x)],
[5309,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5338,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[5343,x*diff(diff(y(x),x),x)-2*diff(y(x),x) = 0,y(x)],
[5356,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5357,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[5383,diff(diff(y(x),x),x)-5*diff(y(x),x)+4*y(x) = 0,y(x)],
[5385,diff(diff(y(x),x),x)-5*diff(y(x),x)+2*y(x) = 0,y(x)],
[5490,x*diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[5515,x*diff(diff(y(x),x),x)-3*diff(y(x),x) = 0,y(x)],
[5516,diff(diff(y(x),x),x)+diff(y(x),x)-6*y(x) = 0,y(x)],
[5517,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[5518,diff(diff(y(x),x),x)+8*y(x) = 0,y(x)],
[5519,2*diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[5520,diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[5521,diff(diff(y(x),x),x)-9*diff(y(x),x)+20*y(x) = 0,y(x)],
[5522,2*diff(diff(y(x),x),x)+2*diff(y(x),x)+3*y(x) = 0,y(x)],
[5523,4*diff(diff(y(x),x),x)-12*diff(y(x),x)+9*y(x) = 0,y(x)],
[5524,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5525,diff(diff(y(x),x),x)-6*diff(y(x),x)+25*y(x) = 0,y(x)],
[5526,4*diff(diff(y(x),x),x)+20*diff(y(x),x)+25*y(x) = 0,y(x)],
[5527,diff(diff(y(x),x),x)+2*diff(y(x),x)+3*y(x) = 0,y(x)],
[5528,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[5529,4*diff(diff(y(x),x),x)-8*diff(y(x),x)+7*y(x) = 0,y(x)],
[5530,2*diff(diff(y(x),x),x)+diff(y(x),x)-y(x) = 0,y(x)],
[5531,diff(diff(y(x),x),x)+4*diff(y(x),x)+5*y(x) = 0,y(x)],
[5532,diff(diff(y(x),x),x)+4*diff(y(x),x)+5*y(x) = 0,y(x)],
[5533,diff(diff(y(x),x),x)+4*diff(y(x),x)-5*y(x) = 0,y(x)],
[5534,diff(diff(y(x),x),x)-5*diff(y(x),x)+6*y(x) = 0,y(x)],
[5535,diff(diff(y(x),x),x)-6*diff(y(x),x)+5*y(x) = 0,y(x)],
[5536,diff(diff(y(x),x),x)-6*diff(y(x),x)+9*y(x) = 0,y(x)],
[5537,diff(diff(y(x),x),x)+4*diff(y(x),x)+5*y(x) = 0,y(x)],
[5538,diff(diff(y(x),x),x)+4*diff(y(x),x)+2*y(x) = 0,y(x)],
[5539,diff(diff(y(x),x),x)+8*diff(y(x),x)-9*y(x) = 0,y(x)],
[5540,x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+10*y(x) = 0,y(x)],
[5541,2*x^2*diff(diff(y(x),x),x)+10*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[5542,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-12*y(x) = 0,y(x)],
[5543,4*x^2*diff(diff(y(x),x),x)-3*y(x) = 0,y(x)],
[5544,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[5545,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-6*y(x) = 0,y(x)],
[5546,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)+3*y(x) = 0,y(x)],
[5547,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-2*y(x) = 0,y(x)],
[5548,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-16*y(x) = 0,y(x)],
[5549,diff(diff(y(x),x),x)+3*diff(y(x),x)-10*y(x) = 0,y(x)],
[5550,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5551,diff(diff(y(x),x),x)+10*diff(y(x),x)+25*y(x) = 0,y(x)],
[5552,diff(diff(y(x),x),x)-2*diff(y(x),x)+5*y(x) = 0,y(x)],
[5553,diff(diff(y(x),x),x)-diff(y(x),x)-6*y(x) = 0,y(x)],
[5554,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[5555,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5556,diff(diff(y(x),x),x)-2*diff(y(x),x) = 0,y(x)],
[5557,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[5558,diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[5559,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[5560,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5561,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[5562,diff(diff(y(x),x),x)-3*y(x) = 0,y(x)],
[5564,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5565,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[5566,diff(diff(y(x),x),x)-2*diff(y(x),x)-3*y(x) = 0,y(x)],
[5567,diff(diff(y(x),x),x)+2*diff(y(x),x)+5*y(x) = 0,y(x)],
[5568,2*diff(diff(y(x),x),x)+3*diff(y(x),x)+y(x) = 0,y(x)],
[5569,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[5570,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5571,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5572,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5573,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5574,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5575,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5576,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5577,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[5578,diff(diff(y(x),x),x)-diff(y(x),x)-6*y(x) = 0,y(x)],
[5579,(x^2-1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5580,(x^2+x)*diff(diff(y(x),x),x)+(-x^2+2)*diff(y(x),x)+(-x-2)*y(x) = 0,y(x)],
[5581,(1-x)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[5582,x*diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[5583,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5584,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5585,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[5586,x*diff(diff(y(x),x),x)+3*diff(y(x),x) = 0,y(x)],
[5587,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[5588,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5589,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[5590,diff(diff(y(x),x),x)-x/(x-1)*diff(y(x),x)+1/(x-1)*y(x) = 0,y(x)],
[5591,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[5592,x^2*diff(diff(y(x),x),x)+(-x^2-2*x)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[5594,x*diff(diff(y(x),x),x)+(-2*x-1)*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[5595,-3*diff(diff(y(x),x),x)+2*diff(y(x),x) = 0,y(x)],
[5596,-3*diff(diff(y(x),x),x)+4*diff(y(x),x)-2*y(x) = 0,y(x)],
[5599,3*diff(diff(y(x),x),x)+3*diff(y(x),x)+y(x) = 0,y(x)],
[5600,6*diff(diff(y(x),x),x)+4*diff(y(x),x)+y(x) = 0,y(x)],
[5602,5*diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5605,2*diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[5606,-2*diff(diff(y(x),x),x)-6*diff(y(x),x)+5*y(x) = 0,y(x)],
[5607,-6*diff(diff(y(x),x),x)+11*diff(y(x),x)-6*y(x) = 0,y(x)],
[5608,-3*diff(diff(y(x),x),x)-5*diff(y(x),x)-2*y(x) = 0,y(x)],
[5609,48*diff(diff(y(x),x),x)+16*diff(y(x),x)-96*y(x) = 0,y(x)],
[5612,-3*diff(diff(y(x),x),x)+2*diff(y(x),x) = 0,y(x)],
[5614,3*x^2*diff(diff(y(x),x),x) = 0,y(x)],
[5615,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5616,2*x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[5617,8*x*diff(diff(y(x),x),x)-8*diff(y(x),x) = 0,y(x)],
[5618,diff(diff(y(x),x),x)-3*diff(y(x),x)+y(x) = 0,y(x)],
[5619,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[5620,diff(diff(y(x),x),x)+6*diff(y(x),x)+9*y(x) = 0,y(x)],
[5621,diff(diff(y(x),x),x)-diff(y(x),x)+6*y(x) = 0,y(x)],
[5622,diff(diff(y(x),x),x)-2*diff(y(x),x)-5*y(x) = 0,y(x)],
[5623,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5624,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[5625,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[5626,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[5627,diff(diff(y(x),x),x)-diff(y(x),x)+4*y(x) = 0,y(x)],
[5628,diff(diff(y(x),x),x)+2*diff(y(x),x)+5*y(x) = 0,y(x)],
[5629,diff(diff(y(x),x),x)+3*diff(y(x),x)+4*y(x) = 0,y(x)],
[5630,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5631,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[5632,diff(diff(y(x),x),x) = 0,y(x)],
[5633,diff(diff(y(x),x),x)-2*diff(y(x),x) = 0,y(x)],
[5634,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[5635,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[5636,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[5637,diff(diff(y(x),x),x)+2*diff(y(x),x)-y(x) = 0,y(x)],
[5638,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[5639,diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[5640,x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+y(x) = 0,y(x)],
[5641,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5642,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[5643,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5644,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[5645,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[5646,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5647,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[5649,diff(diff(y(x),x),x)+3*y(x) = 0,y(x)],
[5674,diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[5678,(x^2+1)*diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[5679,diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)-y(x) = 0,y(x)],
[5680,(x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[5681,diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[5686,(-x^2+1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+p^2*y(x) = 0,y(x)],
[5690,x^2*diff(diff(y(x),x),x)+(-x+2)*diff(y(x),x) = 0,y(x)],
[5700,x^3*diff(diff(y(x),x),x)-4*x^2*diff(y(x),x)+3*x*y(x) = 0,y(x)],
[5702,2*x*diff(diff(y(x),x),x)+(3-x)*diff(y(x),x)-y(x) = 0,y(x)],
[5703,2*x*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)+3*y(x) = 0,y(x)],
[5704,2*x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(-x-1)*y(x) = 0,y(x)],
[5706,diff(diff(y(x),x),x)+1/x^2*diff(y(x),x)-1/x^3*y(x) = 0,y(x)],
[5707,x^2*diff(diff(y(x),x),x)+(3*x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[5709,4*x^2*diff(diff(y(x),x),x)-8*x^2*diff(y(x),x)+(4*x^2+1)*y(x) = 0,y(x)],
[5710,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[5711,x^2*diff(diff(y(x),x),x)-x^2*diff(y(x),x)+(x^2-2)*y(x) = 0,y(x)],
[5712,x*diff(diff(y(x),x),x)-diff(y(x),x)+4*x^3*y(x) = 0,y(x)],
[5713,(x^2-2*x+1)*diff(diff(y(x),x),x)+(-3*x+3)*diff(y(x),x)+2*y(x) = 0,y(x)],
[5714,(3*x^2+6*x+3)*diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)-y(x) = 0,y(x)],
[5716,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[5717,(-x^2+x)*diff(diff(y(x),x),x)+(3/2-2*x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[5718,(2*x^2+2*x)*diff(diff(y(x),x),x)+(1+5*x)*diff(y(x),x)+y(x) = 0,y(x)],
[5719,(x^2-1)*diff(diff(y(x),x),x)+(5*x+4)*diff(y(x),x)+4*y(x) = 0,y(x)],
[5721,(-x^2+1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+p^2*y(x) = 0,y(x)],
[5724,diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[5725,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[5726,2*diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[5728,(x^2+1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[5729,diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)-x*y(x) = 0,y(x)],
[5730,(x-1)*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)+y(x) = 0,y(x)],
[5733,x*diff(diff(y(x),x),x)-4*diff(y(x),x)+x*y(x) = 0,y(x)],
[5735,2*x*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)+y(x) = 0,y(x)],
[5736,x*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[5738,x*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)+y(x) = 0,y(x)],
[5739,2*x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+x*y(x) = 0,y(x)],
[5741,-2*x^2*diff(diff(y(x),x),x)+(x^2+2*x)*diff(y(x),x)-x*y(x) = 0,y(x)],
[5742,(2*x^3-x^2)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[5746,diff(diff(y(t),t),t)+5*diff(y(t),t)+6*y(t) = 0,y(t)],
[5747,diff(diff(y(t),t),t)+diff(y(t),t)-6*y(t) = 0,y(t)],
[5748,diff(diff(y(t),t),t)-y(t) = 0,y(t)],
[5752,diff(diff(y(t),t),t)+3*diff(y(t),t)-5*y(t) = 0,y(t)],
[5753,diff(diff(y(t),t),t)+3*diff(y(t),t)-2*y(t) = 0,y(t)],
[5754,diff(diff(y(t),t),t)+2*diff(y(t),t)-y(t) = 0,y(t)],
[5755,diff(diff(y(t),t),t)-diff(y(t),t)+y(t) = 0,y(t)],
[5756,diff(diff(y(t),t),t)-5*diff(y(t),t)+4*y(t) = 0,y(t)],
[5757,diff(diff(y(t),t),t)+3*diff(y(t),t)+3*y(t) = 0,y(t)],
[5758,diff(diff(y(t),t),t)+diff(y(t),t)+2*y(t) = 0,y(t)],
[5759,diff(diff(y(t),t),t)-7*diff(y(t),t)+12*y(t) = 0,y(t)],
[5760,diff(diff(i(t),t),t)+2*diff(i(t),t)+3*i(t) = 0,i(t)],
[5797,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5798,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5799,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[5800,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[5801,diff(diff(y(x),x),x)-diff(y(x),x) = 0,y(x)],
[5802,diff(diff(y(x),x),x)-diff(y(x),x) = 0,y(x)],
[5803,diff(diff(y(x),x),x)+2*diff(y(x),x) = 0,y(x)],
[5804,diff(diff(y(x),x),x)+2*diff(y(x),x) = 0,y(x)],
[5808,diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5810,diff(diff(y(x),x),x)+2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5811,(x-1)*diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[5812,(x+2)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[5813,diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)-y(x) = 0,y(x)],
[5814,(x^2+1)*diff(diff(y(x),x),x)-6*y(x) = 0,y(x)],
[5815,(x^2+2)*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-y(x) = 0,y(x)],
[5816,(x^2-1)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[5817,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[5818,(x+1)*diff(diff(y(x),x),x)+(x-2)*diff(y(x),x)+y(x) = 0,y(x)],
[5819,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[5820,(x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x) = 0,y(x)],
[5826,diff(diff(y(x),x),x)-4*x*diff(y(x),x)-4*y(x) = 0,y(x)],
[5829,diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[5843,x^2*diff(diff(y(x),x),x)+(5/3*x+x^2)*diff(y(x),x)-1/3*y(x) = 0,y(x)],
[5845,2*x*diff(diff(y(x),x),x)-diff(y(x),x)+2*y(x) = 0,y(x)],
[5849,3*x*diff(diff(y(x),x),x)+(-x+2)*diff(y(x),x)-y(x) = 0,y(x)],
[5851,2*x*diff(diff(y(x),x),x)+(-2*x-3)*diff(y(x),x)+y(x) = 0,y(x)],
[5854,2*x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+(2*x-1)*y(x) = 0,y(x)],
[5855,x*diff(diff(y(x),x),x)+2*diff(y(x),x)-x*y(x) = 0,y(x)],
[5856,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[5857,x*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[5859,x*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)-y(x) = 0,y(x)],
[5861,x*diff(diff(y(x),x),x)+(x-6)*diff(y(x),x)-3*y(x) = 0,y(x)],
[5862,(x^2-x)*diff(diff(y(x),x),x)+3*diff(y(x),x)-2*y(x) = 0,y(x)],
[5865,x^2*diff(diff(y(x),x),x)+(3*x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[5868,4*x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2-25)*y(x) = 0,y(x)],
[5873,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(36*x^2-1/4)*y(x) = 0,y(x)],
[5880,x^2*diff(diff(y(x),x),x)+(x^2-2)*y(x) = 0,y(x)],
[5882,x*diff(diff(y(x),x),x)+3*diff(y(x),x)+x^3*y(x) = 0,y(x)],
[5886,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5887,x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[5888,16*x^2*diff(diff(y(x),x),x)+32*x*diff(y(x),x)+(x^4-12)*y(x) = 0,y(x)],
[5889,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(16*x^2+3)*y(x) = 0,y(x)],
[5890,2*x*diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[5891,diff(diff(y(x),x),x)-x*diff(y(x),x)-y(x) = 0,y(x)],
[5893,diff(diff(y(x),x),x)-x^2*diff(y(x),x)+x*y(x) = 0,y(x)],
[5894,x*diff(diff(y(x),x),x)+(-x-2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[5896,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5899,diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[5902,diff(diff(y(x),x),x)+x^2*diff(y(x),x)+2*x*y(x) = 0,y(x)],
[5907,diff(diff(y(t),t),t)+5*diff(y(t),t)+4*y(t) = 0,y(t)],
[5908,diff(diff(y(t),t),t)-4*diff(y(t),t) = 0,y(t)],
[5909,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[5910,diff(diff(y(t),t),t)+9*y(t) = 0,y(t)],
[5911,3*diff(diff(y(t),t),t)-3*diff(y(t),t)-2*y(t) = 0,y(t)],
[5912,2*diff(diff(y(t),t),t)-diff(y(t),t)-2*y(t) = 0,y(t)],
[5914,diff(diff(y(t),t),t)-2*diff(y(t),t)+5*y(t) = 0,y(t)],
[5917,diff(diff(y(t),t),t)+2*diff(y(t),t)+y(t) = 0,y(t)],
[5918,diff(diff(y(t),t),t)-4*diff(y(t),t)+4*y(t) = 0,y(t)],
[5919,diff(diff(y(t),t),t)-6*diff(y(t),t)+9*y(t) = 0,y(t)],
[5920,diff(diff(y(t),t),t)-4*diff(y(t),t)+4*y(t) = 0,y(t)],
[5921,diff(diff(y(t),t),t)-6*diff(y(t),t)+13*y(t) = 0,y(t)],
[5922,2*diff(diff(y(t),t),t)+20*diff(y(t),t)+51*y(t) = 0,y(t)],
[5923,diff(diff(y(t),t),t)-y(t) = 0,y(t)],
[5924,diff(diff(y(t),t),t)-2*diff(y(t),t)+5*y(t) = 0,y(t)],
[5925,diff(diff(y(t),t),t)+2*diff(y(t),t)+y(t) = 0,y(t)],
[5926,diff(diff(y(t),t),t)+8*diff(y(t),t)+20*y(t) = 0,y(t)],
[5930,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[5931,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[5932,diff(diff(y(t),t),t)-5*diff(y(t),t)+6*y(t) = 0,y(t)],
[5933,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[5934,diff(diff(y(t),t),t)+4*diff(y(t),t)+3*y(t) = 0,y(t)],
[5937,diff(diff(y(t),t),t)+9*y(t) = 0,y(t)],
[5938,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[5939,diff(diff(y(t),t),t)+16*y(t) = 0,y(t)],
[5940,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[5941,t*diff(diff(y(t),t),t)-diff(y(t),t) = 0,y(t)],
[5942,2*diff(diff(y(t),t),t)+t*diff(y(t),t)-2*y(t) = 0,y(t)],
[5943,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[5946,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[5947,diff(diff(y(t),t),t)+16*y(t) = 0,y(t)],
[5948,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[5949,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[5950,diff(diff(y(t),t),t)+2*diff(y(t),t) = 0,y(t)],
[5951,diff(diff(y(t),t),t)-2*diff(y(t),t) = 0,y(t)],
[5952,diff(diff(y(t),t),t)+4*diff(y(t),t)+5*y(t) = 0,y(t)],
[5953,diff(diff(y(t),t),t)+2*diff(y(t),t)+y(t) = 0,y(t)],
[5954,diff(diff(y(t),t),t)+4*diff(y(t),t)+13*y(t) = 0,y(t)],
[5955,diff(diff(y(t),t),t)-7*diff(y(t),t)+6*y(t) = 0,y(t)],
[5956,diff(diff(y(t),t),t)+2*diff(y(t),t)+10*y(t) = 0,y(t)],
[5957,diff(diff(y(t),t),t)+2*diff(y(t),t)+10*y(t) = 0,y(t)],
[6075,x*diff(diff(y(x),x),x)-diff(y(x),x) = 0,y(x)],
[6076,x*diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6088,x^3*diff(diff(y(x),x),x)-x^2*diff(y(x),x) = 0,y(x)],
[6108,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6109,diff(diff(y(x),x),x)-6*diff(y(x),x)+9*y(x) = 0,y(x)],
[6110,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[6111,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[6136,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6137,diff(diff(y(x),x),x)-9*y(x) = 0,y(x)],
[6138,diff(diff(y(x),x),x)+3*x*diff(y(x),x)+3*y(x) = 0,y(x)],
[6139,(4*x^2+1)*diff(diff(y(x),x),x)-8*y(x) = 0,y(x)],
[6140,(-4*x^2+1)*diff(diff(y(x),x),x)+8*y(x) = 0,y(x)],
[6141,(x^2+1)*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[6142,(x^2+1)*diff(diff(y(x),x),x)+10*x*diff(y(x),x)+20*y(x) = 0,y(x)],
[6143,(x^2+4)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-12*y(x) = 0,y(x)],
[6144,(x^2-9)*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-3*y(x) = 0,y(x)],
[6146,(x^2+4)*diff(diff(y(x),x),x)+6*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[6147,(2*x^2+1)*diff(diff(y(x),x),x)-5*x*diff(y(x),x)+3*y(x) = 0,y(x)],
[6149,(-4*x^2+1)*diff(diff(y(x),x),x)+6*x*diff(y(x),x)-4*y(x) = 0,y(x)],
[6150,(2*x^2+1)*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-3*y(x) = 0,y(x)],
[6152,diff(diff(y(x),x),x)+x*diff(y(x),x)+3*y(x) = 0,y(x)],
[6153,diff(diff(y(x),x),x)+2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6155,2*diff(diff(y(x),x),x)+9*x*diff(y(x),x)-36*y(x) = 0,y(x)],
[6156,(x^2+4)*diff(diff(y(x),x),x)+x*diff(y(x),x)-9*y(x) = 0,y(x)],
[6157,(x^2+4)*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-8*y(x) = 0,y(x)],
[6158,(9*x^2+1)*diff(diff(y(x),x),x)-18*y(x) = 0,y(x)],
[6159,(3*x^2+1)*diff(diff(y(x),x),x)+13*x*diff(y(x),x)+7*y(x) = 0,y(x)],
[6160,(2*x^2+1)*diff(diff(y(x),x),x)+11*x*diff(y(x),x)+9*y(x) = 0,y(x)],
[6163,(x^2-2*x+2)*diff(diff(y(x),x),x)+(-4*x+4)*diff(y(x),x)+6*y(x) = 0,y(x)],
[6164,(2*x^2+2*x)*diff(diff(y(x),x),x)+(3*x+3)*diff(y(x),x)-y(x) = 0,y(x)],
[6165,4*x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2-1)*y(x) = 0,y(x)],
[6166,4*x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(-4*x^2-1)*y(x) = 0,y(x)],
[6168,(-2*x^3+2*x^2)*diff(diff(y(x),x),x)+(-7*x^2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[6169,2*x*diff(diff(y(x),x),x)+(-10*x+5)*diff(y(x),x)-5*y(x) = 0,y(x)],
[6171,2*x*diff(diff(y(x),x),x)+(-x+2)*diff(y(x),x)-2*y(x) = 0,y(x)],
[6172,(2*x^2+6*x)*diff(diff(y(x),x),x)+(-3*x-3)*diff(y(x),x)+2*y(x) = 0,y(x)],
[6173,2*x*diff(diff(y(x),x),x)+(-2*x^2+1)*diff(y(x),x)-4*x*y(x) = 0,y(x)],
[6174,(-x^2+4*x)*diff(diff(y(x),x),x)+(-x+2)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6176,2*x*diff(diff(y(x),x),x)+(2*x+1)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6177,2*x*diff(diff(y(x),x),x)+(2*x+1)*diff(y(x),x)-5*y(x) = 0,y(x)],
[6178,2*x^2*diff(diff(y(x),x),x)+(3*x^2-3*x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[6179,2*x^2*diff(diff(y(x),x),x)+(4*x^2-x)*diff(y(x),x)+(6*x-2)*y(x) = 0,y(x)],
[6180,2*x*diff(diff(y(x),x),x)+(-2*x^2-1)*diff(y(x),x)-x*y(x) = 0,y(x)],
[6181,2*x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[6182,2*x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6183,9*x^2*diff(diff(y(x),x),x)+2*y(x) = 0,y(x)],
[6184,2*x^2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[6185,2*x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[6186,2*x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6187,9*x^2*diff(diff(y(x),x),x)+2*y(x) = 0,y(x)],
[6188,2*x^2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[6189,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-12*y(x) = 0,y(x)],
[6190,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-9*y(x) = 0,y(x)],
[6191,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[6192,x^2*diff(diff(y(x),x),x)-5*x*diff(y(x),x)+9*y(x) = 0,y(x)],
[6193,x^2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)+5*y(x) = 0,y(x)],
[6194,4*x^2*diff(diff(y(x),x),x)-8*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[6195,x^2*diff(diff(y(x),x),x)+(-x^2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[6197,x^2*diff(diff(y(x),x),x)+(x^2-3*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6199,(x^2+x)*diff(diff(y(x),x),x)+(1+5*x)*diff(y(x),x)+3*y(x) = 0,y(x)],
[6200,x^2*diff(diff(y(x),x),x)+(-3*x^2-x)*diff(y(x),x)+(1-6*x)*y(x) = 0,y(x)],
[6201,x^2*diff(diff(y(x),x),x)+(x^2-x)*diff(y(x),x)+(1-x)*y(x) = 0,y(x)],
[6202,(x^2-2*x)*diff(diff(y(x),x),x)+(2*x-2)*diff(y(x),x)-2*y(x) = 0,y(x)],
[6203,(x^2-2*x)*diff(diff(y(x),x),x)+(2*x-2)*diff(y(x),x)-2*y(x) = 0,y(x)],
[6204,(4*x^2-32*x+64)*diff(diff(y(x),x),x)+(x^2-12*x+32)*diff(y(x),x)+x*y(x) = 0,y(x)],
[6210,x^2*diff(diff(y(x),x),x)+(3*x^2+3*x)*diff(y(x),x)+(-3*x+1)*y(x) = 0,y(x)],
[6211,x*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)-y(x) = 0,y(x)],
[6212,x^2*diff(diff(y(x),x),x)+(2*x^2-4*x)*diff(y(x),x)+(-6*x+4)*y(x) = 0,y(x)],
[6213,(2*x^3+x^2)*diff(diff(y(x),x),x)+(12*x^2+2*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[6214,x^2*diff(diff(y(x),x),x)+(3*x^2+2*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[6215,x*diff(diff(y(x),x),x)+(-x-3)*diff(y(x),x)+2*y(x) = 0,y(x)],
[6216,(x^2+x)*diff(diff(y(x),x),x)+(x+5)*diff(y(x),x)-4*y(x) = 0,y(x)],
[6217,(x^2+x)*diff(diff(y(x),x),x)+(x+5)*diff(y(x),x)-4*y(x) = 0,y(x)],
[6218,x^2*diff(diff(y(x),x),x)+x^2*diff(y(x),x)-2*y(x) = 0,y(x)],
[6219,(-x^2+x)*diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[6220,(-x^2+x)*diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[6221,x*diff(diff(y(x),x),x)+(4+3*x)*diff(y(x),x)+3*y(x) = 0,y(x)],
[6222,x*diff(diff(y(x),x),x)+(-2*x-4)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6223,x*diff(diff(y(x),x),x)+(2*x+3)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6224,(x^2+3*x)*diff(diff(y(x),x),x)-9*diff(y(x),x)-6*y(x) = 0,y(x)],
[6225,(-2*x^2+x)*diff(diff(y(x),x),x)+(-2*x-4)*diff(y(x),x)+8*y(x) = 0,y(x)],
[6226,x*diff(diff(y(x),x),x)+(x^3-1)*diff(y(x),x)+x^2*y(x) = 0,y(x)],
[6227,(4*x^3-x^2)*diff(diff(y(x),x),x)+(5*x^2+x)*diff(y(x),x)+3*y(x) = 0,y(x)],
[6231,4*x^2*diff(diff(y(x),x),x)+(-2*x^2+4*x)*diff(y(x),x)+(-1-3*x)*y(x) = 0,y(x)],
[6232,x^2*diff(diff(y(x),x),x)+(-x^2-6*x)*diff(y(x),x)+10*y(x) = 0,y(x)],
[6233,x*diff(diff(y(x),x),x)+(2*x+3)*diff(y(x),x)+8*y(x) = 0,y(x)],
[6234,(-x^2+x)*diff(diff(y(x),x),x)+(2-2*x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[6235,(-x^2+x)*diff(diff(y(x),x),x)+(2-2*x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[6239,x*diff(diff(y(x),x),x)+(3-x)*diff(y(x),x)-5*y(x) = 0,y(x)],
[6245,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(-6*x^2+3*x-1)*y(x) = 0,y(x)],
[6247,(x^3-4*x^2+4*x)*diff(diff(y(x),x),x)+(-2*x+4)*diff(y(x),x)+2*y(x) = 0,y(x)],
[6248,(x^3-4*x^2+4*x)*diff(diff(y(x),x),x)+(-2*x+4)*diff(y(x),x)+2*y(x) = 0,y(x)],
[6249,2*x*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)+(-x-1)*y(x) = 0,y(x)],
[6250,x*diff(diff(y(x),x),x)+(-x-2)*diff(y(x),x)-y(x) = 0,y(x)],
[6251,x*diff(diff(y(x),x),x)+(-x-2)*diff(y(x),x)-2*y(x) = 0,y(x)],
[6252,x^2*diff(diff(y(x),x),x)+2*x^2*diff(y(x),x)-2*y(x) = 0,y(x)],
[6253,2*x^2*diff(diff(y(x),x),x)+(-2*x^2-7*x)*diff(y(x),x)+(2*x+10)*y(x) = 0,y(x)],
[6254,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3+6*x)*diff(y(x),x)+6*y(x) = 0,y(x)],
[6255,(-x^2+1)*diff(diff(y(x),x),x)-10*x*diff(y(x),x)-18*y(x) = 0,y(x)],
[6256,2*x*diff(diff(y(x),x),x)+(2*x+1)*diff(y(x),x)-3*y(x) = 0,y(x)],
[6257,diff(diff(y(x),x),x)+2*x*diff(y(x),x)-8*y(x) = 0,y(x)],
[6258,(-x^3+x)*diff(diff(y(x),x),x)+(-x^2-7)*diff(y(x),x)+4*x*y(x) = 0,y(x)],
[6259,2*x^2*diff(diff(y(x),x),x)+(-2*x^2-x)*diff(y(x),x)+(4*x+1)*y(x) = 0,y(x)],
[6260,4*x^2*diff(diff(y(x),x),x)+(-2*x^2-4*x)*diff(y(x),x)+(x+3)*y(x) = 0,y(x)],
[6261,x^2*diff(diff(y(x),x),x)+(-x^3-x)*diff(y(x),x)+(-x^2+1)*y(x) = 0,y(x)],
[6262,2*x*diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6263,x^2*diff(diff(y(x),x),x)+(x^3-3*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6265,(x^2+1)*diff(diff(y(x),x),x)-2*y(x) = 0,y(x)],
[6266,2*x^2*diff(diff(y(x),x),x)+(-2*x^2-x)*diff(y(x),x)+(3*x+1)*y(x) = 0,y(x)],
[6268,x*diff(diff(y(x),x),x)+(-x^2+1)*diff(y(x),x)+2*x*y(x) = 0,y(x)],
[6269,4*x^2*diff(diff(y(x),x),x)+2*x^2*diff(y(x),x)+(-x-3)*y(x) = 0,y(x)],
[6270,(-x^3+x)*diff(diff(y(x),x),x)+(-5*x^2+5)*diff(y(x),x)-4*x*y(x) = 0,y(x)],
[6271,x^2*diff(diff(y(x),x),x)+(x^2+3*x)*diff(y(x),x)+(2*x+1)*y(x) = 0,y(x)],
[6273,(-2*x^2+x)*diff(diff(y(x),x),x)+(-2*x-4)*diff(y(x),x)+18*y(x) = 0,y(x)],
[6274,x*diff(diff(y(x),x),x)+(-x+2)*diff(y(x),x)-y(x) = 0,y(x)],
[6284,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[6285,diff(diff(y(x),x),x)+16*y(x) = 0,y(x)],
[6286,diff(diff(y(x),x),x)-4*diff(y(x),x)+3*y(x) = 0,y(x)],
[6287,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6331,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[6332,5*diff(diff(y(x),x),x)+2*diff(y(x),x)+4*y(x) = 0,y(x)],
[6333,diff(diff(y(x),x),x)+diff(y(x),x)+4*y(x) = 0,y(x)],
[6334,diff(diff(y(x),x),x)+diff(y(x),x)+4*y(x) = 0,y(x)],
[6338,t*diff(diff(y(t),t),t)+4*diff(y(t),t) = 0,y(t)],
[6339,(t^2+9)*diff(diff(y(t),t),t)+2*t*diff(y(t),t) = 0,y(t)],
[6340,t^2*diff(diff(y(t),t),t)-3*t*diff(y(t),t)+5*y(t) = 0,y(t)],
[6341,t*diff(diff(y(t),t),t)+diff(y(t),t) = 0,y(t)],
[6342,t^2*diff(diff(y(t),t),t)-2*diff(y(t),t) = 0,y(t)],
[6344,t*diff(diff(y(t),t),t)-diff(y(t),t)+4*t^3*y(t) = 0,y(t)],
[6345,diff(diff(y(t),t),t) = 0,y(t)],
[6346,diff(diff(y(t),t),t) = 0,y(t)],
[6347,diff(diff(y(t),t),t) = 0,y(t)],
[6348,diff(diff(y(t),t),t) = 0,y(t)],
[6351,diff(diff(y(x),x),x) = 0,y(x)],
[6374,diff(diff(z(t),t),t)+3*diff(z(t),t)+2*z(t) = 0,z(t)],
[6379,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6380,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6381,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6384,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6385,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6386,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6387,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6388,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6389,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6390,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6391,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6392,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6393,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6427,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6432,diff(diff(y(x),x),x)-1/x*diff(y(x),x)-x^2*y(x) = 0,y(x)],
[6440,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6441,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6442,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6443,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6444,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6445,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6446,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6447,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6448,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6449,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6450,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6452,x^4*diff(diff(y(x),x),x)+x^3*diff(y(x),x)-4*x^2*y(x) = 0,y(x)],
[6453,x^4*diff(diff(y(x),x),x)+x^3*diff(y(x),x)-4*x^2*y(x) = 0,y(x)],
[6454,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[6455,x^3*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+x*y(x) = 0,y(x)],
[6456,x^3*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+x*y(x) = 0,y(x)],
[6467,4*x^2*diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6485,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[6486,2*x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6490,x^2*diff(diff(y(x),x),x)+(3*x^2+2*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[6498,(x^3+3*x^2)*diff(diff(y(x),x),x)+(5*x^2+5*x)*diff(y(x),x)+(-1+4*x)*y(x) = 0,y(x)],
[6499,(-x^4+2*x^2)*diff(diff(y(x),x),x)+(-4*x^3-3*x)*diff(y(x),x)+(-2*x^2+2)*y(x) = 0,y(x)],
[6502,x^2*diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6504,4*x*diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[6506,x*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)+2*y(x) = 0,y(x)],
[6507,(x^2-x)*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+y(x) = 0,y(x)],
[6508,(x^4-2*x^3+x^2)*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+(4+x)*y(x) = 0,y(x)],
[6509,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+5*x^2*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[6516,x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[6518,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[6519,(x^2-x)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[6520,x^2*diff(diff(y(x),x),x)+(x^2+6*x)*diff(y(x),x)+x*y(x) = 0,y(x)],
[6522,x^2*diff(diff(y(x),x),x)-9*x*diff(y(x),x)+25*y(x) = 0,y(x)],
[6523,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+(-x^2-5/4)*y(x) = 0,y(x)],
[6524,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[6525,x*diff(diff(y(x),x),x)+(-x+2)*diff(y(x),x)-y(x) = 0,y(x)],
[6526,2*x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-y(x) = 0,y(x)],
[6527,2*x^2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[6528,x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+4*x^4*y(x) = 0,y(x)],
[6530,(-x^2+1)*diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6536,diff(diff(y(x),x),x)+(-x^2-3)*y(x) = 0,y(x)],
[6539,diff(diff(y(x),x),x)+20*diff(y(x),x)+500*y(x) = 0,y(x)],
[6542,diff(diff(y(x),x),x)+2*x*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[6544,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[6545,4*x^2*diff(diff(y(x),x),x)+(-8*x^2+4*x)*diff(y(x),x)+(4*x^2-4*x-1)*y(x) = 0,y(x)],
[6546,x*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[6551,diff(diff(y(x),x),x) = 0,y(x)],
[6552,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6553,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6554,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6556,diff(diff(y(x),x),x)+2*diff(y(x),x)-24*y(x) = 0,y(x)],
[6557,diff(diff(y(t),t),t)+3*diff(y(t),t)-4*y(t) = 0,y(t)],
[6558,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6560,x*diff(diff(y(x),x),x)+(-2*x-1)*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[6634,diff(diff(y(x),x),x) = 0,y(x)],
[6640,diff(diff(y(x),x),x) = 0,y(x)],
[6642,diff(diff(y(x),x),x) = 0,y(x)],
[6645,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6648,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6651,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6654,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6657,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6658,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6659,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6660,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6661,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6662,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6663,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6664,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6665,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6666,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6667,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6668,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6669,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6670,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6671,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6672,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6673,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6674,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6675,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6676,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6677,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6699,diff(diff(y(x),x),x)-2*y(x)/x^2 = 0,y(x)],
[6704,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+3*y(x) = 0,y(x)],
[6708,x*diff(diff(y(x),x),x)-diff(y(x),x)+4*x^3*y(x) = 0,y(x)],
[6709,x*diff(diff(y(x),x),x)-diff(y(x),x)+4*x^3*y(x) = 0,y(x)],
[6712,diff(diff(y(x),x),x)-x^2*diff(y(x),x)+x*y(x) = 0,y(x)],
[6715,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-1)*y(x) = 0,y(x)],
[6717,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-3)*y(x) = 0,y(x)],
[6719,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(2*x^2+2)*y(x) = 0,y(x)],
[6720,4*x^2*diff(diff(y(x),x),x)+4*x^5*diff(y(x),x)+(x^8+6*x^4+4)*y(x) = 0,y(x)],
[6722,x*diff(diff(y(x),x),x)+2*diff(y(x),x)-x*y(x) = 0,y(x)],
[6723,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[6727,-3*diff(diff(y(x),x),x)+5*diff(y(x),x)-2*y(x) = 0,y(x)],
[6728,x^2*diff(diff(y(x),x),x)+(-x^2-6*x)*diff(y(x),x)+10*y(x) = 0,y(x)],
[6731,x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[6735,(x^2-1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6736,(x^2-1)*diff(diff(y(x),x),x)-6*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[6737,(x^2+3)*diff(diff(y(x),x),x)-7*x*diff(y(x),x)+16*y(x) = 0,y(x)],
[6738,(x^2-1)*diff(diff(y(x),x),x)+8*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[6739,3*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[6740,5*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+10*y(x) = 0,y(x)],
[6741,diff(diff(y(x),x),x)-x^2*diff(y(x),x)-3*x*y(x) = 0,y(x)],
[6742,(x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[6743,diff(diff(y(x),x),x)+x*diff(y(x),x)-2*y(x) = 0,y(x)],
[6744,(x^2-6*x+10)*diff(diff(y(x),x),x)+(-4*x+12)*diff(y(x),x)+6*y(x) = 0,y(x)],
[6745,(x^2+6*x)*diff(diff(y(x),x),x)+(3*x+9)*diff(y(x),x)-3*y(x) = 0,y(x)],
[6746,t*diff(diff(y(t),t),t)+(t^2-1)*diff(y(t),t)+t^2*y(t) = 0,y(t)],
[6747,t^2*diff(diff(y(t),t),t)+(-t^2-2*t)*diff(y(t),t)+(t+2)*y(t) = 0,y(t)],
[6748,t*diff(diff(y(t),t),t)+(-t-1)*diff(y(t),t)+y(t) = 0,y(t)],
[6749,(-t+1)*diff(diff(y(t),t),t)+t*diff(y(t),t)-y(t) = 0,y(t)],
[6750,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[6751,t*diff(diff(y(t),t),t)+(-t-1)*diff(y(t),t)+y(t) = 0,y(t)],
[6752,(-t+1)*diff(diff(y(t),t),t)+t*diff(y(t),t)-y(t) = 0,y(t)],
[6753,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6754,(x^2+1)*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[6755,(1-x)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[6756,2*diff(diff(y(x),x),x)+x*diff(y(x),x)+3*y(x) = 0,y(x)],
[6757,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6758,(1-x)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[6759,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6760,(-x^2+4)*diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6761,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(-16*x^2+3)*y(x) = 0,y(x)],
[6762,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[6763,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[6764,(x^2-2*x)*diff(diff(y(x),x),x)+(-x^2+2)*diff(y(x),x)+(2*x-2)*y(x) = 0,y(x)],
[6765,4*x^2*diff(diff(y(x),x),x)+(-8*x^2+4*x)*diff(y(x),x)+(4*x^2-4*x-1)*y(x) = 0,y(x)],
[6766,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[6767,(2*x+1)*diff(diff(y(x),x),x)-2*diff(y(x),x)+(-2*x-3)*y(x) = 0,y(x)],
[6768,x*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[6769,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[6770,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(-16*x^2+3)*y(x) = 0,y(x)],
[6771,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2+3)*y(x) = 0,y(x)],
[6772,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(-x^2+2)*y(x) = 0,y(x)],
[6773,x^2*diff(diff(y(x),x),x)+(-2*x^2-2*x)*diff(y(x),x)+(x^2+2*x+2)*y(x) = 0,y(x)],
[6774,x^2*diff(diff(y(x),x),x)+(-2*x^2-4*x)*diff(y(x),x)+(x^2+4*x+6)*y(x) = 0,y(x)],
[6775,x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(x^2+6)*y(x) = 0,y(x)],
[6776,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[6777,4*x^2*diff(diff(y(x),x),x)+(-4*x^2-4*x)*diff(y(x),x)+(2*x+3)*y(x) = 0,y(x)],
[6778,(3*x-1)*diff(diff(y(x),x),x)+(-3*x-2)*diff(y(x),x)+(-6*x+8)*y(x) = 0,y(x)],
[6779,(x+2)*diff(diff(y(x),x),x)+x*diff(y(x),x)+3*y(x) = 0,y(x)],
[6780,(-x^3+x^2)*diff(diff(y(x),x),x)+(x^2+4*x)*diff(y(x),x)+(-x+2)*y(x) = 0,y(x)],
[6781,(x^3+x^2)*diff(diff(y(x),x),x)+(2*x^2+x)*diff(y(x),x)+(-6*x-4)*y(x) = 0,y(x)],
[6782,(2*x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3+4*x)*diff(y(x),x)+(-2*x^2+2)*y(x) = 0,y(x)],
[6783,(x^4+2*x^2)*diff(diff(y(x),x),x)+(2*x^3+10*x)*diff(y(x),x)+(-2*x^2+6)*y(x) = 0,y(x)],
[6784,(x^2+1)*diff(diff(y(x),x),x)+6*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[6785,(x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[6786,(x^2+1)*diff(diff(y(x),x),x)-8*x*diff(y(x),x)+20*y(x) = 0,y(x)],
[6787,(-x^2+1)*diff(diff(y(x),x),x)-8*x*diff(y(x),x)-12*y(x) = 0,y(x)],
[6788,(2*x^2+1)*diff(diff(y(x),x),x)+7*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6789,(-x^2+1)*diff(diff(y(x),x),x)-5*x*diff(y(x),x)-4*y(x) = 0,y(x)],
[6790,(x^2+1)*diff(diff(y(x),x),x)-10*x*diff(y(x),x)+28*y(x) = 0,y(x)],
[6791,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6792,(2*x^2+1)*diff(diff(y(x),x),x)-9*x*diff(y(x),x)-6*y(x) = 0,y(x)],
[6793,(2*x^2-8*x+11)*diff(diff(y(x),x),x)+(-16*x+32)*diff(y(x),x)+36*y(x) = 0,y(x)],
[6794,diff(diff(y(x),x),x)+(x-3)*diff(y(x),x)+3*y(x) = 0,y(x)],
[6795,(x^2-8*x+14)*diff(diff(y(x),x),x)+(-8*x+32)*diff(y(x),x)+20*y(x) = 0,y(x)],
[6796,(2*x^2+4*x+5)*diff(diff(y(x),x),x)+(-20*x-20)*diff(y(x),x)+60*y(x) = 0,y(x)],
[6797,(x^3+1)*diff(diff(y(x),x),x)+7*x^2*diff(y(x),x)+9*x*y(x) = 0,y(x)],
[6799,diff(diff(y(x),x),x)+x^6*diff(y(x),x)+7*x^5*y(x) = 0,y(x)],
[6801,diff(diff(y(x),x),x)+x^5*diff(y(x),x)+6*x^4*y(x) = 0,y(x)],
[6802,(3*x+1)*diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6803,(3*x^2+x+1)*diff(diff(y(x),x),x)+(2+15*x)*diff(y(x),x)+12*y(x) = 0,y(x)],
[6804,(x+2)*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)+3*y(x) = 0,y(x)],
[6805,(4+x)*diff(diff(y(x),x),x)+(x+2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[6806,(2*x^2+3*x)*diff(diff(y(x),x),x)+(10*x+10)*diff(y(x),x)+8*y(x) = 0,y(x)],
[6807,x^2*diff(diff(y(x),x),x)+(-6+7*x)*diff(y(x),x)+8*y(x) = 0,y(x)],
[6808,(2*x^2+x+1)*diff(diff(y(x),x),x)+(1+7*x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[6809,(x+3)*diff(diff(y(x),x),x)+(2*x+1)*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[6810,diff(diff(y(x),x),x)+3*x*diff(y(x),x)+(2*x^2+4)*y(x) = 0,y(x)],
[6811,(2+4*x)*diff(diff(y(x),x),x)-4*diff(y(x),x)+(-4*x-6)*y(x) = 0,y(x)],
[6812,diff(diff(y(x),x),x)-3*x*diff(y(x),x)+(2*x^2+5)*y(x) = 0,y(x)],
[6813,2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)+(2*x^2+4)*y(x) = 0,y(x)],
[6814,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[6815,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[6817,3*x^2*diff(diff(y(x),x),x)+(-4*x^3+2*x^2+2*x)*diff(y(x),x)+(-8*x^2+2*x)*y(x) = 0,y(x)],
[6818,(12*x^3+12*x^2)*diff(diff(y(x),x),x)+(3*x^3+35*x^2+11*x)*diff(y(x),x)+(5*x^2+10*x-1)*y(x) = 0,y(x)],
[6819,(10*x^4+x^3+5*x^2)*diff(diff(y(x),x),x)+(48*x^3+3*x^2+4*x)*diff(y(x),x)+(36*x^2+x)*y(x) = 0,y(x)],
[6820,(18*x^3+18*x^2)*diff(diff(y(x),x),x)+(3*x^3+33*x^2+15*x)*diff(y(x),x)+(5*x^2+2*x-1)*y(x) = 0,y(x)],
[6821,2*x^2*diff(diff(y(x),x),x)+(2*x^2+3*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[6822,2*x^2*diff(diff(y(x),x),x)+(x^2+5*x)*diff(y(x),x)+(3*x-2)*y(x) = 0,y(x)],
[6823,3*x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)-y(x) = 0,y(x)],
[6824,2*x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+(1-2*x)*y(x) = 0,y(x)],
[6825,3*x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(-3*x-1)*y(x) = 0,y(x)],
[6826,(2*x^3+6*x^2)*diff(diff(y(x),x),x)+(5*x^2+x)*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[6827,(x^3+4*x^2)*diff(diff(y(x),x),x)+(3*x^2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[6828,2*x^2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[6829,6*x^2*diff(diff(y(x),x),x)+(-x^2+10*x)*diff(y(x),x)+(-2-x)*y(x) = 0,y(x)],
[6830,(4*x^3+3*x^2)*diff(diff(y(x),x),x)+(4*x^2+11*x)*diff(y(x),x)+(-4*x-3)*y(x) = 0,y(x)],
[6831,(6*x^3+4*x^2)*diff(diff(y(x),x),x)+(11*x^2+4*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[6832,(x^3+2*x^2)*diff(diff(y(x),x),x)+(-5*x^2+5*x)*diff(y(x),x)+(8*x-2)*y(x) = 0,y(x)],
[6833,(-8*x^4+8*x^2)*diff(diff(y(x),x),x)+(-26*x^3+2*x)*diff(y(x),x)+(-9*x^2+1)*y(x) = 0,y(x)],
[6834,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3-4*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6835,(x^3+3*x)*diff(diff(y(x),x),x)+(-x^2+2)*diff(y(x),x)-8*x*y(x) = 0,y(x)],
[6836,(-4*x^4+4*x^2)*diff(diff(y(x),x),x)+(-19*x^3+7*x)*diff(y(x),x)+(-14*x^2-1)*y(x) = 0,y(x)],
[6837,(-3*x^4+6*x^2)*diff(diff(y(x),x),x)+(-11*x^3+x)*diff(y(x),x)+(-5*x^2+1)*y(x) = 0,y(x)],
[6838,(2*x^4+4*x^2)*diff(diff(y(x),x),x)+(7*x^3-12*x)*diff(y(x),x)+(3*x^2+7)*y(x) = 0,y(x)],
[6839,(2*x^4+4*x^2)*diff(diff(y(x),x),x)+(7*x^3+4*x)*diff(y(x),x)+(3*x^2-1)*y(x) = 0,y(x)],
[6840,(4*x^4+2*x^2)*diff(diff(y(x),x),x)+(30*x^3+5*x)*diff(y(x),x)+(40*x^2-2)*y(x) = 0,y(x)],
[6841,(x^3+x)*diff(diff(y(x),x),x)+(7*x^2+4)*diff(y(x),x)+8*x*y(x) = 0,y(x)],
[6842,(2*x^4+2*x^2)*diff(diff(y(x),x),x)+(8*x^3+3*x)*diff(y(x),x)+(4*x^2-3)*y(x) = 0,y(x)],
[6843,9*x^2*diff(diff(y(x),x),x)+(3*x^3+9*x)*diff(y(x),x)+(5*x^2-1)*y(x) = 0,y(x)],
[6844,6*x^2*diff(diff(y(x),x),x)+(6*x^3+x)*diff(y(x),x)+(9*x^2+1)*y(x) = 0,y(x)],
[6845,(9*x^4+9*x^2)*diff(diff(y(x),x),x)+(39*x^3+9*x)*diff(y(x),x)+(25*x^2-1)*y(x) = 0,y(x)],
[6846,(4*x^4+4*x^2)*diff(diff(y(x),x),x)+(24*x^3+4*x)*diff(y(x),x)+(25*x^2-1)*y(x) = 0,y(x)],
[6847,(16*x^4+8*x^2)*diff(diff(y(x),x),x)+(68*x^3+10*x)*diff(y(x),x)+(30*x^2-1)*y(x) = 0,y(x)],
[6848,(2*x^3+2*x^2)*diff(diff(y(x),x),x)+(3*x^2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[6849,(12*x^4+6*x^2)*diff(diff(y(x),x),x)+(50*x^3+x)*diff(y(x),x)+(30*x^2+1)*y(x) = 0,y(x)],
[6850,(-84*x^3+28*x^2)*diff(diff(y(x),x),x)+(-63*x^2-35*x)*diff(y(x),x)+(63*x+14)*y(x) = 0,y(x)],
[6851,(-8*x^4+16*x^2)*diff(diff(y(x),x),x)+(-42*x^3+20*x)*diff(y(x),x)+(-35*x^2-2)*y(x) = 0,y(x)],
[6852,(4*x^4+12*x^3+4*x^2)*diff(diff(y(x),x),x)+(12*x^3+12*x^2-4*x)*diff(y(x),x)+(3*x^2-3*x+3)*y(x) = 0,y(x)],
[6853,(3*x^4+6*x^3+3*x^2)*diff(diff(y(x),x),x)+(11*x^3+10*x^2-x)*diff(y(x),x)+(5*x^2+1)*y(x) = 0,y(x)],
[6854,(4*x^4+8*x^3+12*x^2)*diff(diff(y(x),x),x)+(15*x^3+14*x^2-3*x)*diff(y(x),x)+(7*x^2+3)*y(x) = 0,y(x)],
[6855,(x^4-2*x^3+x^2)*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+(4+x)*y(x) = 0,y(x)],
[6856,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+5*x^2*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[6857,(-x^4+2*x^2)*diff(diff(y(x),x),x)+(-4*x^3-2*x)*diff(y(x),x)+(-2*x^2+2)*y(x) = 0,y(x)],
[6858,x^2*diff(diff(y(x),x),x)+(x^2-5*x)*diff(y(x),x)+(9-4*x)*y(x) = 0,y(x)],
[6859,(4*x^4+4*x^3+4*x^2)*diff(diff(y(x),x),x)+(12*x^3+12*x^2)*diff(y(x),x)+(3*x^2+3*x+1)*y(x) = 0,y(x)],
[6860,(x^4+x^3+x^2)*diff(diff(y(x),x),x)+(2*x^3+4*x^2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[6861,9*x^2*diff(diff(y(x),x),x)+(-6*x^3+9*x^2+15*x)*diff(y(x),x)+(-14*x^2+12*x+1)*y(x) = 0,y(x)],
[6862,(2*x^3+x^2)*diff(diff(y(x),x),x)+(3*x^3+14*x^2+5*x)*diff(y(x),x)+(12*x^2+18*x+4)*y(x) = 0,y(x)],
[6863,16*x^2*diff(diff(y(x),x),x)+(8*x^3+4*x^2+24*x)*diff(y(x),x)+(18*x^2+5*x+1)*y(x) = 0,y(x)],
[6864,(9*x^3+9*x^2)*diff(diff(y(x),x),x)+(-3*x^3+33*x^2+15*x)*diff(y(x),x)+(-7*x^2+16*x+1)*y(x) = 0,y(x)],
[6865,(-72*x^3+36*x^2)*diff(diff(y(x),x),x)+(-216*x^2+24*x)*diff(y(x),x)+(1-70*x)*y(x) = 0,y(x)],
[6866,(x^3+x^2)*diff(diff(y(x),x),x)+(x^2-3*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6867,(-2*x^3+x^2)*diff(diff(y(x),x),x)+(4*x^2-5*x)*diff(y(x),x)+(9-4*x)*y(x) = 0,y(x)],
[6868,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+(1-x)*y(x) = 0,y(x)],
[6869,(2*x^3+2*x^2)*diff(diff(y(x),x),x)+(x^2-6*x)*diff(y(x),x)+(8-x)*y(x) = 0,y(x)],
[6870,(2*x^3+x^2)*diff(diff(y(x),x),x)+(9*x^2+5*x)*diff(y(x),x)+(4+3*x)*y(x) = 0,y(x)],
[6871,(-2*x^3+x^2)*diff(diff(y(x),x),x)+(-4*x^2-5*x)*diff(y(x),x)+(9+4*x)*y(x) = 0,y(x)],
[6872,(-x^3+x^2)*diff(diff(y(x),x),x)+(x^2+7*x)*diff(y(x),x)+(9-x)*y(x) = 0,y(x)],
[6873,x^2*diff(diff(y(x),x),x)+(x^3-x)*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[6874,(x^4+x^2)*diff(diff(y(x),x),x)+(3*x^3-3*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6875,4*x^2*diff(diff(y(x),x),x)+2*x^3*diff(y(x),x)+(3*x^2+1)*y(x) = 0,y(x)],
[6876,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3-x)*diff(y(x),x)+y(x) = 0,y(x)],
[6877,(2*x^4+4*x^2)*diff(diff(y(x),x),x)+7*x^3*diff(y(x),x)+(3*x^2+1)*y(x) = 0,y(x)],
[6878,(x^4+x^2)*diff(diff(y(x),x),x)+(4*x^3-x)*diff(y(x),x)+(2*x^2+1)*y(x) = 0,y(x)],
[6879,(4*x^4+16*x^2)*diff(diff(y(x),x),x)+(9*x^3+24*x)*diff(y(x),x)+(-9*x^2+1)*y(x) = 0,y(x)],
[6880,(3*x^4+9*x^2)*diff(diff(y(x),x),x)+(11*x^3+3*x)*diff(y(x),x)+(5*x^2+1)*y(x) = 0,y(x)],
[6881,9*x^2*diff(diff(y(x),x),x)+(6*x^3-21*x)*diff(y(x),x)+(2*x^2+25)*y(x) = 0,y(x)],
[6882,x^2*diff(diff(y(x),x),x)+(x^3-x)*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[6883,(-2*x^3+x^2)*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+(4*x+1)*y(x) = 0,y(x)],
[6884,(x^2+x)*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)+y(x) = 0,y(x)],
[6885,(-x^3+x^2)*diff(diff(y(x),x),x)+(5*x^2-3*x)*diff(y(x),x)+(4-5*x)*y(x) = 0,y(x)],
[6886,(x^4+x^2)*diff(diff(y(x),x),x)+(-9*x^3-x)*diff(y(x),x)+(25*x^2+1)*y(x) = 0,y(x)],
[6887,9*x^2*diff(diff(y(x),x),x)+(-3*x^3+3*x)*diff(y(x),x)+(7*x^2+1)*y(x) = 0,y(x)],
[6888,(x^3+x)*diff(diff(y(x),x),x)+(-x^2+1)*diff(y(x),x)-8*x*y(x) = 0,y(x)],
[6889,4*x^2*diff(diff(y(x),x),x)+(-2*x^3+8*x)*diff(y(x),x)+(7*x^2+1)*y(x) = 0,y(x)],
[6890,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+8*x^2*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[6891,(9*x^3+27*x^2)*diff(diff(y(x),x),x)+(21*x^2+9*x)*diff(y(x),x)+(3+4*x)*y(x) = 0,y(x)],
[6892,(-x^4+2*x^2)*diff(diff(y(x),x),x)+(-3*x^3-2*x)*diff(y(x),x)+(-x^2+2)*y(x) = 0,y(x)],
[6893,(16*x^4+16*x^2)*diff(diff(y(x),x),x)+(72*x^3+8*x)*diff(y(x),x)+(49*x^2+1)*y(x) = 0,y(x)],
[6894,(3*x^3+4*x^2)*diff(diff(y(x),x),x)+(3*x^2-4*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6895,(4*x^4+12*x^3+4*x^2)*diff(diff(y(x),x),x)+(16*x^3+24*x^2)*diff(y(x),x)+(9*x^2+3*x+1)*y(x) = 0,y(x)],
[6896,(x^4-2*x^3+x^2)*diff(diff(y(x),x),x)+(3*x^3-2*x^2-x)*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[6897,(9*x^4+9*x^3+9*x^2)*diff(diff(y(x),x),x)+(39*x^3+21*x^2+3*x)*diff(y(x),x)+(25*x^2+4*x+1)*y(x) = 0,y(x)],
[6898,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+(7*x^2-4*x)*diff(y(x),x)+(3*x-5)*y(x) = 0,y(x)],
[6899,(-2*x^3+x^2)*diff(diff(y(x),x),x)+(-9*x^2+8*x)*diff(y(x),x)+(6-3*x)*y(x) = 0,y(x)],
[6900,(x^4+x^2)*diff(diff(y(x),x),x)+(10*x^3+3*x)*diff(y(x),x)+(14*x^2-15)*y(x) = 0,y(x)],
[6901,(-2*x^4+x^2)*diff(diff(y(x),x),x)+(-13*x^3+7*x)*diff(y(x),x)-14*x^2*y(x) = 0,y(x)],
[6902,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+(8*x^2+4*x)*diff(y(x),x)+(-3*x-1)*y(x) = 0,y(x)],
[6903,(6*x^3+4*x^2)*diff(diff(y(x),x),x)+(21*x^2+4*x)*diff(y(x),x)+(9*x-1)*y(x) = 0,y(x)],
[6904,x^2*diff(diff(y(x),x),x)+(x^2+2*x)*diff(y(x),x)+(3*x-2)*y(x) = 0,y(x)],
[6905,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+(32*x^2+12*x)*diff(y(x),x)+(49*x-5)*y(x) = 0,y(x)],
[6906,(x^3+x^2)*diff(diff(y(x),x),x)+(-10*x^2-3*x)*diff(y(x),x)+30*x*y(x) = 0,y(x)],
[6907,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(-3*x-9)*y(x) = 0,y(x)],
[6908,(2*x^3+x^2)*diff(diff(y(x),x),x)+(13*x^2+9*x)*diff(y(x),x)+(7+5*x)*y(x) = 0,y(x)],
[6909,(8*x^3+4*x^2)*diff(diff(y(x),x),x)+(2*x^2-8*x)*diff(y(x),x)+(-5*x-7)*y(x) = 0,y(x)],
[6910,(3*x^3+9*x^2)*diff(diff(y(x),x),x)+(-x^2-15*x)*diff(y(x),x)-20*y(x) = 0,y(x)],
[6911,(x^3+x^2)*diff(diff(y(x),x),x)+(-10*x^2+x)*diff(y(x),x)+(10*x-9)*y(x) = 0,y(x)],
[6912,(x^3+x^2)*diff(diff(y(x),x),x)+3*x^2*diff(y(x),x)+(x-6)*y(x) = 0,y(x)],
[6913,(2*x^3+x^2)*diff(diff(y(x),x),x)+(-28*x^2-6*x)*diff(y(x),x)+(6+100*x)*y(x) = 0,y(x)],
[6914,(x^3+x^2)*diff(diff(y(x),x),x)+(-11*x^2-6*x)*diff(y(x),x)+(6+32*x)*y(x) = 0,y(x)],
[6915,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+(16*x^2+4*x)*diff(y(x),x)+(-27*x-49)*y(x) = 0,y(x)],
[6916,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3-7*x)*diff(y(x),x)+12*y(x) = 0,y(x)],
[6917,x^2*diff(diff(y(x),x),x)+(x^3-7*x)*diff(y(x),x)+12*y(x) = 0,y(x)],
[6918,x^2*diff(diff(y(x),x),x)+(2*x^3+x)*diff(y(x),x)+(10*x^2-1)*y(x) = 0,y(x)],
[6919,x^2*diff(diff(y(x),x),x)+(-2*x^3+x)*diff(y(x),x)+(-8*x^2-4)*y(x) = 0,y(x)],
[6920,x^2*diff(diff(y(x),x),x)+(-3*x^3+x)*diff(y(x),x)+(12*x^2-4)*y(x) = 0,y(x)],
[6921,(x^4+x^2)*diff(diff(y(x),x),x)+(11*x^3+5*x)*diff(y(x),x)+24*x^2*y(x) = 0,y(x)],
[6922,(4*x^4+4*x^2)*diff(diff(y(x),x),x)+8*x*diff(y(x),x)+(x^2-35)*y(x) = 0,y(x)],
[6923,(x^4+x^2)*diff(diff(y(x),x),x)+(x^3-5*x)*diff(y(x),x)+(-25*x^2-7)*y(x) = 0,y(x)],
[6924,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3+5*x)*diff(y(x),x)-21*y(x) = 0,y(x)],
[6925,(4*x^4+4*x^2)*diff(diff(y(x),x),x)+(4*x^3+8*x)*diff(y(x),x)+(-x^2-15)*y(x) = 0,y(x)],
[6926,diff(diff(y(t),t),t)+(-2/(t^2+2*t-1)*t-2/(t^2+2*t-1))*diff(y(t),t)+2/(t^2+2*t-1)*y(t) = 0,y(t)],
[6927,diff(diff(y(t),t),t)-4*t*diff(y(t),t)+(4*t^2-2)*y(t) = 0,y(t)],
[6928,(-t^2+1)*diff(diff(y(t),t),t)-2*t*diff(y(t),t)+2*y(t) = 0,y(t)],
[6929,(t^2+1)*diff(diff(y(t),t),t)-2*t*diff(y(t),t)+2*y(t) = 0,y(t)],
[6930,(-t^2+1)*diff(diff(y(t),t),t)-2*t*diff(y(t),t)+6*y(t) = 0,y(t)],
[6931,(2*t+1)*diff(diff(y(t),t),t)+(-4*t-4)*diff(y(t),t)+4*y(t) = 0,y(t)],
[6932,t^2*diff(diff(y(t),t),t)+t*diff(y(t),t)+(t^2-1/4)*y(t) = 0,y(t)],
[6933,diff(diff(y(t),t),t)-2*t/(t^2+1)*diff(y(t),t)+2/(t^2+1)*y(t) = 0,y(t)],
[6935,2*t*diff(diff(y(t),t),t)+(1-2*t)*diff(y(t),t)-y(t) = 0,y(t)],
[6936,2*t*diff(diff(y(t),t),t)+(t+1)*diff(y(t),t)-2*y(t) = 0,y(t)],
[6937,2*t^2*diff(diff(y(t),t),t)-t*diff(y(t),t)+(t+1)*y(t) = 0,y(t)],
[6938,2*t^2*diff(diff(y(t),t),t)+(t^2-t)*diff(y(t),t)+y(t) = 0,y(t)],
[6939,t^2*diff(diff(y(t),t),t)+(-t^2+t)*diff(y(t),t)-y(t) = 0,y(t)],
[6940,t*diff(diff(y(t),t),t)+(-t^2-2)*diff(y(t),t)+t*y(t) = 0,y(t)],
[6941,t^2*diff(diff(y(t),t),t)+(t^2+t)*diff(y(t),t)-y(t) = 0,y(t)],
[6942,t*diff(diff(y(t),t),t)+(-4-t)*diff(y(t),t)+2*y(t) = 0,y(t)],
[6943,t^2*diff(diff(y(t),t),t)+(t^2-3*t)*diff(y(t),t)+3*y(t) = 0,y(t)],
[6944,t*diff(diff(y(t),t),t)+t*diff(y(t),t)+2*y(t) = 0,y(t)],
[6945,t*diff(diff(y(t),t),t)+(-t^2+1)*diff(y(t),t)+4*t*y(t) = 0,y(t)],
[6946,t^2*diff(diff(y(t),t),t)+(-t^2-t)*diff(y(t),t)+y(t) = 0,y(t)],
[6947,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+6)*y(x) = 0,y(x)],
[6949,4*z*diff(diff(y(z),z),z)+(-2*z+2)*diff(y(z),z)-y(z) = 0,y(z)],
[6950,diff(diff(f(z),z),z)+(2*z-2)*diff(f(z),z)+4*f(z) = 0,f(z)],
[6951,z*diff(diff(y(z),z),z)-2*diff(y(z),z)+z*y(z) = 0,y(z)],
[6952,z*diff(diff(y(z),z),z)+(2*z-3)*diff(y(z),z)+4/z*y(z) = 0,y(z)],
[6953,diff(diff(y(x),x),x)+2*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[6954,diff(diff(y(x),x),x)+x*diff(y(x),x)+3*y(x) = 0,y(x)],
[6955,diff(diff(y(x),x),x)-x^2*diff(y(x),x)-3*x*y(x) = 0,y(x)],
[6956,(-4*x^2+1)*diff(diff(y(x),x),x)-20*x*diff(y(x),x)-16*y(x) = 0,y(x)],
[6957,(x^2-1)*diff(diff(y(x),x),x)-6*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[6958,diff(diff(y(x),x),x)+x*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[6959,(2*x^2+1)*diff(diff(y(x),x),x)+7*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6960,4*diff(diff(y(x),x),x)+x*diff(y(x),x)+4*y(x) = 0,y(x)],
[6961,diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[6962,4*x*diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6963,6*x^2*diff(diff(y(x),x),x)+(18*x^2+x)*diff(y(x),x)+(1+12*x)*y(x) = 0,y(x)],
[6964,3*x^2*diff(diff(y(x),x),x)+(-x^2-8*x)*diff(y(x),x)+6*y(x) = 0,y(x)],
[6965,2*x^2*diff(diff(y(x),x),x)+(-2*x^2-x)*diff(y(x),x)+(8*x-2)*y(x) = 0,y(x)],
[6966,4*x^2*diff(diff(y(x),x),x)-4*x^2*diff(y(x),x)+(2*x+1)*y(x) = 0,y(x)],
[6967,x^2*diff(diff(y(x),x),x)+(-2*x^2+3*x)*diff(y(x),x)+(1-2*x)*y(x) = 0,y(x)],
[6968,x^2*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+(4-x)*y(x) = 0,y(x)],
[6969,x^2*diff(diff(y(x),x),x)+(-x^2+3*x)*diff(y(x),x)+y(x) = 0,y(x)],
[6970,x^2*diff(diff(y(x),x),x)+(-2*x*5^(1/2)+x)*diff(y(x),x)+(19/4-3*x^2)*y(x) = 0,y(x)],
[6971,x^2*diff(diff(y(x),x),x)+(x^2-3*x)*diff(y(x),x)+(4-x)*y(x) = 0,y(x)],
[6972,x^2*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+(-2-x)*y(x) = 0,y(x)],
[6973,x^2*diff(diff(y(x),x),x)+2*x^2*diff(y(x),x)+(x-3/4)*y(x) = 0,y(x)],
[6974,(x^3+x^2)*diff(diff(y(x),x),x)+x^2*diff(y(x),x)-2*y(x) = 0,y(x)],
[6975,x^2*diff(diff(y(x),x),x)+(x^3+6*x)*diff(y(x),x)+6*y(x) = 0,y(x)],
[6976,x^2*diff(diff(y(x),x),x)+(-x^2+x)*diff(y(x),x)-y(x) = 0,y(x)],
[6977,x^2*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6978,x^2*diff(diff(y(x),x),x)-x^2*diff(y(x),x)-2*y(x) = 0,y(x)],
[6979,x^2*diff(diff(y(x),x),x)-x^2*diff(y(x),x)+(-3*x-2)*y(x) = 0,y(x)],
[6980,x^2*diff(diff(y(x),x),x)+(-x^2+5*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6981,4*x^2*diff(diff(y(x),x),x)+(-4*x^2+4*x)*diff(y(x),x)+(2*x-9)*y(x) = 0,y(x)],
[6982,x^2*diff(diff(y(x),x),x)+(2*x^2+4*x)*diff(y(x),x)+(2*x+2)*y(x) = 0,y(x)],
[6983,x^2*diff(diff(y(x),x),x)+(x^2-x)*diff(y(x),x)+(1-x)*y(x) = 0,y(x)],
[6984,4*x^2*diff(diff(y(x),x),x)+(8*x^2+4*x)*diff(y(x),x)+(-1+4*x)*y(x) = 0,y(x)],
[6985,x^2*diff(diff(y(x),x),x)+(x^2+4*x)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[6986,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-9/4)*y(x) = 0,y(x)],
[6987,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[6988,2*x*diff(diff(y(x),x),x)+(-10*x+5)*diff(y(x),x)-5*y(x) = 0,y(x)],
[6989,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[6991,x^4*diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[6992,x^2*diff(diff(y(x),x),x)+(2*x^2+x)*diff(y(x),x)-4*y(x) = 0,y(x)],
[6993,(4*x^3-14*x^2-2*x)*diff(diff(y(x),x),x)+(-6*x^2+7*x-1)*diff(y(x),x)+(6*x-1)*y(x) = 0,y(x)],
[6994,x^2*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[6995,x^2*diff(diff(y(x),x),x)-x^2*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[6996,(-4*x^3+x^2)*diff(diff(y(x),x),x)-1/2*x*diff(y(x),x)-3/4*x*y(x) = 0,y(x)],
[6997,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(x-9)*y(x) = 0,y(x)],
[6998,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(3*x-1)*y(x) = 0,y(x)],
[6999,x^2*diff(diff(y(x),x),x)+(-x^2-4*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[7000,2*x^2*diff(diff(y(x),x),x)+(-3*x-2)*diff(y(x),x)+(2-1/x)*y(x) = 0,y(x)],
[7001,(-x^2+x)*diff(diff(y(x),x),x)+(3/2-2*x)*diff(y(x),x)-1/4*y(x) = 0,y(x)],
[7002,(-2*x^2+2*x)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[7003,(-2*x^2+2*x)*diff(diff(y(x),x),x)+(-11*x+1)*diff(y(x),x)-10*y(x) = 0,y(x)],
[7004,(-x^2+x)*diff(diff(y(x),x),x)+(-2/3*x+1/3)*diff(y(x),x)+20/9*y(x) = 0,y(x)],
[7005,4*diff(diff(y(x),x),x)+(-3/(-x^2+1)^2*x^2+6/(-x^2+1)^2)*y(x) = 0,y(x)],
[7013,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(-x^2-1/4)*y(x) = 0,y(x)],
[7015,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-25/4)*y(x) = 0,y(x)],
[7016,diff(diff(y(x),x),x)+q*diff(y(x),x)-2*y(x)/x^2 = 0,y(x)],
[7017,x*diff(diff(y(x),x),x)+3*diff(y(x),x)+4*x^3*y(x) = 0,y(x)],
[7018,(x^2+2*x)*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[7019,(x^2+2*x)*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[7020,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7021,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7022,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-2)*y(x) = 0,y(x)],
[7023,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-2)*y(x) = 0,y(x)],
[7024,(2*x-3)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7025,diff(diff(y(x),x),x)-x*diff(y(x),x)-3*y(x) = 0,y(x)],
[7026,(x^2+1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7027,diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7028,(-x^2+1)*diff(diff(y(x),x),x)-diff(y(x),x)+y(x) = 0,y(x)],
[7029,(x^3+2*x^2+x)*diff(diff(y(x),x),x)+(-x^2+1)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[7030,2*x*diff(diff(y(x),x),x)-diff(y(x),x)+2*y(x) = 0,y(x)],
[7031,x*diff(diff(y(x),x),x)+x*diff(y(x),x)-2*y(x) = 0,y(x)],
[7032,(x^3-2*x^2+x)*diff(diff(y(x),x),x)-2*y(x) = 0,y(x)],
[7033,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+x^2*y(x) = 0,y(x)],
[7034,(-x^3+2*x)*diff(diff(y(x),x),x)+(x^3+3*x^2-2*x-2)*diff(y(x),x)+(-x^2-4*x-2)*y(x) = 0,y(x)],
[7035,(x^3+x^2)*diff(diff(y(x),x),x)+(-2*x^2-x)*diff(y(x),x)+(2*x+1)*y(x) = 0,y(x)],
[7036,(-2*x^3+4*x^2)*diff(diff(y(x),x),x)+(x^2-4*x)*diff(y(x),x)+(3-x)*y(x) = 0,y(x)],
[7037,(-x^3+x^2)*diff(diff(y(x),x),x)+(5*x^2-4*x)*diff(y(x),x)+(6-9*x)*y(x) = 0,y(x)],
[7038,x*diff(diff(y(x),x),x)+(4*x^2+1)*diff(y(x),x)+(4*x^3+4*x)*y(x) = 0,y(x)],
[7039,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[7040,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[7041,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[7042,(x^2+2*x)*diff(diff(y(x),x),x)+(2*x+2)*diff(y(x),x)-2*y(x) = 0,y(x)],
[7043,(x^2+2*x)*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)-4*y(x) = 0,y(x)],
[7044,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7045,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7046,(x^2-2*x+10)*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[7047,(x^2-2*x+10)*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[7048,diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7049,(x+2)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[7050,(x^2+1)*diff(diff(y(x),x),x)-6*y(x) = 0,y(x)],
[7051,(x^2+2)*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-y(x) = 0,y(x)],
[7052,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7053,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[7054,x^2*diff(diff(y(x),x),x)+(5/3*x+x^2)*diff(y(x),x)-1/3*y(x) = 0,y(x)],
[7055,2*x*diff(diff(y(x),x),x)-diff(y(x),x)+2*y(x) = 0,y(x)],
[7056,2*x*diff(diff(y(x),x),x)+(-2*x-3)*diff(y(x),x)+y(x) = 0,y(x)],
[7057,2*x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+(2*x-1)*y(x) = 0,y(x)],
[7058,x*diff(diff(y(x),x),x)+2*diff(y(x),x)-x*y(x) = 0,y(x)],
[7059,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7060,x*diff(diff(y(x),x),x)+(x-6)*diff(y(x),x)-3*y(x) = 0,y(x)],
[7062,4*x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2-25)*y(x) = 0,y(x)],
[7063,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(36*x^2-1/4)*y(x) = 0,y(x)],
[7064,x^2*diff(diff(y(x),x),x)+(x^2-2)*y(x) = 0,y(x)],
[7065,x*diff(diff(y(x),x),x)+3*diff(y(x),x)+x^3*y(x) = 0,y(x)],
[7066,x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[7067,16*x^2*diff(diff(y(x),x),x)+32*x*diff(y(x),x)+(x^4-12)*y(x) = 0,y(x)],
[7068,diff(diff(y(x),x),x)-x^2*diff(y(x),x)+x*y(x) = 0,y(x)],
[7069,x*diff(diff(y(x),x),x)+(-2-x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[7070,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7071,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7072,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-2)*y(x) = 0,y(x)],
[7073,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+30*y(x) = 0,y(x)],
[7074,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[7075,x*diff(diff(y(x),x),x)+(2*x+1)*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[7076,(2*x^2-2*x)*diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[7077,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+4*x*y(x) = 0,y(x)],
[7078,x*diff(diff(y(x),x),x)+(-2*x+2)*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[7079,x^2*diff(diff(y(x),x),x)+6*x*diff(y(x),x)+(4*x^2+6)*y(x) = 0,y(x)],
[7080,x*diff(diff(y(x),x),x)+(1-2*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[7081,(-x^2+x)*diff(diff(y(x),x),x)+(1/2+2*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[7082,(4*t^2-12*t+8)*diff(diff(y(t),t),t)-2*diff(y(t),t)+y(t) = 0,y(t)],
[7083,(2*t^2-10*t+12)*diff(diff(y(t),t),t)+(2*t-3)*diff(y(t),t)-8*y(t) = 0,y(t)],
[7084,(3*t^2+3*t)*diff(diff(y(t),t),t)+t*diff(y(t),t)-y(t) = 0,y(t)],
[7085,x^2*diff(diff(y(x),x),x)+(1/4*x+3/16)*y(x) = 0,y(x)],
[7086,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(1/4*x^2-1/4)*y(x) = 0,y(x)],
[7087,x*diff(diff(y(x),x),x)+(1-2*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[7088,x*diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[7089,x*diff(diff(y(x),x),x)+3*diff(y(x),x)+4*x^3*y(x) = 0,y(x)],
[7090,(-x^4+x^2)*diff(diff(y(x),x),x)+(-2*x^3+2*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[7091,2*x*diff(diff(y(x),x),x)+(x-2)*diff(y(x),x)-y(x) = 0,y(x)],
[7092,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[7093,diff(diff(y(x),x),x)+2*x^2*diff(y(x),x)+(x^4+2*x-1)*y(x) = 0,y(x)],
[7094,diff(diff(u(x),x),x)+1/x^2*u(x) = 0,u(x)],
[7095,diff(diff(u(x),x),x)+(-2*x-1)*diff(u(x),x)+(x^2+x-1)*u(x) = 0,u(x)],
[7096,diff(diff(y(x),x),x)+2*diff(y(x),x)+(1+2/(3*x+1)^2)*y(x) = 0,y(x)],
[7097,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[7098,diff(diff(y(x),x),x)+2/x*diff(y(x),x)-2/(x+1)^2*y(x) = 0,y(x)],
[7099,diff(diff(y(x),x),x)+1/2/x^4*y(x) = 0,y(x)],
[7100,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7101,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7102,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7103,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7104,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7105,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7106,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7107,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7108,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7109,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7110,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7111,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[7112,2*x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7113,x^2*diff(diff(y(x),x),x)+(3*x^2+2*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[7115,x*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)+2*y(x) = 0,y(x)],
[7116,(x^4-2*x^3+x^2)*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+(4+x)*y(x) = 0,y(x)],
[7117,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+5*x^2*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[7118,x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[7119,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7120,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+(-x^2-5/4)*y(x) = 0,y(x)],
[7121,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7122,x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+4*x^4*y(x) = 0,y(x)],
[7123,diff(diff(y(x),x),x)+(-x^2-3)*y(x) = 0,y(x)],
[7124,diff(diff(y(x),x),x)+2*x*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[7125,x^3*diff(diff(y(x),x),x)+diff(y(x),x)-1/x*y(x) = 0,y(x)],
[7126,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7127,4*x^2*diff(diff(y(x),x),x)+(-8*x^2+4*x)*diff(y(x),x)+(4*x^2-4*x-1)*y(x) = 0,y(x)],
[7128,diff(diff(y(x),x),x)-diff(y(x),x)+y(x) = 0,y(x)],
[7129,(x^2-1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7130,x^2*diff(diff(y(x),x),x)+(-x^2-2*x)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[7131,(x+1)*diff(diff(y(x),x),x)+(-2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[7132,(-x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[7133,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7134,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7135,(x^2-1)*diff(diff(y(x),x),x)-6*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[7136,(x^2+3)*diff(diff(y(x),x),x)-7*x*diff(y(x),x)+16*y(x) = 0,y(x)],
[7137,(x^2-1)*diff(diff(y(x),x),x)+8*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[7138,3*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[7139,5*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+10*y(x) = 0,y(x)],
[7140,diff(diff(y(x),x),x)-x^2*diff(y(x),x)-3*x*y(x) = 0,y(x)],
[7141,(x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[7142,diff(diff(y(x),x),x)+x*diff(y(x),x)-2*y(x) = 0,y(x)],
[7143,(x^2-6*x+10)*diff(diff(y(x),x),x)+(-4*x+12)*diff(y(x),x)+6*y(x) = 0,y(x)],
[7144,(x^2+6*x)*diff(diff(y(x),x),x)+(3*x+9)*diff(y(x),x)-3*y(x) = 0,y(x)],
[7145,t*diff(diff(y(t),t),t)+(t^2-1)*diff(y(t),t)+t^3*y(t) = 0,y(t)],
[7146,t^2*diff(diff(y(t),t),t)+(-t^2-2*t)*diff(y(t),t)+(t+2)*y(t) = 0,y(t)],
[7147,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7148,x^2*diff(diff(y(x),x),x)+(-x+3/16)*y(x) = 0,y(x)],
[7149,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7150,t^2*diff(diff(y(t),t),t)+(-t^2-2*t)*diff(y(t),t)+(t+2)*y(t) = 0,y(t)],
[7151,t*diff(diff(y(t),t),t)+(-t-1)*diff(y(t),t)+y(t) = 0,y(t)],
[7152,(-t+1)*diff(diff(y(t),t),t)+t*diff(y(t),t)-y(t) = 0,y(t)],
[7153,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7154,t*diff(diff(y(t),t),t)+(-t-1)*diff(y(t),t)+y(t) = 0,y(t)],
[7155,(-t+1)*diff(diff(y(t),t),t)+t*diff(y(t),t)-y(t) = 0,y(t)],
[7156,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7157,(x^2+1)*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[7158,(1-x)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[7159,2*diff(diff(y(x),x),x)+x*diff(y(x),x)+3*y(x) = 0,y(x)],
[7160,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7161,(1-x)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[7162,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7163,(-x^2+4)*diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7164,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(-16*x^2+3)*y(x) = 0,y(x)],
[7165,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7166,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[7167,(x^2-2*x)*diff(diff(y(x),x),x)+(-x^2+2)*diff(y(x),x)+(2*x-2)*y(x) = 0,y(x)],
[7168,(2*x+1)*diff(diff(y(x),x),x)-2*diff(y(x),x)+(-2*x-3)*y(x) = 0,y(x)],
[7169,4*x^2*diff(diff(y(x),x),x)+(-8*x^2+4*x)*diff(y(x),x)+(4*x^2-4*x-1)*y(x) = 0,y(x)],
[7170,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[7171,x^2*diff(diff(y(x),x),x)+(2*x^2-2*x)*diff(y(x),x)+(x^2-2*x+2)*y(x) = 0,y(x)],
[7172,x^2*diff(diff(y(x),x),x)+(-2*x^2+x)*diff(y(x),x)+(x^2-x-1)*y(x) = 0,y(x)],
[7173,(1-2*x)*diff(diff(y(x),x),x)+2*diff(y(x),x)+(2*x-3)*y(x) = 0,y(x)],
[7174,2*x*diff(diff(y(x),x),x)+(4*x+1)*diff(y(x),x)+(2*x+1)*y(x) = 0,y(x)],
[7175,x*diff(diff(y(x),x),x)+(-2*x-1)*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[7176,4*x^2*diff(diff(y(x),x),x)+(-4*x^2-4*x)*diff(y(x),x)+(2*x+3)*y(x) = 0,y(x)],
[7177,x*diff(diff(y(x),x),x)+(-2*x+2)*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[7178,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7179,x*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[7180,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[7181,x*diff(diff(y(x),x),x)+(-4*x-1)*diff(y(x),x)+(2+4*x)*y(x) = 0,y(x)],
[7182,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(-16*x^2+3)*y(x) = 0,y(x)],
[7183,(2*x^2+x)*diff(diff(y(x),x),x)+(-4*x^2+2)*diff(y(x),x)+(-4*x-4)*y(x) = 0,y(x)],
[7184,(x^2-2*x)*diff(diff(y(x),x),x)+(-x^2+2)*diff(y(x),x)+(2*x-2)*y(x) = 0,y(x)],
[7185,x*diff(diff(y(x),x),x)+(-4*x-1)*diff(y(x),x)+(2+4*x)*y(x) = 0,y(x)],
[7186,(3*x-1)*diff(diff(y(x),x),x)+(-3*x-2)*diff(y(x),x)+(-6*x+8)*y(x) = 0,y(x)],
[7187,(x^2+2*x+1)*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+(-x^2-2*x+1)*y(x) = 0,y(x)],
[7188,4*x^2*diff(diff(y(x),x),x)+(-8*x^2+4*x)*diff(y(x),x)+(4*x^2-4*x-1)*y(x) = 0,y(x)],
[7189,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[7190,(2*x+1)*diff(diff(y(x),x),x)-2*diff(y(x),x)+(-2*x-3)*y(x) = 0,y(x)],
[7191,x*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[7192,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[7193,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(-16*x^2+3)*y(x) = 0,y(x)],
[7194,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2+3)*y(x) = 0,y(x)],
[7195,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(-x^2+2)*y(x) = 0,y(x)],
[7196,x^2*diff(diff(y(x),x),x)+(-2*x^2-2*x)*diff(y(x),x)+(x^2+2*x+2)*y(x) = 0,y(x)],
[7197,x^2*diff(diff(y(x),x),x)+(-2*x^2-4*x)*diff(y(x),x)+(x^2+4*x+6)*y(x) = 0,y(x)],
[7198,x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(x^2+6)*y(x) = 0,y(x)],
[7199,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7200,4*x^2*diff(diff(y(x),x),x)+(-4*x^2-4*x)*diff(y(x),x)+(2*x+3)*y(x) = 0,y(x)],
[7201,(3*x-1)*diff(diff(y(x),x),x)+(-3*x-2)*diff(y(x),x)+(-6*x+8)*y(x) = 0,y(x)],
[7202,(x+2)*diff(diff(y(x),x),x)+x*diff(y(x),x)+3*y(x) = 0,y(x)],
[7203,(-x^3+x^2)*diff(diff(y(x),x),x)+(x^2+4*x)*diff(y(x),x)+(-x+2)*y(x) = 0,y(x)],
[7204,(x^3+x^2)*diff(diff(y(x),x),x)+(2*x^2+x)*diff(y(x),x)+(-6*x-4)*y(x) = 0,y(x)],
[7205,(2*x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3+4*x)*diff(y(x),x)+(-2*x^2+2)*y(x) = 0,y(x)],
[7206,(x^4+2*x^2)*diff(diff(y(x),x),x)+(2*x^3+10*x)*diff(y(x),x)+(-2*x^2+6)*y(x) = 0,y(x)],
[7207,(x^2+1)*diff(diff(y(x),x),x)+6*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[7208,(x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[7209,(x^2+1)*diff(diff(y(x),x),x)-8*x*diff(y(x),x)+20*y(x) = 0,y(x)],
[7210,(-x^2+1)*diff(diff(y(x),x),x)-8*x*diff(y(x),x)-12*y(x) = 0,y(x)],
[7211,(2*x^2+1)*diff(diff(y(x),x),x)+7*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7212,(-x^2+1)*diff(diff(y(x),x),x)-5*x*diff(y(x),x)-4*y(x) = 0,y(x)],
[7213,(x^2+1)*diff(diff(y(x),x),x)-10*x*diff(y(x),x)+28*y(x) = 0,y(x)],
[7214,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7215,(2*x^2-8*x+11)*diff(diff(y(x),x),x)+(-16*x+32)*diff(y(x),x)+36*y(x) = 0,y(x)],
[7216,diff(diff(y(x),x),x)+(x-3)*diff(y(x),x)+3*y(x) = 0,y(x)],
[7217,(x^2-8*x+14)*diff(diff(y(x),x),x)+(-8*x+32)*diff(y(x),x)+20*y(x) = 0,y(x)],
[7218,(2*x^2+4*x+5)*diff(diff(y(x),x),x)+(-20*x-20)*diff(y(x),x)+60*y(x) = 0,y(x)],
[7219,(x^3+1)*diff(diff(y(x),x),x)+7*x^2*diff(y(x),x)+9*x*y(x) = 0,y(x)],
[7221,diff(diff(y(x),x),x)+x^6*diff(y(x),x)+7*x^5*y(x) = 0,y(x)],
[7223,diff(diff(y(x),x),x)+x^5*diff(y(x),x)+6*x^4*y(x) = 0,y(x)],
[7224,(3*x+1)*diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7225,(3*x^2+x+1)*diff(diff(y(x),x),x)+(2+15*x)*diff(y(x),x)+12*y(x) = 0,y(x)],
[7226,(x+2)*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)+3*y(x) = 0,y(x)],
[7227,(4+x)*diff(diff(y(x),x),x)+(x+2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[7228,(2*x^2+3*x)*diff(diff(y(x),x),x)+(10*x+10)*diff(y(x),x)+8*y(x) = 0,y(x)],
[7229,x^2*diff(diff(y(x),x),x)+(-6+7*x)*diff(y(x),x)+8*y(x) = 0,y(x)],
[7230,(2*x^2+x+1)*diff(diff(y(x),x),x)+(1+7*x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[7231,(x+3)*diff(diff(y(x),x),x)+(2*x+1)*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[7232,diff(diff(y(x),x),x)+3*x*diff(y(x),x)+(2*x^2+4)*y(x) = 0,y(x)],
[7233,(2+4*x)*diff(diff(y(x),x),x)-4*diff(y(x),x)+(-4*x-6)*y(x) = 0,y(x)],
[7234,diff(diff(y(x),x),x)-3*x*diff(y(x),x)+(2*x^2+5)*y(x) = 0,y(x)],
[7235,2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)+(2*x^2+4)*y(x) = 0,y(x)],
[7236,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[7237,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[7239,3*x^2*diff(diff(y(x),x),x)+(-4*x^3+2*x^2+2*x)*diff(y(x),x)+(-8*x^2+2*x)*y(x) = 0,y(x)],
[7240,(12*x^3+12*x^2)*diff(diff(y(x),x),x)+(3*x^3+35*x^2+11*x)*diff(y(x),x)+(5*x^2+10*x-1)*y(x) = 0,y(x)],
[7241,diff(diff(y(x),x),x)+3*diff(y(x),x)+4*y(x) = 0,y(x)],
[7242,(18*x^3+18*x^2)*diff(diff(y(x),x),x)+(3*x^3+33*x^2+15*x)*diff(y(x),x)+(5*x^2+2*x-1)*y(x) = 0,y(x)],
[7243,2*x^2*diff(diff(y(x),x),x)+(2*x^2+3*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[7244,2*x^2*diff(diff(y(x),x),x)+(x^2+5*x)*diff(y(x),x)+(3*x-2)*y(x) = 0,y(x)],
[7245,3*x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)-y(x) = 0,y(x)],
[7246,2*x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+(1-2*x)*y(x) = 0,y(x)],
[7247,3*x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(-3*x-1)*y(x) = 0,y(x)],
[7248,(2*x^3+6*x^2)*diff(diff(y(x),x),x)+(5*x^2+x)*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[7249,(x^3+4*x^2)*diff(diff(y(x),x),x)+(3*x^2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[7250,2*x^2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[7251,6*x^2*diff(diff(y(x),x),x)+(-x^2+10*x)*diff(y(x),x)+(-2-x)*y(x) = 0,y(x)],
[7252,(4*x^3+3*x^2)*diff(diff(y(x),x),x)+(4*x^2+11*x)*diff(y(x),x)+(-4*x-3)*y(x) = 0,y(x)],
[7253,(6*x^3+4*x^2)*diff(diff(y(x),x),x)+(11*x^2+4*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[7254,(x^3+2*x^2)*diff(diff(y(x),x),x)+(-5*x^2+5*x)*diff(y(x),x)+(8*x-2)*y(x) = 0,y(x)],
[7255,(-8*x^4+8*x^2)*diff(diff(y(x),x),x)+(-26*x^3+2*x)*diff(y(x),x)+(-9*x^2+1)*y(x) = 0,y(x)],
[7256,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3-4*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[7257,(x^3+3*x)*diff(diff(y(x),x),x)+(-x^2+2)*diff(y(x),x)-8*x*y(x) = 0,y(x)],
[7258,(-4*x^4+4*x^2)*diff(diff(y(x),x),x)+(-19*x^3+7*x)*diff(y(x),x)+(-14*x^2-1)*y(x) = 0,y(x)],
[7259,(-3*x^4+6*x^2)*diff(diff(y(x),x),x)+(-11*x^3+x)*diff(y(x),x)+(-5*x^2+1)*y(x) = 0,y(x)],
[7260,(2*x^4+4*x^2)*diff(diff(y(x),x),x)+(7*x^3-12*x)*diff(y(x),x)+(3*x^2+7)*y(x) = 0,y(x)],
[7261,(2*x^4+4*x^2)*diff(diff(y(x),x),x)+(7*x^3+4*x)*diff(y(x),x)+(3*x^2-1)*y(x) = 0,y(x)],
[7262,(4*x^4+2*x^2)*diff(diff(y(x),x),x)+(30*x^3+5*x)*diff(y(x),x)+(40*x^2-2)*y(x) = 0,y(x)],
[7263,(x^3+x)*diff(diff(y(x),x),x)+(7*x^2+4)*diff(y(x),x)+8*x*y(x) = 0,y(x)],
[7264,(2*x^4+2*x^2)*diff(diff(y(x),x),x)+(8*x^3+3*x)*diff(y(x),x)+(4*x^2-3)*y(x) = 0,y(x)],
[7265,9*x^2*diff(diff(y(x),x),x)+(3*x^3+9*x)*diff(y(x),x)+(5*x^2-1)*y(x) = 0,y(x)],
[7266,6*x^2*diff(diff(y(x),x),x)+(6*x^3+x)*diff(y(x),x)+(9*x^2+1)*y(x) = 0,y(x)],
[7267,(9*x^4+9*x^2)*diff(diff(y(x),x),x)+(39*x^3+9*x)*diff(y(x),x)+(25*x^2-1)*y(x) = 0,y(x)],
[7268,(4*x^4+4*x^2)*diff(diff(y(x),x),x)+(24*x^3+4*x)*diff(y(x),x)+(25*x^2-1)*y(x) = 0,y(x)],
[7269,(16*x^4+8*x^2)*diff(diff(y(x),x),x)+(68*x^3+10*x)*diff(y(x),x)+(30*x^2-1)*y(x) = 0,y(x)],
[7270,(2*x^3+2*x^2)*diff(diff(y(x),x),x)+(3*x^2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[7271,(12*x^4+6*x^2)*diff(diff(y(x),x),x)+(50*x^3+x)*diff(y(x),x)+(30*x^2+1)*y(x) = 0,y(x)],
[7272,(-84*x^3+28*x^2)*diff(diff(y(x),x),x)+(-63*x^2-35*x)*diff(y(x),x)+(63*x+14)*y(x) = 0,y(x)],
[7273,(-8*x^4+16*x^2)*diff(diff(y(x),x),x)+(-42*x^3+20*x)*diff(y(x),x)+(-35*x^2-2)*y(x) = 0,y(x)],
[7274,(4*x^4+12*x^3+4*x^2)*diff(diff(y(x),x),x)+(12*x^3+12*x^2-4*x)*diff(y(x),x)+(3*x^2-3*x+3)*y(x) = 0,y(x)],
[7275,(3*x^4+6*x^3+3*x^2)*diff(diff(y(x),x),x)+(11*x^3+10*x^2-x)*diff(y(x),x)+(5*x^2+1)*y(x) = 0,y(x)],
[7276,(4*x^4+8*x^3+12*x^2)*diff(diff(y(x),x),x)+(15*x^3+14*x^2-3*x)*diff(y(x),x)+(7*x^2+3)*y(x) = 0,y(x)],
[7277,(x^4-2*x^3+x^2)*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+(4+x)*y(x) = 0,y(x)],
[7278,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+5*x^2*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[7279,(-x^4+2*x^2)*diff(diff(y(x),x),x)+(-4*x^3-2*x)*diff(y(x),x)+(-2*x^2+2)*y(x) = 0,y(x)],
[7280,x^2*diff(diff(y(x),x),x)+(x^2-5*x)*diff(y(x),x)+(9-4*x)*y(x) = 0,y(x)],
[7281,(4*x^4+4*x^3+4*x^2)*diff(diff(y(x),x),x)+(12*x^3+12*x^2)*diff(y(x),x)+(3*x^2+3*x+1)*y(x) = 0,y(x)],
[7282,(x^4+x^3+x^2)*diff(diff(y(x),x),x)+(2*x^3+4*x^2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[7283,9*x^2*diff(diff(y(x),x),x)+(-6*x^3+9*x^2+15*x)*diff(y(x),x)+(-14*x^2+12*x+1)*y(x) = 0,y(x)],
[7284,(2*x^3+x^2)*diff(diff(y(x),x),x)+(3*x^3+14*x^2+5*x)*diff(y(x),x)+(12*x^2+18*x+4)*y(x) = 0,y(x)],
[7285,16*x^2*diff(diff(y(x),x),x)+(8*x^3+4*x^2+24*x)*diff(y(x),x)+(18*x^2+5*x+1)*y(x) = 0,y(x)],
[7286,(9*x^3+9*x^2)*diff(diff(y(x),x),x)+(-3*x^3+33*x^2+15*x)*diff(y(x),x)+(-7*x^2+16*x+1)*y(x) = 0,y(x)],
[7287,(-72*x^3+36*x^2)*diff(diff(y(x),x),x)+(-216*x^2+24*x)*diff(y(x),x)+(1-70*x)*y(x) = 0,y(x)],
[7288,(x^3+x^2)*diff(diff(y(x),x),x)+(x^2-3*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[7289,(-2*x^3+x^2)*diff(diff(y(x),x),x)+(4*x^2-5*x)*diff(y(x),x)+(9-4*x)*y(x) = 0,y(x)],
[7290,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+(1-x)*y(x) = 0,y(x)],
[7291,(2*x^3+2*x^2)*diff(diff(y(x),x),x)+(x^2-6*x)*diff(y(x),x)+(8-x)*y(x) = 0,y(x)],
[7292,(2*x^3+x^2)*diff(diff(y(x),x),x)+(9*x^2+5*x)*diff(y(x),x)+(4+3*x)*y(x) = 0,y(x)],
[7293,(-2*x^3+x^2)*diff(diff(y(x),x),x)+(-4*x^2-5*x)*diff(y(x),x)+(9+4*x)*y(x) = 0,y(x)],
[7294,(-x^3+x^2)*diff(diff(y(x),x),x)+(x^2+7*x)*diff(y(x),x)+(9-x)*y(x) = 0,y(x)],
[7295,x^2*diff(diff(y(x),x),x)+(x^3-x)*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[7296,(x^4+x^2)*diff(diff(y(x),x),x)+(3*x^3-3*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[7297,4*x^2*diff(diff(y(x),x),x)+2*x^3*diff(y(x),x)+(3*x^2+1)*y(x) = 0,y(x)],
[7298,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3-x)*diff(y(x),x)+y(x) = 0,y(x)],
[7299,(2*x^4+4*x^2)*diff(diff(y(x),x),x)+7*x^3*diff(y(x),x)+(3*x^2+1)*y(x) = 0,y(x)],
[7300,(x^4+x^2)*diff(diff(y(x),x),x)+(4*x^3-x)*diff(y(x),x)+(2*x^2+1)*y(x) = 0,y(x)],
[7301,(4*x^4+16*x^2)*diff(diff(y(x),x),x)+(9*x^3+24*x)*diff(y(x),x)+(-9*x^2+1)*y(x) = 0,y(x)],
[7302,(3*x^4+9*x^2)*diff(diff(y(x),x),x)+(11*x^3+3*x)*diff(y(x),x)+(5*x^2+1)*y(x) = 0,y(x)],
[7303,9*x^2*diff(diff(y(x),x),x)+(6*x^3-21*x)*diff(y(x),x)+(2*x^2+25)*y(x) = 0,y(x)],
[7304,x^2*diff(diff(y(x),x),x)+(x^3-x)*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[7305,(-2*x^3+x^2)*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+(4*x+1)*y(x) = 0,y(x)],
[7306,(x^2+x)*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)+y(x) = 0,y(x)],
[7307,(-x^3+x^2)*diff(diff(y(x),x),x)+(5*x^2-3*x)*diff(y(x),x)+(4-5*x)*y(x) = 0,y(x)],
[7308,(x^4+x^2)*diff(diff(y(x),x),x)+(-9*x^3-x)*diff(y(x),x)+(25*x^2+1)*y(x) = 0,y(x)],
[7309,9*x^2*diff(diff(y(x),x),x)+(-3*x^3+3*x)*diff(y(x),x)+(7*x^2+1)*y(x) = 0,y(x)],
[7310,(x^3+x)*diff(diff(y(x),x),x)+(-x^2+1)*diff(y(x),x)-8*x*y(x) = 0,y(x)],
[7311,4*x^2*diff(diff(y(x),x),x)+(-2*x^3+8*x)*diff(y(x),x)+(7*x^2+1)*y(x) = 0,y(x)],
[7312,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+8*x^2*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[7313,(9*x^3+27*x^2)*diff(diff(y(x),x),x)+(21*x^2+9*x)*diff(y(x),x)+(3+4*x)*y(x) = 0,y(x)],
[7314,(-x^4+2*x^2)*diff(diff(y(x),x),x)+(-3*x^3-2*x)*diff(y(x),x)+(-x^2+2)*y(x) = 0,y(x)],
[7315,(16*x^4+16*x^2)*diff(diff(y(x),x),x)+(72*x^3+8*x)*diff(y(x),x)+(49*x^2+1)*y(x) = 0,y(x)],
[7316,(3*x^3+4*x^2)*diff(diff(y(x),x),x)+(3*x^2-4*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[7317,(4*x^4+12*x^3+4*x^2)*diff(diff(y(x),x),x)+(16*x^3+24*x^2)*diff(y(x),x)+(9*x^2+3*x+1)*y(x) = 0,y(x)],
[7318,(x^4-2*x^3+x^2)*diff(diff(y(x),x),x)+(3*x^3-2*x^2-x)*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[7319,(9*x^4+9*x^3+9*x^2)*diff(diff(y(x),x),x)+(39*x^3+21*x^2+3*x)*diff(y(x),x)+(25*x^2+4*x+1)*y(x) = 0,y(x)],
[7320,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+(7*x^2-4*x)*diff(y(x),x)+(3*x-5)*y(x) = 0,y(x)],
[7321,(-2*x^3+x^2)*diff(diff(y(x),x),x)+(-9*x^2+8*x)*diff(y(x),x)+(6-3*x)*y(x) = 0,y(x)],
[7322,(x^4+x^2)*diff(diff(y(x),x),x)+(10*x^3+3*x)*diff(y(x),x)+(14*x^2-15)*y(x) = 0,y(x)],
[7323,(-2*x^4+x^2)*diff(diff(y(x),x),x)+(-13*x^3+7*x)*diff(y(x),x)-14*x^2*y(x) = 0,y(x)],
[7324,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+(8*x^2+4*x)*diff(y(x),x)+(-3*x-1)*y(x) = 0,y(x)],
[7325,(6*x^3+4*x^2)*diff(diff(y(x),x),x)+(21*x^2+4*x)*diff(y(x),x)+(9*x-1)*y(x) = 0,y(x)],
[7326,x^2*diff(diff(y(x),x),x)+(x^2+2*x)*diff(y(x),x)+(3*x-2)*y(x) = 0,y(x)],
[7327,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+(32*x^2+12*x)*diff(y(x),x)+(49*x-5)*y(x) = 0,y(x)],
[7329,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(-3*x-9)*y(x) = 0,y(x)],
[7330,(2*x^3+x^2)*diff(diff(y(x),x),x)+(13*x^2+9*x)*diff(y(x),x)+(7+5*x)*y(x) = 0,y(x)],
[7331,(8*x^3+4*x^2)*diff(diff(y(x),x),x)+(2*x^2-8*x)*diff(y(x),x)+(-5*x-7)*y(x) = 0,y(x)],
[7332,(3*x^3+9*x^2)*diff(diff(y(x),x),x)+(-x^2-15*x)*diff(y(x),x)-20*y(x) = 0,y(x)],
[7333,(x^3+x^2)*diff(diff(y(x),x),x)+(-10*x^2+x)*diff(y(x),x)+(10*x-9)*y(x) = 0,y(x)],
[7334,(x^3+x^2)*diff(diff(y(x),x),x)+3*x^2*diff(y(x),x)+(x-6)*y(x) = 0,y(x)],
[7335,(2*x^3+x^2)*diff(diff(y(x),x),x)+(-28*x^2-6*x)*diff(y(x),x)+(6+100*x)*y(x) = 0,y(x)],
[7336,(x^3+x^2)*diff(diff(y(x),x),x)+(-11*x^2-6*x)*diff(y(x),x)+(6+32*x)*y(x) = 0,y(x)],
[7337,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+(16*x^2+4*x)*diff(y(x),x)+(-27*x-49)*y(x) = 0,y(x)],
[7338,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3-7*x)*diff(y(x),x)+12*y(x) = 0,y(x)],
[7339,x^2*diff(diff(y(x),x),x)+(x^3-7*x)*diff(y(x),x)+12*y(x) = 0,y(x)],
[7340,x^2*diff(diff(y(x),x),x)+(2*x^3+x)*diff(y(x),x)+(10*x^2-1)*y(x) = 0,y(x)],
[7341,x^2*diff(diff(y(x),x),x)+(-2*x^3+x)*diff(y(x),x)+(-8*x^2-4)*y(x) = 0,y(x)],
[7342,x^2*diff(diff(y(x),x),x)+(-3*x^3+x)*diff(y(x),x)+(12*x^2-4)*y(x) = 0,y(x)],
[7343,(x^4+x^2)*diff(diff(y(x),x),x)+(11*x^3+5*x)*diff(y(x),x)+24*x^2*y(x) = 0,y(x)],
[7344,(4*x^4+4*x^2)*diff(diff(y(x),x),x)+8*x*diff(y(x),x)+(x^2-35)*y(x) = 0,y(x)],
[7345,(x^4+x^2)*diff(diff(y(x),x),x)+(x^3-5*x)*diff(y(x),x)+(-25*x^2-7)*y(x) = 0,y(x)],
[7346,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3+5*x)*diff(y(x),x)-21*y(x) = 0,y(x)],
[7347,(4*x^4+4*x^2)*diff(diff(y(x),x),x)+(4*x^3+8*x)*diff(y(x),x)+(-x^2-15)*y(x) = 0,y(x)],
[7348,diff(diff(y(t),t),t)+(-2/(t^2+2*t-1)*t-2/(t^2+2*t-1))*diff(y(t),t)+2/(t^2+2*t-1)*y(t) = 0,y(t)],
[7349,diff(diff(y(t),t),t)-4*t*diff(y(t),t)+(4*t^2-2)*y(t) = 0,y(t)],
[7350,(-t^2+1)*diff(diff(y(t),t),t)-2*t*diff(y(t),t)+2*y(t) = 0,y(t)],
[7351,(t^2+1)*diff(diff(y(t),t),t)-2*t*diff(y(t),t)+2*y(t) = 0,y(t)],
[7352,(-t^2+1)*diff(diff(y(t),t),t)-2*t*diff(y(t),t)+6*y(t) = 0,y(t)],
[7353,(2*t+1)*diff(diff(y(t),t),t)+(-4*t-4)*diff(y(t),t)+4*y(t) = 0,y(t)],
[7354,t^2*diff(diff(y(t),t),t)+t*diff(y(t),t)+(t^2-1/4)*y(t) = 0,y(t)],
[7355,diff(diff(y(t),t),t)-2*t/(t^2+1)*diff(y(t),t)+2/(t^2+1)*y(t) = 0,y(t)],
[7357,2*t*diff(diff(y(t),t),t)+(1-2*t)*diff(y(t),t)-y(t) = 0,y(t)],
[7358,2*t*diff(diff(y(t),t),t)+(t+1)*diff(y(t),t)-2*y(t) = 0,y(t)],
[7359,2*t^2*diff(diff(y(t),t),t)-t*diff(y(t),t)+(t+1)*y(t) = 0,y(t)],
[7360,2*t^2*diff(diff(y(t),t),t)+(t^2-t)*diff(y(t),t)+y(t) = 0,y(t)],
[7361,t^2*diff(diff(y(t),t),t)+(-t^2+t)*diff(y(t),t)-y(t) = 0,y(t)],
[7362,t*diff(diff(y(t),t),t)+(-t^2-2)*diff(y(t),t)+t*y(t) = 0,y(t)],
[7363,t^2*diff(diff(y(t),t),t)+(t^2+t)*diff(y(t),t)-y(t) = 0,y(t)],
[7364,t*diff(diff(y(t),t),t)+(-4-t)*diff(y(t),t)+2*y(t) = 0,y(t)],
[7365,t^2*diff(diff(y(t),t),t)+(t^2-3*t)*diff(y(t),t)+3*y(t) = 0,y(t)],
[7366,t*diff(diff(y(t),t),t)+t*diff(y(t),t)+2*y(t) = 0,y(t)],
[7367,t*diff(diff(y(t),t),t)+(-t^2+1)*diff(y(t),t)+4*t*y(t) = 0,y(t)],
[7368,t^2*diff(diff(y(t),t),t)+(-t^2-t)*diff(y(t),t)+y(t) = 0,y(t)],
[7369,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+6)*y(x) = 0,y(x)],
[7370,(-z^2+1)*diff(diff(y(z),z),z)-3*z*diff(y(z),z)+y(z) = 0,y(z)],
[7371,4*z*diff(diff(y(z),z),z)+(-2*z+2)*diff(y(z),z)-y(z) = 0,y(z)],
[7372,diff(diff(f(z),z),z)+(2*z-2)*diff(f(z),z)+4*f(z) = 0,f(z)],
[7373,z*diff(diff(y(z),z),z)-2*diff(y(z),z)+z*y(z) = 0,y(z)],
[7374,z*diff(diff(y(z),z),z)+(2*z-3)*diff(y(z),z)+4/z*y(z) = 0,y(z)],
[7375,x*diff(diff(y(x),x),x)+(1-2*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[7376,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[7377,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7378,4*x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2-1)*y(x) = 0,y(x)],
[7379,x*diff(diff(y(x),x),x)+(-2*x-1)*diff(y(x),x)+2*y(x) = 0,y(x)],
[7380,diff(diff(y(x),x),x)+2*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[7381,diff(diff(y(x),x),x)+x*diff(y(x),x)+3*y(x) = 0,y(x)],
[7382,diff(diff(y(x),x),x)-x^2*diff(y(x),x)-3*x*y(x) = 0,y(x)],
[7383,(-4*x^2+1)*diff(diff(y(x),x),x)-20*x*diff(y(x),x)-16*y(x) = 0,y(x)],
[7384,(x^2-1)*diff(diff(y(x),x),x)-6*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[7385,diff(diff(y(x),x),x)+x*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[7386,(2*x^2+1)*diff(diff(y(x),x),x)+7*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7387,4*diff(diff(y(x),x),x)+x*diff(y(x),x)+4*y(x) = 0,y(x)],
[7388,diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[7389,4*x*diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7390,6*x^2*diff(diff(y(x),x),x)+(18*x^2+x)*diff(y(x),x)+(1+12*x)*y(x) = 0,y(x)],
[7391,3*x^2*diff(diff(y(x),x),x)+(-x^2-8*x)*diff(y(x),x)+6*y(x) = 0,y(x)],
[7392,2*x^2*diff(diff(y(x),x),x)+(-2*x^2-x)*diff(y(x),x)+(8*x-2)*y(x) = 0,y(x)],
[7393,4*x^2*diff(diff(y(x),x),x)-4*x^2*diff(y(x),x)+(2*x+1)*y(x) = 0,y(x)],
[7394,x^2*diff(diff(y(x),x),x)+(-2*x^2+3*x)*diff(y(x),x)+(1-2*x)*y(x) = 0,y(x)],
[7395,x^2*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+(4-x)*y(x) = 0,y(x)],
[7396,x^2*diff(diff(y(x),x),x)+(-x^2+3*x)*diff(y(x),x)+y(x) = 0,y(x)],
[7397,x^2*diff(diff(y(x),x),x)+(-2*x*5^(1/2)+x)*diff(y(x),x)+(19/4-3*x^2)*y(x) = 0,y(x)],
[7398,x^2*diff(diff(y(x),x),x)+(x^2-3*x)*diff(y(x),x)+(4-x)*y(x) = 0,y(x)],
[7399,x^2*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+(-x-2)*y(x) = 0,y(x)],
[7400,x^2*diff(diff(y(x),x),x)+2*x^2*diff(y(x),x)+(x-3/4)*y(x) = 0,y(x)],
[7401,(x^3+x^2)*diff(diff(y(x),x),x)+x^2*diff(y(x),x)-2*y(x) = 0,y(x)],
[7402,x^2*diff(diff(y(x),x),x)+(x^3+6*x)*diff(y(x),x)+6*y(x) = 0,y(x)],
[7403,x^2*diff(diff(y(x),x),x)+(-x^2+x)*diff(y(x),x)-y(x) = 0,y(x)],
[7404,x^2*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[7405,x^2*diff(diff(y(x),x),x)-x^2*diff(y(x),x)-2*y(x) = 0,y(x)],
[7406,x^2*diff(diff(y(x),x),x)-x^2*diff(y(x),x)+(-3*x-2)*y(x) = 0,y(x)],
[7407,x^2*diff(diff(y(x),x),x)+(-x^2+5*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[7408,4*x^2*diff(diff(y(x),x),x)+(-4*x^2+4*x)*diff(y(x),x)+(2*x-9)*y(x) = 0,y(x)],
[7409,x^2*diff(diff(y(x),x),x)+(2*x^2+4*x)*diff(y(x),x)+(2*x+2)*y(x) = 0,y(x)],
[7410,x^2*diff(diff(y(x),x),x)+(x^2-x)*diff(y(x),x)+(1-x)*y(x) = 0,y(x)],
[7411,4*x^2*diff(diff(y(x),x),x)+(8*x^2+4*x)*diff(y(x),x)+(-1+4*x)*y(x) = 0,y(x)],
[7412,x^2*diff(diff(y(x),x),x)+(x^2+4*x)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[7413,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-9/4)*y(x) = 0,y(x)],
[7414,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[7415,2*x*diff(diff(y(x),x),x)+(-10*x+5)*diff(y(x),x)-5*y(x) = 0,y(x)],
[7416,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7418,x^4*diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[7419,x^2*diff(diff(y(x),x),x)+(2*x^2+x)*diff(y(x),x)-4*y(x) = 0,y(x)],
[7420,(4*x^3-14*x^2-2*x)*diff(diff(y(x),x),x)+(-6*x^2+7*x-1)*diff(y(x),x)+(6*x-1)*y(x) = 0,y(x)],
[7421,x^2*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[7422,x^2*diff(diff(y(x),x),x)-x^2*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[7423,(-4*x^3+x^2)*diff(diff(y(x),x),x)+(-1/4*x-x^2)*diff(y(x),x)-5/16*x*y(x) = 0,y(x)],
[7424,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(x-9)*y(x) = 0,y(x)],
[7425,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(3*x-1)*y(x) = 0,y(x)],
[7426,x^2*diff(diff(y(x),x),x)+(-x^2-4*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[7427,2*x^2*diff(diff(y(x),x),x)+(-3*x-2)*diff(y(x),x)+(2-1/x)*y(x) = 0,y(x)],
[7428,(-x^2+x)*diff(diff(y(x),x),x)+(3/2-2*x)*diff(y(x),x)-1/4*y(x) = 0,y(x)],
[7429,(-2*x^2+2*x)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[7430,(-2*x^2+2*x)*diff(diff(y(x),x),x)+(1-11*x)*diff(y(x),x)-10*y(x) = 0,y(x)],
[7431,(-x^2+x)*diff(diff(y(x),x),x)+(-2/3*x+1/3)*diff(y(x),x)+20/9*y(x) = 0,y(x)],
[7432,4*diff(diff(y(x),x),x)+(-3/(-x^2+1)^2*x^2+6/(-x^2+1)^2)*y(x) = 0,y(x)],
[7440,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(-x^2-1/4)*y(x) = 0,y(x)],
[7442,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-25/4)*y(x) = 0,y(x)],
[7444,x*diff(diff(y(x),x),x)+3*diff(y(x),x)+4*x^3*y(x) = 0,y(x)],
[7445,(-x^3+2*x^2)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[7446,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7447,x*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[7448,3*x*diff(diff(y(x),x),x)+(-6*x+2)*diff(y(x),x)+(3*x-2)*y(x) = 0,y(x)],
[7449,(x^2+x)*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)+y(x) = 0,y(x)],
[7450,(x^2+2*x)*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[7451,(x^2+2*x)*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[7452,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7453,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7454,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-2)*y(x) = 0,y(x)],
[7455,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-2)*y(x) = 0,y(x)],
[7456,(2*x-3)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7457,diff(diff(y(x),x),x)-x*diff(y(x),x)-3*y(x) = 0,y(x)],
[7458,(x^2+1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7459,diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7460,(-x^2+1)*diff(diff(y(x),x),x)-diff(y(x),x)+y(x) = 0,y(x)],
[7461,(x^3+2*x^2+x)*diff(diff(y(x),x),x)+(-x^2+1)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[7462,2*x*diff(diff(y(x),x),x)-diff(y(x),x)+2*y(x) = 0,y(x)],
[7463,x*diff(diff(y(x),x),x)+x*diff(y(x),x)-2*y(x) = 0,y(x)],
[7464,(x^3-2*x^2+x)*diff(diff(y(x),x),x)-2*y(x) = 0,y(x)],
[7465,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+x^2*y(x) = 0,y(x)],
[7466,(-x^3+2*x)*diff(diff(y(x),x),x)+(x^3+3*x^2-2*x-2)*diff(y(x),x)+(-x^2-4*x-2)*y(x) = 0,y(x)],
[7467,(x^3+x^2)*diff(diff(y(x),x),x)+(-2*x^2-x)*diff(y(x),x)+(2*x+1)*y(x) = 0,y(x)],
[7468,(-2*x^3+4*x^2)*diff(diff(y(x),x),x)+(x^2-4*x)*diff(y(x),x)+(3-x)*y(x) = 0,y(x)],
[7469,(-x^3+x^2)*diff(diff(y(x),x),x)+(5*x^2-4*x)*diff(y(x),x)+(6-9*x)*y(x) = 0,y(x)],
[7470,x*diff(diff(y(x),x),x)+(4*x^2+1)*diff(y(x),x)+(4*x^3+4*x)*y(x) = 0,y(x)],
[7471,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[7472,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[7473,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[7474,(x^2+2*x)*diff(diff(y(x),x),x)+(2*x+2)*diff(y(x),x)-2*y(x) = 0,y(x)],
[7475,(x^2+2*x)*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)-4*y(x) = 0,y(x)],
[7476,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7477,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7478,(x^2-2*x+10)*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[7479,(x^2-2*x+10)*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[7480,diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7481,(x+2)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[7482,(x^2+1)*diff(diff(y(x),x),x)-6*y(x) = 0,y(x)],
[7483,(x^2+2)*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-y(x) = 0,y(x)],
[7484,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7485,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[7486,x^2*diff(diff(y(x),x),x)+(5/3*x+x^2)*diff(y(x),x)-1/3*y(x) = 0,y(x)],
[7487,2*x*diff(diff(y(x),x),x)-diff(y(x),x)+2*y(x) = 0,y(x)],
[7488,2*x*diff(diff(y(x),x),x)+(-2*x-3)*diff(y(x),x)+y(x) = 0,y(x)],
[7489,2*x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+(2*x-1)*y(x) = 0,y(x)],
[7490,x*diff(diff(y(x),x),x)+2*diff(y(x),x)-x*y(x) = 0,y(x)],
[7491,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7492,x*diff(diff(y(x),x),x)+(x-6)*diff(y(x),x)-3*y(x) = 0,y(x)],
[7494,4*x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2-25)*y(x) = 0,y(x)],
[7495,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(36*x^2-1/4)*y(x) = 0,y(x)],
[7496,x^2*diff(diff(y(x),x),x)+(x^2-2)*y(x) = 0,y(x)],
[7497,x*diff(diff(y(x),x),x)+3*diff(y(x),x)+x^3*y(x) = 0,y(x)],
[7498,x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[7499,16*x^2*diff(diff(y(x),x),x)+32*x*diff(y(x),x)+(x^4-12)*y(x) = 0,y(x)],
[7500,diff(diff(y(x),x),x)-x^2*diff(y(x),x)+x*y(x) = 0,y(x)],
[7501,x*diff(diff(y(x),x),x)+(-x-2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[7502,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7503,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7504,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-2)*y(x) = 0,y(x)],
[7505,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+30*y(x) = 0,y(x)],
[7506,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[7507,x*diff(diff(y(x),x),x)+(2*x+1)*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[7508,(2*x^2-2*x)*diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[7509,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+4*x*y(x) = 0,y(x)],
[7510,x*diff(diff(y(x),x),x)+(-2*x+2)*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[7511,x^2*diff(diff(y(x),x),x)+6*x*diff(y(x),x)+(4*x^2+6)*y(x) = 0,y(x)],
[7512,x*diff(diff(y(x),x),x)+(1-2*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[7513,(-x^2+x)*diff(diff(y(x),x),x)+(1/2+2*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[7514,(4*t^2-12*t+8)*diff(diff(y(t),t),t)-2*diff(y(t),t)+y(t) = 0,y(t)],
[7515,(2*t^2-10*t+12)*diff(diff(y(t),t),t)+(2*t-3)*diff(y(t),t)-8*y(t) = 0,y(t)],
[7516,(3*t^2+3*t)*diff(diff(y(t),t),t)+t*diff(y(t),t)-y(t) = 0,y(t)],
[7517,x^2*diff(diff(y(x),x),x)+(1/4*x+3/16)*y(x) = 0,y(x)],
[7518,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(1/4*x^2-1/4)*y(x) = 0,y(x)],
[7519,x*diff(diff(y(x),x),x)+(1-2*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[7520,x*diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[7521,x*diff(diff(y(x),x),x)+3*diff(y(x),x)+4*x^3*y(x) = 0,y(x)],
[7522,(-x^4+x^2)*diff(diff(y(x),x),x)+(-2*x^3+2*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[7523,2*x*diff(diff(y(x),x),x)+(x-2)*diff(y(x),x)-y(x) = 0,y(x)],
[7524,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[7525,diff(diff(y(x),x),x)+2*x^2*diff(y(x),x)+(x^4+2*x-1)*y(x) = 0,y(x)],
[7526,diff(diff(u(x),x),x)+2*diff(u(x),x)+u(x) = 0,u(x)],
[7527,diff(diff(u(x),x),x)+(-2*x-1)*diff(u(x),x)+(x^2+x-1)*u(x) = 0,u(x)],
[7528,diff(diff(y(x),x),x)+2*diff(y(x),x)+(1+2/(3*x+1)^2)*y(x) = 0,y(x)],
[7529,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[7530,diff(diff(y(x),x),x)+2/x*diff(y(x),x)-2/(x+1)^2*y(x) = 0,y(x)],
[7531,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7532,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7533,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7534,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7535,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7536,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7537,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7538,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7539,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7540,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7541,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7542,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[7543,2*x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7544,x^2*diff(diff(y(x),x),x)+(3*x^2+2*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[7546,x*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)+2*y(x) = 0,y(x)],
[7547,(x^4-2*x^3+x^2)*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+(4+x)*y(x) = 0,y(x)],
[7548,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+5*x^2*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[7549,x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[7550,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7551,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+(-x^2-5/4)*y(x) = 0,y(x)],
[7552,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7553,x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+4*x^4*y(x) = 0,y(x)],
[7554,diff(diff(y(x),x),x)+(-x^2-3)*y(x) = 0,y(x)],
[7555,diff(diff(y(x),x),x)+2*x*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[7556,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7557,4*x^2*diff(diff(y(x),x),x)+(-8*x^2+4*x)*diff(y(x),x)+(4*x^2-4*x-1)*y(x) = 0,y(x)],
[7558,diff(diff(y(x),x),x) = 0,y(x)],
[7559,diff(diff(y(x),x),x)-2*y(x)/x^2 = 0,y(x)],
[7560,diff(diff(y(x),x),x)-6*y(x)/x^2 = 0,y(x)],
[7561,diff(diff(y(x),x),x)+(3/16/x^2+2/9/(x-1)^2-3/16/x/(x-1))*y(x) = 0,y(x)],
[7562,diff(diff(y(x),x),x)-20*y(x)/x^2 = 0,y(x)],
[7563,diff(diff(y(x),x),x)-12*y(x)/x^2 = 0,y(x)],
[7564,diff(diff(y(x),x),x)-1/4*y(x)/x^2 = 0,y(x)],
[7565,x*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[7566,diff(diff(y(x),x),x)+y(x)/x^2 = 0,y(x)],
[7567,(-x^2+1)*diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[7568,(x^2-x)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7569,(-x^4+2*x^2)*diff(diff(y(x),x),x)+(-4*x^3-3*x)*diff(y(x),x)+(-2*x^2+2)*y(x) = 0,y(x)],
[7570,diff(diff(y(x),x),x)+(-x^2+2*x-3-1/x-7/4/x^2+5/x^3-1/x^4)*y(x) = 0,y(x)],
[7571,diff(diff(y(x),x),x)+(-6/x^2+1)*y(x) = 0,y(x)],
[7572,diff(diff(y(x),x),x)+(-1/4*x^2+11/2)*y(x) = 0,y(x)],
[7573,diff(diff(y(x),x),x)+(-1/x+3/16/x^2)*y(x) = 0,y(x)],
[7574,diff(diff(y(x),x),x)+(3/16/x^2+2/9/(x-1)^2-3/16/x/(x-1))*y(x) = 0,y(x)],
[7575,diff(diff(y(x),x),x)+(5/36/(x^2-1)^2*x^2+3/4/(x^2-1)^2)*y(x) = 0,y(x)],
[7576,diff(diff(y(x),x),x)+1/4*y(x)/x^2 = 0,y(x)],
[7577,diff(diff(y(x),x),x)+(-x^2-3)*y(x) = 0,y(x)],
[7578,x^2*diff(diff(y(x),x),x)-2*y(x) = 0,y(x)],
[7579,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[7580,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[7581,(x^2-4*x+4)*diff(diff(y(x),x),x)+(-x+2)*diff(y(x),x)-3*y(x) = 0,y(x)],
[8581,diff(diff(y(x),x),x) = 0,y(x)],
[8582,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[8583,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[8584,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[8585,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[8586,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[8587,diff(diff(y(x),x),x)-2*y(x) = 0,y(x)],
[8589,diff(diff(y(x),x),x)+l*y(x) = 0,y(x)],
[8591,diff(diff(y(x),x),x)+(-x^2-1)*y(x) = 0,y(x)],
[8619,diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[8620,diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[8623,diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[8625,diff(diff(y(x),x),x)-x*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[8627,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[8629,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-1)*y(x) = 0,y(x)],
[8630,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-2)*y(x) = 0,y(x)],
[8631,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-3)*y(x) = 0,y(x)],
[8636,diff(diff(y(x),x),x)-x^2*diff(y(x),x)+x*y(x) = 0,y(x)],
[8637,diff(diff(y(x),x),x)-x^2*diff(y(x),x)+(-x^2-2*x-1)*y(x) = 0,y(x)],
[8638,diff(diff(y(x),x),x)+(-x^3-x^2)*diff(y(x),x)+(x^5-2*x)*y(x) = 0,y(x)],
[8639,diff(diff(y(x),x),x)+x^4*diff(y(x),x)-x^3*y(x) = 0,y(x)],
[8671,x*diff(diff(y(x),x),x)+x*y(x) = 0,y(x)],
[8673,x*diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[8680,x*diff(diff(y(x),x),x)+2*diff(y(x),x)-x*y(x) = 0,y(x)],
[8689,x*diff(diff(y(x),x),x)-x*diff(y(x),x)-y(x) = 0,y(x)],
[8691,x*diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[8692,x*diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)+(-2*x+2)*y(x) = 0,y(x)],
[8701,x*diff(diff(y(x),x),x)+(-x^2+x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[8702,x*diff(diff(y(x),x),x)+(-x^2+x+2)*diff(y(x),x)+(-x^2-3*x)*y(x) = 0,y(x)],
[8705,x*diff(diff(y(x),x),x)+(4*x^2-1)*diff(y(x),x)-4*x^3*y(x) = 0,y(x)],
[8709,(x-3)*diff(diff(y(x),x),x)+(-4*x+9)*diff(y(x),x)+(3*x-6)*y(x) = 0,y(x)],
[8713,(2*x-1)*diff(diff(y(x),x),x)+(-3*x+4)*diff(y(x),x)+(x-3)*y(x) = 0,y(x)],
[8715,4*x*diff(diff(y(x),x),x)+2*diff(y(x),x)-y(x) = 0,y(x)],
[8716,4*x*diff(diff(y(x),x),x)+4*diff(y(x),x)+(-x-2)*y(x) = 0,y(x)],
[8726,x^2*diff(diff(y(x),x),x)-6*y(x) = 0,y(x)],
[8727,x^2*diff(diff(y(x),x),x)-12*y(x) = 0,y(x)],
[8730,x^2*diff(diff(y(x),x),x)+(x^2-2)*y(x) = 0,y(x)],
[8739,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[8746,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[8748,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x) = 0,y(x)],
[8754,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[8755,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)-4*y(x) = 0,y(x)],
[8756,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[8757,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[8758,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[8761,x^2*diff(diff(y(x),x),x)+(3*x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[8762,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[8763,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)-5*y(x) = 0,y(x)],
[8764,x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[8766,x^2*diff(diff(y(x),x),x)-5*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[8771,x^2*diff(diff(y(x),x),x)+x^2*diff(y(x),x)-2*y(x) = 0,y(x)],
[8772,x^2*diff(diff(y(x),x),x)+(x^2-1)*diff(y(x),x)-y(x) = 0,y(x)],
[8773,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(x-9)*y(x) = 0,y(x)],
[8774,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(3*x-1)*y(x) = 0,y(x)],
[8776,x^2*diff(diff(y(x),x),x)+(-x^2+x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[8778,x^2*diff(diff(y(x),x),x)+(-x^2+2*x)*diff(y(x),x)+(-3*x-2)*y(x) = 0,y(x)],
[8779,x^2*diff(diff(y(x),x),x)+(-x^2-4*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[8781,x^2*diff(diff(y(x),x),x)+(2*x^2+x)*diff(y(x),x)-4*y(x) = 0,y(x)],
[8782,x^2*diff(diff(y(x),x),x)+(-2*x^2-2*x)*diff(y(x),x)+(2*x+2)*y(x) = 0,y(x)],
[8788,x^2*diff(diff(y(x),x),x)+x^3*diff(y(x),x)+(x^2-2)*y(x) = 0,y(x)],
[8789,x^2*diff(diff(y(x),x),x)+(x^3+2*x)*diff(y(x),x)+(x^2-2)*y(x) = 0,y(x)],
[8791,x^2*diff(diff(y(x),x),x)+4*x^3*diff(y(x),x)+(4*x^4+2*x^2+1)*y(x) = 0,y(x)],
[8802,(x^2+1)*diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[8803,(x^2+1)*diff(diff(y(x),x),x)+x*diff(y(x),x)-9*y(x) = 0,y(x)],
[8805,(x^2+1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[8807,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[8809,(x^2+1)*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[8814,(x^2-1)*diff(diff(y(x),x),x)+x*diff(y(x),x) = 0,y(x)],
[8817,(x^2-1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x) = 0,y(x)],
[8818,(x^2-1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x) = 0,y(x)],
[8822,(x^2-1)*diff(diff(y(x),x),x)+(-3*x-1)*diff(y(x),x)+(-x^2+x)*y(x) = 0,y(x)],
[8823,(x^2-1)*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[8831,(x^2+x)*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)+y(x) = 0,y(x)],
[8833,(x^2+x)*diff(diff(y(x),x),x)+(3*x+2)*diff(y(x),x)+y(x) = 0,y(x)],
[8842,(x^2+2*x+1)*diff(diff(y(x),x),x)+(x^2+x-1)*diff(y(x),x)+(-x-2)*y(x) = 0,y(x)],
[8843,(x^2+3*x)*diff(diff(y(x),x),x)+(3*x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[8844,(x^2+3*x+4)*diff(diff(y(x),x),x)+(x^2+x+1)*diff(y(x),x)+(-2*x-3)*y(x) = 0,y(x)],
[8846,(x^2-4*x+4)*diff(diff(y(x),x),x)+(-x+2)*diff(y(x),x)-3*y(x) = 0,y(x)],
[8847,2*x^2*diff(diff(y(x),x),x)+(-2*x^2-l+5*x)*diff(y(x),x)+(1-4*x)*y(x) = 0,y(x)],
[8850,(2*x^2+6*x+4)*diff(diff(y(x),x),x)+(10*x^2+21*x+8)*diff(y(x),x)+(12*x^2+17*x+8)*y(x) = 0,y(x)],
[8851,4*x^2*diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[8856,4*x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(-4*x^2-1)*y(x) = 0,y(x)],
[8859,4*x^2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)-y(x) = 0,y(x)],
[8860,4*x^2*diff(diff(y(x),x),x)+8*x*diff(y(x),x)+(-4*x^2-12*x-3)*y(x) = 0,y(x)],
[8861,4*x^2*diff(diff(y(x),x),x)+(-8*x^2+4*x)*diff(y(x),x)+(4*x^2-4*x-1)*y(x) = 0,y(x)],
[8862,4*x^2*diff(diff(y(x),x),x)+4*x^3*diff(y(x),x)+(x^4+2*x^2-24)*y(x) = 0,y(x)],
[8864,(4*x^2+4*x+1)*diff(diff(y(x),x),x)+(-4*x-2)*diff(y(x),x)-12*y(x) = 0,y(x)],
[8866,(9*x^2-6*x+1)*diff(diff(y(x),x),x)+(9*x-3)*diff(y(x),x)-9*y(x) = 0,y(x)],
[8867,(9*x^2-9*x)*diff(diff(y(x),x),x)+(6*x-3)*diff(y(x),x)-20*y(x) = 0,y(x)],
[8868,16*x^2*diff(diff(y(x),x),x)+(3+4*x)*y(x) = 0,y(x)],
[8869,16*x^2*diff(diff(y(x),x),x)+32*x*diff(y(x),x)+(-4*x-5)*y(x) = 0,y(x)],
[8870,(27*x^2+4)*diff(diff(y(x),x),x)+27*x*diff(y(x),x)-3*y(x) = 0,y(x)],
[8872,(50*x^2-50*x)*diff(diff(y(x),x),x)+(50*x-25)*diff(y(x),x)-2*y(x) = 0,y(x)],
[8884,x^3*diff(diff(y(x),x),x)+x*diff(y(x),x)+(-2*x-3)*y(x) = 0,y(x)],
[8887,x^3*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[8888,x^3*diff(diff(y(x),x),x)-x^2*diff(y(x),x)+x*y(x) = 0,y(x)],
[8890,x^3*diff(diff(y(x),x),x)+3*x^2*diff(y(x),x)+x*y(x) = 0,y(x)],
[8892,(x^3+x)*diff(diff(y(x),x),x)+(2*x^2-2)*diff(y(x),x)-2*x*y(x) = 0,y(x)],
[8899,(x^3+2*x)*diff(diff(y(x),x),x)-diff(y(x),x)-6*x*y(x) = 0,y(x)],
[8900,(x^3-2*x)*diff(diff(y(x),x),x)+(-x^3-3*x^2+2*x+2)*diff(y(x),x)+(x^2+4*x+2)*y(x) = 0,y(x)],
[8901,(x^3+x^2)*diff(diff(y(x),x),x)+(-2*x^2-x)*diff(y(x),x)+(2*x+1)*y(x) = 0,y(x)],
[8902,(x^3+x^2)*diff(diff(y(x),x),x)+(6*x^2+4*x)*diff(y(x),x) = 0,y(x)],
[8903,diff(diff(y(x),x),x)+(2/(x-1)-4/x/(x-1))*diff(y(x),x)+(-2/x/(x-1)-2/x^2/(x-1))*y(x) = 0,y(x)],
[8904,diff(diff(y(x),x),x)+(-5/(x-1)+4/x/(x-1))*diff(y(x),x)+(9/x/(x-1)-6/x^2/(x-1))*y(x) = 0,y(x)],
[8906,diff(diff(y(x),x),x)+1/(x+1)*diff(y(x),x)+1/x/(x+1)^2*y(x) = 0,y(x)],
[8908,diff(diff(y(x),x),x)-2*y(x)/x/(x-1)^2 = 0,y(x)],
[8911,diff(diff(y(x),x),x)+(-1/2/(x-2)+2/x/(x-2))*diff(y(x),x)+(1/2/x/(x-2)-3/2/x^2/(x-2))*y(x) = 0,y(x)],
[8912,diff(diff(y(x),x),x)-1/(x+1)*diff(y(x),x)+(3/4/x/(x+1)+1/4/x^2/(x+1))*y(x) = 0,y(x)],
[8916,diff(diff(y(x),x),x)+(-3/(x-1)/(2*x-1)^2*x+1/(x-1)/(2*x-1)^2)*y(x) = 0,y(x)],
[8918,diff(diff(y(x),x),x)+(-2/(x-2)+1/3/x/(x-2))*diff(y(x),x)-1/3/x^2/(x-2)*y(x) = 0,y(x)],
[8925,diff(diff(y(x),x),x)+1/x^3*diff(y(x),x)-2/x^4*y(x) = 0,y(x)],
[8931,diff(diff(y(x),x),x)+(2/x+1/x^3)*diff(y(x),x)-1/x^4*y(x) = 0,y(x)],
[8933,diff(diff(y(x),x),x)+(-2/x+1/x^3)*diff(y(x),x)+1/x^4*y(x) = 0,y(x)],
[8934,diff(diff(y(x),x),x)+(-2/x+1/x^3)*diff(y(x),x)+2/x^4*y(x) = 0,y(x)],
[8935,diff(diff(y(x),x),x)+(x^2/(x^3+1)-1/x/(x^3+1))*diff(y(x),x)-x/(x^3+1)*y(x) = 0,y(x)],
[8938,diff(diff(y(x),x),x)+(-x/(x^2-1)+2/x/(x^2-1))*diff(y(x),x)+(1/(x^2-1)-2/x^2/(x^2-1))*y(x) = 0,y(x)],
[8946,diff(diff(y(x),x),x)+2/(x^2+1)*x*diff(y(x),x)+1/(x^2+1)^2*y(x) = 0,y(x)],
[8958,diff(diff(y(x),x),x)+(2*x/(x-1)^2-2/x/(x-1)^2)*diff(y(x),x)+(-2/(x-1)^2+2/x/(x-1)^2+2/x^2/(x-1)^2)*y(x) = 0,y(x)],
[8959,diff(diff(y(x),x),x)-12/(x+1)^2/(x^2+2*x+3)*y(x) = 0,y(x)],
[8966,diff(diff(y(x),x),x)-18/(2*x+1)^2/(x^2+x+1)*y(x) = 0,y(x)],
[8967,diff(diff(y(x),x),x)-3/4/(x^2+x+1)^2*y(x) = 0,y(x)],
[8970,diff(diff(y(x),x),x)+3/16/x^2/(x-1)^2*y(x) = 0,y(x)],
[8977,diff(diff(y(x),x),x)+1/x^4*diff(y(x),x)-1/x^5*y(x) = 0,y(x)],
[8979,diff(diff(y(x),x),x)+(-3*x/(x-1)/(x+1)-1/(x-1)/(x+1))*diff(y(x),x)+(36/(x-1)^2/(3*x+5)^2*x^2+72/(x-1)^2/(3*x+5)^2*x+36/(x-1)^2/(3*x+5)^2)*y(x) = 0,y(x)],
[8984,diff(diff(y(x),x),x)+(2/x+1/x^3)*diff(y(x),x)+(-1/2/x^4+1/4/x^6)*y(x) = 0,y(x)],
[8986,diff(diff(y(x),x),x)+27/16*x/(x^3-1)^2*y(x) = 0,y(x)],
[9026,diff(diff(y(x),x),x)+1/x*diff(y(x),x)+(1/x^3-1/x^4)*y(x) = 0,y(x)],
[9027,diff(diff(y(x),x),x)+1/x*diff(y(x),x)+(-1/x^3-1/x^4)*y(x) = 0,y(x)],
[9044,-2*diff(diff(y(x),x),x)-3*diff(y(x),x)+10*y(x) = 0,y(x)],
[9055,-8*diff(diff(y(x),x),x)-11*diff(y(x),x)-3*y(x) = 0,y(x)],
[9061,(x^2-3)*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[9065,(-x^2+2*x)*diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[9067,(4+x)*diff(diff(y(x),x),x)+2*diff(y(x),x) = 0,y(x)],
[9070,-x*diff(diff(y(x),x),x)+(x^2+1)*diff(y(x),x) = 0,y(x)],
[9074,5*x*diff(diff(y(x),x),x)+4*diff(y(x),x) = 0,y(x)],
[9075,6*x*diff(diff(y(x),x),x)+6*diff(y(x),x) = 0,y(x)],
[9083,8*x*diff(diff(y(x),x),x)+10*diff(y(x),x) = 0,y(x)],
[9084,-2*x*diff(diff(y(x),x),x)+(x^2+2)*diff(y(x),x)-2*x*y(x) = 0,y(x)],
[9086,(x^2+14*x-1)*diff(diff(y(x),x),x)+(4*x+4)*diff(y(x),x)+2*y(x) = 0,y(x)],
[9091,3*x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[9093,-4*x^2*diff(diff(y(x),x),x)+(x^3+8*x)*diff(y(x),x)+(-2*x^2-8)*y(x) = 0,y(x)],
[9096,(x^3+3*x^2)*diff(diff(y(x),x),x)+(5*x^2-30*x)*diff(y(x),x)+(4*x+30)*y(x) = 0,y(x)],
[9097,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-y(x) = 0,y(x)],
[9098,(6*x^2+3)*diff(diff(y(x),x),x)-12*y(x) = 0,y(x)],
[9099,(-3*x^2-6*x)*diff(diff(y(x),x),x)+(6*x+6)*diff(y(x),x)-6*y(x) = 0,y(x)],
[9101,(-4*x^3-2*x^2)*diff(diff(y(x),x),x)+(10*x^2+4*x)*diff(y(x),x)+(-12*x-4)*y(x) = 0,y(x)],
[9102,-4*x^3*diff(diff(y(x),x),x)+4*x^2*diff(y(x),x) = 0,y(x)],
[9103,(-4*x^4-2*x^2)*diff(diff(y(x),x),x)+(10*x^3+4*x)*diff(y(x),x)+(-12*x^2-4)*y(x) = 0,y(x)],
[9104,x^2*diff(diff(y(x),x),x)-2*y(x) = 0,y(x)],
[9117,-12*diff(diff(y(x),x),x)+12*y(x) = 0,y(x)],
[9125,-3*diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[9128,11*diff(diff(y(x),x),x)-3*diff(y(x),x) = 0,y(x)],
[9133,2*diff(diff(y(x),x),x) = 0,y(x)],
[9134,6*diff(diff(y(x),x),x) = 0,y(x)],
[9136,12*diff(diff(y(x),x),x) = 0,y(x)],
[9140,6*x*diff(diff(y(x),x),x) = 0,y(x)],
[9147,12*x^2*diff(diff(y(x),x),x) = 0,y(x)]];

print("main testing ");
for item in DATA do
    ODE := Object(kovacic_class,item[2],item[3]);
    sol := ODE:-dsolve();
    try 
        res_from_odetest := timelimit(60,odetest(sol,item[2]));
        if res_from_odetest <> 0 then
            number_failed := number_failed + 1;
            problems_failed ,= item[1];
            print(">>>>>>>>>>>>>>>>>Test ",item[1]," FAILED");
        else
            N:=N+1;
            print("Test ",item[1]," PASSED ");
            case_used := ODE:-get_case_used();
            cases_used_tally[case_used] := cases_used_tally[case_used]+1;
            if case_used = 3 then
                n_used := ODE:-get_n_case_3();
                if n_used = 4 then 
                   n_used_for_case_3_tally[1]:=n_used_for_case_3_tally[1]+1;
                elif n_used = 6 then 
                   n_used_for_case_3_tally[2]:=n_used_for_case_3_tally[2]+1;
                else
                   n_used_for_case_3_tally[3]:=n_used_for_case_3_tally[3]+1;
                fi;
            fi;
        fi;
        possible_cases := ODE:-get_possible_cases();
        if member(1,possible_cases) then 
           possible_cases_tally[1]:=possible_cases_tally[1]+1;
        fi;

        if member(2,possible_cases) then 
           possible_cases_tally[2]:=possible_cases_tally[2]+1;
        fi;

        if member(3,possible_cases) then 
           possible_cases_tally[3]:=possible_cases_tally[3]+1;
        fi;


    catch:
         print("Test ",item[1]," TIMEDOUT on odetest");
    end try;
od;


print("Number of ode is ",N,"\nNumber failed = ",number_failed);
if number_failed>0 then
   print("ID of problems fails = ",convert(problems_failed,list));
fi;

print("cases_used_tally=",cases_used_tally,
      "\nn_used_for_case_3_tally=",n_used_for_case_3_tally,
      "\npossible_cases_tally=",possible_cases_tally);

print("cases_used_tally as PERCENTAGE=",map(Z->Z*100./N,cases_used_tally),
      "\npossible_cases_tally as PERCENTAGE=",
            map(Z->Z*100./N,possible_cases_tally));
end proc;


#--------------------------------------------------------------------
#  CASE 1 tests
#--------------------------------------------------------------------
export unit_test_case_1:=proc()
local sol,ode,t::symbol,x::nothing,y::nothing,DATA::list;
local o::kovacic_class;
local item::list;

DATA :=[[1,diff(y(x),x$2)=(4*x^6-8*x^5+12*x^4+4*x^3+7*x^2-20*x+4)/(4*x^4)*y(x)],
    [2,x^2*diff(y(x),x$2)+4*x*diff(y(x),x)+(x^2+2)*y(x)=0],
    [3,diff(y(x),x$2)=2/x^2*y(x)],
    [4,diff(y(x),x$2)= y(x)],
    [5,(x^2-2*x)*diff(y(x),x$2)+(2-x^2)*diff(y(x),x)+(2*x-2)*y(x)=0],
    [6,(x^2+1)*diff(y(x),x$2)+2*x*diff(y(x),x)-2*y(x)=0],
    [7,(1-x)*diff(y(x),x$2)+x*diff(y(x),x)-y(x)=0],
    [8,diff(y(x),x$2)-x^2*diff(y(x),x)-3*x*y(x)=0],
    [9,diff(y(x),x$2)-2/5*x*diff(y(x),x)+2*y(x)=0],
    [10,diff(y(x),x$2)+(x^2-1)/x*diff(y(x),x)+x^2*y(x)=0],
   [11,(1-x)*diff(y(x),x$2)+x*diff(y(x),x)-y(x)=0],
   [12,3*diff(y(x),x$2)+x*diff(y(x),x)-4*y(x)=0],
   [13,(1+2*x)*diff(y(x),x$2)-2*diff(y(x),x)-(2*x+3)*y(x)=0],
   [14,(3*x-1)*diff(y(x),x$2)-(2+3*x)*diff(y(x),x)-(6*x-8)*y(x)=0],
   [15,(-x^2+1)*diff(y(x),x$2)-2*x*diff(y(x),x)+6*y(x)=0],
   [16,x*diff(y(x),x$2)+x*diff(y(x),x)-2*y(x)=0],
   [17,2*diff(y(x),x$2)+x*diff(y(x),x)-2*y(x)=0],
   [18,diff(y(x),x$2)-x*diff(y(x),x)-x*y(x)=0],
   [19,diff(y(x),x$2)=(x^2+3)*y(x)],
   [20,13*diff(y(x),x$2)+x*diff(y(x),x)-4*y(x)=0],
   [21,x^2*diff(y(x),x$2)-x*(2+x)*diff(y(x),x)+(2+x)*y(x)=0],
   [22,2*diff(y(x),x$2)+x*diff(y(x),x)+3*y(x)=0],
   [23,diff(y(x),x$2)+x*diff(y(x),x)+2*y(x)=0],
   [24,(1-x)*diff(y(x),x$2)+x*diff(y(x),x)-y(x)=0],
   [25,x^2*diff(y(x),x$2)-2*x*diff(y(x),x)+(x^2+2)*y(x)=0],
   [26,(x^2-2*x)*diff(y(x),x$2)+(-x^2+2)*diff(y(x),x)+(2*x-2)*y(x)=0],
   [27,4*x^2*diff(y(x),x$2)+(-8*x^2+4*x)*diff(y(x),x)+(4*x^2-4*x-1)*y(x)=0],
   [28,diff(y(x),x$2)+4*x*diff(y(x),x)+(4*x^2+2)*y(x)=0],
   [29,(1+2*x)*diff(y(x),x$2)-2*diff(y(x),x)-(2*x+3)*y(x)=0],
   [30,(4*x^2)*diff(y(x),x$2)-4*x*diff(y(x),x)+(-16*x^2+3)*y(x)=0],
   [31,(-1+x)*diff(y(x),x$2)-x*diff(y(x),x)+y(x)=0],
   [32,(3*x-1)*diff(y(x),x$2)-(2+3*x)*diff(y(x),x)-(6*x-8)*y(x)=0],
   [33,x^2*diff(y(x),x$2)-(6-7*x)*diff(y(x),x)+8*y(x)=0],
   [34,2*x^2*diff(y(x),x$2)-(2+3*x)*diff(y(x),x)+(2*x-1)/x*y(x)=0],
   [35,x^2*diff(y(x),x$2)-(6-7*x)*diff(y(x),x)+8*y(x)=0],
   [36,x^4*diff(y(x),x$2)+x*diff(y(x),x)+y(x)=0],
   [37,x^3*diff(y(x),x$2)+diff(y(x),x)-1/x*y(x)=0],
   [38,x^4*diff(y(x),x$2)+x*diff(y(x),x)+y(x)=0],
   [39,diff(y(x),x$2)=(2*x^2-1)/x^3*diff(y(x),x)-y(x)/x^4],
   [40,diff(y(x),x$2)=(2*x^2-1)/x^3*diff(y(x),x)-2*y(x)/x^4],
   [41,diff(y(x),x$2)=-diff(y(x),x)/x-(-x-1)/x^4*y(x)],
   [42,diff(y(x),x$2)=-diff(y(x),x)/x-(x-1)/x^4*y(x)],
   [43,diff(y(x),x$2)=(3*x+1)*diff(y(x),x)/((x-1)*(x+1))- 36*(1+x)^2*y(x)/( (x-1)^2*(3*x+5)^2)],
   [44,diff(y(x),x$2)=-3*y(x)/( 16*x^2*(x-1)^2)]
   ];


print("Testing case 1 ");
for item in DATA do
    o:=Object(kovacic_class,item[2],y(x));
    sol:= o:-dsolve_case(1);
    if odetest(sol,item[2]) <> 0 then
       print("Test ",item[1]," FAILED");
    else
       print("Test ",item[1]," PASSED ");
    fi;
od;
end proc;


#--------------------------------------------------------------------
#  CASE 2 tests
#--------------------------------------------------------------------
export unit_test_case_2:=proc()
local sol,ode,x::nothing,y::nothing,DATA::list;
local o::kovacic_class;
local item;

DATA :=[[1,(1+2*x)*diff(y(x),x$2)-2*diff(y(x),x)-(2*x+3)*y(x)=0],
     [2,(3*x-1)*diff(y(x),x$2)-(2+3*x)*diff(y(x),x)-(6*x-8)*y(x)=0],
     [3,diff(y(x),x$2)+2*diff(y(x),x)+(1+2/(1+3*x)^2)*y(x)=0],
     [4,(x^2+1)*diff(y(x),x$2)+2*x*diff(y(x),x)-2*y(x)=0],
     [5,(x^2-6*x+10)*diff(y(x),x$2)-4*(x-3)*diff(y(x),x)+6*y(x)=0],
     [6,(x^2+6*x)*diff(y(x),x$2)+(3*x+9)*diff(y(x),x)-3*y(x)=0],     
     [7,x*diff(y(x),x$2)-(x+1)*diff(y(x),x)+y(x)=0],
     [8,(-x^2+4)*diff(y(x),x$2)+x*diff(y(x),x)+2*y(x)=0],
     [9,2*x^2*diff(y(x),x$2)-x*diff(y(x),x)+(-2*x+1)*y(x)=0],
     [10,2*x^2*diff(y(x),x$2)+5*x*diff(y(x),x)+(1+x)*y(x)=0], #case 2 ONLY !!
     [11,2*x^2*diff(y(x),x$2)-x*diff(y(x),x)+(1+x)*y(x)=0], #case 2 ONLY !!
     [12,2*x*diff(y(x),x$2)-diff(y(x),x)+2*y(x)=0], #case 2 ONLY !!
     [13,2*x^2*diff(y(x),x$2)+3*x*diff(y(x),x)+(2*x-1)*y(x)=0], #case 2 ONLY !!
     [14,x^2*diff(y(x),x$2)+(x+3/4)/4*y(x)=0], #case 2 ONLY !!
     [15,2*x^2*diff(y(x),x$2)+3*x*diff(y(x),x)-x*y(x)=0],
     [16,x^2*(1-x^2)*diff(y(x),x$2)+2*x*(1-x^2)*diff(y(x),x)-2*y(x)=0],
     [17,diff(y(x),x$2)=(1/x-3/(16*x^2))*y(x)],
     [18,2*x^2*diff(y(x),x$2)-x*diff(y(x),x)+(1-2*x)*y(x)=0],
     [19,2*x^2*diff(y(x),x$2)+5*x*diff(y(x),x)+(1+x)*y(x)=0],
     [20,2*x^2*diff(y(x),x$2)-x*diff(y(x),x)+(1+x)*y(x)=0],
     [21,x^2*(1-4*x)*diff(y(x),x$2)-x/2*diff(y(x),x)-3*x/4*y(x)=0],
     [22,(1-x^2)*diff(y(x),x$2)-diff(y(x),x)+y(x)=0],
     [23,(4-x^2)*diff(y(x),x$2)+x*diff(y(x),x)+2*y(x)=0],
     [24,diff(y(x),x$2)=-27*x*y(x)/(16*(x^3-1)^2)],
     [25,diff(y(x),x$2)=(3*x+1)*diff(y(x),x)/((x-1)*(x+1))- 36*(1+x)^2*y(x)/( (x-1)^2*(3*x+5)^2)],
     [26,diff(y(x),x$2)=-3*y(x)/( 16*x^2*(x-1)^2)],
     [27,2*x*diff(y(x),x$2)-diff(y(x),x)+2*y(x)=0],
     [28,diff(y(x),x$2)=-27*x*y(x)/(16*(x^3-1)^2)]];

print("Testing case 2 ");
for item in DATA do
    o:=Object(kovacic_class,item[2],y(x));
    sol:= o:-dsolve_case(2);
    if odetest(sol,item[2]) <> 0 then
       print("Test ",item[1]," FAILED");
    else
       print("Test ",item[1]," PASSED ");
    fi;
od;

end proc;

#--------------------------------------------------------------------
#  CASE 3 tests
#--------------------------------------------------------------------
export unit_test_case_3:=proc()
local sol,ode,x::nothing,y::nothing,DATA::list;
local o::kovacic_class;
local item;


DATA :=[[1,(x^2+6*x)*diff(y(x),x$2)+(3*x+9)*diff(y(x),x)-3*y(x)=0],
     [2,(x^2+1)*diff(y(x),x$2)-4*x*diff(y(x),x)+6*y(x)=0],
     [3,(-x^2+4)*diff(y(x),x$2)+x*diff(y(x),x)+2*y(x)=0],#signum
     [4,diff(y(x),x$2) = ( -3/(16*x^2) - 2/( 9*(x-1)^2)+3/( 16*x*(x-1)))*y(x)],
     [5,x^2*(1+x)*diff(y(x),x$2)+x*(1+2*x)*diff(y(x),x)-(4+6*x)*y(x)=0],
     [6,(x-2)*diff(y(x),x$2)+3*diff(y(x),x)+4/x^2*y(x)=0],        
     [7,diff(y(x),x$2)+2*diff(y(x),x)+(1+2/(3*x+1)^2 )*y(x)=0],
     [8,diff(y(x),x$2)=(-3/(16*x^2)-2/(9*(-1+x)^2)+ 3/(16*x*(x-1)))*y(x)],
     [9,diff(y(x),x$2)=20/x^2*y(x)],
     [10,x*diff(y(x),x$2)-(2*x+2)*diff(y(x),x)+(2+x)*y(x)=0],
     [11,(1-x^2)*diff(y(x),x$2)+diff(y(x),x)+y(x)=0],#signum
     [12,diff(y(x),x$2)+y(x)/x^2=0],     
     [13,diff(y(x),x$2)=(3*x+1)*diff(y(x),x)/((x-1)*(x+1))- 36*(1+x)^2*y(x)/( (x-1)^2*(3*x+5)^2)],
     [14,diff(y(x),x$2)=-3*y(x)/( 16*x^2*(x-1)^2)],
     [15,diff(y(x),x$2)=- (5*x^2+27)*y(x)/( 36*(x^2-1)^2 )],
     [16,(-x^2+4)*diff(y(x),x$2)+x*diff(y(x),x)+2*y(x)=0] #signum
 
];   

print("Testing case 3 ");
for item in DATA do
    o:=Object(kovacic_class,item[2],y(x));
    sol:= o:-dsolve_case(3);
    if odetest(sol,item[2]) <> 0 then
       print("Test ",item[1]," FAILED");
    else
       print("Test ",item[1]," PASSED ");
    fi;
od;

end proc;



#--------------------------------------------------------------------
#  test using my original code
#--------------------------------------------------------------------
export unit_test_old_api:=proc()
local sol,ode,x::nothing,y::nothing,DATA::list;
local N::integer:=0;
local ODE;
local item::list;
local f::symbol,r::symbol,z::symbol;
local u::symbol,v::symbol;
local res_from_odetest;

#keep track of COUNT which case uses. 1,2 or 3.
local cases_used_tally:=[0,0,0]; 
local case_used::integer;

#keep track of n used by case 3
local n_used_for_case_3_tally:=[0,0,0]; 
local n_used::integer;

#keep track of distribution of cases that meets neccessary conditions
local possible_cases_tally:=[0,0,0]; 
local possible_cases::list;
local number_failed::integer:=0;
local problems_failed:=Array(1..0);
local Z;
local res;

DATA :=[[157,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[158,diff(diff(y(x),x),x)-9*y(x) = 0,y(x)],
[159,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[160,diff(diff(y(x),x),x)+25*y(x) = 0,y(x)],
[161,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[162,diff(diff(y(x),x),x)+diff(y(x),x)-6*y(x) = 0,y(x)],
[163,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[164,diff(diff(y(x),x),x)-3*diff(y(x),x) = 0,y(x)],
[165,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[166,diff(diff(y(x),x),x)-10*diff(y(x),x)+25*y(x) = 0,y(x)],
[167,diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[168,diff(diff(y(x),x),x)+6*diff(y(x),x)+13*y(x) = 0,y(x)],
[169,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[170,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-6*y(x) = 0,y(x)],
[171,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[172,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[173,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[174,diff(diff(y(x),x),x)+2*diff(y(x),x)-15*y(x) = 0,y(x)],
[175,diff(diff(y(x),x),x)+5*diff(y(x),x) = 0,y(x)],
[176,2*diff(diff(y(x),x),x)+3*diff(y(x),x) = 0,y(x)],
[177,2*diff(diff(y(x),x),x)-diff(y(x),x)-y(x) = 0,y(x)],
[178,4*diff(diff(y(x),x),x)+8*diff(y(x),x)+3*y(x) = 0,y(x)],
[179,4*diff(diff(y(x),x),x)+4*diff(y(x),x)+y(x) = 0,y(x)],
[180,9*diff(diff(y(x),x),x)-12*diff(y(x),x)+4*y(x) = 0,y(x)],
[181,6*diff(diff(y(x),x),x)-7*diff(y(x),x)-20*y(x) = 0,y(x)],
[182,35*diff(diff(y(x),x),x)-diff(y(x),x)-12*y(x) = 0,y(x)],
[183,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[184,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-12*y(x) = 0,y(x)],
[185,4*x^2*diff(diff(y(x),x),x)+8*x*diff(y(x),x)-3*y(x) = 0,y(x)],
[186,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x) = 0,y(x)],
[187,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[188,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[189,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[190,diff(diff(y(x),x),x)-2*diff(y(x),x)-3*y(x) = 0,y(x)],
[191,diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[192,diff(diff(y(x),x),x)+2*y(x) = 0,y(x)],
[193,diff(diff(y(x),x),x)+2*y(x) = 0,y(x)],
[194,diff(diff(y(x),x),x)+2*y(x) = 0,y(x)],
[195,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[196,2*diff(diff(y(x),x),x)-3*diff(y(x),x) = 0,y(x)],
[197,diff(diff(y(x),x),x)+3*diff(y(x),x)-10*y(x) = 0,y(x)],
[198,2*diff(diff(y(x),x),x)-7*diff(y(x),x)+3*y(x) = 0,y(x)],
[199,diff(diff(y(x),x),x)+6*diff(y(x),x)+9*y(x) = 0,y(x)],
[200,diff(diff(y(x),x),x)+5*diff(y(x),x)+5*y(x) = 0,y(x)],
[201,4*diff(diff(y(x),x),x)-12*diff(y(x),x)+9*y(x) = 0,y(x)],
[202,diff(diff(y(x),x),x)-6*diff(y(x),x)+13*y(x) = 0,y(x)],
[203,diff(diff(y(x),x),x)+8*diff(y(x),x)+25*y(x) = 0,y(x)],
[204,diff(diff(y(x),x),x)-4*diff(y(x),x)+3*y(x) = 0,y(x)],
[205,9*diff(diff(y(x),x),x)+6*diff(y(x),x)+4*y(x) = 0,y(x)],
[206,diff(diff(y(x),x),x)-6*diff(y(x),x)+25*y(x) = 0,y(x)],
[207,diff(diff(y(x),x),x)-2*I*diff(y(x),x)+3*y(x) = 0,y(x)],
[208,diff(diff(y(x),x),x)-I*diff(y(x),x)+6*y(x) = 0,y(x)],
[209,diff(diff(y(x),x),x)+(-2*I*3^(1/2)+2)*y(x) = 0,y(x)],
[210,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+9*y(x) = 0,y(x)],
[211,x^2*diff(diff(y(x),x),x)+7*x*diff(y(x),x)+25*y(x) = 0,y(x)],
[212,1/2*diff(diff(x(t),t),t)+3*diff(x(t),t)+4*x(t) = 0,x(t)],
[213,3*diff(diff(x(t),t),t)+30*diff(x(t),t)+63*x(t) = 0,x(t)],
[214,diff(diff(x(t),t),t)+8*diff(x(t),t)+16*x(t) = 0,x(t)],
[215,2*diff(diff(x(t),t),t)+12*diff(x(t),t)+50*x(t) = 0,x(t)],
[216,4*diff(diff(x(t),t),t)+20*diff(x(t),t)+169*x(t) = 0,x(t)],
[217,2*diff(diff(x(t),t),t)+16*diff(x(t),t)+40*x(t) = 0,x(t)],
[218,diff(diff(x(t),t),t)+10*diff(x(t),t)+125*x(t) = 0,x(t)],
[219,diff(diff(y(x),x),x)+16*y(x) = 0,y(x)],
[220,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[221,diff(diff(y(x),x),x)-diff(y(x),x)-6*y(x) = 0,y(x)],
[222,4*diff(diff(y(x),x),x)+4*diff(y(x),x)+y(x) = 0,y(x)],
[223,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[224,2*diff(diff(y(x),x),x)+4*diff(y(x),x)+7*y(x) = 0,y(x)],
[225,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[226,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[227,diff(diff(y(x),x),x)+2*diff(y(x),x)-3*y(x) = 0,y(x)],
[228,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[229,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[230,diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[231,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[232,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[233,diff(diff(y(x),x),x)-6*diff(y(x),x)+13*y(x) = 0,y(x)],
[234,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[235,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[236,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[237,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[238,diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[239,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[240,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[241,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[242,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[243,diff(diff(y(x),x),x)-2*diff(y(x),x)-8*y(x) = 0,y(x)],
[244,diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[245,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[246,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[247,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[248,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[249,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[250,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[251,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[252,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[253,x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[254,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[255,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+3*y(x) = 0,y(x)],
[256,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[257,(x^2-1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[258,diff(diff(x(t),t),t)+9*x(t) = 0,x(t)],
[259,diff(diff(x(t),t),t)+4*x(t) = 0,x(t)],
[260,diff(diff(x(t),t),t)+100*x(t) = 0,x(t)],
[261,diff(diff(x(t),t),t)+25*x(t) = 0,x(t)],
[262,m*diff(diff(x(t),t),t)+k*x(t) = 0,x(t)],
[263,diff(diff(x(t),t),t)+4*diff(x(t),t)+4*x(t) = 0,x(t)],
[264,diff(diff(x(t),t),t)+3*diff(x(t),t)+5*x(t) = 0,x(t)],
[265,2*diff(diff(x(t),t),t)+2*diff(x(t),t)+x(t) = 0,x(t)],
[266,diff(diff(x(t),t),t)+3*diff(x(t),t)+3*x(t) = 0,x(t)],
[267,diff(diff(x(t),t),t)+4*diff(x(t),t)+5*x(t) = 0,x(t)],
[268,diff(diff(x(t),t),t)+6*diff(x(t),t)+13*x(t) = 0,x(t)],
[269,diff(diff(x(t),t),t)+6*diff(x(t),t)+13*x(t) = 0,x(t)],
[270,diff(diff(x(t),t),t)+2*diff(x(t),t)+26*x(t) = 0,x(t)],
[271,diff(diff(x(t),t),t)+8*diff(x(t),t)+25*x(t) = 0,x(t)],
[278,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-9*y(x) = 0,y(x)],
[279,4*diff(diff(y(x),x),x)-4*diff(y(x),x)+y(x) = 0,y(x)],
[280,x^2*diff(diff(y(x),x),x)+(-x^2-2*x)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[281,(x+1)*diff(diff(y(x),x),x)+(-x-2)*diff(y(x),x)+y(x) = 0,y(x)],
[282,(-x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[283,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[284,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[286,16*diff(diff(y(x),x),x) = 0,y(x)],
[287,3*diff(diff(y(x),x),x)-diff(y(x),x) = 0,y(x)],
[288,12*diff(diff(y(x),x),x)+4*diff(y(x),x) = 0,y(x)],
[289,3*diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[290,-16*diff(diff(y(x),x),x)+16*y(x) = 0,y(x)],
[291,18*diff(diff(y(x),x),x)+81*y(x) = 0,y(x)],
[292,11*diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[294,diff(diff(y(x),x),x)-diff(y(x),x)-y(x) = 0,y(x)],
[295,3*diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[296,-3*diff(diff(y(x),x),x)-2*diff(y(x),x) = 0,y(x)],
[297,2*diff(diff(y(x),x),x) = 0,y(x)],
[298,10*diff(diff(y(x),x),x)+25*diff(y(x),x) = 0,y(x)],
[299,3*diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[300,-diff(diff(y(x),x),x)-5*diff(y(x),x)-2*y(x) = 0,y(x)],
[302,diff(diff(y(x),x),x)-3*diff(y(x),x)-6*y(x) = 0,y(x)],
[303,3*diff(diff(y(x),x),x)+4*diff(y(x),x)-8*y(x) = 0,y(x)],
[304,-3*diff(diff(y(x),x),x)-5*diff(y(x),x)-2*y(x) = 0,y(x)],
[305,-5*diff(diff(y(x),x),x)+100*diff(y(x),x)-500*y(x) = 0,y(x)],
[307,-diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[308,6*x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x) = 0,y(x)],
[309,-x^2*diff(diff(y(x),x),x)+x*diff(y(x),x) = 0,y(x)],
[310,3*x^2*diff(diff(y(x),x),x)+x*diff(y(x),x) = 0,y(x)],
[311,-3*x^2*diff(diff(y(x),x),x)+x*diff(y(x),x) = 0,y(x)],
[312,6*x^2*diff(diff(y(x),x),x)+7*x*diff(y(x),x)+y(x) = 0,y(x)],
[402,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[403,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[404,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[405,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[410,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[411,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[412,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[413,diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[416,(x^2-1)*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[417,(x^2+2)*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[418,diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[419,(x^2+1)*diff(diff(y(x),x),x)+6*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[420,(x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x) = 0,y(x)],
[421,(x^2-1)*diff(diff(y(x),x),x)-6*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[422,(x^2+3)*diff(diff(y(x),x),x)-7*x*diff(y(x),x)+16*y(x) = 0,y(x)],
[423,(-x^2+2)*diff(diff(y(x),x),x)-x*diff(y(x),x)+16*y(x) = 0,y(x)],
[424,(x^2-1)*diff(diff(y(x),x),x)+8*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[425,3*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[426,5*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+10*y(x) = 0,y(x)],
[427,diff(diff(y(x),x),x)-x^2*diff(y(x),x)-3*x*y(x) = 0,y(x)],
[428,diff(diff(y(x),x),x)+x^2*diff(y(x),x)+2*x*y(x) = 0,y(x)],
[431,(x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[432,diff(diff(y(x),x),x)+x*diff(y(x),x)-2*y(x) = 0,y(x)],
[433,diff(diff(y(x),x),x)+(x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[434,(-x^2+2*x)*diff(diff(y(x),x),x)+(-6*x+6)*diff(y(x),x)-4*y(x) = 0,y(x)],
[435,(x^2-6*x+10)*diff(diff(y(x),x),x)+(-4*x+12)*diff(y(x),x)+6*y(x) = 0,y(x)],
[436,(4*x^2+16*x+17)*diff(diff(y(x),x),x)-8*y(x) = 0,y(x)],
[437,(x^2+6*x)*diff(diff(y(x),x),x)+(3*x+9)*diff(y(x),x)-3*y(x) = 0,y(x)],
[599,diff(diff(y(x),x),x)+2*diff(y(x),x)-3*y(x) = 0,y(x)],
[600,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[601,6*diff(diff(y(x),x),x)-diff(y(x),x)-y(x) = 0,y(x)],
[602,2*diff(diff(y(x),x),x)-3*diff(y(x),x)+y(x) = 0,y(x)],
[603,diff(diff(y(x),x),x)+5*diff(y(x),x) = 0,y(x)],
[604,4*diff(diff(y(x),x),x)-9*y(x) = 0,y(x)],
[605,diff(diff(y(x),x),x)-9*diff(y(x),x)+9*y(x) = 0,y(x)],
[606,diff(diff(y(x),x),x)-2*diff(y(x),x)-2*y(x) = 0,y(x)],
[607,diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[608,diff(diff(y(x),x),x)+4*diff(y(x),x)+3*y(x) = 0,y(x)],
[609,6*diff(diff(y(x),x),x)-5*diff(y(x),x)+y(x) = 0,y(x)],
[610,diff(diff(y(x),x),x)+3*diff(y(x),x) = 0,y(x)],
[611,diff(diff(y(x),x),x)+5*diff(y(x),x)+3*y(x) = 0,y(x)],
[612,2*diff(diff(y(x),x),x)+diff(y(x),x)-4*y(x) = 0,y(x)],
[613,diff(diff(y(x),x),x)+8*diff(y(x),x)-9*y(x) = 0,y(x)],
[614,4*diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[615,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[616,2*diff(diff(y(x),x),x)-3*diff(y(x),x)+y(x) = 0,y(x)],
[617,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[618,4*diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[621,2*diff(diff(y(x),x),x)+3*diff(y(x),x)-2*y(x) = 0,y(x)],
[622,diff(diff(y(x),x),x)+5*diff(y(x),x)+6*y(x) = 0,y(x)],
[623,diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[624,diff(diff(y(x),x),x)-2*diff(y(x),x)+6*y(x) = 0,y(x)],
[625,diff(diff(y(x),x),x)+2*diff(y(x),x)-8*y(x) = 0,y(x)],
[626,diff(diff(y(x),x),x)+2*diff(y(x),x)+2*y(x) = 0,y(x)],
[627,diff(diff(y(x),x),x)+6*diff(y(x),x)+13*y(x) = 0,y(x)],
[628,4*diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[629,diff(diff(y(x),x),x)+2*diff(y(x),x)+5/4*y(x) = 0,y(x)],
[630,9*diff(diff(y(x),x),x)+9*diff(y(x),x)-4*y(x) = 0,y(x)],
[631,diff(diff(y(x),x),x)+diff(y(x),x)+5/4*y(x) = 0,y(x)],
[632,diff(diff(y(x),x),x)+4*diff(y(x),x)+25/4*y(x) = 0,y(x)],
[633,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[634,diff(diff(y(x),x),x)+4*diff(y(x),x)+5*y(x) = 0,y(x)],
[635,diff(diff(y(x),x),x)-2*diff(y(x),x)+5*y(x) = 0,y(x)],
[636,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[637,diff(diff(y(x),x),x)+diff(y(x),x)+5/4*y(x) = 0,y(x)],
[638,diff(diff(y(x),x),x)+2*diff(y(x),x)+2*y(x) = 0,y(x)],
[639,diff(diff(u(x),x),x)-diff(u(x),x)+2*u(x) = 0,u(x)],
[640,5*diff(diff(u(x),x),x)+2*diff(u(x),x)+7*u(x) = 0,u(x)],
[641,diff(diff(y(x),x),x)+2*diff(y(x),x)+6*y(x) = 0,y(x)],
[643,t^2*diff(diff(y(t),t),t)+t*diff(y(t),t)+y(t) = 0,y(t)],
[644,t^2*diff(diff(y(t),t),t)+4*t*diff(y(t),t)+2*y(t) = 0,y(t)],
[645,t^2*diff(diff(y(t),t),t)+3*t*diff(y(t),t)+5/4*y(t) = 0,y(t)],
[646,t^2*diff(diff(y(t),t),t)-4*t*diff(y(t),t)-6*y(t) = 0,y(t)],
[647,t^2*diff(diff(y(t),t),t)-4*t*diff(y(t),t)+6*y(t) = 0,y(t)],
[648,t^2*diff(diff(y(t),t),t)-t*diff(y(t),t)+5*y(t) = 0,y(t)],
[649,t^2*diff(diff(y(t),t),t)+3*t*diff(y(t),t)-3*y(t) = 0,y(t)],
[650,t^2*diff(diff(y(t),t),t)+7*t*diff(y(t),t)+10*y(t) = 0,y(t)],
[652,t*diff(diff(y(t),t),t)+(t^2-1)*diff(y(t),t)+t^3*y(t) = 0,y(t)],
[653,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[654,9*diff(diff(y(x),x),x)+6*diff(y(x),x)+y(x) = 0,y(x)],
[655,4*diff(diff(y(x),x),x)-4*diff(y(x),x)-3*y(x) = 0,y(x)],
[656,4*diff(diff(y(x),x),x)+12*diff(y(x),x)+9*y(x) = 0,y(x)],
[657,diff(diff(y(x),x),x)-2*diff(y(x),x)+10*y(x) = 0,y(x)],
[658,diff(diff(y(x),x),x)-6*diff(y(x),x)+9*y(x) = 0,y(x)],
[659,4*diff(diff(y(x),x),x)+17*diff(y(x),x)+4*y(x) = 0,y(x)],
[660,16*diff(diff(y(x),x),x)+24*diff(y(x),x)+9*y(x) = 0,y(x)],
[661,25*diff(diff(y(x),x),x)-20*diff(y(x),x)+4*y(x) = 0,y(x)],
[662,2*diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[663,9*diff(diff(y(t),t),t)-12*diff(y(t),t)+4*y(t) = 0,y(t)],
[664,diff(diff(y(t),t),t)-6*diff(y(t),t)+9*y(t) = 0,y(t)],
[665,9*diff(diff(y(t),t),t)+6*diff(y(t),t)+82*y(t) = 0,y(t)],
[666,diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[667,4*diff(diff(y(t),t),t)+12*diff(y(t),t)+9*y(t) = 0,y(t)],
[668,diff(diff(y(t),t),t)-diff(y(t),t)+1/4*y(t) = 0,y(t)],
[669,t^2*diff(diff(y(t),t),t)-4*t*diff(y(t),t)+6*y(t) = 0,y(t)],
[670,t^2*diff(diff(y(t),t),t)+2*t*diff(y(t),t)-2*y(t) = 0,y(t)],
[671,t^2*diff(diff(y(t),t),t)+3*t*diff(y(t),t)+y(t) = 0,y(t)],
[672,t^2*diff(diff(y(t),t),t)+(-t^2-2*t)*diff(y(t),t)+(t+2)*y(t) = 0,y(t)],
[673,x*diff(diff(y(x),x),x)-diff(y(x),x)+4*x^3*y(x) = 0,y(x)],
[674,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[675,x^2*diff(diff(y(x),x),x)+(-x+3/16)*y(x) = 0,y(x)],
[676,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[677,t^2*diff(diff(y(t),t),t)-3*t*diff(y(t),t)+4*y(t) = 0,y(t)],
[678,t^2*diff(diff(y(t),t),t)+2*t*diff(y(t),t)+1/4*y(t) = 0,y(t)],
[679,2*t^2*diff(diff(y(t),t),t)-5*t*diff(y(t),t)+5*y(t) = 0,y(t)],
[680,t^2*diff(diff(y(t),t),t)+3*t*diff(y(t),t)+y(t) = 0,y(t)],
[681,4*t^2*diff(diff(y(t),t),t)-8*t*diff(y(t),t)+9*y(t) = 0,y(t)],
[682,t^2*diff(diff(y(t),t),t)+5*t*diff(y(t),t)+13*y(t) = 0,y(t)],
[683,diff(diff(y(t),t),t)-5*diff(y(t),t)+6*y(t) = 0,y(t)],
[684,diff(diff(y(t),t),t)-diff(y(t),t)-2*y(t) = 0,y(t)],
[685,diff(diff(y(t),t),t)+2*diff(y(t),t)+y(t) = 0,y(t)],
[686,4*diff(diff(y(t),t),t)-4*diff(y(t),t)+y(t) = 0,y(t)],
[687,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[688,diff(diff(y(t),t),t)+9*y(t) = 0,y(t)],
[689,diff(diff(y(t),t),t)+4*diff(y(t),t)+4*y(t) = 0,y(t)],
[690,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[691,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[692,diff(diff(y(t),t),t)-2*diff(y(t),t)+y(t) = 0,y(t)],
[693,diff(diff(y(t),t),t)-5*diff(y(t),t)+6*y(t) = 0,y(t)],
[694,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[695,t^2*diff(diff(y(t),t),t)-2*y(t) = 0,y(t)],
[696,t^2*diff(diff(y(t),t),t)+(-t^2-2*t)*diff(y(t),t)+(t+2)*y(t) = 0,y(t)],
[697,t*diff(diff(y(t),t),t)+(-t-1)*diff(y(t),t)+y(t) = 0,y(t)],
[698,(1-t)*diff(diff(y(t),t),t)+t*diff(y(t),t)-y(t) = 0,y(t)],
[699,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[700,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[701,t^2*diff(diff(y(t),t),t)-2*t*diff(y(t),t)+2*y(t) = 0,y(t)],
[702,t^2*diff(diff(y(t),t),t)+7*t*diff(y(t),t)+5*y(t) = 0,y(t)],
[703,t*diff(diff(y(t),t),t)+(-t-1)*diff(y(t),t)+y(t) = 0,y(t)],
[704,(1-t)*diff(diff(y(t),t),t)+t*diff(y(t),t)-y(t) = 0,y(t)],
[705,diff(diff(u(t),t),t)+2*u(t) = 0,u(t)],
[706,diff(diff(u(t),t),t)+1/4*diff(u(t),t)+2*u(t) = 0,u(t)],
[707,diff(diff(u(t),t),t)+1/8*diff(u(t),t)+4*u(t) = 0,u(t)],
[708,diff(diff(u(t),t),t)+1/8*diff(u(t),t)+4*u(t) = 0,u(t)],
[709,diff(diff(u(t),t),t)+1/8*diff(u(t),t)+4*u(t) = 0,u(t)],
[711,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[712,diff(diff(y(x),x),x)-x*diff(y(x),x)-y(x) = 0,y(x)],
[715,(x^2+2)*diff(diff(y(x),x),x)-x*diff(y(x),x)+4*y(x) = 0,y(x)],
[716,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[717,(x^2+1)*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[718,(-x^2+4)*diff(diff(y(x),x),x)+2*y(x) = 0,y(x)],
[719,(-x^2+3)*diff(diff(y(x),x),x)-3*x*diff(y(x),x)-y(x) = 0,y(x)],
[720,(1-x)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[721,2*diff(diff(y(x),x),x)+x*diff(y(x),x)+3*y(x) = 0,y(x)],
[722,diff(diff(y(x),x),x)-x*diff(y(x),x)-y(x) = 0,y(x)],
[723,(x^2+2)*diff(diff(y(x),x),x)-x*diff(y(x),x)+4*y(x) = 0,y(x)],
[724,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[725,(1-x)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[727,diff(diff(y(x),x),x)-x*diff(y(x),x)-y(x) = 0,y(x)],
[728,(x^2+2)*diff(diff(y(x),x),x)-x*diff(y(x),x)+4*y(x) = 0,y(x)],
[729,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[730,(-x^2+4)*diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[732,(1-x)*diff(diff(y(x),x),x)+x*diff(y(x),x)-2*y(x) = 0,y(x)],
[733,diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[814,diff(diff(y(t),t),t) = 0,y(t)],
[815,2*diff(diff(y(t),t),t)-diff(y(t),t)-2*y(t) = 0,y(t)],
[816,-diff(diff(y(x),x),x) = 0,y(x)],
[817,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[818,2*diff(diff(y(x),x),x)-diff(y(x),x)-3*y(x) = 0,y(x)],
[820,(2*t-3)*diff(diff(y(t),t),t)-t*diff(y(t),t)+y(t) = 0,y(t)],
[821,(-3*t^2-6*t)*diff(diff(y(t),t),t)+(6*t+6)*diff(y(t),t)-6*y(t) = 0,y(t)],
[822,-diff(diff(y(x),x),x)-diff(y(x),x)+y(x) = 0,y(x)],
[823,-3*diff(diff(y(x),x),x)+3*diff(y(x),x)+y(x) = 0,y(x)],
[824,4*diff(diff(y(x),x),x) = 0,y(x)],
[826,3*diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[827,-diff(diff(y(x),x),x) = 0,y(x)],
[828,-3*diff(diff(y(x),x),x)+2*diff(y(x),x) = 0,y(x)],
[830,2*diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[831,5*diff(diff(y(x),x),x)+6*diff(y(x),x)+2*y(x) = 0,y(x)],
[832,6*diff(diff(y(x),x),x)+30*diff(y(x),x)-36*y(x) = 0,y(x)],
[833,diff(diff(y(t),t),t)-diff(y(t),t)-6*y(t) = 0,y(t)],
[834,diff(diff(y(t),t),t)+3*diff(y(t),t)+2*y(t) = 0,y(t)],
[835,diff(diff(y(t),t),t)-2*diff(y(t),t)+2*y(t) = 0,y(t)],
[836,diff(diff(y(t),t),t)-2*diff(y(t),t)+4*y(t) = 0,y(t)],
[837,diff(diff(y(t),t),t)+2*diff(y(t),t)+5*y(t) = 0,y(t)],
[838,6*diff(diff(y(t),t),t)-4*diff(y(t),t)+y(t) = 0,y(t)],
[841,diff(diff(y(t),t),t)-2*diff(y(t),t)+2*y(t) = 0,y(t)],
[842,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[843,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[844,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[845,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[846,diff(diff(y(t),t),t)+2*diff(y(t),t)+2*y(t) = 0,y(t)],
[847,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[848,diff(diff(y(t),t),t)+3*diff(y(t),t)+2*y(t) = 0,y(t)],
[849,diff(diff(y(t),t),t)+diff(y(t),t)+5/4*y(t) = 0,y(t)],
[850,diff(diff(y(t),t),t)+diff(y(t),t)+5/4*y(t) = 0,y(t)],
[851,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[852,5*diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[853,diff(diff(u(t),t),t)+1/4*diff(u(t),t)+u(t) = 0,u(t)],
[854,diff(diff(u(t),t),t)+1/4*diff(u(t),t)+u(t) = 0,u(t)],
[855,diff(diff(u(t),t),t)+1/4*diff(u(t),t)+u(t) = 0,u(t)],
[856,diff(diff(y(t),t),t)+2*diff(y(t),t)+2*y(t) = 0,y(t)],
[857,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[858,diff(diff(y(t),t),t)+3*diff(y(t),t)+2*y(t) = 0,y(t)],
[859,diff(diff(y(t),t),t)+2*diff(y(t),t)+3*y(t) = 0,y(t)],
[860,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[861,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[862,diff(diff(y(t),t),t)+2*diff(y(t),t)+2*y(t) = 0,y(t)],
[864,diff(diff(y(t),t),t)+1/2*diff(y(t),t)+y(t) = 0,y(t)],
[865,diff(diff(y(t),t),t)+1/4*diff(y(t),t)+y(t) = 0,y(t)],
[866,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[867,diff(diff(y(t),t),t)+2*diff(y(t),t)+2*y(t) = 0,y(t)],
[868,diff(diff(y(t),t),t)+2*diff(y(t),t)+2*y(t) = 0,y(t)],
[1087,diff(diff(y(x),x),x)-7*diff(y(x),x)+10*y(x) = 0,y(x)],
[1088,diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[1089,diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[1090,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[1091,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[1092,(x^2-1)*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1093,diff(diff(y(x),x),x)-2*diff(y(x),x)-3*y(x) = 0,y(x)],
[1094,diff(diff(y(x),x),x)-6*diff(y(x),x)+9*y(x) = 0,y(x)],
[1096,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[1097,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[1099,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(-16*x^2+3)*y(x) = 0,y(x)],
[1100,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[1101,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[1104,(x^2-4)*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1106,(x^2-2*x)*diff(diff(y(x),x),x)+(-x^2+2)*diff(y(x),x)+(2*x-2)*y(x) = 0,y(x)],
[1107,(2*x+1)*diff(diff(y(x),x),x)-2*diff(y(x),x)+(-2*x-3)*y(x) = 0,y(x)],
[1108,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[1109,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[1110,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[1111,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[1112,4*x^2*diff(diff(y(x),x),x)+(-8*x^2+4*x)*diff(y(x),x)+(4*x^2-4*x-1)*y(x) = 0,y(x)],
[1113,diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[1114,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[1115,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[1116,x^2*diff(diff(y(x),x),x)+(2*x^2-2*x)*diff(y(x),x)+(x^2-2*x+2)*y(x) = 0,y(x)],
[1117,x^2*diff(diff(y(x),x),x)+(-2*x^2+x)*diff(y(x),x)+(x^2-x-1)*y(x) = 0,y(x)],
[1118,(1-2*x)*diff(diff(y(x),x),x)+2*diff(y(x),x)+(2*x-3)*y(x) = 0,y(x)],
[1119,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[1120,2*x*diff(diff(y(x),x),x)+(1+4*x)*diff(y(x),x)+(2*x+1)*y(x) = 0,y(x)],
[1121,x*diff(diff(y(x),x),x)+(-2*x-1)*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[1122,4*x^2*diff(diff(y(x),x),x)+(-4*x^2-4*x)*diff(y(x),x)+(2*x+3)*y(x) = 0,y(x)],
[1123,x^2*diff(diff(y(x),x),x)-5*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[1124,x*diff(diff(y(x),x),x)+(-2*x+2)*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[1125,x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[1127,4*x*diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[1128,x*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[1130,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[1131,x*diff(diff(y(x),x),x)+(-4*x-1)*diff(y(x),x)+(4*x+2)*y(x) = 0,y(x)],
[1133,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(-16*x^2+3)*y(x) = 0,y(x)],
[1134,(2*x^2+x)*diff(diff(y(x),x),x)+(-4*x^2+2)*diff(y(x),x)+(-4*x-4)*y(x) = 0,y(x)],
[1135,(x^2-2*x)*diff(diff(y(x),x),x)+(-x^2+2)*diff(y(x),x)+(2*x-2)*y(x) = 0,y(x)],
[1136,x*diff(diff(y(x),x),x)+(-4*x-1)*diff(y(x),x)+(4*x+2)*y(x) = 0,y(x)],
[1137,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[1138,(3*x-1)*diff(diff(y(x),x),x)+(-3*x-2)*diff(y(x),x)+(-6*x+8)*y(x) = 0,y(x)],
[1139,(x^2+2*x+1)*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+(-x^2-2*x+1)*y(x) = 0,y(x)],
[1140,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[1141,(x^2-4)*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1155,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[1156,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[1157,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[1158,diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[1159,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[1160,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[1161,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[1163,4*x^2*diff(diff(y(x),x),x)+(-8*x^2+4*x)*diff(y(x),x)+(4*x^2-4*x-1)*y(x) = 0,y(x)],
[1164,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[1165,x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[1166,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+3*y(x) = 0,y(x)],
[1167,(2*x+1)*diff(diff(y(x),x),x)-2*diff(y(x),x)+(-2*x-3)*y(x) = 0,y(x)],
[1169,x*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[1171,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[1172,x*diff(diff(y(x),x),x)-diff(y(x),x)-4*x^3*y(x) = 0,y(x)],
[1174,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(-16*x^2+3)*y(x) = 0,y(x)],
[1175,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2+3)*y(x) = 0,y(x)],
[1176,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(-x^2+2)*y(x) = 0,y(x)],
[1177,x^2*diff(diff(y(x),x),x)+(-2*x^2-2*x)*diff(y(x),x)+(x^2+2*x+2)*y(x) = 0,y(x)],
[1178,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)-3*y(x) = 0,y(x)],
[1179,x^2*diff(diff(y(x),x),x)+(-x^2-4*x)*diff(y(x),x)+(2*x+6)*y(x) = 0,y(x)],
[1180,x^2*diff(diff(y(x),x),x)+(-2*x^2-4*x)*diff(y(x),x)+(x^2+4*x+6)*y(x) = 0,y(x)],
[1181,x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(x^2+6)*y(x) = 0,y(x)],
[1182,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[1183,4*x^2*diff(diff(y(x),x),x)+(-4*x^2-4*x)*diff(y(x),x)+(2*x+3)*y(x) = 0,y(x)],
[1184,(3*x-1)*diff(diff(y(x),x),x)+(-3*x-2)*diff(y(x),x)+(-6*x+8)*y(x) = 0,y(x)],
[1185,(x^2-2*x+1)*diff(diff(y(x),x),x)+(-2*x+2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[1187,(x^2-2*x+1)*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1188,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[1189,(2*x^2+5*x+3)*diff(diff(y(x),x),x)+(2*x+4)*diff(y(x),x)-2*y(x) = 0,y(x)],
[1190,(x+2)*diff(diff(y(x),x),x)+x*diff(y(x),x)+3*y(x) = 0,y(x)],
[1199,(-x^3+x^2)*diff(diff(y(x),x),x)+(x^2+4*x)*diff(y(x),x)+(2-x)*y(x) = 0,y(x)],
[1200,(x^3+x^2)*diff(diff(y(x),x),x)+(2*x^2+x)*diff(y(x),x)+(-6*x-4)*y(x) = 0,y(x)],
[1202,(3*x^3+x^2)*diff(diff(y(x),x),x)+(x^3+12*x^2+2*x)*diff(y(x),x)+(2*x^2+6*x)*y(x) = 0,y(x)],
[1203,(2*x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3+4*x)*diff(y(x),x)+(-2*x^2+2)*y(x) = 0,y(x)],
[1204,(x^4+2*x^2)*diff(diff(y(x),x),x)+(2*x^3+10*x)*diff(y(x),x)+(-2*x^2+6)*y(x) = 0,y(x)],
[1205,(x^2+1)*diff(diff(y(x),x),x)+6*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[1206,(x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[1207,(x^2+1)*diff(diff(y(x),x),x)-8*x*diff(y(x),x)+20*y(x) = 0,y(x)],
[1208,(-x^2+1)*diff(diff(y(x),x),x)-8*x*diff(y(x),x)-12*y(x) = 0,y(x)],
[1209,(2*x^2+1)*diff(diff(y(x),x),x)+7*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1211,(-x^2+1)*diff(diff(y(x),x),x)-5*x*diff(y(x),x)-4*y(x) = 0,y(x)],
[1212,(x^2+1)*diff(diff(y(x),x),x)-10*x*diff(y(x),x)+28*y(x) = 0,y(x)],
[1213,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1215,(x^2+1)*diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[1216,(2*x^2+1)*diff(diff(y(x),x),x)-9*x*diff(y(x),x)-6*y(x) = 0,y(x)],
[1218,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[1219,diff(diff(y(x),x),x)+(-x+3)*diff(y(x),x)-y(x) = 0,y(x)],
[1220,(2*x^2-4*x+1)*diff(diff(y(x),x),x)+(10*x-10)*diff(y(x),x)+6*y(x) = 0,y(x)],
[1221,(2*x^2-8*x+11)*diff(diff(y(x),x),x)+(-16*x+32)*diff(y(x),x)+36*y(x) = 0,y(x)],
[1222,(3*x^2+6*x+5)*diff(diff(y(x),x),x)+(9*x+9)*diff(y(x),x)+3*y(x) = 0,y(x)],
[1223,(x^2-4)*diff(diff(y(x),x),x)-x*diff(y(x),x)-3*y(x) = 0,y(x)],
[1224,diff(diff(y(x),x),x)+(x-3)*diff(y(x),x)+3*y(x) = 0,y(x)],
[1227,(x^2-8*x+14)*diff(diff(y(x),x),x)+(-8*x+32)*diff(y(x),x)+20*y(x) = 0,y(x)],
[1228,(2*x^2+4*x+5)*diff(diff(y(x),x),x)+(-20*x-20)*diff(y(x),x)+60*y(x) = 0,y(x)],
[1229,(x^2+1)*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1232,(-2*x^3+1)*diff(diff(y(x),x),x)-10*x^2*diff(y(x),x)-8*x*y(x) = 0,y(x)],
[1233,(x^3+1)*diff(diff(y(x),x),x)+7*x^2*diff(y(x),x)+9*x*y(x) = 0,y(x)],
[1234,(-2*x^3+1)*diff(diff(y(x),x),x)+6*x^2*diff(y(x),x)+24*x*y(x) = 0,y(x)],
[1238,diff(diff(y(x),x),x)+x^6*diff(y(x),x)+7*x^5*y(x) = 0,y(x)],
[1240,(-x^6+1)*diff(diff(y(x),x),x)-12*x^5*diff(y(x),x)-30*x^4*y(x) = 0,y(x)],
[1241,diff(diff(y(x),x),x)+x^5*diff(y(x),x)+6*x^4*y(x) = 0,y(x)],
[1242,(1+3*x)*diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1243,(2*x^2+x+1)*diff(diff(y(x),x),x)+(2+8*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[1244,(-2*x^2+1)*diff(diff(y(x),x),x)+(2-6*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[1245,(3*x^2+x+1)*diff(diff(y(x),x),x)+(2+15*x)*diff(y(x),x)+12*y(x) = 0,y(x)],
[1246,(x+2)*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)+3*y(x) = 0,y(x)],
[1247,(x^2+3*x+3)*diff(diff(y(x),x),x)+(6+4*x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[1248,(x+4)*diff(diff(y(x),x),x)+(x+2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[1249,(2*x^2-3*x+2)*diff(diff(y(x),x),x)+(6*x-4)*diff(y(x),x)+2*y(x) = 0,y(x)],
[1250,(2*x^2+3*x)*diff(diff(y(x),x),x)+(10*x+10)*diff(y(x),x)+8*y(x) = 0,y(x)],
[1251,(x^2-x+1)*diff(diff(y(x),x),x)+(-1+4*x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[1252,(x+2)*diff(diff(y(x),x),x)+(x+2)*diff(y(x),x)+y(x) = 0,y(x)],
[1253,x^2*diff(diff(y(x),x),x)+(-6+7*x)*diff(y(x),x)+8*y(x) = 0,y(x)],
[1254,(2*x^2+x+1)*diff(diff(y(x),x),x)+(1+7*x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[1255,(x+3)*diff(diff(y(x),x),x)+(2*x+1)*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[1256,diff(diff(y(x),x),x)+3*x*diff(y(x),x)+(2*x^2+4)*y(x) = 0,y(x)],
[1257,(4*x+2)*diff(diff(y(x),x),x)-4*diff(y(x),x)+(-4*x-6)*y(x) = 0,y(x)],
[1268,(2*x^2+3*x+1)*diff(diff(y(x),x),x)+(6+8*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[1269,(6*x^2-5*x+1)*diff(diff(y(x),x),x)+(24*x-10)*diff(y(x),x)+12*y(x) = 0,y(x)],
[1270,(4*x^2-4*x+1)*diff(diff(y(x),x),x)+(16*x-8)*diff(y(x),x)+8*y(x) = 0,y(x)],
[1271,(x^2+4*x+4)*diff(diff(y(x),x),x)+(8+4*x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[1272,(3*x^2+8*x+4)*diff(diff(y(x),x),x)+(16+12*x)*diff(y(x),x)+6*y(x) = 0,y(x)],
[1274,diff(diff(y(x),x),x)-3*x*diff(y(x),x)+(2*x^2+5)*y(x) = 0,y(x)],
[1278,2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)+(2*x^2+4)*y(x) = 0,y(x)],
[1280,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[1281,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[1293,(x^3+3*x^2)*diff(diff(y(x),x),x)+(5*x^2+5*x)*diff(y(x),x)+(-1+4*x)*y(x) = 0,y(x)],
[1296,3*x^2*diff(diff(y(x),x),x)+(-4*x^3+2*x^2+2*x)*diff(y(x),x)+(-8*x^2+2*x)*y(x) = 0,y(x)],
[1299,(12*x^3+12*x^2)*diff(diff(y(x),x),x)+(3*x^3+35*x^2+11*x)*diff(y(x),x)+(5*x^2+10*x-1)*y(x) = 0,y(x)],
[1300,(10*x^4+x^3+5*x^2)*diff(diff(y(x),x),x)+(48*x^3+3*x^2+4*x)*diff(y(x),x)+(36*x^2+x)*y(x) = 0,y(x)],
[1302,(18*x^3+18*x^2)*diff(diff(y(x),x),x)+(3*x^3+33*x^2+15*x)*diff(y(x),x)+(5*x^2+2*x-1)*y(x) = 0,y(x)],
[1305,2*x^2*diff(diff(y(x),x),x)+(2*x^2+3*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[1306,(x^3+3*x^2)*diff(diff(y(x),x),x)+(4*x^2+5*x)*diff(y(x),x)+(2*x-1)*y(x) = 0,y(x)],
[1307,2*x^2*diff(diff(y(x),x),x)+(x^2+5*x)*diff(y(x),x)+(3*x-2)*y(x) = 0,y(x)],
[1308,3*x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)-y(x) = 0,y(x)],
[1309,2*x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+(1-2*x)*y(x) = 0,y(x)],
[1311,3*x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(-1-3*x)*y(x) = 0,y(x)],
[1312,(2*x^3+6*x^2)*diff(diff(y(x),x),x)+(5*x^2+x)*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[1313,(x^3+4*x^2)*diff(diff(y(x),x),x)+(3*x^2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[1314,2*x^2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[1315,(4*x^3+3*x^2)*diff(diff(y(x),x),x)+(18*x^2+5*x)*diff(y(x),x)+(12*x-1)*y(x) = 0,y(x)],
[1316,6*x^2*diff(diff(y(x),x),x)+(-x^2+10*x)*diff(y(x),x)+(-x-2)*y(x) = 0,y(x)],
[1318,(4*x^3+3*x^2)*diff(diff(y(x),x),x)+(4*x^2+11*x)*diff(y(x),x)+(-4*x-3)*y(x) = 0,y(x)],
[1319,(6*x^3+4*x^2)*diff(diff(y(x),x),x)+(11*x^2+4*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[1320,(x^3+2*x^2)*diff(diff(y(x),x),x)+(-5*x^2+5*x)*diff(y(x),x)+(8*x-2)*y(x) = 0,y(x)],
[1323,(-8*x^4+8*x^2)*diff(diff(y(x),x),x)+(-26*x^3+2*x)*diff(y(x),x)+(-9*x^2+1)*y(x) = 0,y(x)],
[1324,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3-4*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[1325,(x^3+3*x)*diff(diff(y(x),x),x)+(-x^2+2)*diff(y(x),x)-8*x*y(x) = 0,y(x)],
[1326,(-4*x^4+4*x^2)*diff(diff(y(x),x),x)+(-19*x^3+7*x)*diff(y(x),x)+(-14*x^2-1)*y(x) = 0,y(x)],
[1327,(-3*x^4+6*x^2)*diff(diff(y(x),x),x)+(-11*x^3+x)*diff(y(x),x)+(-5*x^2+1)*y(x) = 0,y(x)],
[1328,(2*x^4+4*x^2)*diff(diff(y(x),x),x)+(7*x^3-12*x)*diff(y(x),x)+(3*x^2+7)*y(x) = 0,y(x)],
[1329,(2*x^4+4*x^2)*diff(diff(y(x),x),x)+(7*x^3+4*x)*diff(y(x),x)+(3*x^2-1)*y(x) = 0,y(x)],
[1330,(4*x^4+2*x^2)*diff(diff(y(x),x),x)+(30*x^3+5*x)*diff(y(x),x)+(40*x^2-2)*y(x) = 0,y(x)],
[1332,(x^3+x)*diff(diff(y(x),x),x)+(7*x^2+4)*diff(y(x),x)+8*x*y(x) = 0,y(x)],
[1334,(2*x^4+2*x^2)*diff(diff(y(x),x),x)+(8*x^3+3*x)*diff(y(x),x)+(4*x^2-3)*y(x) = 0,y(x)],
[1335,9*x^2*diff(diff(y(x),x),x)+(3*x^3+9*x)*diff(y(x),x)+(5*x^2-1)*y(x) = 0,y(x)],
[1336,6*x^2*diff(diff(y(x),x),x)+(6*x^3+x)*diff(y(x),x)+(9*x^2+1)*y(x) = 0,y(x)],
[1338,(9*x^4+9*x^2)*diff(diff(y(x),x),x)+(39*x^3+9*x)*diff(y(x),x)+(25*x^2-1)*y(x) = 0,y(x)],
[1339,(4*x^4+4*x^2)*diff(diff(y(x),x),x)+(24*x^3+4*x)*diff(y(x),x)+(25*x^2-1)*y(x) = 0,y(x)],
[1340,(16*x^4+8*x^2)*diff(diff(y(x),x),x)+(68*x^3+10*x)*diff(y(x),x)+(30*x^2-1)*y(x) = 0,y(x)],
[1341,(2*x^3+2*x^2)*diff(diff(y(x),x),x)+(3*x^2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[1342,(12*x^4+6*x^2)*diff(diff(y(x),x),x)+(50*x^3+x)*diff(y(x),x)+(30*x^2+1)*y(x) = 0,y(x)],
[1343,(-84*x^3+28*x^2)*diff(diff(y(x),x),x)+(-63*x^2-35*x)*diff(y(x),x)+(63*x+14)*y(x) = 0,y(x)],
[1345,(-8*x^4+16*x^2)*diff(diff(y(x),x),x)+(-42*x^3+20*x)*diff(y(x),x)+(-35*x^2-2)*y(x) = 0,y(x)],
[1346,(4*x^4+12*x^3+4*x^2)*diff(diff(y(x),x),x)+(12*x^3+12*x^2-4*x)*diff(y(x),x)+(3*x^2-3*x+3)*y(x) = 0,y(x)],
[1347,(3*x^4+6*x^3+3*x^2)*diff(diff(y(x),x),x)+(11*x^3+10*x^2-x)*diff(y(x),x)+(5*x^2+1)*y(x) = 0,y(x)],
[1348,(4*x^4+8*x^3+12*x^2)*diff(diff(y(x),x),x)+(15*x^3+14*x^2-3*x)*diff(y(x),x)+(7*x^2+3)*y(x) = 0,y(x)],
[1349,(x^4-2*x^3+x^2)*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+(x+4)*y(x) = 0,y(x)],
[1350,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+5*x^2*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[1351,(-x^4+2*x^2)*diff(diff(y(x),x),x)+(-4*x^3-2*x)*diff(y(x),x)+(-2*x^2+2)*y(x) = 0,y(x)],
[1352,x^2*diff(diff(y(x),x),x)+(x^2-5*x)*diff(y(x),x)+(9-4*x)*y(x) = 0,y(x)],
[1354,(2*x^4+x^3+x^2)*diff(diff(y(x),x),x)+(7*x^3+6*x^2+3*x)*diff(y(x),x)+(-3*x^2+6*x+1)*y(x) = 0,y(x)],
[1355,(x^4+2*x^3+x^2)*diff(diff(y(x),x),x)+(4*x^3+3*x^2+x)*diff(y(x),x)+(2*x^2-x)*y(x) = 0,y(x)],
[1356,(4*x^4+4*x^3+4*x^2)*diff(diff(y(x),x),x)+(12*x^3+12*x^2)*diff(y(x),x)+(3*x^2+3*x+1)*y(x) = 0,y(x)],
[1357,(x^4+x^3+x^2)*diff(diff(y(x),x),x)+(2*x^3+4*x^2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[1358,9*x^2*diff(diff(y(x),x),x)+(-6*x^3+9*x^2+15*x)*diff(y(x),x)+(-14*x^2+12*x+1)*y(x) = 0,y(x)],
[1360,(2*x^3+x^2)*diff(diff(y(x),x),x)+(3*x^3+14*x^2+5*x)*diff(y(x),x)+(12*x^2+18*x+4)*y(x) = 0,y(x)],
[1362,16*x^2*diff(diff(y(x),x),x)+(8*x^3+4*x^2+24*x)*diff(y(x),x)+(18*x^2+5*x+1)*y(x) = 0,y(x)],
[1363,(9*x^3+9*x^2)*diff(diff(y(x),x),x)+(-3*x^3+33*x^2+15*x)*diff(y(x),x)+(-7*x^2+16*x+1)*y(x) = 0,y(x)],
[1365,(-72*x^3+36*x^2)*diff(diff(y(x),x),x)+(-216*x^2+24*x)*diff(y(x),x)+(1-70*x)*y(x) = 0,y(x)],
[1366,(x^3+x^2)*diff(diff(y(x),x),x)+(x^2-3*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[1367,(-2*x^3+x^2)*diff(diff(y(x),x),x)+(4*x^2-5*x)*diff(y(x),x)+(9-4*x)*y(x) = 0,y(x)],
[1369,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+(1-x)*y(x) = 0,y(x)],
[1372,(-4*x^3+x^2)*diff(diff(y(x),x),x)+(-18*x^2+3*x)*diff(y(x),x)+(1-12*x)*y(x) = 0,y(x)],
[1373,(2*x^3+x^2)*diff(diff(y(x),x),x)+(5*x^2+3*x)*diff(y(x),x)+(1-2*x)*y(x) = 0,y(x)],
[1374,(2*x^3+2*x^2)*diff(diff(y(x),x),x)+(x^2-6*x)*diff(y(x),x)+(8-x)*y(x) = 0,y(x)],
[1375,(2*x^3+x^2)*diff(diff(y(x),x),x)+(9*x^2+5*x)*diff(y(x),x)+(4+3*x)*y(x) = 0,y(x)],
[1376,(-2*x^3+x^2)*diff(diff(y(x),x),x)+(-4*x^2-5*x)*diff(y(x),x)+(9+4*x)*y(x) = 0,y(x)],
[1379,(-x^3+x^2)*diff(diff(y(x),x),x)+(x^2+7*x)*diff(y(x),x)+(9-x)*y(x) = 0,y(x)],
[1380,x^2*diff(diff(y(x),x),x)+(x^3-x)*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[1381,(x^4+x^2)*diff(diff(y(x),x),x)+(3*x^3-3*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[1382,4*x^2*diff(diff(y(x),x),x)+2*x^3*diff(y(x),x)+(3*x^2+1)*y(x) = 0,y(x)],
[1383,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3-x)*diff(y(x),x)+y(x) = 0,y(x)],
[1384,(2*x^4+4*x^2)*diff(diff(y(x),x),x)+7*x^3*diff(y(x),x)+(3*x^2+1)*y(x) = 0,y(x)],
[1385,(x^4+x^2)*diff(diff(y(x),x),x)+(4*x^3-x)*diff(y(x),x)+(2*x^2+1)*y(x) = 0,y(x)],
[1386,(4*x^4+16*x^2)*diff(diff(y(x),x),x)+(9*x^3+24*x)*diff(y(x),x)+(-9*x^2+1)*y(x) = 0,y(x)],
[1387,(3*x^4+9*x^2)*diff(diff(y(x),x),x)+(11*x^3+3*x)*diff(y(x),x)+(5*x^2+1)*y(x) = 0,y(x)],
[1389,9*x^2*diff(diff(y(x),x),x)+(6*x^3-21*x)*diff(y(x),x)+(2*x^2+25)*y(x) = 0,y(x)],
[1390,(2*x^4+x^2)*diff(diff(y(x),x),x)+(7*x^3+3*x)*diff(y(x),x)+(-3*x^2+1)*y(x) = 0,y(x)],
[1391,(x^4+x^2)*diff(diff(y(x),x),x)+(8*x^3+3*x)*diff(y(x),x)+(12*x^2+1)*y(x) = 0,y(x)],
[1392,x^2*diff(diff(y(x),x),x)+(x^3-x)*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[1396,(-2*x^3+x^2)*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+(1+4*x)*y(x) = 0,y(x)],
[1397,(x^2+x)*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)+y(x) = 0,y(x)],
[1398,(-x^3+x^2)*diff(diff(y(x),x),x)+(-2*x^2+3*x)*diff(y(x),x)+(2*x+1)*y(x) = 0,y(x)],
[1400,(-x^3+x^2)*diff(diff(y(x),x),x)+(5*x^2-3*x)*diff(y(x),x)+(4-5*x)*y(x) = 0,y(x)],
[1401,(x^4+x^2)*diff(diff(y(x),x),x)+(-9*x^3-x)*diff(y(x),x)+(25*x^2+1)*y(x) = 0,y(x)],
[1402,9*x^2*diff(diff(y(x),x),x)+(-3*x^3+3*x)*diff(y(x),x)+(7*x^2+1)*y(x) = 0,y(x)],
[1403,(x^3+x)*diff(diff(y(x),x),x)+(-x^2+1)*diff(y(x),x)-8*x*y(x) = 0,y(x)],
[1404,4*x^2*diff(diff(y(x),x),x)+(-2*x^3+8*x)*diff(y(x),x)+(7*x^2+1)*y(x) = 0,y(x)],
[1405,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+8*x^2*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[1406,(9*x^3+27*x^2)*diff(diff(y(x),x),x)+(21*x^2+9*x)*diff(y(x),x)+(4*x+3)*y(x) = 0,y(x)],
[1407,(-x^4+2*x^2)*diff(diff(y(x),x),x)+(-3*x^3-2*x)*diff(y(x),x)+(-x^2+2)*y(x) = 0,y(x)],
[1408,(16*x^4+16*x^2)*diff(diff(y(x),x),x)+(72*x^3+8*x)*diff(y(x),x)+(49*x^2+1)*y(x) = 0,y(x)],
[1409,(3*x^3+4*x^2)*diff(diff(y(x),x),x)+(3*x^2-4*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[1410,(4*x^4+12*x^3+4*x^2)*diff(diff(y(x),x),x)+(16*x^3+24*x^2)*diff(y(x),x)+(9*x^2+3*x+1)*y(x) = 0,y(x)],
[1411,(x^4-2*x^3+x^2)*diff(diff(y(x),x),x)+(3*x^3-2*x^2-x)*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[1412,(9*x^4+9*x^3+9*x^2)*diff(diff(y(x),x),x)+(39*x^3+21*x^2+3*x)*diff(y(x),x)+(25*x^2+4*x+1)*y(x) = 0,y(x)],
[1413,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+(7*x^2-4*x)*diff(y(x),x)+(3*x-5)*y(x) = 0,y(x)],
[1414,(-2*x^3+x^2)*diff(diff(y(x),x),x)+(-9*x^2+8*x)*diff(y(x),x)+(6-3*x)*y(x) = 0,y(x)],
[1415,(x^4+x^2)*diff(diff(y(x),x),x)+(10*x^3+3*x)*diff(y(x),x)+(14*x^2-15)*y(x) = 0,y(x)],
[1416,(-2*x^4+x^2)*diff(diff(y(x),x),x)+(-13*x^3+7*x)*diff(y(x),x)-14*x^2*y(x) = 0,y(x)],
[1419,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+(8*x^2+4*x)*diff(y(x),x)+(-1-3*x)*y(x) = 0,y(x)],
[1421,(6*x^3+4*x^2)*diff(diff(y(x),x),x)+(21*x^2+4*x)*diff(y(x),x)+(9*x-1)*y(x) = 0,y(x)],
[1422,x^2*diff(diff(y(x),x),x)+(x^2+2*x)*diff(y(x),x)+(3*x-2)*y(x) = 0,y(x)],
[1425,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+(32*x^2+12*x)*diff(y(x),x)+(49*x-5)*y(x) = 0,y(x)],
[1426,(x^3+x^2)*diff(diff(y(x),x),x)+(-10*x^2-3*x)*diff(y(x),x)+30*x*y(x) = 0,y(x)],
[1427,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(-3*x-9)*y(x) = 0,y(x)],
[1429,(x^2+x)*diff(diff(y(x),x),x)-4*diff(y(x),x)-2*y(x) = 0,y(x)],
[1430,(2*x^3+x^2)*diff(diff(y(x),x),x)+(13*x^2+9*x)*diff(y(x),x)+(7+5*x)*y(x) = 0,y(x)],
[1431,(8*x^3+4*x^2)*diff(diff(y(x),x),x)+(2*x^2-8*x)*diff(y(x),x)+(-5*x-7)*y(x) = 0,y(x)],
[1432,(3*x^3+9*x^2)*diff(diff(y(x),x),x)+(-x^2-15*x)*diff(y(x),x)-20*y(x) = 0,y(x)],
[1433,(x^3+x^2)*diff(diff(y(x),x),x)+(-10*x^2+x)*diff(y(x),x)+(10*x-9)*y(x) = 0,y(x)],
[1434,(x^3+x^2)*diff(diff(y(x),x),x)+3*x^2*diff(y(x),x)+(x-6)*y(x) = 0,y(x)],
[1435,(2*x^3+x^2)*diff(diff(y(x),x),x)+(-28*x^2-6*x)*diff(y(x),x)+(6+100*x)*y(x) = 0,y(x)],
[1436,(x^3+x^2)*diff(diff(y(x),x),x)+(-11*x^2-6*x)*diff(y(x),x)+(6+32*x)*y(x) = 0,y(x)],
[1437,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+(16*x^2+4*x)*diff(y(x),x)+(-27*x-49)*y(x) = 0,y(x)],
[1438,(2*x^3+x^2)*diff(diff(y(x),x),x)+(-8*x^2-9*x)*diff(y(x),x)-12*x*y(x) = 0,y(x)],
[1439,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3-7*x)*diff(y(x),x)+12*y(x) = 0,y(x)],
[1440,x^2*diff(diff(y(x),x),x)+(x^3-7*x)*diff(y(x),x)+12*y(x) = 0,y(x)],
[1442,x^2*diff(diff(y(x),x),x)+(2*x^3+x)*diff(y(x),x)+(10*x^2-1)*y(x) = 0,y(x)],
[1445,x^2*diff(diff(y(x),x),x)+(x^3+x)*diff(y(x),x)+(3*x^2-1)*y(x) = 0,y(x)],
[1446,x^2*diff(diff(y(x),x),x)+(-2*x^3+x)*diff(y(x),x)+(-8*x^2-4)*y(x) = 0,y(x)],
[1449,x^2*diff(diff(y(x),x),x)+(-2*x^3+x)*diff(y(x),x)+(4*x^2-4)*y(x) = 0,y(x)],
[1450,x^2*diff(diff(y(x),x),x)+(-3*x^3+x)*diff(y(x),x)+(12*x^2-4)*y(x) = 0,y(x)],
[1451,(x^4+x^2)*diff(diff(y(x),x),x)+(11*x^3+5*x)*diff(y(x),x)+24*x^2*y(x) = 0,y(x)],
[1452,(4*x^4+4*x^2)*diff(diff(y(x),x),x)+8*x*diff(y(x),x)+(x^2-35)*y(x) = 0,y(x)],
[1453,(x^4+x^2)*diff(diff(y(x),x),x)+(x^3-5*x)*diff(y(x),x)+(-25*x^2-7)*y(x) = 0,y(x)],
[1454,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3+5*x)*diff(y(x),x)-21*y(x) = 0,y(x)],
[1456,(4*x^4+4*x^2)*diff(diff(y(x),x),x)+(4*x^3+8*x)*diff(y(x),x)+(-x^2-15)*y(x) = 0,y(x)],
[1457,-x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[1458,-7*diff(diff(y(x),x),x)-diff(y(x),x)+6*y(x) = 0,y(x)],
[1459,-x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[1460,-x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[1461,-x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[1462,-x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[1463,diff(diff(y(x),x),x)-diff(y(x),x)-y(x) = 0,y(x)],
[1464,-3*diff(diff(y(x),x),x)+7*diff(y(x),x)-5*y(x) = 0,y(x)],
[1465,-3*diff(diff(y(x),x),x)+3*diff(y(x),x)-y(x) = 0,y(x)],
[1466,8*diff(diff(y(x),x),x)-9*y(x) = 0,y(x)],
[1467,-diff(diff(y(x),x),x)+16*diff(y(x),x)-16*y(x) = 0,y(x)],
[1468,3*diff(diff(y(x),x),x)-2*diff(y(x),x)-3*y(x) = 0,y(x)],
[1469,5*diff(diff(y(x),x),x)+9*diff(y(x),x)+5*y(x) = 0,y(x)],
[1470,-8*diff(diff(y(x),x),x)+5*diff(y(x),x)-y(x) = 0,y(x)],
[1471,27*diff(diff(y(x),x),x)+9*diff(y(x),x)+y(x) = 0,y(x)],
[1472,diff(diff(y(x),x),x) = 0,y(x)],
[1474,12*diff(diff(y(x),x),x)+36*y(x) = 0,y(x)],
[1475,-72*diff(diff(y(x),x),x)+81*y(x) = 0,y(x)],
[1476,7*diff(diff(y(x),x),x)+5*diff(y(x),x)+y(x) = 0,y(x)],
[1477,3*diff(diff(y(x),x),x)-13*diff(y(x),x)-6*y(x) = 0,y(x)],
[1478,7*diff(diff(y(x),x),x)-6*diff(y(x),x)+2*y(x) = 0,y(x)],
[1479,-2*diff(diff(y(x),x),x)+4*diff(y(x),x)-8*y(x) = 0,y(x)],
[1480,3*diff(diff(y(x),x),x)-diff(y(x),x)-3*y(x) = 0,y(x)],
[1481,-diff(diff(y(x),x),x)-diff(y(x),x)+y(x) = 0,y(x)],
[1483,-diff(diff(y(x),x),x)-7*diff(y(x),x)+5*y(x) = 0,y(x)],
[1484,-6*diff(diff(y(x),x),x)+12*diff(y(x),x)-8*y(x) = 0,y(x)],
[1485,-11*diff(diff(y(x),x),x)+12*diff(y(x),x)+9*y(x) = 0,y(x)],
[1486,-4*diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[1488,7*diff(diff(y(x),x),x)+6*diff(y(x),x)-8*y(x) = 0,y(x)],
[1489,-13*diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[1490,-2*diff(diff(y(x),x),x)-8*diff(y(x),x)-8*y(x) = 0,y(x)],
[1491,19*diff(diff(y(x),x),x)+32*diff(y(x),x)+12*y(x) = 0,y(x)],
[1497,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[1498,-6*diff(diff(y(x),x),x)+11*diff(y(x),x)-6*y(x) = 0,y(x)],
[1499,-2*diff(diff(y(x),x),x)-5*diff(y(x),x)+6*y(x) = 0,y(x)],
[1500,8*diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[1501,3*diff(diff(y(x),x),x)-diff(y(x),x)-3*y(x) = 0,y(x)],
[1502,3*diff(diff(y(x),x),x)-diff(y(x),x)-3*y(x) = 0,y(x)],
[1503,diff(diff(y(x),x),x)-2*y(x) = 0,y(x)],
[1504,8*diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[1505,-diff(diff(y(x),x),x)-diff(y(x),x)+y(x) = 0,y(x)],
[1506,-7*diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[1507,-5*diff(diff(y(x),x),x)+3*diff(y(x),x)+9*y(x) = 0,y(x)],
[1508,-7*diff(diff(y(x),x),x)+8*diff(y(x),x)+16*y(x) = 0,y(x)],
[1509,-12*diff(diff(y(x),x),x)+6*diff(y(x),x)-y(x) = 0,y(x)],
[1510,-3*diff(diff(y(x),x),x)-7*diff(y(x),x)+6*y(x) = 0,y(x)],
[1511,diff(diff(y(x),x),x)-3*diff(y(x),x)-2*y(x) = 0,y(x)],
[1512,24*diff(diff(y(x),x),x)+32*diff(y(x),x) = 0,y(x)],
[1513,-11*diff(diff(y(x),x),x)-9*diff(y(x),x)-2*y(x) = 0,y(x)],
[1515,6*diff(diff(y(x),x),x)-4*diff(y(x),x)+2*y(x) = 0,y(x)],
[1517,-2*diff(diff(y(x),x),x)-6*diff(y(x),x)-4*y(x) = 0,y(x)],
[1519,-5*diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[1520,-3*diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[1523,3*diff(diff(y(x),x),x)+diff(y(x),x)-y(x) = 0,y(x)],
[1524,3*diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[1525,18*diff(diff(y(x),x),x)-20*diff(y(x),x)+8*y(x) = 0,y(x)],
[1526,-diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[1527,diff(diff(y(x),x),x)-4*diff(y(x),x)-4*y(x) = 0,y(x)],
[1528,-diff(diff(y(x),x),x)+2*diff(y(x),x)-2*y(x) = 0,y(x)],
[1529,-2*diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[1530,3*diff(diff(y(x),x),x)+4*diff(y(x),x)+12*y(x) = 0,y(x)],
[1531,-diff(diff(y(x),x),x)+2*y(x) = 0,y(x)],
[1532,-7*diff(diff(y(x),x),x)+20*diff(y(x),x)-24*y(x) = 0,y(x)],
[1533,-6*diff(diff(y(x),x),x)+18*diff(y(x),x) = 0,y(x)],
[1534,-2*diff(diff(y(x),x),x)-8*diff(y(x),x)-8*y(x) = 0,y(x)],
[1535,2*diff(diff(y(x),x),x)+2*diff(y(x),x)-4*y(x) = 0,y(x)],
[1536,24*diff(diff(y(x),x),x)-32*diff(y(x),x)+15*y(x) = 0,y(x)],
[1537,13*diff(diff(y(x),x),x)+12*diff(y(x),x)+4*y(x) = 0,y(x)],
[1538,2*diff(diff(y(x),x),x)-2*diff(y(x),x)-4*y(x) = 0,y(x)],
[1539,13*diff(diff(y(x),x),x)-19*diff(y(x),x)+10*y(x) = 0,y(x)],
[1540,32*diff(diff(y(x),x),x)+64*diff(y(x),x)+39*y(x) = 0,y(x)],
[1541,13*diff(diff(y(x),x),x)-19*diff(y(x),x)+10*y(x) = 0,y(x)],
[1542,8*diff(diff(y(x),x),x)+8*diff(y(x),x)+4*y(x) = 0,y(x)],
[1543,32*diff(diff(y(x),x),x)-64*diff(y(x),x)+64*y(x) = 0,y(x)],
[1544,26*diff(diff(y(x),x),x)-40*diff(y(x),x)+25*y(x) = 0,y(x)],
[1545,-4*diff(diff(y(x),x),x)+5*diff(y(x),x)-2*y(x) = 0,y(x)],
[1546,-diff(diff(y(x),x),x)+diff(y(x),x)-y(x) = 0,y(x)],
[1548,-4*diff(diff(y(x),x),x)+9*diff(y(x),x)-10*y(x) = 0,y(x)],
[1549,3*diff(diff(y(x),x),x)+3*diff(y(x),x)+y(x) = 0,y(x)],
[1550,diff(diff(y(x),x),x)-diff(y(x),x)-y(x) = 0,y(x)],
[1551,-5*diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[1552,11*diff(diff(y(x),x),x)-14*diff(y(x),x)+10*y(x) = 0,y(x)],
[1553,-3*diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[1555,9*diff(diff(y(x),x),x)+7*diff(y(x),x)+2*y(x) = 0,y(x)],
[1556,7*diff(diff(y(x),x),x)-6*diff(y(x),x)+2*y(x) = 0,y(x)],
[1557,-diff(diff(y(x),x),x)-diff(y(x),x)+y(x) = 0,y(x)],
[1558,diff(diff(y(x),x),x)-2*y(x) = 0,y(x)],
[1559,-6*diff(diff(y(x),x),x)+11*diff(y(x),x)-6*y(x) = 0,y(x)],
[1560,2*diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[1561,-3*diff(diff(y(x),x),x)+3*diff(y(x),x)-y(x) = 0,y(x)],
[1562,-2*diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[1563,2*diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[1564,4*diff(diff(y(x),x),x)-2*diff(y(x),x) = 0,y(x)],
[1565,14*diff(diff(y(x),x),x)-20*diff(y(x),x)+25*y(x) = 0,y(x)],
[1566,-2*diff(diff(y(x),x),x)-5*diff(y(x),x)+6*y(x) = 0,y(x)],
[1567,-diff(diff(y(x),x),x)-diff(y(x),x)+y(x) = 0,y(x)],
[1569,2*diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[1570,2*diff(diff(y(x),x),x)+diff(y(x),x)+2*y(x) = 0,y(x)],
[1571,5*diff(diff(y(x),x),x)-2*diff(y(x),x) = 0,y(x)],
[1572,-3*x^2*diff(diff(y(x),x),x)+6*x*diff(y(x),x)-6*y(x) = 0,y(x)],
[1573,4*x^2*diff(diff(y(x),x),x)-5*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1574,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1575,72*x^2*diff(diff(y(x),x),x)-24*x*diff(y(x),x)+9*y(x) = 0,y(x)],
[1576,12*x^2*diff(diff(y(x),x),x)-24*x*diff(y(x),x)+24*y(x) = 0,y(x)],
[1577,2*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[1578,-2*x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-3*y(x) = 0,y(x)],
[1579,-5*x^2*diff(diff(y(x),x),x)+14*x*diff(y(x),x)-18*y(x) = 0,y(x)],
[1580,-6*x^2*diff(diff(y(x),x),x)+16*x*diff(y(x),x)-16*y(x) = 0,y(x)],
[1581,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1582,-x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[1583,23*x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[1584,-3*x^2*diff(diff(y(x),x),x)-6*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[1585,2*diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[1586,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[1587,-5*diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[1588,2*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[1712,2*t^2*diff(diff(y(t),t),t)+3*t*diff(y(t),t)-y(t) = 0,y(t)],
[1713,2*t^2*diff(diff(y(t),t),t)+3*t*diff(y(t),t)-y(t) = 0,y(t)],
[1714,diff(diff(y(t),t),t)+t*diff(y(t),t)+y(t) = 0,y(t)],
[1715,diff(diff(y(t),t),t)+t*diff(y(t),t)+y(t) = 0,y(t)],
[1716,diff(diff(y(t),t),t)-y(t) = 0,y(t)],
[1717,6*diff(diff(y(t),t),t)-7*diff(y(t),t)+y(t) = 0,y(t)],
[1718,diff(diff(y(t),t),t)-3*diff(y(t),t)+y(t) = 0,y(t)],
[1719,3*diff(diff(y(t),t),t)+6*diff(y(t),t)+3*y(t) = 0,y(t)],
[1720,diff(diff(y(t),t),t)-3*diff(y(t),t)-4*y(t) = 0,y(t)],
[1721,2*diff(diff(y(t),t),t)+diff(y(t),t)-10*y(t) = 0,y(t)],
[1722,5*diff(diff(y(t),t),t)+5*diff(y(t),t)-y(t) = 0,y(t)],
[1723,diff(diff(y(t),t),t)-6*diff(y(t),t)+y(t) = 0,y(t)],
[1724,diff(diff(y(t),t),t)+5*diff(y(t),t)+6*y(t) = 0,y(t)],
[1726,t^2*diff(diff(y(t),t),t)+5*t*diff(y(t),t)-5*y(t) = 0,y(t)],
[1727,t^2*diff(diff(y(t),t),t)-t*diff(y(t),t)-2*y(t) = 0,y(t)],
[1728,diff(diff(y(t),t),t)+2*diff(y(t),t)+4*y(t) = 0,y(t)],
[1729,diff(diff(y(t),t),t)+diff(y(t),t)+y(t) = 0,y(t)],
[1730,2*diff(diff(y(t),t),t)+3*diff(y(t),t)+4*y(t) = 0,y(t)],
[1731,diff(diff(y(t),t),t)+2*diff(y(t),t)+3*y(t) = 0,y(t)],
[1732,4*diff(diff(y(t),t),t)-diff(y(t),t)+y(t) = 0,y(t)],
[1733,diff(diff(y(t),t),t)+diff(y(t),t)+2*y(t) = 0,y(t)],
[1734,diff(diff(y(t),t),t)+2*diff(y(t),t)+5*y(t) = 0,y(t)],
[1735,2*diff(diff(y(t),t),t)-diff(y(t),t)+3*y(t) = 0,y(t)],
[1736,3*diff(diff(y(t),t),t)-2*diff(y(t),t)+4*y(t) = 0,y(t)],
[1737,t^2*diff(diff(y(t),t),t)+t*diff(y(t),t)+y(t) = 0,y(t)],
[1738,t^2*diff(diff(y(t),t),t)+2*t*diff(y(t),t)+2*y(t) = 0,y(t)],
[1739,diff(diff(y(t),t),t)-6*diff(y(t),t)+9*y(t) = 0,y(t)],
[1740,4*diff(diff(y(t),t),t)-12*diff(y(t),t)+9*y(t) = 0,y(t)],
[1741,9*diff(diff(y(t),t),t)+6*diff(y(t),t)+y(t) = 0,y(t)],
[1742,4*diff(diff(y(t),t),t)-4*diff(y(t),t)+y(t) = 0,y(t)],
[1743,diff(diff(y(t),t),t)+2*diff(y(t),t)+y(t) = 0,y(t)],
[1744,9*diff(diff(y(t),t),t)-12*diff(y(t),t)+4*y(t) = 0,y(t)],
[1745,diff(diff(y(t),t),t)+(-2/(t^2+2*t-1)*t-2/(t^2+2*t-1))*diff(y(t),t)+2/(t^2+2*t-1)*y(t) = 0,y(t)],
[1746,diff(diff(y(t),t),t)-4*t*diff(y(t),t)+(4*t^2-2)*y(t) = 0,y(t)],
[1747,(-t^2+1)*diff(diff(y(t),t),t)-2*t*diff(y(t),t)+2*y(t) = 0,y(t)],
[1748,(t^2+1)*diff(diff(y(t),t),t)-2*t*diff(y(t),t)+2*y(t) = 0,y(t)],
[1749,(-t^2+1)*diff(diff(y(t),t),t)-2*t*diff(y(t),t)+6*y(t) = 0,y(t)],
[1750,(2*t+1)*diff(diff(y(t),t),t)+(-4*t-4)*diff(y(t),t)+4*y(t) = 0,y(t)],
[1751,t^2*diff(diff(y(t),t),t)+t*diff(y(t),t)+(t^2-1/4)*y(t) = 0,y(t)],
[1752,t^2*diff(diff(y(t),t),t)+3*t*diff(y(t),t)+y(t) = 0,y(t)],
[1753,t^2*diff(diff(y(t),t),t)-t*diff(y(t),t)+y(t) = 0,y(t)],
[1754,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[1755,diff(diff(y(t),t),t)-4*diff(y(t),t)+4*y(t) = 0,y(t)],
[1756,2*diff(diff(y(t),t),t)-3*diff(y(t),t)+y(t) = 0,y(t)],
[1757,diff(diff(y(t),t),t)-3*diff(y(t),t)+2*y(t) = 0,y(t)],
[1758,3*diff(diff(y(t),t),t)+4*diff(y(t),t)+y(t) = 0,y(t)],
[1759,diff(diff(y(t),t),t)+4*diff(y(t),t)+4*y(t) = 0,y(t)],
[1760,diff(diff(y(t),t),t)-3*diff(y(t),t)+2*y(t) = 0,y(t)],
[1761,diff(diff(y(t),t),t)-y(t) = 0,y(t)],
[1763,diff(diff(y(t),t),t)-2*t/(t^2+1)*diff(y(t),t)+2/(t^2+1)*y(t) = 0,y(t)],
[1765,diff(diff(y(t),t),t)+t*diff(y(t),t)+y(t) = 0,y(t)],
[1767,(t^2+2)*diff(diff(y(t),t),t)-t*diff(y(t),t)-3*y(t) = 0,y(t)],
[1769,(-t^2+2*t)*diff(diff(y(t),t),t)+(-6*t+6)*diff(y(t),t)-4*y(t) = 0,y(t)],
[1776,diff(diff(y(t),t),t)+t^3*diff(y(t),t)+3*t^2*y(t) = 0,y(t)],
[1777,diff(diff(y(t),t),t)+t^3*diff(y(t),t)+3*t^2*y(t) = 0,y(t)],
[1778,(-t+1)*diff(diff(y(t),t),t)+t*diff(y(t),t)+y(t) = 0,y(t)],
[1783,t^2*diff(diff(y(t),t),t)-5*t*diff(y(t),t)+9*y(t) = 0,y(t)],
[1784,t^2*diff(diff(y(t),t),t)+5*t*diff(y(t),t)-5*y(t) = 0,y(t)],
[1785,2*t^2*diff(diff(y(t),t),t)+3*t*diff(y(t),t)-y(t) = 0,y(t)],
[1786,(t^2-2*t+1)*diff(diff(y(t),t),t)+(-2*t+2)*diff(y(t),t)+2*y(t) = 0,y(t)],
[1787,t^2*diff(diff(y(t),t),t)+3*t*diff(y(t),t)+y(t) = 0,y(t)],
[1788,t^2*diff(diff(y(t),t),t)-t*diff(y(t),t)+y(t) = 0,y(t)],
[1789,(t^2-4*t+4)*diff(diff(y(t),t),t)+(5*t-10)*diff(y(t),t)+4*y(t) = 0,y(t)],
[1790,t^2*diff(diff(y(t),t),t)+t*diff(y(t),t)+y(t) = 0,y(t)],
[1791,t^2*diff(diff(y(t),t),t)-t*diff(y(t),t)+2*y(t) = 0,y(t)],
[1792,t^2*diff(diff(y(t),t),t)-3*t*diff(y(t),t)+4*y(t) = 0,y(t)],
[1799,2*t^2*diff(diff(y(t),t),t)+3*t*diff(y(t),t)+(-t-1)*y(t) = 0,y(t)],
[1800,2*t*diff(diff(y(t),t),t)+(1-2*t)*diff(y(t),t)-y(t) = 0,y(t)],
[1801,2*t*diff(diff(y(t),t),t)+(t+1)*diff(y(t),t)-2*y(t) = 0,y(t)],
[1802,2*t^2*diff(diff(y(t),t),t)-t*diff(y(t),t)+(t+1)*y(t) = 0,y(t)],
[1804,2*t^2*diff(diff(y(t),t),t)+(t^2-t)*diff(y(t),t)+y(t) = 0,y(t)],
[1806,t^2*diff(diff(y(t),t),t)+(-t^2+t)*diff(y(t),t)-y(t) = 0,y(t)],
[1807,t*diff(diff(y(t),t),t)+(-t^2-2)*diff(y(t),t)+t*y(t) = 0,y(t)],
[1808,t^2*diff(diff(y(t),t),t)+(-t^2+3*t)*diff(y(t),t)-t*y(t) = 0,y(t)],
[1809,t^2*diff(diff(y(t),t),t)+(t^2+t)*diff(y(t),t)-y(t) = 0,y(t)],
[1810,t*diff(diff(y(t),t),t)+(-4-t)*diff(y(t),t)+2*y(t) = 0,y(t)],
[1811,t^2*diff(diff(y(t),t),t)+(t^2-3*t)*diff(y(t),t)+3*y(t) = 0,y(t)],
[1813,t*diff(diff(y(t),t),t)+t*diff(y(t),t)+2*y(t) = 0,y(t)],
[1814,t*diff(diff(y(t),t),t)+(-t^2+1)*diff(y(t),t)+4*t*y(t) = 0,y(t)],
[1821,t^2*diff(diff(y(t),t),t)+(-t^2-t)*diff(y(t),t)+y(t) = 0,y(t)],
[2005,diff(diff(f(t),t),t)+2*diff(f(t),t)+5*f(t) = 0,f(t)],
[2006,diff(diff(f(t),t),t)+2*diff(f(t),t)+5*f(t) = 0,f(t)],
[2007,diff(diff(f(t),t),t)+6*diff(f(t),t)+9*f(t) = 0,f(t)],
[2008,diff(diff(f(t),t),t)+8*diff(f(t),t)+12*f(t) = 0,f(t)],
[2009,diff(diff(f(t),t),t)+8*diff(f(t),t)+12*f(t) = 0,f(t)],
[2010,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[2013,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[2014,(x^2+2*x+1)*diff(diff(y(x),x),x)+(3*x+3)*diff(y(x),x)+y(x) = 0,y(x)],
[2015,(x-2)*diff(diff(y(x),x),x)+3*diff(y(x),x)+4*y(x)/x^2 = 0,y(x)],
[2016,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[2017,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[2019,2*diff(diff(y(x),x),x) = 0,y(x)],
[2020,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+6)*y(x) = 0,y(x)],
[2022,4*z*diff(diff(y(z),z),z)+(-2*z+2)*diff(y(z),z)-y(z) = 0,y(z)],
[2023,z*diff(diff(y(z),z),z)-2*diff(y(z),z)+9*z^5*y(z) = 0,y(z)],
[2024,diff(diff(f(z),z),z)+(2*z-2)*diff(f(z),z)+4*f(z) = 0,f(z)],
[2025,z^2*diff(diff(y(z),z),z)-3/2*z*diff(y(z),z)+(z+1)*y(z) = 0,y(z)],
[2026,z*diff(diff(y(z),z),z)-2*diff(y(z),z)+z*y(z) = 0,y(z)],
[2027,diff(diff(y(z),z),z)-2*z*diff(y(z),z)-2*y(z) = 0,y(z)],
[2029,z*diff(diff(y(z),z),z)+(2*z-3)*diff(y(z),z)+4/z*y(z) = 0,y(z)],
[2034,(-z^2+1)*diff(diff(y(z),z),z)-z*diff(y(z),z)+m^2*y(z) = 0,y(z)],
[2078,diff(diff(y(x),x),x)-25*y(x) = 0,y(x)],
[2079,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[2080,diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[2083,diff(diff(y(x),x),x)+2*diff(y(x),x)+5*y(x) = 0,y(x)],
[2084,diff(diff(y(x),x),x)-9*y(x) = 0,y(x)],
[2085,x^2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)+3*y(x) = 0,y(x)],
[2086,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[2087,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+13*y(x) = 0,y(x)],
[2088,2*x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[2089,x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[2093,diff(diff(y(x),x),x)-diff(y(x),x)-6*y(x) = 0,y(x)],
[2094,diff(diff(y(x),x),x)+6*diff(y(x),x)+9*y(x) = 0,y(x)],
[2095,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[2096,x^2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[2104,diff(diff(y(x),x),x) = 0,y(x)],
[2105,diff(diff(y(x),x),x) = 0,y(x)],
[2107,diff(diff(y(x),x),x) = 0,y(x)],
[2109,diff(diff(y(x),x),x) = 0,y(x)],
[2110,diff(diff(y(x),x),x)+diff(y(x),x)-6*y(x) = 0,y(x)],
[2111,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)-8*y(x) = 0,y(x)],
[2112,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[2151,diff(diff(y(x),x),x)+1/x*diff(y(x),x) = 0,y(x)],
[2216,diff(diff(y(x),x),x)-2*diff(y(x),x)-3*y(x) = 0,y(x)],
[2217,diff(diff(y(x),x),x)+7*diff(y(x),x)+10*y(x) = 0,y(x)],
[2218,diff(diff(y(x),x),x)-36*y(x) = 0,y(x)],
[2219,diff(diff(y(x),x),x)+4*diff(y(x),x) = 0,y(x)],
[2220,-3*diff(diff(y(x),x),x)-diff(y(x),x)+3*y(x) = 0,y(x)],
[2221,3*diff(diff(y(x),x),x)-4*diff(y(x),x)-12*y(x) = 0,y(x)],
[2222,3*diff(diff(y(x),x),x)-18*diff(y(x),x)-40*y(x) = 0,y(x)],
[2223,-diff(diff(y(x),x),x)-2*diff(y(x),x) = 0,y(x)],
[2224,diff(diff(y(x),x),x)-10*diff(y(x),x)+8*y(x) = 0,y(x)],
[2225,-diff(diff(y(x),x),x)+2*diff(y(x),x) = 0,y(x)],
[2226,-13*diff(diff(y(x),x),x)+36*y(x) = 0,y(x)],
[2227,x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-8*y(x) = 0,y(x)],
[2228,2*x^2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)+y(x) = 0,y(x)],
[2229,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[2230,3*x^2*diff(diff(y(x),x),x)-6*x*diff(y(x),x) = 0,y(x)],
[2231,diff(diff(y(x),x),x)+diff(y(x),x)-6*y(x) = 0,y(x)],
[2232,diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[2233,2*diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[2234,diff(diff(y(x),x),x)-10*diff(y(x),x)+8*y(x) = 0,y(x)],
[2235,5*diff(diff(y(x),x),x)+6*diff(y(x),x) = 0,y(x)],
[2236,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[2237,diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[2238,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[2239,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[2240,diff(diff(y(x),x),x)+2*diff(y(x),x)+5*y(x) = 0,y(x)],
[2241,2*diff(diff(y(x),x),x)-5*diff(y(x),x)-6*y(x) = 0,y(x)],
[2242,-diff(diff(y(x),x),x)+diff(y(x),x)-y(x) = 0,y(x)],
[2243,3*diff(diff(y(x),x),x)+3*diff(y(x),x)+y(x) = 0,y(x)],
[2244,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[2245,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[2246,diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[2247,diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[2249,diff(diff(y(x),x),x)-4*diff(y(x),x)+6*y(x) = 0,y(x)],
[2250,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[2251,2740*diff(diff(y(x),x),x) = 0,y(x)],
[2252,diff(diff(y(x),x),x)+2*diff(y(x),x)-3*y(x) = 0,y(x)],
[2253,diff(diff(y(x),x),x)+6*y(x) = 0,y(x)],
[2254,diff(diff(y(x),x),x)-16*y(x) = 0,y(x)],
[2255,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[2256,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[2257,diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[2258,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[2259,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[2260,diff(diff(y(x),x),x)+2*diff(y(x),x)+2*y(x) = 0,y(x)],
[2261,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[2262,diff(diff(y(x),x),x)+2*diff(y(x),x)+5*y(x) = 0,y(x)],
[2263,diff(diff(y(x),x),x)-2*diff(y(x),x)+10*y(x) = 0,y(x)],
[2264,diff(diff(y(x),x),x)+16*y(x) = 0,y(x)],
[2265,diff(diff(y(x),x),x)-6*diff(y(x),x)+9*y(x) = 0,y(x)],
[2266,diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[2267,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[2268,diff(diff(y(x),x),x)+6*diff(y(x),x)+9*y(x) = 0,y(x)],
[2269,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[2270,diff(diff(y(x),x),x)-4*diff(y(x),x)+5*y(x) = 0,y(x)],
[2271,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[2272,diff(diff(y(x),x),x)-10*diff(y(x),x)+25*y(x) = 0,y(x)],
[2273,diff(diff(y(x),x),x)-6*diff(y(x),x)+13*y(x) = 0,y(x)],
[2274,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[2275,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[2276,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[2277,diff(diff(y(x),x),x)-2*m*diff(y(x),x)+m^2*y(x) = 0,y(x)],
[2278,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[2279,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[2280,diff(diff(y(x),x),x)+2*diff(y(x),x)+17*y(x) = 0,y(x)],
[2281,diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[2282,diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[2283,-3*diff(diff(y(x),x),x)+3*diff(y(x),x)-y(x) = 0,y(x)],
[2284,-6*diff(diff(y(x),x),x)+12*diff(y(x),x)-8*y(x) = 0,y(x)],
[2285,3*diff(diff(y(x),x),x)+3*diff(y(x),x)+y(x) = 0,y(x)],
[2286,-6*diff(diff(y(x),x),x)+9*diff(y(x),x) = 0,y(x)],
[2287,diff(diff(y(x),x),x)-9*y(x) = 0,y(x)],
[2288,diff(diff(y(x),x),x)+5*diff(y(x),x)+4*y(x) = 0,y(x)],
[2289,diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[2290,diff(diff(y(x),x),x)+4*diff(y(x),x)-12*y(x) = 0,y(x)],
[2291,diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[2292,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[2293,x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[2294,x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[2295,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+9*y(x) = 0,y(x)],
[2296,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+5*y(x) = 0,y(x)],
[2297,x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[2298,x^2*diff(diff(y(x),x),x)+6*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[2299,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[2300,x^2*diff(diff(y(x),x),x)+(-2*m*x+x)*diff(y(x),x)+m^2*y(x) = 0,y(x)],
[2301,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+5*y(x) = 0,y(x)],
[2302,t^2*diff(diff(y(t),t),t)+t*diff(y(t),t)+25*y(t) = 0,y(t)],
[2303,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[2304,x*diff(diff(y(x),x),x)+(1-2*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[2305,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[2306,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[2307,diff(diff(y(x),x),x)-1/x*diff(y(x),x)+4*x^2*y(x) = 0,y(x)],
[2308,4*x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2-1)*y(x) = 0,y(x)],
[2309,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[2310,x*diff(diff(y(x),x),x)+(-2*x-1)*diff(y(x),x)+2*y(x) = 0,y(x)],
[2311,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[2312,diff(diff(y(x),x),x)-6*diff(y(x),x)+9*y(x) = 0,y(x)],
[2313,diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[2314,4*x^2*diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[2315,3*diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[2316,11*diff(diff(y(x),x),x)+36*diff(y(x),x)+26*y(x) = 0,y(x)],
[2317,diff(diff(y(x),x),x)+6*diff(y(x),x)+9*y(x) = 0,y(x)],
[2318,diff(diff(y(x),x),x)+6*diff(y(x),x)+9*y(x) = 0,y(x)],
[2319,-6*diff(diff(y(x),x),x)+25*diff(y(x),x) = 0,y(x)],
[2320,-6*diff(diff(y(x),x),x)+25*diff(y(x),x) = 0,y(x)],
[2321,9*diff(diff(y(x),x),x)+24*diff(y(x),x)+16*y(x) = 0,y(x)],
[2322,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[2323,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[2324,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[2326,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[2327,diff(diff(y(x),x),x)+2*diff(y(x),x)-3*y(x) = 0,y(x)],
[2328,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[2329,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[2337,diff(diff(y(t),t),t)+diff(y(t),t)-2*y(t) = 0,y(t)],
[2338,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[2339,diff(diff(y(t),t),t)-3*diff(y(t),t)+2*y(t) = 0,y(t)],
[2340,diff(diff(y(t),t),t)-diff(y(t),t)-12*y(t) = 0,y(t)],
[2341,diff(diff(y(t),t),t)+diff(y(t),t)-2*y(t) = 0,y(t)],
[2342,diff(diff(y(t),t),t)-3*diff(y(t),t)+2*y(t) = 0,y(t)],
[2343,diff(diff(y(t),t),t)-2*diff(y(t),t) = 0,y(t)],
[2344,diff(diff(y(t),t),t)-y(t) = 0,y(t)],
[2345,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[2346,diff(diff(y(t),t),t)-diff(y(t),t)-6*y(t) = 0,y(t)],
[2347,diff(diff(y(t),t),t)-y(t) = 0,y(t)],
[2348,diff(diff(y(t),t),t)-9*y(t) = 0,y(t)],
[2349,diff(diff(y(t),t),t)-y(t) = 0,y(t)],
[2350,diff(diff(y(t),t),t)-diff(y(t),t)-2*y(t) = 0,y(t)],
[2351,diff(diff(y(t),t),t)+5*diff(y(t),t)+4*y(t) = 0,y(t)],
[2352,diff(diff(y(t),t),t)+5*diff(y(t),t)+4*y(t) = 0,y(t)],
[2353,diff(diff(y(t),t),t)-3*diff(y(t),t)+2*y(t) = 0,y(t)],
[2354,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[2355,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[2356,diff(diff(y(t),t),t)+9*y(t) = 0,y(t)],
[2357,diff(diff(y(t),t),t)-y(t) = 0,y(t)],
[2365,diff(diff(y(t),t),t)-y(t) = 0,y(t)],
[2366,diff(diff(y(t),t),t)-diff(y(t),t)-2*y(t) = 0,y(t)],
[2367,diff(diff(y(t),t),t)-4*y(t) = 0,y(t)],
[2368,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[2369,diff(diff(y(t),t),t)+3*diff(y(t),t)+2*y(t) = 0,y(t)],
[2370,diff(diff(y(t),t),t)+diff(y(t),t)-6*y(t) = 0,y(t)],
[2371,diff(diff(y(t),t),t)+4*diff(y(t),t)+5*y(t) = 0,y(t)],
[2372,diff(diff(y(t),t),t)-2*diff(y(t),t)+5*y(t) = 0,y(t)],
[2379,diff(diff(y(t),t),t)-3*diff(y(t),t)+2*y(t) = 0,y(t)],
[2380,diff(diff(y(t),t),t)-4*y(t) = 0,y(t)],
[2381,diff(diff(y(t),t),t)+2*diff(y(t),t)+5*y(t) = 0,y(t)],
[2382,diff(diff(y(t),t),t)-4*diff(y(t),t)+13*y(t) = 0,y(t)],
[2383,diff(diff(y(t),t),t)+4*diff(y(t),t)+3*y(t) = 0,y(t)],
[2384,diff(diff(y(t),t),t)+6*diff(y(t),t)+13*y(t) = 0,y(t)],
[2385,diff(diff(y(t),t),t)+9*y(t) = 0,y(t)],
[2386,diff(diff(y(t),t),t)+16*y(t) = 0,y(t)],
[2387,diff(diff(y(t),t),t)+2*diff(y(t),t)+5*y(t) = 0,y(t)],
[2388,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[2389,diff(diff(y(x),x),x)+2*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[2390,diff(diff(y(x),x),x)-2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[2391,diff(diff(y(x),x),x)-x^2*diff(y(x),x)-2*x*y(x) = 0,y(x)],
[2393,diff(diff(y(x),x),x)+x*diff(y(x),x)+3*y(x) = 0,y(x)],
[2394,diff(diff(y(x),x),x)-x^2*diff(y(x),x)-3*x*y(x) = 0,y(x)],
[2396,(x^2-3)*diff(diff(y(x),x),x)-3*x*diff(y(x),x)-5*y(x) = 0,y(x)],
[2397,(x^2+1)*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[2398,(-4*x^2+1)*diff(diff(y(x),x),x)-20*x*diff(y(x),x)-16*y(x) = 0,y(x)],
[2399,(x^2-1)*diff(diff(y(x),x),x)-6*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[2401,diff(diff(y(x),x),x)+x*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[2404,(2*x^2+1)*diff(diff(y(x),x),x)+7*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[2405,4*diff(diff(y(x),x),x)+x*diff(y(x),x)+4*y(x) = 0,y(x)],
[2407,diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[2414,4*x*diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[2417,6*x^2*diff(diff(y(x),x),x)+(18*x^2+x)*diff(y(x),x)+(1+12*x)*y(x) = 0,y(x)],
[2420,3*x^2*diff(diff(y(x),x),x)+(-x^2-8*x)*diff(y(x),x)+6*y(x) = 0,y(x)],
[2421,2*x^2*diff(diff(y(x),x),x)+(-2*x^2-x)*diff(y(x),x)+(8*x-2)*y(x) = 0,y(x)],
[2423,3*x^2*diff(diff(y(x),x),x)+(3*x^2+7*x)*diff(y(x),x)+(1+6*x)*y(x) = 0,y(x)],
[2426,4*x^2*diff(diff(y(x),x),x)-4*x^2*diff(y(x),x)+(2*x+1)*y(x) = 0,y(x)],
[2427,x^2*diff(diff(y(x),x),x)+(-2*x^2+3*x)*diff(y(x),x)+(1-2*x)*y(x) = 0,y(x)],
[2428,x^2*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+(4-x)*y(x) = 0,y(x)],
[2429,x^2*diff(diff(y(x),x),x)+(-x^2+3*x)*diff(y(x),x)+y(x) = 0,y(x)],
[2432,x^2*diff(diff(y(x),x),x)+(-2*x*5^(1/2)+x)*diff(y(x),x)+(19/4-3*x^2)*y(x) = 0,y(x)],
[2435,x^2*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+x*y(x) = 0,y(x)],
[2436,x^2*diff(diff(y(x),x),x)+(x^2-3*x)*diff(y(x),x)+(4-x)*y(x) = 0,y(x)],
[2439,x^2*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+(-x-2)*y(x) = 0,y(x)],
[2440,x^2*diff(diff(y(x),x),x)+2*x^2*diff(y(x),x)+(x-3/4)*y(x) = 0,y(x)],
[2444,(x^3+x^2)*diff(diff(y(x),x),x)+x^2*diff(y(x),x)-2*y(x) = 0,y(x)],
[2447,x^2*diff(diff(y(x),x),x)+(x^3+6*x)*diff(y(x),x)+6*y(x) = 0,y(x)],
[2448,x^2*diff(diff(y(x),x),x)+(-x^2+x)*diff(y(x),x)-y(x) = 0,y(x)],
[2452,x^2*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[2453,x^2*diff(diff(y(x),x),x)-x^2*diff(y(x),x)-2*y(x) = 0,y(x)],
[2454,x^2*diff(diff(y(x),x),x)-x^2*diff(y(x),x)+(-3*x-2)*y(x) = 0,y(x)],
[2455,x^2*diff(diff(y(x),x),x)+(-x^2+5*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[2456,4*x^2*diff(diff(y(x),x),x)+(-4*x^2+4*x)*diff(y(x),x)+(2*x-9)*y(x) = 0,y(x)],
[2457,x^2*diff(diff(y(x),x),x)+(2*x^2+4*x)*diff(y(x),x)+(2*x+2)*y(x) = 0,y(x)],
[2458,x^2*diff(diff(y(x),x),x)+(x^2-x)*diff(y(x),x)+(1-x)*y(x) = 0,y(x)],
[2459,4*x^2*diff(diff(y(x),x),x)+(8*x^2+4*x)*diff(y(x),x)+(-1+4*x)*y(x) = 0,y(x)],
[2461,x*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[2462,x^2*diff(diff(y(x),x),x)+(x^2+4*x)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[2463,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-9/4)*y(x) = 0,y(x)],
[2467,(-x^2+1)*diff(diff(y(x),x),x)-6*x*diff(y(x),x)-4*y(x) = 0,y(x)],
[2469,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[2470,2*x*diff(diff(y(x),x),x)+(-10*x+5)*diff(y(x),x)-5*y(x) = 0,y(x)],
[2472,(4*x^2+1)*diff(diff(y(x),x),x)-8*y(x) = 0,y(x)],
[2473,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[2475,x^2*diff(diff(y(x),x),x)+3/2*x*diff(y(x),x)+(-1/2*x-1/2)*y(x) = 0,y(x)],
[2733,-2*diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[2734,diff(diff(y(x),x),x)+9*diff(y(x),x)+9*y(x) = 0,y(x)],
[2735,diff(diff(y(x),x),x)-diff(y(x),x)-y(x) = 0,y(x)],
[2739,18*diff(diff(y(x),x),x)+81*y(x) = 0,y(x)],
[2740,-4*diff(diff(y(x),x),x)+16*y(x) = 0,y(x)],
[2741,2*diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[2742,5*diff(diff(y(x),x),x)+5*diff(y(x),x)-6*y(x) = 0,y(x)],
[2745,diff(diff(y(x),x),x)+6*diff(y(x),x)+10*y(x) = 0,y(x)],
[2746,diff(diff(y(x),x),x)-8*diff(y(x),x)+17*y(x) = 0,y(x)],
[2747,diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[2748,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[2749,diff(diff(y(x),x),x)+2*diff(y(x),x)+2*y(x) = 0,y(x)],
[2751,-2*diff(diff(y(x),x),x)+4*diff(y(x),x)-8*y(x) = 0,y(x)],
[2752,-4*diff(diff(y(x),x),x)+3*diff(y(x),x) = 0,y(x)],
[2753,2*diff(diff(y(x),x),x) = 0,y(x)],
[2754,5*diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[4064,diff(diff(y(x),x),x)+2*diff(y(x),x) = 0,y(x)],
[4065,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4066,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4067,6*diff(diff(y(x),x),x)-11*diff(y(x),x)+4*y(x) = 0,y(x)],
[4068,diff(diff(y(x),x),x)+2*diff(y(x),x)-y(x) = 0,y(x)],
[4069,diff(diff(y(x),x),x)-10*diff(y(x),x)-6*y(x) = 0,y(x)],
[4070,-4*diff(diff(y(x),x),x)+4*diff(y(x),x) = 0,y(x)],
[4071,diff(diff(y(x),x),x)-4*diff(y(x),x)-2*y(x) = 0,y(x)],
[4073,diff(diff(y(x),x),x)-2*k*diff(y(x),x)-2*y(x) = 0,y(x)],
[4076,diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[4077,5*diff(diff(y(x),x),x)+diff(y(x),x)-y(x) = 0,y(x)],
[4078,-6*diff(diff(y(x),x),x)+12*diff(y(x),x)-8*y(x) = 0,y(x)],
[4081,-2*diff(diff(y(x),x),x) = 0,y(x)],
[4082,-11*diff(diff(y(x),x),x)-12*diff(y(x),x)+36*y(x) = 0,y(x)],
[4083,-37*diff(diff(y(x),x),x)+4*diff(y(x),x)+5*y(x) = 0,y(x)],
[4084,-8*diff(diff(y(x),x),x)+36*y(x) = 0,y(x)],
[4085,diff(diff(y(x),x),x)-2*diff(y(x),x)+5*y(x) = 0,y(x)],
[4086,diff(diff(y(x),x),x)-diff(y(x),x)+y(x) = 0,y(x)],
[4087,5*diff(diff(y(x),x),x)+6*y(x) = 0,y(x)],
[4088,diff(diff(y(x),x),x)-4*diff(y(x),x)+20*y(x) = 0,y(x)],
[4089,4*diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[4091,4*diff(diff(y(x),x),x) = 0,y(x)],
[4093,diff(diff(y(x),x),x) = 0,y(x)],
[4094,diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[4095,diff(diff(y(x),x),x)-2*diff(y(x),x)+5*y(x) = 0,y(x)],
[4096,diff(diff(y(x),x),x)-4*diff(y(x),x)+20*y(x) = 0,y(x)],
[4097,5*diff(diff(y(x),x),x)+diff(y(x),x)-y(x) = 0,y(x)],
[4098,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4099,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4100,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4101,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4102,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4103,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4104,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[4105,diff(diff(y(x),x),x)-2*diff(y(x),x)-8*y(x) = 0,y(x)],
[4106,diff(diff(y(x),x),x)-3*diff(y(x),x) = 0,y(x)],
[4107,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[4108,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[4109,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4110,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[4111,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[4112,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4113,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4114,diff(diff(y(x),x),x)+diff(y(x),x)-6*y(x) = 0,y(x)],
[4115,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4116,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4117,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4118,diff(diff(y(x),x),x)-5*diff(y(x),x)-6*y(x) = 0,y(x)],
[4119,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[4120,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[4121,diff(diff(y(x),x),x)-5*diff(y(x),x)+6*y(x) = 0,y(x)],
[4122,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4123,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4124,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4125,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4126,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4127,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4128,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4129,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[4130,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4131,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[4132,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4133,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4134,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[4135,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4136,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4137,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4138,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[4139,diff(diff(y(x),x),x)-2/x*diff(y(x),x)+2*y(x)/x^2 = 0,y(x)],
[4140,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[4141,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[4142,2*x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-y(x) = 0,y(x)],
[4146,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x) = 0,y(x)],
[4147,x*diff(diff(y(x),x),x)-diff(y(x),x) = 0,y(x)],
[4157,(x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x) = 0,y(x)],
[4162,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x) = 0,y(x)],
[4163,x*diff(diff(y(x),x),x)-diff(y(x),x) = 0,y(x)],
[4174,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[4193,x^4*diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[4194,x^2*diff(diff(y(x),x),x)+(2*x^2+x)*diff(y(x),x)-4*y(x) = 0,y(x)],
[4195,(-x^2+x)*diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4196,(4*x^3-14*x^2-2*x)*diff(diff(y(x),x),x)+(-6*x^2+7*x-1)*diff(y(x),x)+(6*x-1)*y(x) = 0,y(x)],
[4197,x^2*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[4198,x^2*diff(diff(y(x),x),x)-x^2*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[4200,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(x-9)*y(x) = 0,y(x)],
[4207,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(3*x-1)*y(x) = 0,y(x)],
[4211,x^2*diff(diff(y(x),x),x)+(-x^2-4*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[4215,2*x^2*diff(diff(y(x),x),x)+(-3*x-2)*diff(y(x),x)+(2-1/x)*y(x) = 0,y(x)],
[4216,(-x^2+x)*diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4217,(-x^2+x)*diff(diff(y(x),x),x)+(3/2-2*x)*diff(y(x),x)-1/4*y(x) = 0,y(x)],
[4218,(-2*x^2+2*x)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[4219,(-2*x^2+2*x)*diff(diff(y(x),x),x)+(1-11*x)*diff(y(x),x)-10*y(x) = 0,y(x)],
[4220,(-x^2+x)*diff(diff(y(x),x),x)+(-2/3*x+1/3)*diff(y(x),x)+20/9*y(x) = 0,y(x)],
[4221,(-2*x^2+2*x)*diff(diff(y(x),x),x)+diff(y(x),x)+4*y(x) = 0,y(x)],
[4222,4*diff(diff(y(x),x),x)+(-3/(-x^2+1)^2*x^2+6/(-x^2+1)^2)*y(x) = 0,y(x)],
[4232,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(-x^2-1/4)*y(x) = 0,y(x)],
[4234,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-25/4)*y(x) = 0,y(x)],
[4235,diff(diff(y(x),x),x)+q*diff(y(x),x)-2*y(x)/x^2 = 0,y(x)],
[4239,x*diff(diff(y(x),x),x)+3*diff(y(x),x)+4*x^3*y(x) = 0,y(x)],
[4283,diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[4284,diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[4285,diff(diff(y(x),x),x)+9*diff(y(x),x) = 0,y(x)],
[4286,diff(diff(y(x),x),x)+2*diff(y(x),x)+2*y(x) = 0,y(x)],
[4287,diff(diff(y(x),x),x)-2*diff(y(x),x)+6*y(x) = 0,y(x)],
[4288,diff(diff(y(x),x),x)+16*y(x) = 0,y(x)],
[4289,diff(diff(y(x),x),x)-5*diff(y(x),x)+6*y(x) = 0,y(x)],
[4290,diff(diff(y(x),x),x)+5*diff(y(x),x) = 0,y(x)],
[4291,diff(diff(y(x),x),x)-4*diff(y(x),x)+13*y(x) = 0,y(x)],
[4292,2*diff(diff(y(x),x),x)+diff(y(x),x)-y(x) = 0,y(x)],
[4293,diff(diff(y(x),x),x)+(1+2*I)*diff(y(x),x)+(-1+I)*y(x) = 0,y(x)],
[4294,diff(diff(y(x),x),x)+(1+2*I)*diff(y(x),x)+(-1+I)*y(x) = 0,y(x)],
[4296,diff(diff(y(x),x),x)-6*diff(y(x),x) = 0,y(x)],
[4297,3*diff(diff(y(x),x),x)-9*diff(y(x),x)-5*y(x) = 0,y(x)],
[4299,diff(diff(y(x),x),x)-4*diff(y(x),x) = 0,y(x)],
[4300,diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[4301,diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[4302,diff(diff(y(x),x),x)-2*diff(y(x),x)-3*y(x) = 0,y(x)],
[4303,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4304,diff(diff(y(x),x),x)+6*diff(y(x),x)+9*y(x) = 0,y(x)],
[4305,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[4306,diff(diff(y(x),x),x)-16*y(x) = 0,y(x)],
[4307,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[4308,diff(diff(y(x),x),x)-6*diff(y(x),x)+9*y(x) = 0,y(x)],
[4309,diff(diff(y(x),x),x)+2*diff(y(x),x)+10*y(x) = 0,y(x)],
[4310,diff(diff(y(x),x),x)+4*diff(y(x),x)+12*y(x) = 0,y(x)],
[4311,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4312,diff(diff(y(x),x),x)+8*diff(y(x),x)+25*y(x) = 0,y(x)],
[4313,5*diff(diff(y(x),x),x)+12*diff(y(x),x)+20*y(x) = 0,y(x)],
[4314,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[4315,diff(diff(y(x),x),x)+16*y(x) = 0,y(x)],
[4316,diff(diff(y(x),x),x)+2*diff(y(x),x)+17*y(x) = 0,y(x)],
[4317,4*diff(diff(y(x),x),x)+4*diff(y(x),x)+5*y(x) = 0,y(x)],
[4318,diff(diff(y(x),x),x)+4*diff(y(x),x)+8*y(x) = 0,y(x)],
[4319,5*diff(diff(y(x),x),x)+6*diff(y(x),x)+2*y(x) = 0,y(x)],
[4320,2*diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[4321,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4322,diff(diff(y(x),x),x)-6*diff(y(x),x)+9*y(x) = 0,y(x)],
[4323,diff(diff(y(x),x),x)-2*diff(y(x),x)-3*y(x) = 0,y(x)],
[4324,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4325,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4326,diff(diff(y(x),x),x)-5*diff(y(x),x)+6*y(x) = 0,y(x)],
[4327,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4328,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4329,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[4330,diff(diff(y(x),x),x)-2*diff(y(x),x) = 0,y(x)],
[4335,diff(diff(y(x),x),x)+2*x*diff(y(x),x) = 0,y(x)],
[4340,x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-3*y(x) = 0,y(x)],
[4341,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[4342,x^2*diff(diff(y(x),x),x)+7*x*diff(y(x),x)+9*y(x) = 0,y(x)],
[4343,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+6*y(x) = 0,y(x)],
[4344,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-16*y(x) = 0,y(x)],
[4345,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[4346,x^2*diff(diff(y(x),x),x)-5*x*diff(y(x),x)+9*y(x) = 0,y(x)],
[4347,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[4348,x^2*diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4349,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[4350,(-x^3+2*x^2)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[4351,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[4352,x*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[4353,3*x*diff(diff(y(x),x),x)+(-6*x+2)*diff(y(x),x)+(3*x-2)*y(x) = 0,y(x)],
[4354,x^2*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)-y(x) = 0,y(x)],
[4355,(x^2+x)*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)+y(x) = 0,y(x)],
[4358,2*diff(diff(y(x),x),x)+2*diff(y(x),x) = 0,y(x)],
[4359,diff(diff(r(t),t),t)-6*diff(r(t),t)+9*r(t) = 0,r(t)],
[4361,diff(diff(y(x),x),x)+2*diff(y(x),x)+2*y(x) = 0,y(x)],
[4363,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[4367,x*diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[4368,diff(diff(y(x),x),x)+4*diff(y(x),x)+5*y(x) = 0,y(x)],
[4369,diff(diff(y(x),x),x)+4*diff(y(x),x)+5*y(x) = 0,y(x)],
[4370,diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[4371,diff(diff(y(x),x),x)-5*diff(y(x),x)+6*y(x) = 0,y(x)],
[4375,diff(diff(y(x),x),x)-2*diff(y(x),x)+5*y(x) = 0,y(x)],
[4377,13*diff(diff(y(x),x),x)-18*diff(y(x),x)+36*y(x) = 0,y(x)],
[4382,diff(diff(y(x),x),x)+diff(y(x),x)-6*y(x) = 0,y(x)],
[4390,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[4391,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[4392,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4393,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4394,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4395,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4396,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+3*y(x) = 0,y(x)],
[4397,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+3*y(x) = 0,y(x)],
[4398,(x^2+2*x)*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[4399,(x^2+2*x)*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[4400,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[4401,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[4402,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-2)*y(x) = 0,y(x)],
[4403,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-2)*y(x) = 0,y(x)],
[4507,diff(diff(y(x),x),x)+(x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[4508,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4510,(2*x-3)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[4512,diff(diff(y(x),x),x)-x*diff(y(x),x)-3*y(x) = 0,y(x)],
[4520,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[4530,diff(diff(z(x),x),x)+x*diff(z(x),x)+z(x) = 0,z(x)],
[4532,(x^2+1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[4533,diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[4534,(-x^2+1)*diff(diff(y(x),x),x)-diff(y(x),x)+y(x) = 0,y(x)],
[4538,-diff(diff(x(t),t),t)+diff(x(t),t)-x(t) = 0,x(t)],
[4539,diff(diff(x(t),t),t)+42*diff(x(t),t)+x(t) = 0,x(t)],
[4541,-3*diff(diff(x(t),t),t)-9*diff(x(t),t)-5*x(t) = 0,x(t)],
[4543,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[4544,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4545,diff(diff(y(x),x),x)+16*y(x) = 0,y(x)],
[4546,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4556,(x^3+2*x^2+x)*diff(diff(y(x),x),x)+(-x^2+1)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[4557,(-x^2+x)*diff(diff(y(x),x),x)+(2-4*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[4558,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-9*y(x) = 0,y(x)],
[4559,x*diff(diff(y(x),x),x)+1/2*diff(y(x),x)+2*y(x) = 0,y(x)],
[4560,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[4561,2*x*diff(diff(y(x),x),x)-diff(y(x),x)+2*y(x) = 0,y(x)],
[4562,x*diff(diff(y(x),x),x)+x*diff(y(x),x)-2*y(x) = 0,y(x)],
[4563,(x^3-2*x^2+x)*diff(diff(y(x),x),x)-2*y(x) = 0,y(x)],
[4628,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[4629,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[4630,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[4631,diff(diff(y(x),x),x)+25*y(x) = 0,y(x)],
[4632,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4633,diff(diff(y(x),x),x)+4*diff(y(x),x)+5*y(x) = 0,y(x)],
[4634,3*diff(diff(y(x),x),x)-2*diff(y(x),x)-y(x) = 0,y(x)],
[4635,diff(diff(y(x),x),x)-6*diff(y(x),x)+8*y(x) = 0,y(x)],
[4636,2*diff(diff(y(x),x),x)-7*diff(y(x),x)-4*y(x) = 0,y(x)],
[4637,diff(diff(y(x),x),x)-6*diff(y(x),x)+9*y(x) = 0,y(x)],
[4638,diff(diff(y(x),x),x)-5*diff(y(x),x)+6*y(x) = 0,y(x)],
[4639,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[4640,diff(diff(y(x),x),x)+diff(y(x),x)-2*y(x) = 0,y(x)],
[4641,diff(diff(y(x),x),x)-diff(y(x),x)+10*y(x) = 0,y(x)],
[4642,diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[4643,diff(diff(y(x),x),x)-4*diff(y(x),x)+3*y(x) = 0,y(x)],
[4644,diff(diff(y(x),x),x)-2*diff(y(x),x)+3*y(x) = 0,y(x)],
[4645,diff(diff(y(x),x),x)-9*y(x) = 0,y(x)],
[4646,diff(diff(x(t),t),t)+4*diff(x(t),t)+3*x(t) = 0,x(t)],
[4647,diff(diff(y(t),t),t)+4*diff(y(t),t)+5*y(t) = 0,y(t)],
[4648,diff(diff(x(t),t),t)-3*diff(x(t),t)+2*x(t) = 0,x(t)],
[4649,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[4650,diff(diff(y(x),x),x)+6*diff(y(x),x)+10*y(x) = 0,y(x)],
[4651,diff(diff(x(t),t),t)+2*diff(x(t),t)+2*x(t) = 0,x(t)],
[4652,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[4653,1/2*diff(diff(x(t),t),t)+48*x(t) = 0,x(t)],
[4654,diff(diff(x(t),t),t)+5*diff(x(t),t)+6*x(t) = 0,x(t)],
[4655,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[4656,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[4657,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[4658,diff(diff(y(t),t),t)-6*diff(y(t),t)+25*y(t) = 0,y(t)],
[4659,diff(diff(y(t),t),t)-6*diff(y(t),t)+25*y(t) = 0,y(t)],
[4660,diff(diff(y(t),t),t)-6*diff(y(t),t)+25*y(t) = 0,y(t)],
[4661,-6*diff(diff(y(x),x),x)+11*diff(y(x),x)-6*y(x) = 0,y(x)],
[4662,diff(diff(y(x),x),x) = 0,y(x)],
[4663,diff(diff(y(x),x),x)-5*y(x) = 0,y(x)],
[4667,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4668,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4669,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4670,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4671,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4675,-3*diff(diff(y(x),x),x)+3*diff(y(x),x)-y(x) = 0,y(x)],
[4677,-3*diff(diff(y(x),x),x)+2*diff(y(x),x) = 0,y(x)],
[4678,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4679,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[4680,diff(diff(x(t),t),t)+4*x(t) = 0,x(t)],
[4681,t^2*diff(diff(y(t),t),t)-2*t*diff(y(t),t)+2*y(t) = 0,y(t)],
[4684,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[4685,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4686,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[4687,diff(diff(y(x),x),x)-60*diff(y(x),x)-900*y(x) = 0,y(x)],
[4688,diff(diff(y(x),x),x)-7*diff(y(x),x) = 0,y(x)],
[4689,diff(diff(y(x),x),x)+1/x*diff(y(x),x)-y(x)/x^2 = 0,y(x)],
[4690,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x) = 0,y(x)],
[4695,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4696,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4697,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4698,diff(diff(y(x),x),x)+2*diff(y(x),x)-3*y(x) = 0,y(x)],
[4699,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4700,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[4701,diff(diff(y(x),x),x)+2*diff(y(x),x)+5*y(x) = 0,y(x)],
[4702,diff(diff(y(x),x),x)+5*diff(y(x),x)-3*y(x) = 0,y(x)],
[4705,-3*diff(diff(y(x),x),x)+3*diff(y(x),x)-y(x) = 0,y(x)],
[4706,diff(diff(x(t),t),t)+4*diff(x(t),t)+4*x(t) = 0,x(t)],
[4707,diff(diff(q(t),t),t)+9*diff(q(t),t)+14*q(t) = 0,q(t)],
[4711,diff(diff(y(x),x),x)-2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[4712,diff(diff(y(x),x),x)+x^2*diff(y(x),x)+2*x*y(x) = 0,y(x)],
[4715,(x^2-1)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[4717,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+x^2*y(x) = 0,y(x)],
[4718,(-x^3+2*x)*diff(diff(y(x),x),x)+(x^3+3*x^2-2*x-2)*diff(y(x),x)+(-x^2-4*x-2)*y(x) = 0,y(x)],
[4719,(x^3+x^2)*diff(diff(y(x),x),x)+(-2*x^2-x)*diff(y(x),x)+(2*x+1)*y(x) = 0,y(x)],
[4720,(-4*x^3-2*x^2)*diff(diff(y(x),x),x)+(10*x^2+4*x)*diff(y(x),x)+(-12*x-4)*y(x) = 0,y(x)],
[4721,(-4*x^4-2*x^2)*diff(diff(y(x),x),x)+(10*x^3+4*x)*diff(y(x),x)+(-12*x^2-4)*y(x) = 0,y(x)],
[4722,(-2*x^3+4*x^2)*diff(diff(y(x),x),x)+(x^2-4*x)*diff(y(x),x)+(3-x)*y(x) = 0,y(x)],
[4723,(-x^3+x^2)*diff(diff(y(x),x),x)+(5*x^2-4*x)*diff(y(x),x)+(6-9*x)*y(x) = 0,y(x)],
[4724,x*diff(diff(y(x),x),x)+(4*x^2+1)*diff(y(x),x)+(4*x^3+4*x)*y(x) = 0,y(x)],
[4727,(x^2-3*x+2)*diff(diff(y(x),x),x)+(4*x-6)*diff(y(x),x)+2*y(x) = 0,y(x)],
[4728,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[4729,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[4730,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[4732,(x^2+2*x)*diff(diff(y(x),x),x)+(2*x+2)*diff(y(x),x)-2*y(x) = 0,y(x)],
[4735,(-x^2+x)*diff(diff(y(x),x),x)-3*x*diff(y(x),x)-y(x) = 0,y(x)],
[4736,2*x*diff(diff(y(x),x),x)-diff(y(x),x)+x^2*y(x) = 0,y(x)],
[4739,(x^2+2*x)*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)-4*y(x) = 0,y(x)],
[4740,x*diff(diff(y(x),x),x)+(1/2-x)*diff(y(x),x)-y(x) = 0,y(x)],
[4744,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[4750,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4755,(-x^2+1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+p^2*y(x) = 0,y(x)],
[4756,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[4761,x^2*diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4763,x^2*diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4766,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)-y(x) = 0,y(x)],
[4771,x^2*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+x^2*y(x) = 0,y(x)],
[4772,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4777,x^2*diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[4779,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[4782,(x^2-2*x+10)*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[4783,(x^2-2*x+10)*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[4787,diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[4789,diff(diff(y(x),x),x)+2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[4790,(x-1)*diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[4791,(x+2)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[4792,diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)-y(x) = 0,y(x)],
[4793,(x^2+1)*diff(diff(y(x),x),x)-6*y(x) = 0,y(x)],
[4794,(x^2+2)*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-y(x) = 0,y(x)],
[4795,(x^2-1)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[4796,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[4797,(x+1)*diff(diff(y(x),x),x)+(x-2)*diff(y(x),x)+y(x) = 0,y(x)],
[4798,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[4799,(x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x) = 0,y(x)],
[4802,diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[4815,x^2*diff(diff(y(x),x),x)+(5/3*x+x^2)*diff(y(x),x)-1/3*y(x) = 0,y(x)],
[4817,2*x*diff(diff(y(x),x),x)-diff(y(x),x)+2*y(x) = 0,y(x)],
[4821,3*x*diff(diff(y(x),x),x)+(-x+2)*diff(y(x),x)-y(x) = 0,y(x)],
[4823,2*x*diff(diff(y(x),x),x)+(-2*x-3)*diff(y(x),x)+y(x) = 0,y(x)],
[4826,2*x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+(2*x-1)*y(x) = 0,y(x)],
[4827,x*diff(diff(y(x),x),x)+2*diff(y(x),x)-x*y(x) = 0,y(x)],
[4828,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[4829,x*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[4831,x*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)-y(x) = 0,y(x)],
[4833,x*diff(diff(y(x),x),x)+(x-6)*diff(y(x),x)-3*y(x) = 0,y(x)],
[4834,(x^2-x)*diff(diff(y(x),x),x)+3*diff(y(x),x)-2*y(x) = 0,y(x)],
[4837,x^2*diff(diff(y(x),x),x)+(3*x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[4840,4*x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2-25)*y(x) = 0,y(x)],
[4845,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(36*x^2-1/4)*y(x) = 0,y(x)],
[4852,x^2*diff(diff(y(x),x),x)+(x^2-2)*y(x) = 0,y(x)],
[4854,x*diff(diff(y(x),x),x)+3*diff(y(x),x)+x^3*y(x) = 0,y(x)],
[4858,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4859,x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[4860,16*x^2*diff(diff(y(x),x),x)+32*x*diff(y(x),x)+(x^4-12)*y(x) = 0,y(x)],
[4862,2*x*diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[4863,diff(diff(y(x),x),x)-x*diff(y(x),x)-y(x) = 0,y(x)],
[4865,diff(diff(y(x),x),x)-x^2*diff(y(x),x)+x*y(x) = 0,y(x)],
[4866,x*diff(diff(y(x),x),x)+(-x-2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[4868,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[4873,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[4876,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[4878,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-2)*y(x) = 0,y(x)],
[4881,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+30*y(x) = 0,y(x)],
[4883,(x^2-4*x+4)*diff(diff(y(x),x),x)+(x+2)*diff(y(x),x)-y(x) = 0,y(x)],
[4884,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[4886,x*diff(diff(y(x),x),x)+(2*x+1)*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[4890,(2*x^2-2*x)*diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[4891,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+4*x*y(x) = 0,y(x)],
[4892,x*diff(diff(y(x),x),x)+(2-2*x)*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[4893,x^2*diff(diff(y(x),x),x)+6*x*diff(y(x),x)+(4*x^2+6)*y(x) = 0,y(x)],
[4894,x*diff(diff(y(x),x),x)+(1-2*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[4895,(-2*x^2+2*x)*diff(diff(y(x),x),x)+(-6*x-1)*diff(y(x),x)-2*y(x) = 0,y(x)],
[4896,(-x^2+x)*diff(diff(y(x),x),x)+(1/2+2*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[4898,(4*t^2-12*t+8)*diff(diff(y(t),t),t)-2*diff(y(t),t)+y(t) = 0,y(t)],
[4899,(2*t^2-10*t+12)*diff(diff(y(t),t),t)+(2*t-3)*diff(y(t),t)-8*y(t) = 0,y(t)],
[4900,(3*t^2+3*t)*diff(diff(y(t),t),t)+t*diff(y(t),t)-y(t) = 0,y(t)],
[4904,x^2*diff(diff(y(x),x),x)+(1/4*x+3/16)*y(x) = 0,y(x)],
[4905,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(1/4*x^2-1/4)*y(x) = 0,y(x)],
[4916,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[4917,x*diff(diff(y(x),x),x)+(1-2*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[4918,(x^2-2*x+1)*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)-35*y(x) = 0,y(x)],
[4919,(16*x^2+32*x+16)*diff(diff(y(x),x),x)+3*y(x) = 0,y(x)],
[4922,x*diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[4923,x*diff(diff(y(x),x),x)+3*diff(y(x),x)+4*x^3*y(x) = 0,y(x)],
[4928,diff(diff(y(t),t),t)-diff(y(t),t)-6*y(t) = 0,y(t)],
[4929,diff(diff(y(t),t),t)+9*y(t) = 0,y(t)],
[4930,diff(diff(y(t),t),t)-1/4*y(t) = 0,y(t)],
[4931,diff(diff(y(t),t),t)-6*diff(y(t),t)+5*y(t) = 0,y(t)],
[4932,diff(diff(y(t),t),t)+7*diff(y(t),t)+12*y(t) = 0,y(t)],
[4933,diff(diff(y(t),t),t)-4*diff(y(t),t)+4*y(t) = 0,y(t)],
[4934,diff(diff(y(t),t),t)-4*diff(y(t),t)+3*y(t) = 0,y(t)],
[4935,diff(diff(y(t),t),t)+1/25*y(t) = 0,y(t)],
[4936,diff(diff(y(t),t),t)+3*diff(y(t),t)+9/4*y(t) = 0,y(t)],
[4937,diff(diff(y(t),t),t)-2*diff(y(t),t)-3*y(t) = 0,y(t)],
[4939,diff(diff(y(t),t),t)+2*diff(y(t),t)+5*y(t) = 0,y(t)],
[4940,diff(diff(y(t),t),t)+3*diff(y(t),t)-4*y(t) = 0,y(t)],
[4941,9*diff(diff(y(t),t),t)-6*diff(y(t),t)+y(t) = 0,y(t)],
[4942,diff(diff(y(t),t),t)+6*diff(y(t),t)+8*y(t) = 0,y(t)],
[4943,diff(diff(y(t),t),t)+10*diff(y(t),t)+24*y(t) = 0,y(t)],
[4944,diff(diff(y(t),t),t)+9*y(t) = 0,y(t)],
[4945,diff(diff(y(t),t),t)+3*diff(y(t),t)+2*y(t) = 0,y(t)],
[4946,diff(diff(y(t),t),t)+diff(y(t),t)-2*y(t) = 0,y(t)],
[4947,diff(diff(y(t),t),t)+3*diff(y(t),t)+2*y(t) = 0,y(t)],
[4948,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[4949,diff(diff(y(t),t),t)+2*diff(y(t),t)+5*y(t) = 0,y(t)],
[4950,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[4951,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[4952,diff(diff(y(t),t),t)+16*y(t) = 0,y(t)],
[4953,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[4954,diff(diff(y(t),t),t)+4*diff(y(t),t)+5*y(t) = 0,y(t)],
[4955,4*diff(diff(y(t),t),t)+24*diff(y(t),t)+37*y(t) = 0,y(t)],
[4956,diff(diff(y(t),t),t)+3*diff(y(t),t)+2*y(t) = 0,y(t)],
[4957,diff(diff(y(t),t),t)+4*diff(y(t),t)+5*y(t) = 0,y(t)],
[4958,diff(diff(y(t),t),t)+5*diff(y(t),t)+6*y(t) = 0,y(t)],
[4959,diff(diff(y(t),t),t)+5*diff(y(t),t)+6*y(t) = 0,y(t)],
[4960,diff(diff(y(t),t),t)+2*diff(y(t),t)+5*y(t) = 0,y(t)],
[5057,diff(diff(y(x),x),x)+2*diff(y(x),x)-y(x) = 0,y(x)],
[5058,diff(diff(y(x),x),x)+1/x*diff(y(x),x)-y(x)/x^2 = 0,y(x)],
[5059,(x^2+1)*diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[5062,(-x^4+x^2)*diff(diff(y(x),x),x)+(-2*x^3+2*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[5063,(-x^2+1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[5066,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[5067,-x^2*diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5068,(x^2+1)*diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[5069,diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[5070,x*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[5071,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[5072,x^3*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[5073,(x^2+x)*diff(diff(y(x),x),x)+(x+2)*diff(y(x),x)-y(x) = 0,y(x)],
[5074,2*x*diff(diff(y(x),x),x)+(x-2)*diff(y(x),x)-y(x) = 0,y(x)],
[5077,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[5078,(-x^2+1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+1/4*y(x) = 0,y(x)],
[5096,diff(diff(y(x),x),x)-2*diff(y(x),x)-3*y(x) = 0,y(x)],
[5097,diff(diff(s(t),t),t)+2*diff(s(t),t)+s(t) = 0,s(t)],
[5098,diff(diff(y(x),x),x)-2*diff(y(x),x)+5*y(x) = 0,y(x)],
[5099,diff(diff(y(x),x),x)-2*diff(y(x),x)-3*y(x) = 0,y(x)],
[5100,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[5101,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5102,diff(diff(y(x),x),x)+2*x^2*diff(y(x),x)+(x^4+2*x-1)*y(x) = 0,y(x)],
[5103,p*x^2*diff(diff(u(x),x),x)+q*x*diff(u(x),x)+r*u(x) = 0,u(x)],
[5106,diff(diff(y(x),x),x)-x/(-x^2+1)*diff(y(x),x)+y(x)/(-x^2+1) = 0,y(x)],
[5108,-3*diff(diff(y(t),t),t)+3*diff(y(t),t)-y(t) = 0,y(t)],
[5109,2*diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[5110,-diff(diff(y(t),t),t)-diff(y(t),t)+y(t) = 0,y(t)],
[5113,3*diff(diff(y(x),x),x)-4*diff(y(x),x)-4*y(x) = 0,y(x)],
[5114,diff(diff(u(x),x),x)+(-2*x-1)*diff(u(x),x)+(x^2+x-1)*u(x) = 0,u(x)],
[5115,diff(diff(y(x),x),x)+6*diff(y(x),x)+9*y(x) = 0,y(x)],
[5116,diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[5117,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[5118,6*diff(diff(y(x),x),x)+11*diff(y(x),x)+6*y(x) = 0,y(x)],
[5119,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5120,diff(diff(y(x),x),x)-4*diff(y(x),x)+3*y(x) = 0,y(x)],
[5121,diff(diff(y(x),x),x)+2*diff(y(x),x)+(1+2/(3*x+1)^2)*y(x) = 0,y(x)],
[5124,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[5125,diff(diff(y(x),x),x)+2/x*diff(y(x),x)-2*y(x)/(x+1)^2 = 0,y(x)],
[5133,-diff(diff(y(x),x),x) = 0,y(x)],
[5160,diff(diff(y(x),x),x) = 0,y(x)],
[5164,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[5165,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5168,diff(diff(y(x),x),x) = 0,y(x)],
[5191,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[5192,3*diff(diff(y(x),x),x)+2*y(x) = 0,y(x)],
[5193,diff(diff(y(x),x),x)+16*y(x) = 0,y(x)],
[5194,diff(diff(y(x),x),x) = 0,y(x)],
[5195,diff(diff(y(x),x),x)+2*I*diff(y(x),x)+y(x) = 0,y(x)],
[5196,diff(diff(y(x),x),x)-4*diff(y(x),x)+5*y(x) = 0,y(x)],
[5197,diff(diff(y(x),x),x)+(-1+3*I)*diff(y(x),x)-3*I*y(x) = 0,y(x)],
[5198,diff(diff(y(x),x),x)+diff(y(x),x)-6*y(x) = 0,y(x)],
[5199,diff(diff(y(x),x),x)+diff(y(x),x)-6*y(x) = 0,y(x)],
[5200,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5201,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5202,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5203,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5204,diff(diff(y(x),x),x)-2*diff(y(x),x)-3*y(x) = 0,y(x)],
[5205,diff(diff(y(x),x),x)+(1+4*I)*diff(y(x),x)+y(x) = 0,y(x)],
[5206,diff(diff(y(x),x),x)+(-1+3*I)*diff(y(x),x)-3*I*y(x) = 0,y(x)],
[5207,diff(diff(y(x),x),x)+10*y(x) = 0,y(x)],
[5208,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5209,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[5210,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5211,diff(diff(y(x),x),x)+2*I*diff(y(x),x)+y(x) = 0,y(x)],
[5212,diff(diff(y(x),x),x)-4*diff(y(x),x)+5*y(x) = 0,y(x)],
[5213,diff(diff(y(x),x),x)-7*diff(y(x),x)+6*y(x) = 0,y(x)],
[5214,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5215,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5216,4*diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[5217,6*diff(diff(y(x),x),x)+5*diff(y(x),x)-6*y(x) = 0,y(x)],
[5221,-5*diff(diff(y(x),x),x)+6*diff(y(x),x) = 0,y(x)],
[5222,-I*diff(diff(y(x),x),x)+4*diff(y(x),x)-4*I*y(x) = 0,y(x)],
[5223,5*diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5226,-3*I*diff(diff(y(x),x),x)-3*diff(y(x),x)+I*y(x) = 0,y(x)],
[5229,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5230,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[5233,-5*diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5235,-I*diff(diff(y(x),x),x)+diff(y(x),x)-I*y(x) = 0,y(x)],
[5236,diff(diff(y(x),x),x)-2*I*diff(y(x),x)-y(x) = 0,y(x)],
[5241,6*diff(diff(y(x),x),x)-4*diff(y(x),x)+y(x) = 0,y(x)],
[5243,diff(diff(y(x),x),x)-2*I*diff(y(x),x)-y(x) = 0,y(x)],
[5244,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5245,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5246,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[5247,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[5248,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[5249,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5250,diff(diff(y(x),x),x)+I*diff(y(x),x)+2*y(x) = 0,y(x)],
[5252,3*diff(diff(y(x),x),x)+3*diff(y(x),x)+y(x) = 0,y(x)],
[5253,diff(diff(y(x),x),x)+1/x*diff(y(x),x)-y(x)/x^2 = 0,y(x)],
[5254,diff(diff(y(x),x),x)+1/x*diff(y(x),x)-y(x)/x^2 = 0,y(x)],
[5255,(9*x^2-6*x+1)*diff(diff(y(x),x),x)+(9*x-3)*diff(y(x),x)-9*y(x) = 0,y(x)],
[5256,x^2*diff(diff(y(x),x),x)-7*x*diff(y(x),x)+15*y(x) = 0,y(x)],
[5257,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[5258,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-2)*y(x) = 0,y(x)],
[5259,x*diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[5260,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5261,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5262,-3*x^2*diff(diff(y(x),x),x)+6*x*diff(y(x),x)-6*y(x) = 0,y(x)],
[5263,x^2*diff(diff(y(x),x),x)-2*y(x) = 0,y(x)],
[5264,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[5265,x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[5266,diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[5270,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5278,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-6*y(x) = 0,y(x)],
[5279,2*x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[5280,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[5281,x^2*diff(diff(y(x),x),x)-5*x*diff(y(x),x)+9*y(x) = 0,y(x)],
[5282,2*x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[5283,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+4*y(x) = 0,y(x)],
[5284,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+5*y(x) = 0,y(x)],
[5285,x^2*diff(diff(y(x),x),x)+(-I*x-2*x)*diff(y(x),x)+3*I*y(x) = 0,y(x)],
[5286,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*Pi*y(x) = 0,y(x)],
[5287,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)-y(x) = 0,y(x)],
[5291,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5294,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[5304,x^2*diff(diff(y(x),x),x)+2*x^2*diff(y(x),x)-2*y(x) = 0,y(x)],
[5306,x^2*diff(diff(y(x),x),x)+(-2*x^2-2*x)*diff(y(x),x)+(2*x+2)*y(x) = 0,y(x)],
[5308,x^2*diff(diff(y(x),x),x)-2*x^2*diff(y(x),x)+(4*x-2)*y(x) = 0,y(x)],
[5309,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5338,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[5343,x*diff(diff(y(x),x),x)-2*diff(y(x),x) = 0,y(x)],
[5356,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5357,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[5383,diff(diff(y(x),x),x)-5*diff(y(x),x)+4*y(x) = 0,y(x)],
[5385,diff(diff(y(x),x),x)-5*diff(y(x),x)+2*y(x) = 0,y(x)],
[5490,x*diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[5515,x*diff(diff(y(x),x),x)-3*diff(y(x),x) = 0,y(x)],
[5516,diff(diff(y(x),x),x)+diff(y(x),x)-6*y(x) = 0,y(x)],
[5517,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[5518,diff(diff(y(x),x),x)+8*y(x) = 0,y(x)],
[5519,2*diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[5520,diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[5521,diff(diff(y(x),x),x)-9*diff(y(x),x)+20*y(x) = 0,y(x)],
[5522,2*diff(diff(y(x),x),x)+2*diff(y(x),x)+3*y(x) = 0,y(x)],
[5523,4*diff(diff(y(x),x),x)-12*diff(y(x),x)+9*y(x) = 0,y(x)],
[5524,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5525,diff(diff(y(x),x),x)-6*diff(y(x),x)+25*y(x) = 0,y(x)],
[5526,4*diff(diff(y(x),x),x)+20*diff(y(x),x)+25*y(x) = 0,y(x)],
[5527,diff(diff(y(x),x),x)+2*diff(y(x),x)+3*y(x) = 0,y(x)],
[5528,diff(diff(y(x),x),x)-4*y(x) = 0,y(x)],
[5529,4*diff(diff(y(x),x),x)-8*diff(y(x),x)+7*y(x) = 0,y(x)],
[5530,2*diff(diff(y(x),x),x)+diff(y(x),x)-y(x) = 0,y(x)],
[5531,diff(diff(y(x),x),x)+4*diff(y(x),x)+5*y(x) = 0,y(x)],
[5532,diff(diff(y(x),x),x)+4*diff(y(x),x)+5*y(x) = 0,y(x)],
[5533,diff(diff(y(x),x),x)+4*diff(y(x),x)-5*y(x) = 0,y(x)],
[5534,diff(diff(y(x),x),x)-5*diff(y(x),x)+6*y(x) = 0,y(x)],
[5535,diff(diff(y(x),x),x)-6*diff(y(x),x)+5*y(x) = 0,y(x)],
[5536,diff(diff(y(x),x),x)-6*diff(y(x),x)+9*y(x) = 0,y(x)],
[5537,diff(diff(y(x),x),x)+4*diff(y(x),x)+5*y(x) = 0,y(x)],
[5538,diff(diff(y(x),x),x)+4*diff(y(x),x)+2*y(x) = 0,y(x)],
[5539,diff(diff(y(x),x),x)+8*diff(y(x),x)-9*y(x) = 0,y(x)],
[5540,x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+10*y(x) = 0,y(x)],
[5541,2*x^2*diff(diff(y(x),x),x)+10*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[5542,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-12*y(x) = 0,y(x)],
[5543,4*x^2*diff(diff(y(x),x),x)-3*y(x) = 0,y(x)],
[5544,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[5545,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-6*y(x) = 0,y(x)],
[5546,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)+3*y(x) = 0,y(x)],
[5547,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-2*y(x) = 0,y(x)],
[5548,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-16*y(x) = 0,y(x)],
[5549,diff(diff(y(x),x),x)+3*diff(y(x),x)-10*y(x) = 0,y(x)],
[5550,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5551,diff(diff(y(x),x),x)+10*diff(y(x),x)+25*y(x) = 0,y(x)],
[5552,diff(diff(y(x),x),x)-2*diff(y(x),x)+5*y(x) = 0,y(x)],
[5553,diff(diff(y(x),x),x)-diff(y(x),x)-6*y(x) = 0,y(x)],
[5554,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[5555,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5556,diff(diff(y(x),x),x)-2*diff(y(x),x) = 0,y(x)],
[5557,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[5558,diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[5559,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[5560,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5561,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[5562,diff(diff(y(x),x),x)-3*y(x) = 0,y(x)],
[5564,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5565,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[5566,diff(diff(y(x),x),x)-2*diff(y(x),x)-3*y(x) = 0,y(x)],
[5567,diff(diff(y(x),x),x)+2*diff(y(x),x)+5*y(x) = 0,y(x)],
[5568,2*diff(diff(y(x),x),x)+3*diff(y(x),x)+y(x) = 0,y(x)],
[5569,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[5570,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5571,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5572,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5573,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5574,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5575,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5576,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5577,diff(diff(y(x),x),x)-2*diff(y(x),x)+y(x) = 0,y(x)],
[5578,diff(diff(y(x),x),x)-diff(y(x),x)-6*y(x) = 0,y(x)],
[5579,(x^2-1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5580,(x^2+x)*diff(diff(y(x),x),x)+(-x^2+2)*diff(y(x),x)+(-x-2)*y(x) = 0,y(x)],
[5581,(1-x)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[5582,x*diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[5583,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5584,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5585,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[5586,x*diff(diff(y(x),x),x)+3*diff(y(x),x) = 0,y(x)],
[5587,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[5588,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5589,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[5590,diff(diff(y(x),x),x)-x/(x-1)*diff(y(x),x)+1/(x-1)*y(x) = 0,y(x)],
[5591,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[5592,x^2*diff(diff(y(x),x),x)+(-x^2-2*x)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[5594,x*diff(diff(y(x),x),x)+(-2*x-1)*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[5595,-3*diff(diff(y(x),x),x)+2*diff(y(x),x) = 0,y(x)],
[5596,-3*diff(diff(y(x),x),x)+4*diff(y(x),x)-2*y(x) = 0,y(x)],
[5599,3*diff(diff(y(x),x),x)+3*diff(y(x),x)+y(x) = 0,y(x)],
[5600,6*diff(diff(y(x),x),x)+4*diff(y(x),x)+y(x) = 0,y(x)],
[5602,5*diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5605,2*diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[5606,-2*diff(diff(y(x),x),x)-6*diff(y(x),x)+5*y(x) = 0,y(x)],
[5607,-6*diff(diff(y(x),x),x)+11*diff(y(x),x)-6*y(x) = 0,y(x)],
[5608,-3*diff(diff(y(x),x),x)-5*diff(y(x),x)-2*y(x) = 0,y(x)],
[5609,48*diff(diff(y(x),x),x)+16*diff(y(x),x)-96*y(x) = 0,y(x)],
[5612,-3*diff(diff(y(x),x),x)+2*diff(y(x),x) = 0,y(x)],
[5614,3*x^2*diff(diff(y(x),x),x) = 0,y(x)],
[5615,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5616,2*x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[5617,8*x*diff(diff(y(x),x),x)-8*diff(y(x),x) = 0,y(x)],
[5618,diff(diff(y(x),x),x)-3*diff(y(x),x)+y(x) = 0,y(x)],
[5619,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[5620,diff(diff(y(x),x),x)+6*diff(y(x),x)+9*y(x) = 0,y(x)],
[5621,diff(diff(y(x),x),x)-diff(y(x),x)+6*y(x) = 0,y(x)],
[5622,diff(diff(y(x),x),x)-2*diff(y(x),x)-5*y(x) = 0,y(x)],
[5623,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5624,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[5625,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[5626,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[5627,diff(diff(y(x),x),x)-diff(y(x),x)+4*y(x) = 0,y(x)],
[5628,diff(diff(y(x),x),x)+2*diff(y(x),x)+5*y(x) = 0,y(x)],
[5629,diff(diff(y(x),x),x)+3*diff(y(x),x)+4*y(x) = 0,y(x)],
[5630,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5631,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[5632,diff(diff(y(x),x),x) = 0,y(x)],
[5633,diff(diff(y(x),x),x)-2*diff(y(x),x) = 0,y(x)],
[5634,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[5635,diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[5636,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[5637,diff(diff(y(x),x),x)+2*diff(y(x),x)-y(x) = 0,y(x)],
[5638,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[5639,diff(diff(y(x),x),x)+4*diff(y(x),x)+4*y(x) = 0,y(x)],
[5640,x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+y(x) = 0,y(x)],
[5641,diff(diff(y(x),x),x)+4*y(x) = 0,y(x)],
[5642,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[5643,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5644,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[5645,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[5646,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5647,diff(diff(y(x),x),x)+9*y(x) = 0,y(x)],
[5649,diff(diff(y(x),x),x)+3*y(x) = 0,y(x)],
[5674,diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[5678,(x^2+1)*diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[5679,diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)-y(x) = 0,y(x)],
[5680,(x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[5681,diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[5686,(-x^2+1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+p^2*y(x) = 0,y(x)],
[5690,x^2*diff(diff(y(x),x),x)+(-x+2)*diff(y(x),x) = 0,y(x)],
[5700,x^3*diff(diff(y(x),x),x)-4*x^2*diff(y(x),x)+3*x*y(x) = 0,y(x)],
[5702,2*x*diff(diff(y(x),x),x)+(3-x)*diff(y(x),x)-y(x) = 0,y(x)],
[5703,2*x*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)+3*y(x) = 0,y(x)],
[5704,2*x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(-x-1)*y(x) = 0,y(x)],
[5706,diff(diff(y(x),x),x)+1/x^2*diff(y(x),x)-1/x^3*y(x) = 0,y(x)],
[5707,x^2*diff(diff(y(x),x),x)+(3*x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[5709,4*x^2*diff(diff(y(x),x),x)-8*x^2*diff(y(x),x)+(4*x^2+1)*y(x) = 0,y(x)],
[5710,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[5711,x^2*diff(diff(y(x),x),x)-x^2*diff(y(x),x)+(x^2-2)*y(x) = 0,y(x)],
[5712,x*diff(diff(y(x),x),x)-diff(y(x),x)+4*x^3*y(x) = 0,y(x)],
[5713,(x^2-2*x+1)*diff(diff(y(x),x),x)+(-3*x+3)*diff(y(x),x)+2*y(x) = 0,y(x)],
[5714,(3*x^2+6*x+3)*diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)-y(x) = 0,y(x)],
[5716,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[5717,(-x^2+x)*diff(diff(y(x),x),x)+(3/2-2*x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[5718,(2*x^2+2*x)*diff(diff(y(x),x),x)+(1+5*x)*diff(y(x),x)+y(x) = 0,y(x)],
[5719,(x^2-1)*diff(diff(y(x),x),x)+(5*x+4)*diff(y(x),x)+4*y(x) = 0,y(x)],
[5721,(-x^2+1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+p^2*y(x) = 0,y(x)],
[5724,diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[5725,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[5726,2*diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[5728,(x^2+1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[5729,diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)-x*y(x) = 0,y(x)],
[5730,(x-1)*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)+y(x) = 0,y(x)],
[5733,x*diff(diff(y(x),x),x)-4*diff(y(x),x)+x*y(x) = 0,y(x)],
[5735,2*x*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)+y(x) = 0,y(x)],
[5736,x*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[5738,x*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)+y(x) = 0,y(x)],
[5739,2*x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+x*y(x) = 0,y(x)],
[5741,-2*x^2*diff(diff(y(x),x),x)+(x^2+2*x)*diff(y(x),x)-x*y(x) = 0,y(x)],
[5742,(2*x^3-x^2)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[5746,diff(diff(y(t),t),t)+5*diff(y(t),t)+6*y(t) = 0,y(t)],
[5747,diff(diff(y(t),t),t)+diff(y(t),t)-6*y(t) = 0,y(t)],
[5748,diff(diff(y(t),t),t)-y(t) = 0,y(t)],
[5752,diff(diff(y(t),t),t)+3*diff(y(t),t)-5*y(t) = 0,y(t)],
[5753,diff(diff(y(t),t),t)+3*diff(y(t),t)-2*y(t) = 0,y(t)],
[5754,diff(diff(y(t),t),t)+2*diff(y(t),t)-y(t) = 0,y(t)],
[5755,diff(diff(y(t),t),t)-diff(y(t),t)+y(t) = 0,y(t)],
[5756,diff(diff(y(t),t),t)-5*diff(y(t),t)+4*y(t) = 0,y(t)],
[5757,diff(diff(y(t),t),t)+3*diff(y(t),t)+3*y(t) = 0,y(t)],
[5758,diff(diff(y(t),t),t)+diff(y(t),t)+2*y(t) = 0,y(t)],
[5759,diff(diff(y(t),t),t)-7*diff(y(t),t)+12*y(t) = 0,y(t)],
[5760,diff(diff(i(t),t),t)+2*diff(i(t),t)+3*i(t) = 0,i(t)],
[5797,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5798,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5799,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[5800,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[5801,diff(diff(y(x),x),x)-diff(y(x),x) = 0,y(x)],
[5802,diff(diff(y(x),x),x)-diff(y(x),x) = 0,y(x)],
[5803,diff(diff(y(x),x),x)+2*diff(y(x),x) = 0,y(x)],
[5804,diff(diff(y(x),x),x)+2*diff(y(x),x) = 0,y(x)],
[5808,diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5810,diff(diff(y(x),x),x)+2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5811,(x-1)*diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[5812,(x+2)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[5813,diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)-y(x) = 0,y(x)],
[5814,(x^2+1)*diff(diff(y(x),x),x)-6*y(x) = 0,y(x)],
[5815,(x^2+2)*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-y(x) = 0,y(x)],
[5816,(x^2-1)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[5817,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[5818,(x+1)*diff(diff(y(x),x),x)+(x-2)*diff(y(x),x)+y(x) = 0,y(x)],
[5819,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[5820,(x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x) = 0,y(x)],
[5826,diff(diff(y(x),x),x)-4*x*diff(y(x),x)-4*y(x) = 0,y(x)],
[5829,diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[5843,x^2*diff(diff(y(x),x),x)+(5/3*x+x^2)*diff(y(x),x)-1/3*y(x) = 0,y(x)],
[5845,2*x*diff(diff(y(x),x),x)-diff(y(x),x)+2*y(x) = 0,y(x)],
[5849,3*x*diff(diff(y(x),x),x)+(-x+2)*diff(y(x),x)-y(x) = 0,y(x)],
[5851,2*x*diff(diff(y(x),x),x)+(-2*x-3)*diff(y(x),x)+y(x) = 0,y(x)],
[5854,2*x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+(2*x-1)*y(x) = 0,y(x)],
[5855,x*diff(diff(y(x),x),x)+2*diff(y(x),x)-x*y(x) = 0,y(x)],
[5856,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[5857,x*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[5859,x*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)-y(x) = 0,y(x)],
[5861,x*diff(diff(y(x),x),x)+(x-6)*diff(y(x),x)-3*y(x) = 0,y(x)],
[5862,(x^2-x)*diff(diff(y(x),x),x)+3*diff(y(x),x)-2*y(x) = 0,y(x)],
[5865,x^2*diff(diff(y(x),x),x)+(3*x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[5868,4*x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2-25)*y(x) = 0,y(x)],
[5873,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(36*x^2-1/4)*y(x) = 0,y(x)],
[5880,x^2*diff(diff(y(x),x),x)+(x^2-2)*y(x) = 0,y(x)],
[5882,x*diff(diff(y(x),x),x)+3*diff(y(x),x)+x^3*y(x) = 0,y(x)],
[5886,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[5887,x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[5888,16*x^2*diff(diff(y(x),x),x)+32*x*diff(y(x),x)+(x^4-12)*y(x) = 0,y(x)],
[5889,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(16*x^2+3)*y(x) = 0,y(x)],
[5890,2*x*diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[5891,diff(diff(y(x),x),x)-x*diff(y(x),x)-y(x) = 0,y(x)],
[5893,diff(diff(y(x),x),x)-x^2*diff(y(x),x)+x*y(x) = 0,y(x)],
[5894,x*diff(diff(y(x),x),x)+(-x-2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[5896,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[5899,diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[5902,diff(diff(y(x),x),x)+x^2*diff(y(x),x)+2*x*y(x) = 0,y(x)],
[5907,diff(diff(y(t),t),t)+5*diff(y(t),t)+4*y(t) = 0,y(t)],
[5908,diff(diff(y(t),t),t)-4*diff(y(t),t) = 0,y(t)],
[5909,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[5910,diff(diff(y(t),t),t)+9*y(t) = 0,y(t)],
[5911,3*diff(diff(y(t),t),t)-3*diff(y(t),t)-2*y(t) = 0,y(t)],
[5912,2*diff(diff(y(t),t),t)-diff(y(t),t)-2*y(t) = 0,y(t)],
[5914,diff(diff(y(t),t),t)-2*diff(y(t),t)+5*y(t) = 0,y(t)],
[5917,diff(diff(y(t),t),t)+2*diff(y(t),t)+y(t) = 0,y(t)],
[5918,diff(diff(y(t),t),t)-4*diff(y(t),t)+4*y(t) = 0,y(t)],
[5919,diff(diff(y(t),t),t)-6*diff(y(t),t)+9*y(t) = 0,y(t)],
[5920,diff(diff(y(t),t),t)-4*diff(y(t),t)+4*y(t) = 0,y(t)],
[5921,diff(diff(y(t),t),t)-6*diff(y(t),t)+13*y(t) = 0,y(t)],
[5922,2*diff(diff(y(t),t),t)+20*diff(y(t),t)+51*y(t) = 0,y(t)],
[5923,diff(diff(y(t),t),t)-y(t) = 0,y(t)],
[5924,diff(diff(y(t),t),t)-2*diff(y(t),t)+5*y(t) = 0,y(t)],
[5925,diff(diff(y(t),t),t)+2*diff(y(t),t)+y(t) = 0,y(t)],
[5926,diff(diff(y(t),t),t)+8*diff(y(t),t)+20*y(t) = 0,y(t)],
[5930,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[5931,diff(diff(y(t),t),t)+4*y(t) = 0,y(t)],
[5932,diff(diff(y(t),t),t)-5*diff(y(t),t)+6*y(t) = 0,y(t)],
[5933,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[5934,diff(diff(y(t),t),t)+4*diff(y(t),t)+3*y(t) = 0,y(t)],
[5937,diff(diff(y(t),t),t)+9*y(t) = 0,y(t)],
[5938,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[5939,diff(diff(y(t),t),t)+16*y(t) = 0,y(t)],
[5940,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[5941,t*diff(diff(y(t),t),t)-diff(y(t),t) = 0,y(t)],
[5942,2*diff(diff(y(t),t),t)+t*diff(y(t),t)-2*y(t) = 0,y(t)],
[5943,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[5946,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[5947,diff(diff(y(t),t),t)+16*y(t) = 0,y(t)],
[5948,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[5949,diff(diff(y(t),t),t)+y(t) = 0,y(t)],
[5950,diff(diff(y(t),t),t)+2*diff(y(t),t) = 0,y(t)],
[5951,diff(diff(y(t),t),t)-2*diff(y(t),t) = 0,y(t)],
[5952,diff(diff(y(t),t),t)+4*diff(y(t),t)+5*y(t) = 0,y(t)],
[5953,diff(diff(y(t),t),t)+2*diff(y(t),t)+y(t) = 0,y(t)],
[5954,diff(diff(y(t),t),t)+4*diff(y(t),t)+13*y(t) = 0,y(t)],
[5955,diff(diff(y(t),t),t)-7*diff(y(t),t)+6*y(t) = 0,y(t)],
[5956,diff(diff(y(t),t),t)+2*diff(y(t),t)+10*y(t) = 0,y(t)],
[5957,diff(diff(y(t),t),t)+2*diff(y(t),t)+10*y(t) = 0,y(t)],
[6075,x*diff(diff(y(x),x),x)-diff(y(x),x) = 0,y(x)],
[6076,x*diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6088,x^3*diff(diff(y(x),x),x)-x^2*diff(y(x),x) = 0,y(x)],
[6108,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6109,diff(diff(y(x),x),x)-6*diff(y(x),x)+9*y(x) = 0,y(x)],
[6110,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[6111,diff(diff(y(x),x),x)+3*diff(y(x),x)+2*y(x) = 0,y(x)],
[6136,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6137,diff(diff(y(x),x),x)-9*y(x) = 0,y(x)],
[6138,diff(diff(y(x),x),x)+3*x*diff(y(x),x)+3*y(x) = 0,y(x)],
[6139,(4*x^2+1)*diff(diff(y(x),x),x)-8*y(x) = 0,y(x)],
[6140,(-4*x^2+1)*diff(diff(y(x),x),x)+8*y(x) = 0,y(x)],
[6141,(x^2+1)*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[6142,(x^2+1)*diff(diff(y(x),x),x)+10*x*diff(y(x),x)+20*y(x) = 0,y(x)],
[6143,(x^2+4)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-12*y(x) = 0,y(x)],
[6144,(x^2-9)*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-3*y(x) = 0,y(x)],
[6146,(x^2+4)*diff(diff(y(x),x),x)+6*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[6147,(2*x^2+1)*diff(diff(y(x),x),x)-5*x*diff(y(x),x)+3*y(x) = 0,y(x)],
[6149,(-4*x^2+1)*diff(diff(y(x),x),x)+6*x*diff(y(x),x)-4*y(x) = 0,y(x)],
[6150,(2*x^2+1)*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-3*y(x) = 0,y(x)],
[6152,diff(diff(y(x),x),x)+x*diff(y(x),x)+3*y(x) = 0,y(x)],
[6153,diff(diff(y(x),x),x)+2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6155,2*diff(diff(y(x),x),x)+9*x*diff(y(x),x)-36*y(x) = 0,y(x)],
[6156,(x^2+4)*diff(diff(y(x),x),x)+x*diff(y(x),x)-9*y(x) = 0,y(x)],
[6157,(x^2+4)*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-8*y(x) = 0,y(x)],
[6158,(9*x^2+1)*diff(diff(y(x),x),x)-18*y(x) = 0,y(x)],
[6159,(3*x^2+1)*diff(diff(y(x),x),x)+13*x*diff(y(x),x)+7*y(x) = 0,y(x)],
[6160,(2*x^2+1)*diff(diff(y(x),x),x)+11*x*diff(y(x),x)+9*y(x) = 0,y(x)],
[6163,(x^2-2*x+2)*diff(diff(y(x),x),x)+(-4*x+4)*diff(y(x),x)+6*y(x) = 0,y(x)],
[6164,(2*x^2+2*x)*diff(diff(y(x),x),x)+(3*x+3)*diff(y(x),x)-y(x) = 0,y(x)],
[6165,4*x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2-1)*y(x) = 0,y(x)],
[6166,4*x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(-4*x^2-1)*y(x) = 0,y(x)],
[6168,(-2*x^3+2*x^2)*diff(diff(y(x),x),x)+(-7*x^2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[6169,2*x*diff(diff(y(x),x),x)+(-10*x+5)*diff(y(x),x)-5*y(x) = 0,y(x)],
[6171,2*x*diff(diff(y(x),x),x)+(-x+2)*diff(y(x),x)-2*y(x) = 0,y(x)],
[6172,(2*x^2+6*x)*diff(diff(y(x),x),x)+(-3*x-3)*diff(y(x),x)+2*y(x) = 0,y(x)],
[6173,2*x*diff(diff(y(x),x),x)+(-2*x^2+1)*diff(y(x),x)-4*x*y(x) = 0,y(x)],
[6174,(-x^2+4*x)*diff(diff(y(x),x),x)+(-x+2)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6176,2*x*diff(diff(y(x),x),x)+(2*x+1)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6177,2*x*diff(diff(y(x),x),x)+(2*x+1)*diff(y(x),x)-5*y(x) = 0,y(x)],
[6178,2*x^2*diff(diff(y(x),x),x)+(3*x^2-3*x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[6179,2*x^2*diff(diff(y(x),x),x)+(4*x^2-x)*diff(y(x),x)+(6*x-2)*y(x) = 0,y(x)],
[6180,2*x*diff(diff(y(x),x),x)+(-2*x^2-1)*diff(y(x),x)-x*y(x) = 0,y(x)],
[6181,2*x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[6182,2*x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6183,9*x^2*diff(diff(y(x),x),x)+2*y(x) = 0,y(x)],
[6184,2*x^2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[6185,2*x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[6186,2*x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6187,9*x^2*diff(diff(y(x),x),x)+2*y(x) = 0,y(x)],
[6188,2*x^2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[6189,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-12*y(x) = 0,y(x)],
[6190,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-9*y(x) = 0,y(x)],
[6191,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[6192,x^2*diff(diff(y(x),x),x)-5*x*diff(y(x),x)+9*y(x) = 0,y(x)],
[6193,x^2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)+5*y(x) = 0,y(x)],
[6194,4*x^2*diff(diff(y(x),x),x)-8*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[6195,x^2*diff(diff(y(x),x),x)+(-x^2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[6197,x^2*diff(diff(y(x),x),x)+(x^2-3*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6199,(x^2+x)*diff(diff(y(x),x),x)+(1+5*x)*diff(y(x),x)+3*y(x) = 0,y(x)],
[6200,x^2*diff(diff(y(x),x),x)+(-3*x^2-x)*diff(y(x),x)+(1-6*x)*y(x) = 0,y(x)],
[6201,x^2*diff(diff(y(x),x),x)+(x^2-x)*diff(y(x),x)+(1-x)*y(x) = 0,y(x)],
[6202,(x^2-2*x)*diff(diff(y(x),x),x)+(2*x-2)*diff(y(x),x)-2*y(x) = 0,y(x)],
[6203,(x^2-2*x)*diff(diff(y(x),x),x)+(2*x-2)*diff(y(x),x)-2*y(x) = 0,y(x)],
[6204,(4*x^2-32*x+64)*diff(diff(y(x),x),x)+(x^2-12*x+32)*diff(y(x),x)+x*y(x) = 0,y(x)],
[6210,x^2*diff(diff(y(x),x),x)+(3*x^2+3*x)*diff(y(x),x)+(-3*x+1)*y(x) = 0,y(x)],
[6211,x*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)-y(x) = 0,y(x)],
[6212,x^2*diff(diff(y(x),x),x)+(2*x^2-4*x)*diff(y(x),x)+(-6*x+4)*y(x) = 0,y(x)],
[6213,(2*x^3+x^2)*diff(diff(y(x),x),x)+(12*x^2+2*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[6214,x^2*diff(diff(y(x),x),x)+(3*x^2+2*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[6215,x*diff(diff(y(x),x),x)+(-x-3)*diff(y(x),x)+2*y(x) = 0,y(x)],
[6216,(x^2+x)*diff(diff(y(x),x),x)+(x+5)*diff(y(x),x)-4*y(x) = 0,y(x)],
[6217,(x^2+x)*diff(diff(y(x),x),x)+(x+5)*diff(y(x),x)-4*y(x) = 0,y(x)],
[6218,x^2*diff(diff(y(x),x),x)+x^2*diff(y(x),x)-2*y(x) = 0,y(x)],
[6219,(-x^2+x)*diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[6220,(-x^2+x)*diff(diff(y(x),x),x)-3*diff(y(x),x)+2*y(x) = 0,y(x)],
[6221,x*diff(diff(y(x),x),x)+(4+3*x)*diff(y(x),x)+3*y(x) = 0,y(x)],
[6222,x*diff(diff(y(x),x),x)+(-2*x-4)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6223,x*diff(diff(y(x),x),x)+(2*x+3)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6224,(x^2+3*x)*diff(diff(y(x),x),x)-9*diff(y(x),x)-6*y(x) = 0,y(x)],
[6225,(-2*x^2+x)*diff(diff(y(x),x),x)+(-2*x-4)*diff(y(x),x)+8*y(x) = 0,y(x)],
[6226,x*diff(diff(y(x),x),x)+(x^3-1)*diff(y(x),x)+x^2*y(x) = 0,y(x)],
[6227,(4*x^3-x^2)*diff(diff(y(x),x),x)+(5*x^2+x)*diff(y(x),x)+3*y(x) = 0,y(x)],
[6231,4*x^2*diff(diff(y(x),x),x)+(-2*x^2+4*x)*diff(y(x),x)+(-1-3*x)*y(x) = 0,y(x)],
[6232,x^2*diff(diff(y(x),x),x)+(-x^2-6*x)*diff(y(x),x)+10*y(x) = 0,y(x)],
[6233,x*diff(diff(y(x),x),x)+(2*x+3)*diff(y(x),x)+8*y(x) = 0,y(x)],
[6234,(-x^2+x)*diff(diff(y(x),x),x)+(2-2*x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[6235,(-x^2+x)*diff(diff(y(x),x),x)+(2-2*x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[6239,x*diff(diff(y(x),x),x)+(3-x)*diff(y(x),x)-5*y(x) = 0,y(x)],
[6245,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(-6*x^2+3*x-1)*y(x) = 0,y(x)],
[6247,(x^3-4*x^2+4*x)*diff(diff(y(x),x),x)+(-2*x+4)*diff(y(x),x)+2*y(x) = 0,y(x)],
[6248,(x^3-4*x^2+4*x)*diff(diff(y(x),x),x)+(-2*x+4)*diff(y(x),x)+2*y(x) = 0,y(x)],
[6249,2*x*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)+(-x-1)*y(x) = 0,y(x)],
[6250,x*diff(diff(y(x),x),x)+(-x-2)*diff(y(x),x)-y(x) = 0,y(x)],
[6251,x*diff(diff(y(x),x),x)+(-x-2)*diff(y(x),x)-2*y(x) = 0,y(x)],
[6252,x^2*diff(diff(y(x),x),x)+2*x^2*diff(y(x),x)-2*y(x) = 0,y(x)],
[6253,2*x^2*diff(diff(y(x),x),x)+(-2*x^2-7*x)*diff(y(x),x)+(2*x+10)*y(x) = 0,y(x)],
[6254,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3+6*x)*diff(y(x),x)+6*y(x) = 0,y(x)],
[6255,(-x^2+1)*diff(diff(y(x),x),x)-10*x*diff(y(x),x)-18*y(x) = 0,y(x)],
[6256,2*x*diff(diff(y(x),x),x)+(2*x+1)*diff(y(x),x)-3*y(x) = 0,y(x)],
[6257,diff(diff(y(x),x),x)+2*x*diff(y(x),x)-8*y(x) = 0,y(x)],
[6258,(-x^3+x)*diff(diff(y(x),x),x)+(-x^2-7)*diff(y(x),x)+4*x*y(x) = 0,y(x)],
[6259,2*x^2*diff(diff(y(x),x),x)+(-2*x^2-x)*diff(y(x),x)+(4*x+1)*y(x) = 0,y(x)],
[6260,4*x^2*diff(diff(y(x),x),x)+(-2*x^2-4*x)*diff(y(x),x)+(x+3)*y(x) = 0,y(x)],
[6261,x^2*diff(diff(y(x),x),x)+(-x^3-x)*diff(y(x),x)+(-x^2+1)*y(x) = 0,y(x)],
[6262,2*x*diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6263,x^2*diff(diff(y(x),x),x)+(x^3-3*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6265,(x^2+1)*diff(diff(y(x),x),x)-2*y(x) = 0,y(x)],
[6266,2*x^2*diff(diff(y(x),x),x)+(-2*x^2-x)*diff(y(x),x)+(3*x+1)*y(x) = 0,y(x)],
[6268,x*diff(diff(y(x),x),x)+(-x^2+1)*diff(y(x),x)+2*x*y(x) = 0,y(x)],
[6269,4*x^2*diff(diff(y(x),x),x)+2*x^2*diff(y(x),x)+(-x-3)*y(x) = 0,y(x)],
[6270,(-x^3+x)*diff(diff(y(x),x),x)+(-5*x^2+5)*diff(y(x),x)-4*x*y(x) = 0,y(x)],
[6271,x^2*diff(diff(y(x),x),x)+(x^2+3*x)*diff(y(x),x)+(2*x+1)*y(x) = 0,y(x)],
[6273,(-2*x^2+x)*diff(diff(y(x),x),x)+(-2*x-4)*diff(y(x),x)+18*y(x) = 0,y(x)],
[6274,x*diff(diff(y(x),x),x)+(-x+2)*diff(y(x),x)-y(x) = 0,y(x)],
[6284,diff(diff(y(x),x),x)-diff(y(x),x)-2*y(x) = 0,y(x)],
[6285,diff(diff(y(x),x),x)+16*y(x) = 0,y(x)],
[6286,diff(diff(y(x),x),x)-4*diff(y(x),x)+3*y(x) = 0,y(x)],
[6287,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6331,diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[6332,5*diff(diff(y(x),x),x)+2*diff(y(x),x)+4*y(x) = 0,y(x)],
[6333,diff(diff(y(x),x),x)+diff(y(x),x)+4*y(x) = 0,y(x)],
[6334,diff(diff(y(x),x),x)+diff(y(x),x)+4*y(x) = 0,y(x)],
[6338,t*diff(diff(y(t),t),t)+4*diff(y(t),t) = 0,y(t)],
[6339,(t^2+9)*diff(diff(y(t),t),t)+2*t*diff(y(t),t) = 0,y(t)],
[6340,t^2*diff(diff(y(t),t),t)-3*t*diff(y(t),t)+5*y(t) = 0,y(t)],
[6341,t*diff(diff(y(t),t),t)+diff(y(t),t) = 0,y(t)],
[6342,t^2*diff(diff(y(t),t),t)-2*diff(y(t),t) = 0,y(t)],
[6344,t*diff(diff(y(t),t),t)-diff(y(t),t)+4*t^3*y(t) = 0,y(t)],
[6345,diff(diff(y(t),t),t) = 0,y(t)],
[6346,diff(diff(y(t),t),t) = 0,y(t)],
[6347,diff(diff(y(t),t),t) = 0,y(t)],
[6348,diff(diff(y(t),t),t) = 0,y(t)],
[6351,diff(diff(y(x),x),x) = 0,y(x)],
[6374,diff(diff(z(t),t),t)+3*diff(z(t),t)+2*z(t) = 0,z(t)],
[6379,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6380,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6381,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6384,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6385,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6386,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6387,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6388,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6389,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6390,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6391,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6392,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6393,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6427,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6432,diff(diff(y(x),x),x)-1/x*diff(y(x),x)-x^2*y(x) = 0,y(x)],
[6440,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6441,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6442,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6443,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6444,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6445,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6446,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6447,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6448,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6449,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6450,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6452,x^4*diff(diff(y(x),x),x)+x^3*diff(y(x),x)-4*x^2*y(x) = 0,y(x)],
[6453,x^4*diff(diff(y(x),x),x)+x^3*diff(y(x),x)-4*x^2*y(x) = 0,y(x)],
[6454,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[6455,x^3*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+x*y(x) = 0,y(x)],
[6456,x^3*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+x*y(x) = 0,y(x)],
[6467,4*x^2*diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6485,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[6486,2*x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-x*y(x) = 0,y(x)],
[6490,x^2*diff(diff(y(x),x),x)+(3*x^2+2*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[6498,(x^3+3*x^2)*diff(diff(y(x),x),x)+(5*x^2+5*x)*diff(y(x),x)+(-1+4*x)*y(x) = 0,y(x)],
[6499,(-x^4+2*x^2)*diff(diff(y(x),x),x)+(-4*x^3-3*x)*diff(y(x),x)+(-2*x^2+2)*y(x) = 0,y(x)],
[6502,x^2*diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6504,4*x*diff(diff(y(x),x),x)+2*diff(y(x),x)+y(x) = 0,y(x)],
[6506,x*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)+2*y(x) = 0,y(x)],
[6507,(x^2-x)*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+y(x) = 0,y(x)],
[6508,(x^4-2*x^3+x^2)*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+(4+x)*y(x) = 0,y(x)],
[6509,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+5*x^2*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[6516,x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[6518,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[6519,(x^2-x)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[6520,x^2*diff(diff(y(x),x),x)+(x^2+6*x)*diff(y(x),x)+x*y(x) = 0,y(x)],
[6522,x^2*diff(diff(y(x),x),x)-9*x*diff(y(x),x)+25*y(x) = 0,y(x)],
[6523,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+(-x^2-5/4)*y(x) = 0,y(x)],
[6524,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[6525,x*diff(diff(y(x),x),x)+(-x+2)*diff(y(x),x)-y(x) = 0,y(x)],
[6526,2*x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-y(x) = 0,y(x)],
[6527,2*x^2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[6528,x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+4*x^4*y(x) = 0,y(x)],
[6530,(-x^2+1)*diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6536,diff(diff(y(x),x),x)+(-x^2-3)*y(x) = 0,y(x)],
[6539,diff(diff(y(x),x),x)+20*diff(y(x),x)+500*y(x) = 0,y(x)],
[6542,diff(diff(y(x),x),x)+2*x*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[6544,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[6545,4*x^2*diff(diff(y(x),x),x)+(-8*x^2+4*x)*diff(y(x),x)+(4*x^2-4*x-1)*y(x) = 0,y(x)],
[6546,x*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[6551,diff(diff(y(x),x),x) = 0,y(x)],
[6552,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6553,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6554,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6556,diff(diff(y(x),x),x)+2*diff(y(x),x)-24*y(x) = 0,y(x)],
[6557,diff(diff(y(t),t),t)+3*diff(y(t),t)-4*y(t) = 0,y(t)],
[6558,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6560,x*diff(diff(y(x),x),x)+(-2*x-1)*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[6634,diff(diff(y(x),x),x) = 0,y(x)],
[6640,diff(diff(y(x),x),x) = 0,y(x)],
[6642,diff(diff(y(x),x),x) = 0,y(x)],
[6645,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6648,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6651,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6654,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6657,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6658,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6659,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6660,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6661,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6662,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6663,diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[6664,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6665,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6666,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6667,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6668,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6669,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6670,diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[6671,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6672,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6673,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6674,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6675,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6676,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6677,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[6699,diff(diff(y(x),x),x)-2*y(x)/x^2 = 0,y(x)],
[6704,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+3*y(x) = 0,y(x)],
[6708,x*diff(diff(y(x),x),x)-diff(y(x),x)+4*x^3*y(x) = 0,y(x)],
[6709,x*diff(diff(y(x),x),x)-diff(y(x),x)+4*x^3*y(x) = 0,y(x)],
[6712,diff(diff(y(x),x),x)-x^2*diff(y(x),x)+x*y(x) = 0,y(x)],
[6715,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-1)*y(x) = 0,y(x)],
[6717,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-3)*y(x) = 0,y(x)],
[6719,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(2*x^2+2)*y(x) = 0,y(x)],
[6720,4*x^2*diff(diff(y(x),x),x)+4*x^5*diff(y(x),x)+(x^8+6*x^4+4)*y(x) = 0,y(x)],
[6722,x*diff(diff(y(x),x),x)+2*diff(y(x),x)-x*y(x) = 0,y(x)],
[6723,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[6727,-3*diff(diff(y(x),x),x)+5*diff(y(x),x)-2*y(x) = 0,y(x)],
[6728,x^2*diff(diff(y(x),x),x)+(-x^2-6*x)*diff(y(x),x)+10*y(x) = 0,y(x)],
[6731,x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[6735,(x^2-1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6736,(x^2-1)*diff(diff(y(x),x),x)-6*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[6737,(x^2+3)*diff(diff(y(x),x),x)-7*x*diff(y(x),x)+16*y(x) = 0,y(x)],
[6738,(x^2-1)*diff(diff(y(x),x),x)+8*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[6739,3*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[6740,5*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+10*y(x) = 0,y(x)],
[6741,diff(diff(y(x),x),x)-x^2*diff(y(x),x)-3*x*y(x) = 0,y(x)],
[6742,(x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[6743,diff(diff(y(x),x),x)+x*diff(y(x),x)-2*y(x) = 0,y(x)],
[6744,(x^2-6*x+10)*diff(diff(y(x),x),x)+(-4*x+12)*diff(y(x),x)+6*y(x) = 0,y(x)],
[6745,(x^2+6*x)*diff(diff(y(x),x),x)+(3*x+9)*diff(y(x),x)-3*y(x) = 0,y(x)],
[6746,t*diff(diff(y(t),t),t)+(t^2-1)*diff(y(t),t)+t^2*y(t) = 0,y(t)],
[6747,t^2*diff(diff(y(t),t),t)+(-t^2-2*t)*diff(y(t),t)+(t+2)*y(t) = 0,y(t)],
[6748,t*diff(diff(y(t),t),t)+(-t-1)*diff(y(t),t)+y(t) = 0,y(t)],
[6749,(-t+1)*diff(diff(y(t),t),t)+t*diff(y(t),t)-y(t) = 0,y(t)],
[6750,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[6751,t*diff(diff(y(t),t),t)+(-t-1)*diff(y(t),t)+y(t) = 0,y(t)],
[6752,(-t+1)*diff(diff(y(t),t),t)+t*diff(y(t),t)-y(t) = 0,y(t)],
[6753,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6754,(x^2+1)*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[6755,(1-x)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[6756,2*diff(diff(y(x),x),x)+x*diff(y(x),x)+3*y(x) = 0,y(x)],
[6757,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6758,(1-x)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[6759,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6760,(-x^2+4)*diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6761,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(-16*x^2+3)*y(x) = 0,y(x)],
[6762,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[6763,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[6764,(x^2-2*x)*diff(diff(y(x),x),x)+(-x^2+2)*diff(y(x),x)+(2*x-2)*y(x) = 0,y(x)],
[6765,4*x^2*diff(diff(y(x),x),x)+(-8*x^2+4*x)*diff(y(x),x)+(4*x^2-4*x-1)*y(x) = 0,y(x)],
[6766,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[6767,(2*x+1)*diff(diff(y(x),x),x)-2*diff(y(x),x)+(-2*x-3)*y(x) = 0,y(x)],
[6768,x*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[6769,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[6770,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(-16*x^2+3)*y(x) = 0,y(x)],
[6771,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2+3)*y(x) = 0,y(x)],
[6772,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(-x^2+2)*y(x) = 0,y(x)],
[6773,x^2*diff(diff(y(x),x),x)+(-2*x^2-2*x)*diff(y(x),x)+(x^2+2*x+2)*y(x) = 0,y(x)],
[6774,x^2*diff(diff(y(x),x),x)+(-2*x^2-4*x)*diff(y(x),x)+(x^2+4*x+6)*y(x) = 0,y(x)],
[6775,x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(x^2+6)*y(x) = 0,y(x)],
[6776,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[6777,4*x^2*diff(diff(y(x),x),x)+(-4*x^2-4*x)*diff(y(x),x)+(2*x+3)*y(x) = 0,y(x)],
[6778,(3*x-1)*diff(diff(y(x),x),x)+(-3*x-2)*diff(y(x),x)+(-6*x+8)*y(x) = 0,y(x)],
[6779,(x+2)*diff(diff(y(x),x),x)+x*diff(y(x),x)+3*y(x) = 0,y(x)],
[6780,(-x^3+x^2)*diff(diff(y(x),x),x)+(x^2+4*x)*diff(y(x),x)+(-x+2)*y(x) = 0,y(x)],
[6781,(x^3+x^2)*diff(diff(y(x),x),x)+(2*x^2+x)*diff(y(x),x)+(-6*x-4)*y(x) = 0,y(x)],
[6782,(2*x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3+4*x)*diff(y(x),x)+(-2*x^2+2)*y(x) = 0,y(x)],
[6783,(x^4+2*x^2)*diff(diff(y(x),x),x)+(2*x^3+10*x)*diff(y(x),x)+(-2*x^2+6)*y(x) = 0,y(x)],
[6784,(x^2+1)*diff(diff(y(x),x),x)+6*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[6785,(x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[6786,(x^2+1)*diff(diff(y(x),x),x)-8*x*diff(y(x),x)+20*y(x) = 0,y(x)],
[6787,(-x^2+1)*diff(diff(y(x),x),x)-8*x*diff(y(x),x)-12*y(x) = 0,y(x)],
[6788,(2*x^2+1)*diff(diff(y(x),x),x)+7*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6789,(-x^2+1)*diff(diff(y(x),x),x)-5*x*diff(y(x),x)-4*y(x) = 0,y(x)],
[6790,(x^2+1)*diff(diff(y(x),x),x)-10*x*diff(y(x),x)+28*y(x) = 0,y(x)],
[6791,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6792,(2*x^2+1)*diff(diff(y(x),x),x)-9*x*diff(y(x),x)-6*y(x) = 0,y(x)],
[6793,(2*x^2-8*x+11)*diff(diff(y(x),x),x)+(-16*x+32)*diff(y(x),x)+36*y(x) = 0,y(x)],
[6794,diff(diff(y(x),x),x)+(x-3)*diff(y(x),x)+3*y(x) = 0,y(x)],
[6795,(x^2-8*x+14)*diff(diff(y(x),x),x)+(-8*x+32)*diff(y(x),x)+20*y(x) = 0,y(x)],
[6796,(2*x^2+4*x+5)*diff(diff(y(x),x),x)+(-20*x-20)*diff(y(x),x)+60*y(x) = 0,y(x)],
[6797,(x^3+1)*diff(diff(y(x),x),x)+7*x^2*diff(y(x),x)+9*x*y(x) = 0,y(x)],
[6799,diff(diff(y(x),x),x)+x^6*diff(y(x),x)+7*x^5*y(x) = 0,y(x)],
[6801,diff(diff(y(x),x),x)+x^5*diff(y(x),x)+6*x^4*y(x) = 0,y(x)],
[6802,(3*x+1)*diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6803,(3*x^2+x+1)*diff(diff(y(x),x),x)+(2+15*x)*diff(y(x),x)+12*y(x) = 0,y(x)],
[6804,(x+2)*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)+3*y(x) = 0,y(x)],
[6805,(4+x)*diff(diff(y(x),x),x)+(x+2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[6806,(2*x^2+3*x)*diff(diff(y(x),x),x)+(10*x+10)*diff(y(x),x)+8*y(x) = 0,y(x)],
[6807,x^2*diff(diff(y(x),x),x)+(-6+7*x)*diff(y(x),x)+8*y(x) = 0,y(x)],
[6808,(2*x^2+x+1)*diff(diff(y(x),x),x)+(1+7*x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[6809,(x+3)*diff(diff(y(x),x),x)+(2*x+1)*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[6810,diff(diff(y(x),x),x)+3*x*diff(y(x),x)+(2*x^2+4)*y(x) = 0,y(x)],
[6811,(2+4*x)*diff(diff(y(x),x),x)-4*diff(y(x),x)+(-4*x-6)*y(x) = 0,y(x)],
[6812,diff(diff(y(x),x),x)-3*x*diff(y(x),x)+(2*x^2+5)*y(x) = 0,y(x)],
[6813,2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)+(2*x^2+4)*y(x) = 0,y(x)],
[6814,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[6815,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[6817,3*x^2*diff(diff(y(x),x),x)+(-4*x^3+2*x^2+2*x)*diff(y(x),x)+(-8*x^2+2*x)*y(x) = 0,y(x)],
[6818,(12*x^3+12*x^2)*diff(diff(y(x),x),x)+(3*x^3+35*x^2+11*x)*diff(y(x),x)+(5*x^2+10*x-1)*y(x) = 0,y(x)],
[6819,(10*x^4+x^3+5*x^2)*diff(diff(y(x),x),x)+(48*x^3+3*x^2+4*x)*diff(y(x),x)+(36*x^2+x)*y(x) = 0,y(x)],
[6820,(18*x^3+18*x^2)*diff(diff(y(x),x),x)+(3*x^3+33*x^2+15*x)*diff(y(x),x)+(5*x^2+2*x-1)*y(x) = 0,y(x)],
[6821,2*x^2*diff(diff(y(x),x),x)+(2*x^2+3*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[6822,2*x^2*diff(diff(y(x),x),x)+(x^2+5*x)*diff(y(x),x)+(3*x-2)*y(x) = 0,y(x)],
[6823,3*x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)-y(x) = 0,y(x)],
[6824,2*x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+(1-2*x)*y(x) = 0,y(x)],
[6825,3*x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(-3*x-1)*y(x) = 0,y(x)],
[6826,(2*x^3+6*x^2)*diff(diff(y(x),x),x)+(5*x^2+x)*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[6827,(x^3+4*x^2)*diff(diff(y(x),x),x)+(3*x^2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[6828,2*x^2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[6829,6*x^2*diff(diff(y(x),x),x)+(-x^2+10*x)*diff(y(x),x)+(-2-x)*y(x) = 0,y(x)],
[6830,(4*x^3+3*x^2)*diff(diff(y(x),x),x)+(4*x^2+11*x)*diff(y(x),x)+(-4*x-3)*y(x) = 0,y(x)],
[6831,(6*x^3+4*x^2)*diff(diff(y(x),x),x)+(11*x^2+4*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[6832,(x^3+2*x^2)*diff(diff(y(x),x),x)+(-5*x^2+5*x)*diff(y(x),x)+(8*x-2)*y(x) = 0,y(x)],
[6833,(-8*x^4+8*x^2)*diff(diff(y(x),x),x)+(-26*x^3+2*x)*diff(y(x),x)+(-9*x^2+1)*y(x) = 0,y(x)],
[6834,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3-4*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6835,(x^3+3*x)*diff(diff(y(x),x),x)+(-x^2+2)*diff(y(x),x)-8*x*y(x) = 0,y(x)],
[6836,(-4*x^4+4*x^2)*diff(diff(y(x),x),x)+(-19*x^3+7*x)*diff(y(x),x)+(-14*x^2-1)*y(x) = 0,y(x)],
[6837,(-3*x^4+6*x^2)*diff(diff(y(x),x),x)+(-11*x^3+x)*diff(y(x),x)+(-5*x^2+1)*y(x) = 0,y(x)],
[6838,(2*x^4+4*x^2)*diff(diff(y(x),x),x)+(7*x^3-12*x)*diff(y(x),x)+(3*x^2+7)*y(x) = 0,y(x)],
[6839,(2*x^4+4*x^2)*diff(diff(y(x),x),x)+(7*x^3+4*x)*diff(y(x),x)+(3*x^2-1)*y(x) = 0,y(x)],
[6840,(4*x^4+2*x^2)*diff(diff(y(x),x),x)+(30*x^3+5*x)*diff(y(x),x)+(40*x^2-2)*y(x) = 0,y(x)],
[6841,(x^3+x)*diff(diff(y(x),x),x)+(7*x^2+4)*diff(y(x),x)+8*x*y(x) = 0,y(x)],
[6842,(2*x^4+2*x^2)*diff(diff(y(x),x),x)+(8*x^3+3*x)*diff(y(x),x)+(4*x^2-3)*y(x) = 0,y(x)],
[6843,9*x^2*diff(diff(y(x),x),x)+(3*x^3+9*x)*diff(y(x),x)+(5*x^2-1)*y(x) = 0,y(x)],
[6844,6*x^2*diff(diff(y(x),x),x)+(6*x^3+x)*diff(y(x),x)+(9*x^2+1)*y(x) = 0,y(x)],
[6845,(9*x^4+9*x^2)*diff(diff(y(x),x),x)+(39*x^3+9*x)*diff(y(x),x)+(25*x^2-1)*y(x) = 0,y(x)],
[6846,(4*x^4+4*x^2)*diff(diff(y(x),x),x)+(24*x^3+4*x)*diff(y(x),x)+(25*x^2-1)*y(x) = 0,y(x)],
[6847,(16*x^4+8*x^2)*diff(diff(y(x),x),x)+(68*x^3+10*x)*diff(y(x),x)+(30*x^2-1)*y(x) = 0,y(x)],
[6848,(2*x^3+2*x^2)*diff(diff(y(x),x),x)+(3*x^2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[6849,(12*x^4+6*x^2)*diff(diff(y(x),x),x)+(50*x^3+x)*diff(y(x),x)+(30*x^2+1)*y(x) = 0,y(x)],
[6850,(-84*x^3+28*x^2)*diff(diff(y(x),x),x)+(-63*x^2-35*x)*diff(y(x),x)+(63*x+14)*y(x) = 0,y(x)],
[6851,(-8*x^4+16*x^2)*diff(diff(y(x),x),x)+(-42*x^3+20*x)*diff(y(x),x)+(-35*x^2-2)*y(x) = 0,y(x)],
[6852,(4*x^4+12*x^3+4*x^2)*diff(diff(y(x),x),x)+(12*x^3+12*x^2-4*x)*diff(y(x),x)+(3*x^2-3*x+3)*y(x) = 0,y(x)],
[6853,(3*x^4+6*x^3+3*x^2)*diff(diff(y(x),x),x)+(11*x^3+10*x^2-x)*diff(y(x),x)+(5*x^2+1)*y(x) = 0,y(x)],
[6854,(4*x^4+8*x^3+12*x^2)*diff(diff(y(x),x),x)+(15*x^3+14*x^2-3*x)*diff(y(x),x)+(7*x^2+3)*y(x) = 0,y(x)],
[6855,(x^4-2*x^3+x^2)*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+(4+x)*y(x) = 0,y(x)],
[6856,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+5*x^2*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[6857,(-x^4+2*x^2)*diff(diff(y(x),x),x)+(-4*x^3-2*x)*diff(y(x),x)+(-2*x^2+2)*y(x) = 0,y(x)],
[6858,x^2*diff(diff(y(x),x),x)+(x^2-5*x)*diff(y(x),x)+(9-4*x)*y(x) = 0,y(x)],
[6859,(4*x^4+4*x^3+4*x^2)*diff(diff(y(x),x),x)+(12*x^3+12*x^2)*diff(y(x),x)+(3*x^2+3*x+1)*y(x) = 0,y(x)],
[6860,(x^4+x^3+x^2)*diff(diff(y(x),x),x)+(2*x^3+4*x^2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[6861,9*x^2*diff(diff(y(x),x),x)+(-6*x^3+9*x^2+15*x)*diff(y(x),x)+(-14*x^2+12*x+1)*y(x) = 0,y(x)],
[6862,(2*x^3+x^2)*diff(diff(y(x),x),x)+(3*x^3+14*x^2+5*x)*diff(y(x),x)+(12*x^2+18*x+4)*y(x) = 0,y(x)],
[6863,16*x^2*diff(diff(y(x),x),x)+(8*x^3+4*x^2+24*x)*diff(y(x),x)+(18*x^2+5*x+1)*y(x) = 0,y(x)],
[6864,(9*x^3+9*x^2)*diff(diff(y(x),x),x)+(-3*x^3+33*x^2+15*x)*diff(y(x),x)+(-7*x^2+16*x+1)*y(x) = 0,y(x)],
[6865,(-72*x^3+36*x^2)*diff(diff(y(x),x),x)+(-216*x^2+24*x)*diff(y(x),x)+(1-70*x)*y(x) = 0,y(x)],
[6866,(x^3+x^2)*diff(diff(y(x),x),x)+(x^2-3*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6867,(-2*x^3+x^2)*diff(diff(y(x),x),x)+(4*x^2-5*x)*diff(y(x),x)+(9-4*x)*y(x) = 0,y(x)],
[6868,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+(1-x)*y(x) = 0,y(x)],
[6869,(2*x^3+2*x^2)*diff(diff(y(x),x),x)+(x^2-6*x)*diff(y(x),x)+(8-x)*y(x) = 0,y(x)],
[6870,(2*x^3+x^2)*diff(diff(y(x),x),x)+(9*x^2+5*x)*diff(y(x),x)+(4+3*x)*y(x) = 0,y(x)],
[6871,(-2*x^3+x^2)*diff(diff(y(x),x),x)+(-4*x^2-5*x)*diff(y(x),x)+(9+4*x)*y(x) = 0,y(x)],
[6872,(-x^3+x^2)*diff(diff(y(x),x),x)+(x^2+7*x)*diff(y(x),x)+(9-x)*y(x) = 0,y(x)],
[6873,x^2*diff(diff(y(x),x),x)+(x^3-x)*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[6874,(x^4+x^2)*diff(diff(y(x),x),x)+(3*x^3-3*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6875,4*x^2*diff(diff(y(x),x),x)+2*x^3*diff(y(x),x)+(3*x^2+1)*y(x) = 0,y(x)],
[6876,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3-x)*diff(y(x),x)+y(x) = 0,y(x)],
[6877,(2*x^4+4*x^2)*diff(diff(y(x),x),x)+7*x^3*diff(y(x),x)+(3*x^2+1)*y(x) = 0,y(x)],
[6878,(x^4+x^2)*diff(diff(y(x),x),x)+(4*x^3-x)*diff(y(x),x)+(2*x^2+1)*y(x) = 0,y(x)],
[6879,(4*x^4+16*x^2)*diff(diff(y(x),x),x)+(9*x^3+24*x)*diff(y(x),x)+(-9*x^2+1)*y(x) = 0,y(x)],
[6880,(3*x^4+9*x^2)*diff(diff(y(x),x),x)+(11*x^3+3*x)*diff(y(x),x)+(5*x^2+1)*y(x) = 0,y(x)],
[6881,9*x^2*diff(diff(y(x),x),x)+(6*x^3-21*x)*diff(y(x),x)+(2*x^2+25)*y(x) = 0,y(x)],
[6882,x^2*diff(diff(y(x),x),x)+(x^3-x)*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[6883,(-2*x^3+x^2)*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+(4*x+1)*y(x) = 0,y(x)],
[6884,(x^2+x)*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)+y(x) = 0,y(x)],
[6885,(-x^3+x^2)*diff(diff(y(x),x),x)+(5*x^2-3*x)*diff(y(x),x)+(4-5*x)*y(x) = 0,y(x)],
[6886,(x^4+x^2)*diff(diff(y(x),x),x)+(-9*x^3-x)*diff(y(x),x)+(25*x^2+1)*y(x) = 0,y(x)],
[6887,9*x^2*diff(diff(y(x),x),x)+(-3*x^3+3*x)*diff(y(x),x)+(7*x^2+1)*y(x) = 0,y(x)],
[6888,(x^3+x)*diff(diff(y(x),x),x)+(-x^2+1)*diff(y(x),x)-8*x*y(x) = 0,y(x)],
[6889,4*x^2*diff(diff(y(x),x),x)+(-2*x^3+8*x)*diff(y(x),x)+(7*x^2+1)*y(x) = 0,y(x)],
[6890,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+8*x^2*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[6891,(9*x^3+27*x^2)*diff(diff(y(x),x),x)+(21*x^2+9*x)*diff(y(x),x)+(3+4*x)*y(x) = 0,y(x)],
[6892,(-x^4+2*x^2)*diff(diff(y(x),x),x)+(-3*x^3-2*x)*diff(y(x),x)+(-x^2+2)*y(x) = 0,y(x)],
[6893,(16*x^4+16*x^2)*diff(diff(y(x),x),x)+(72*x^3+8*x)*diff(y(x),x)+(49*x^2+1)*y(x) = 0,y(x)],
[6894,(3*x^3+4*x^2)*diff(diff(y(x),x),x)+(3*x^2-4*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6895,(4*x^4+12*x^3+4*x^2)*diff(diff(y(x),x),x)+(16*x^3+24*x^2)*diff(y(x),x)+(9*x^2+3*x+1)*y(x) = 0,y(x)],
[6896,(x^4-2*x^3+x^2)*diff(diff(y(x),x),x)+(3*x^3-2*x^2-x)*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[6897,(9*x^4+9*x^3+9*x^2)*diff(diff(y(x),x),x)+(39*x^3+21*x^2+3*x)*diff(y(x),x)+(25*x^2+4*x+1)*y(x) = 0,y(x)],
[6898,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+(7*x^2-4*x)*diff(y(x),x)+(3*x-5)*y(x) = 0,y(x)],
[6899,(-2*x^3+x^2)*diff(diff(y(x),x),x)+(-9*x^2+8*x)*diff(y(x),x)+(6-3*x)*y(x) = 0,y(x)],
[6900,(x^4+x^2)*diff(diff(y(x),x),x)+(10*x^3+3*x)*diff(y(x),x)+(14*x^2-15)*y(x) = 0,y(x)],
[6901,(-2*x^4+x^2)*diff(diff(y(x),x),x)+(-13*x^3+7*x)*diff(y(x),x)-14*x^2*y(x) = 0,y(x)],
[6902,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+(8*x^2+4*x)*diff(y(x),x)+(-3*x-1)*y(x) = 0,y(x)],
[6903,(6*x^3+4*x^2)*diff(diff(y(x),x),x)+(21*x^2+4*x)*diff(y(x),x)+(9*x-1)*y(x) = 0,y(x)],
[6904,x^2*diff(diff(y(x),x),x)+(x^2+2*x)*diff(y(x),x)+(3*x-2)*y(x) = 0,y(x)],
[6905,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+(32*x^2+12*x)*diff(y(x),x)+(49*x-5)*y(x) = 0,y(x)],
[6906,(x^3+x^2)*diff(diff(y(x),x),x)+(-10*x^2-3*x)*diff(y(x),x)+30*x*y(x) = 0,y(x)],
[6907,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(-3*x-9)*y(x) = 0,y(x)],
[6908,(2*x^3+x^2)*diff(diff(y(x),x),x)+(13*x^2+9*x)*diff(y(x),x)+(7+5*x)*y(x) = 0,y(x)],
[6909,(8*x^3+4*x^2)*diff(diff(y(x),x),x)+(2*x^2-8*x)*diff(y(x),x)+(-5*x-7)*y(x) = 0,y(x)],
[6910,(3*x^3+9*x^2)*diff(diff(y(x),x),x)+(-x^2-15*x)*diff(y(x),x)-20*y(x) = 0,y(x)],
[6911,(x^3+x^2)*diff(diff(y(x),x),x)+(-10*x^2+x)*diff(y(x),x)+(10*x-9)*y(x) = 0,y(x)],
[6912,(x^3+x^2)*diff(diff(y(x),x),x)+3*x^2*diff(y(x),x)+(x-6)*y(x) = 0,y(x)],
[6913,(2*x^3+x^2)*diff(diff(y(x),x),x)+(-28*x^2-6*x)*diff(y(x),x)+(6+100*x)*y(x) = 0,y(x)],
[6914,(x^3+x^2)*diff(diff(y(x),x),x)+(-11*x^2-6*x)*diff(y(x),x)+(6+32*x)*y(x) = 0,y(x)],
[6915,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+(16*x^2+4*x)*diff(y(x),x)+(-27*x-49)*y(x) = 0,y(x)],
[6916,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3-7*x)*diff(y(x),x)+12*y(x) = 0,y(x)],
[6917,x^2*diff(diff(y(x),x),x)+(x^3-7*x)*diff(y(x),x)+12*y(x) = 0,y(x)],
[6918,x^2*diff(diff(y(x),x),x)+(2*x^3+x)*diff(y(x),x)+(10*x^2-1)*y(x) = 0,y(x)],
[6919,x^2*diff(diff(y(x),x),x)+(-2*x^3+x)*diff(y(x),x)+(-8*x^2-4)*y(x) = 0,y(x)],
[6920,x^2*diff(diff(y(x),x),x)+(-3*x^3+x)*diff(y(x),x)+(12*x^2-4)*y(x) = 0,y(x)],
[6921,(x^4+x^2)*diff(diff(y(x),x),x)+(11*x^3+5*x)*diff(y(x),x)+24*x^2*y(x) = 0,y(x)],
[6922,(4*x^4+4*x^2)*diff(diff(y(x),x),x)+8*x*diff(y(x),x)+(x^2-35)*y(x) = 0,y(x)],
[6923,(x^4+x^2)*diff(diff(y(x),x),x)+(x^3-5*x)*diff(y(x),x)+(-25*x^2-7)*y(x) = 0,y(x)],
[6924,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3+5*x)*diff(y(x),x)-21*y(x) = 0,y(x)],
[6925,(4*x^4+4*x^2)*diff(diff(y(x),x),x)+(4*x^3+8*x)*diff(y(x),x)+(-x^2-15)*y(x) = 0,y(x)],
[6926,diff(diff(y(t),t),t)+(-2/(t^2+2*t-1)*t-2/(t^2+2*t-1))*diff(y(t),t)+2/(t^2+2*t-1)*y(t) = 0,y(t)],
[6927,diff(diff(y(t),t),t)-4*t*diff(y(t),t)+(4*t^2-2)*y(t) = 0,y(t)],
[6928,(-t^2+1)*diff(diff(y(t),t),t)-2*t*diff(y(t),t)+2*y(t) = 0,y(t)],
[6929,(t^2+1)*diff(diff(y(t),t),t)-2*t*diff(y(t),t)+2*y(t) = 0,y(t)],
[6930,(-t^2+1)*diff(diff(y(t),t),t)-2*t*diff(y(t),t)+6*y(t) = 0,y(t)],
[6931,(2*t+1)*diff(diff(y(t),t),t)+(-4*t-4)*diff(y(t),t)+4*y(t) = 0,y(t)],
[6932,t^2*diff(diff(y(t),t),t)+t*diff(y(t),t)+(t^2-1/4)*y(t) = 0,y(t)],
[6933,diff(diff(y(t),t),t)-2*t/(t^2+1)*diff(y(t),t)+2/(t^2+1)*y(t) = 0,y(t)],
[6935,2*t*diff(diff(y(t),t),t)+(1-2*t)*diff(y(t),t)-y(t) = 0,y(t)],
[6936,2*t*diff(diff(y(t),t),t)+(t+1)*diff(y(t),t)-2*y(t) = 0,y(t)],
[6937,2*t^2*diff(diff(y(t),t),t)-t*diff(y(t),t)+(t+1)*y(t) = 0,y(t)],
[6938,2*t^2*diff(diff(y(t),t),t)+(t^2-t)*diff(y(t),t)+y(t) = 0,y(t)],
[6939,t^2*diff(diff(y(t),t),t)+(-t^2+t)*diff(y(t),t)-y(t) = 0,y(t)],
[6940,t*diff(diff(y(t),t),t)+(-t^2-2)*diff(y(t),t)+t*y(t) = 0,y(t)],
[6941,t^2*diff(diff(y(t),t),t)+(t^2+t)*diff(y(t),t)-y(t) = 0,y(t)],
[6942,t*diff(diff(y(t),t),t)+(-4-t)*diff(y(t),t)+2*y(t) = 0,y(t)],
[6943,t^2*diff(diff(y(t),t),t)+(t^2-3*t)*diff(y(t),t)+3*y(t) = 0,y(t)],
[6944,t*diff(diff(y(t),t),t)+t*diff(y(t),t)+2*y(t) = 0,y(t)],
[6945,t*diff(diff(y(t),t),t)+(-t^2+1)*diff(y(t),t)+4*t*y(t) = 0,y(t)],
[6946,t^2*diff(diff(y(t),t),t)+(-t^2-t)*diff(y(t),t)+y(t) = 0,y(t)],
[6947,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+6)*y(x) = 0,y(x)],
[6949,4*z*diff(diff(y(z),z),z)+(-2*z+2)*diff(y(z),z)-y(z) = 0,y(z)],
[6950,diff(diff(f(z),z),z)+(2*z-2)*diff(f(z),z)+4*f(z) = 0,f(z)],
[6951,z*diff(diff(y(z),z),z)-2*diff(y(z),z)+z*y(z) = 0,y(z)],
[6952,z*diff(diff(y(z),z),z)+(2*z-3)*diff(y(z),z)+4/z*y(z) = 0,y(z)],
[6953,diff(diff(y(x),x),x)+2*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[6954,diff(diff(y(x),x),x)+x*diff(y(x),x)+3*y(x) = 0,y(x)],
[6955,diff(diff(y(x),x),x)-x^2*diff(y(x),x)-3*x*y(x) = 0,y(x)],
[6956,(-4*x^2+1)*diff(diff(y(x),x),x)-20*x*diff(y(x),x)-16*y(x) = 0,y(x)],
[6957,(x^2-1)*diff(diff(y(x),x),x)-6*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[6958,diff(diff(y(x),x),x)+x*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[6959,(2*x^2+1)*diff(diff(y(x),x),x)+7*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6960,4*diff(diff(y(x),x),x)+x*diff(y(x),x)+4*y(x) = 0,y(x)],
[6961,diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[6962,4*x*diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[6963,6*x^2*diff(diff(y(x),x),x)+(18*x^2+x)*diff(y(x),x)+(1+12*x)*y(x) = 0,y(x)],
[6964,3*x^2*diff(diff(y(x),x),x)+(-x^2-8*x)*diff(y(x),x)+6*y(x) = 0,y(x)],
[6965,2*x^2*diff(diff(y(x),x),x)+(-2*x^2-x)*diff(y(x),x)+(8*x-2)*y(x) = 0,y(x)],
[6966,4*x^2*diff(diff(y(x),x),x)-4*x^2*diff(y(x),x)+(2*x+1)*y(x) = 0,y(x)],
[6967,x^2*diff(diff(y(x),x),x)+(-2*x^2+3*x)*diff(y(x),x)+(1-2*x)*y(x) = 0,y(x)],
[6968,x^2*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+(4-x)*y(x) = 0,y(x)],
[6969,x^2*diff(diff(y(x),x),x)+(-x^2+3*x)*diff(y(x),x)+y(x) = 0,y(x)],
[6970,x^2*diff(diff(y(x),x),x)+(-2*x*5^(1/2)+x)*diff(y(x),x)+(19/4-3*x^2)*y(x) = 0,y(x)],
[6971,x^2*diff(diff(y(x),x),x)+(x^2-3*x)*diff(y(x),x)+(4-x)*y(x) = 0,y(x)],
[6972,x^2*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+(-2-x)*y(x) = 0,y(x)],
[6973,x^2*diff(diff(y(x),x),x)+2*x^2*diff(y(x),x)+(x-3/4)*y(x) = 0,y(x)],
[6974,(x^3+x^2)*diff(diff(y(x),x),x)+x^2*diff(y(x),x)-2*y(x) = 0,y(x)],
[6975,x^2*diff(diff(y(x),x),x)+(x^3+6*x)*diff(y(x),x)+6*y(x) = 0,y(x)],
[6976,x^2*diff(diff(y(x),x),x)+(-x^2+x)*diff(y(x),x)-y(x) = 0,y(x)],
[6977,x^2*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6978,x^2*diff(diff(y(x),x),x)-x^2*diff(y(x),x)-2*y(x) = 0,y(x)],
[6979,x^2*diff(diff(y(x),x),x)-x^2*diff(y(x),x)+(-3*x-2)*y(x) = 0,y(x)],
[6980,x^2*diff(diff(y(x),x),x)+(-x^2+5*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[6981,4*x^2*diff(diff(y(x),x),x)+(-4*x^2+4*x)*diff(y(x),x)+(2*x-9)*y(x) = 0,y(x)],
[6982,x^2*diff(diff(y(x),x),x)+(2*x^2+4*x)*diff(y(x),x)+(2*x+2)*y(x) = 0,y(x)],
[6983,x^2*diff(diff(y(x),x),x)+(x^2-x)*diff(y(x),x)+(1-x)*y(x) = 0,y(x)],
[6984,4*x^2*diff(diff(y(x),x),x)+(8*x^2+4*x)*diff(y(x),x)+(-1+4*x)*y(x) = 0,y(x)],
[6985,x^2*diff(diff(y(x),x),x)+(x^2+4*x)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[6986,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-9/4)*y(x) = 0,y(x)],
[6987,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[6988,2*x*diff(diff(y(x),x),x)+(-10*x+5)*diff(y(x),x)-5*y(x) = 0,y(x)],
[6989,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[6991,x^4*diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[6992,x^2*diff(diff(y(x),x),x)+(2*x^2+x)*diff(y(x),x)-4*y(x) = 0,y(x)],
[6993,(4*x^3-14*x^2-2*x)*diff(diff(y(x),x),x)+(-6*x^2+7*x-1)*diff(y(x),x)+(6*x-1)*y(x) = 0,y(x)],
[6994,x^2*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[6995,x^2*diff(diff(y(x),x),x)-x^2*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[6996,(-4*x^3+x^2)*diff(diff(y(x),x),x)-1/2*x*diff(y(x),x)-3/4*x*y(x) = 0,y(x)],
[6997,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(x-9)*y(x) = 0,y(x)],
[6998,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(3*x-1)*y(x) = 0,y(x)],
[6999,x^2*diff(diff(y(x),x),x)+(-x^2-4*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[7000,2*x^2*diff(diff(y(x),x),x)+(-3*x-2)*diff(y(x),x)+(2-1/x)*y(x) = 0,y(x)],
[7001,(-x^2+x)*diff(diff(y(x),x),x)+(3/2-2*x)*diff(y(x),x)-1/4*y(x) = 0,y(x)],
[7002,(-2*x^2+2*x)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[7003,(-2*x^2+2*x)*diff(diff(y(x),x),x)+(-11*x+1)*diff(y(x),x)-10*y(x) = 0,y(x)],
[7004,(-x^2+x)*diff(diff(y(x),x),x)+(-2/3*x+1/3)*diff(y(x),x)+20/9*y(x) = 0,y(x)],
[7005,4*diff(diff(y(x),x),x)+(-3/(-x^2+1)^2*x^2+6/(-x^2+1)^2)*y(x) = 0,y(x)],
[7013,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(-x^2-1/4)*y(x) = 0,y(x)],
[7015,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-25/4)*y(x) = 0,y(x)],
[7016,diff(diff(y(x),x),x)+q*diff(y(x),x)-2*y(x)/x^2 = 0,y(x)],
[7017,x*diff(diff(y(x),x),x)+3*diff(y(x),x)+4*x^3*y(x) = 0,y(x)],
[7018,(x^2+2*x)*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[7019,(x^2+2*x)*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[7020,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7021,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7022,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-2)*y(x) = 0,y(x)],
[7023,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-2)*y(x) = 0,y(x)],
[7024,(2*x-3)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7025,diff(diff(y(x),x),x)-x*diff(y(x),x)-3*y(x) = 0,y(x)],
[7026,(x^2+1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7027,diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7028,(-x^2+1)*diff(diff(y(x),x),x)-diff(y(x),x)+y(x) = 0,y(x)],
[7029,(x^3+2*x^2+x)*diff(diff(y(x),x),x)+(-x^2+1)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[7030,2*x*diff(diff(y(x),x),x)-diff(y(x),x)+2*y(x) = 0,y(x)],
[7031,x*diff(diff(y(x),x),x)+x*diff(y(x),x)-2*y(x) = 0,y(x)],
[7032,(x^3-2*x^2+x)*diff(diff(y(x),x),x)-2*y(x) = 0,y(x)],
[7033,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+x^2*y(x) = 0,y(x)],
[7034,(-x^3+2*x)*diff(diff(y(x),x),x)+(x^3+3*x^2-2*x-2)*diff(y(x),x)+(-x^2-4*x-2)*y(x) = 0,y(x)],
[7035,(x^3+x^2)*diff(diff(y(x),x),x)+(-2*x^2-x)*diff(y(x),x)+(2*x+1)*y(x) = 0,y(x)],
[7036,(-2*x^3+4*x^2)*diff(diff(y(x),x),x)+(x^2-4*x)*diff(y(x),x)+(3-x)*y(x) = 0,y(x)],
[7037,(-x^3+x^2)*diff(diff(y(x),x),x)+(5*x^2-4*x)*diff(y(x),x)+(6-9*x)*y(x) = 0,y(x)],
[7038,x*diff(diff(y(x),x),x)+(4*x^2+1)*diff(y(x),x)+(4*x^3+4*x)*y(x) = 0,y(x)],
[7039,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[7040,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[7041,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[7042,(x^2+2*x)*diff(diff(y(x),x),x)+(2*x+2)*diff(y(x),x)-2*y(x) = 0,y(x)],
[7043,(x^2+2*x)*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)-4*y(x) = 0,y(x)],
[7044,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7045,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7046,(x^2-2*x+10)*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[7047,(x^2-2*x+10)*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[7048,diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7049,(x+2)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[7050,(x^2+1)*diff(diff(y(x),x),x)-6*y(x) = 0,y(x)],
[7051,(x^2+2)*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-y(x) = 0,y(x)],
[7052,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7053,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[7054,x^2*diff(diff(y(x),x),x)+(5/3*x+x^2)*diff(y(x),x)-1/3*y(x) = 0,y(x)],
[7055,2*x*diff(diff(y(x),x),x)-diff(y(x),x)+2*y(x) = 0,y(x)],
[7056,2*x*diff(diff(y(x),x),x)+(-2*x-3)*diff(y(x),x)+y(x) = 0,y(x)],
[7057,2*x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+(2*x-1)*y(x) = 0,y(x)],
[7058,x*diff(diff(y(x),x),x)+2*diff(y(x),x)-x*y(x) = 0,y(x)],
[7059,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7060,x*diff(diff(y(x),x),x)+(x-6)*diff(y(x),x)-3*y(x) = 0,y(x)],
[7062,4*x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2-25)*y(x) = 0,y(x)],
[7063,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(36*x^2-1/4)*y(x) = 0,y(x)],
[7064,x^2*diff(diff(y(x),x),x)+(x^2-2)*y(x) = 0,y(x)],
[7065,x*diff(diff(y(x),x),x)+3*diff(y(x),x)+x^3*y(x) = 0,y(x)],
[7066,x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[7067,16*x^2*diff(diff(y(x),x),x)+32*x*diff(y(x),x)+(x^4-12)*y(x) = 0,y(x)],
[7068,diff(diff(y(x),x),x)-x^2*diff(y(x),x)+x*y(x) = 0,y(x)],
[7069,x*diff(diff(y(x),x),x)+(-2-x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[7070,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7071,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7072,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-2)*y(x) = 0,y(x)],
[7073,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+30*y(x) = 0,y(x)],
[7074,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[7075,x*diff(diff(y(x),x),x)+(2*x+1)*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[7076,(2*x^2-2*x)*diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[7077,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+4*x*y(x) = 0,y(x)],
[7078,x*diff(diff(y(x),x),x)+(-2*x+2)*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[7079,x^2*diff(diff(y(x),x),x)+6*x*diff(y(x),x)+(4*x^2+6)*y(x) = 0,y(x)],
[7080,x*diff(diff(y(x),x),x)+(1-2*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[7081,(-x^2+x)*diff(diff(y(x),x),x)+(1/2+2*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[7082,(4*t^2-12*t+8)*diff(diff(y(t),t),t)-2*diff(y(t),t)+y(t) = 0,y(t)],
[7083,(2*t^2-10*t+12)*diff(diff(y(t),t),t)+(2*t-3)*diff(y(t),t)-8*y(t) = 0,y(t)],
[7084,(3*t^2+3*t)*diff(diff(y(t),t),t)+t*diff(y(t),t)-y(t) = 0,y(t)],
[7085,x^2*diff(diff(y(x),x),x)+(1/4*x+3/16)*y(x) = 0,y(x)],
[7086,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(1/4*x^2-1/4)*y(x) = 0,y(x)],
[7087,x*diff(diff(y(x),x),x)+(1-2*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[7088,x*diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[7089,x*diff(diff(y(x),x),x)+3*diff(y(x),x)+4*x^3*y(x) = 0,y(x)],
[7090,(-x^4+x^2)*diff(diff(y(x),x),x)+(-2*x^3+2*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[7091,2*x*diff(diff(y(x),x),x)+(x-2)*diff(y(x),x)-y(x) = 0,y(x)],
[7092,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[7093,diff(diff(y(x),x),x)+2*x^2*diff(y(x),x)+(x^4+2*x-1)*y(x) = 0,y(x)],
[7094,diff(diff(u(x),x),x)+1/x^2*u(x) = 0,u(x)],
[7095,diff(diff(u(x),x),x)+(-2*x-1)*diff(u(x),x)+(x^2+x-1)*u(x) = 0,u(x)],
[7096,diff(diff(y(x),x),x)+2*diff(y(x),x)+(1+2/(3*x+1)^2)*y(x) = 0,y(x)],
[7097,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[7098,diff(diff(y(x),x),x)+2/x*diff(y(x),x)-2/(x+1)^2*y(x) = 0,y(x)],
[7099,diff(diff(y(x),x),x)+1/2/x^4*y(x) = 0,y(x)],
[7100,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7101,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7102,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7103,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7104,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7105,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7106,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7107,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7108,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7109,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7110,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7111,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[7112,2*x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7113,x^2*diff(diff(y(x),x),x)+(3*x^2+2*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[7115,x*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)+2*y(x) = 0,y(x)],
[7116,(x^4-2*x^3+x^2)*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+(4+x)*y(x) = 0,y(x)],
[7117,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+5*x^2*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[7118,x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[7119,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7120,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+(-x^2-5/4)*y(x) = 0,y(x)],
[7121,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7122,x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+4*x^4*y(x) = 0,y(x)],
[7123,diff(diff(y(x),x),x)+(-x^2-3)*y(x) = 0,y(x)],
[7124,diff(diff(y(x),x),x)+2*x*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[7125,x^3*diff(diff(y(x),x),x)+diff(y(x),x)-1/x*y(x) = 0,y(x)],
[7126,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7127,4*x^2*diff(diff(y(x),x),x)+(-8*x^2+4*x)*diff(y(x),x)+(4*x^2-4*x-1)*y(x) = 0,y(x)],
[7128,diff(diff(y(x),x),x)-diff(y(x),x)+y(x) = 0,y(x)],
[7129,(x^2-1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7130,x^2*diff(diff(y(x),x),x)+(-x^2-2*x)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[7131,(x+1)*diff(diff(y(x),x),x)+(-2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[7132,(-x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[7133,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7134,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7135,(x^2-1)*diff(diff(y(x),x),x)-6*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[7136,(x^2+3)*diff(diff(y(x),x),x)-7*x*diff(y(x),x)+16*y(x) = 0,y(x)],
[7137,(x^2-1)*diff(diff(y(x),x),x)+8*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[7138,3*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[7139,5*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+10*y(x) = 0,y(x)],
[7140,diff(diff(y(x),x),x)-x^2*diff(y(x),x)-3*x*y(x) = 0,y(x)],
[7141,(x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[7142,diff(diff(y(x),x),x)+x*diff(y(x),x)-2*y(x) = 0,y(x)],
[7143,(x^2-6*x+10)*diff(diff(y(x),x),x)+(-4*x+12)*diff(y(x),x)+6*y(x) = 0,y(x)],
[7144,(x^2+6*x)*diff(diff(y(x),x),x)+(3*x+9)*diff(y(x),x)-3*y(x) = 0,y(x)],
[7145,t*diff(diff(y(t),t),t)+(t^2-1)*diff(y(t),t)+t^3*y(t) = 0,y(t)],
[7146,t^2*diff(diff(y(t),t),t)+(-t^2-2*t)*diff(y(t),t)+(t+2)*y(t) = 0,y(t)],
[7147,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7148,x^2*diff(diff(y(x),x),x)+(-x+3/16)*y(x) = 0,y(x)],
[7149,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7150,t^2*diff(diff(y(t),t),t)+(-t^2-2*t)*diff(y(t),t)+(t+2)*y(t) = 0,y(t)],
[7151,t*diff(diff(y(t),t),t)+(-t-1)*diff(y(t),t)+y(t) = 0,y(t)],
[7152,(-t+1)*diff(diff(y(t),t),t)+t*diff(y(t),t)-y(t) = 0,y(t)],
[7153,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7154,t*diff(diff(y(t),t),t)+(-t-1)*diff(y(t),t)+y(t) = 0,y(t)],
[7155,(-t+1)*diff(diff(y(t),t),t)+t*diff(y(t),t)-y(t) = 0,y(t)],
[7156,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7157,(x^2+1)*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[7158,(1-x)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[7159,2*diff(diff(y(x),x),x)+x*diff(y(x),x)+3*y(x) = 0,y(x)],
[7160,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7161,(1-x)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[7162,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7163,(-x^2+4)*diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7164,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(-16*x^2+3)*y(x) = 0,y(x)],
[7165,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7166,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[7167,(x^2-2*x)*diff(diff(y(x),x),x)+(-x^2+2)*diff(y(x),x)+(2*x-2)*y(x) = 0,y(x)],
[7168,(2*x+1)*diff(diff(y(x),x),x)-2*diff(y(x),x)+(-2*x-3)*y(x) = 0,y(x)],
[7169,4*x^2*diff(diff(y(x),x),x)+(-8*x^2+4*x)*diff(y(x),x)+(4*x^2-4*x-1)*y(x) = 0,y(x)],
[7170,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[7171,x^2*diff(diff(y(x),x),x)+(2*x^2-2*x)*diff(y(x),x)+(x^2-2*x+2)*y(x) = 0,y(x)],
[7172,x^2*diff(diff(y(x),x),x)+(-2*x^2+x)*diff(y(x),x)+(x^2-x-1)*y(x) = 0,y(x)],
[7173,(1-2*x)*diff(diff(y(x),x),x)+2*diff(y(x),x)+(2*x-3)*y(x) = 0,y(x)],
[7174,2*x*diff(diff(y(x),x),x)+(4*x+1)*diff(y(x),x)+(2*x+1)*y(x) = 0,y(x)],
[7175,x*diff(diff(y(x),x),x)+(-2*x-1)*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[7176,4*x^2*diff(diff(y(x),x),x)+(-4*x^2-4*x)*diff(y(x),x)+(2*x+3)*y(x) = 0,y(x)],
[7177,x*diff(diff(y(x),x),x)+(-2*x+2)*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[7178,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7179,x*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[7180,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[7181,x*diff(diff(y(x),x),x)+(-4*x-1)*diff(y(x),x)+(2+4*x)*y(x) = 0,y(x)],
[7182,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(-16*x^2+3)*y(x) = 0,y(x)],
[7183,(2*x^2+x)*diff(diff(y(x),x),x)+(-4*x^2+2)*diff(y(x),x)+(-4*x-4)*y(x) = 0,y(x)],
[7184,(x^2-2*x)*diff(diff(y(x),x),x)+(-x^2+2)*diff(y(x),x)+(2*x-2)*y(x) = 0,y(x)],
[7185,x*diff(diff(y(x),x),x)+(-4*x-1)*diff(y(x),x)+(2+4*x)*y(x) = 0,y(x)],
[7186,(3*x-1)*diff(diff(y(x),x),x)+(-3*x-2)*diff(y(x),x)+(-6*x+8)*y(x) = 0,y(x)],
[7187,(x^2+2*x+1)*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+(-x^2-2*x+1)*y(x) = 0,y(x)],
[7188,4*x^2*diff(diff(y(x),x),x)+(-8*x^2+4*x)*diff(y(x),x)+(4*x^2-4*x-1)*y(x) = 0,y(x)],
[7189,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[7190,(2*x+1)*diff(diff(y(x),x),x)-2*diff(y(x),x)+(-2*x-3)*y(x) = 0,y(x)],
[7191,x*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[7192,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[7193,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(-16*x^2+3)*y(x) = 0,y(x)],
[7194,4*x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2+3)*y(x) = 0,y(x)],
[7195,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(-x^2+2)*y(x) = 0,y(x)],
[7196,x^2*diff(diff(y(x),x),x)+(-2*x^2-2*x)*diff(y(x),x)+(x^2+2*x+2)*y(x) = 0,y(x)],
[7197,x^2*diff(diff(y(x),x),x)+(-2*x^2-4*x)*diff(y(x),x)+(x^2+4*x+6)*y(x) = 0,y(x)],
[7198,x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(x^2+6)*y(x) = 0,y(x)],
[7199,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7200,4*x^2*diff(diff(y(x),x),x)+(-4*x^2-4*x)*diff(y(x),x)+(2*x+3)*y(x) = 0,y(x)],
[7201,(3*x-1)*diff(diff(y(x),x),x)+(-3*x-2)*diff(y(x),x)+(-6*x+8)*y(x) = 0,y(x)],
[7202,(x+2)*diff(diff(y(x),x),x)+x*diff(y(x),x)+3*y(x) = 0,y(x)],
[7203,(-x^3+x^2)*diff(diff(y(x),x),x)+(x^2+4*x)*diff(y(x),x)+(-x+2)*y(x) = 0,y(x)],
[7204,(x^3+x^2)*diff(diff(y(x),x),x)+(2*x^2+x)*diff(y(x),x)+(-6*x-4)*y(x) = 0,y(x)],
[7205,(2*x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3+4*x)*diff(y(x),x)+(-2*x^2+2)*y(x) = 0,y(x)],
[7206,(x^4+2*x^2)*diff(diff(y(x),x),x)+(2*x^3+10*x)*diff(y(x),x)+(-2*x^2+6)*y(x) = 0,y(x)],
[7207,(x^2+1)*diff(diff(y(x),x),x)+6*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[7208,(x^2+1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[7209,(x^2+1)*diff(diff(y(x),x),x)-8*x*diff(y(x),x)+20*y(x) = 0,y(x)],
[7210,(-x^2+1)*diff(diff(y(x),x),x)-8*x*diff(y(x),x)-12*y(x) = 0,y(x)],
[7211,(2*x^2+1)*diff(diff(y(x),x),x)+7*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7212,(-x^2+1)*diff(diff(y(x),x),x)-5*x*diff(y(x),x)-4*y(x) = 0,y(x)],
[7213,(x^2+1)*diff(diff(y(x),x),x)-10*x*diff(y(x),x)+28*y(x) = 0,y(x)],
[7214,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7215,(2*x^2-8*x+11)*diff(diff(y(x),x),x)+(-16*x+32)*diff(y(x),x)+36*y(x) = 0,y(x)],
[7216,diff(diff(y(x),x),x)+(x-3)*diff(y(x),x)+3*y(x) = 0,y(x)],
[7217,(x^2-8*x+14)*diff(diff(y(x),x),x)+(-8*x+32)*diff(y(x),x)+20*y(x) = 0,y(x)],
[7218,(2*x^2+4*x+5)*diff(diff(y(x),x),x)+(-20*x-20)*diff(y(x),x)+60*y(x) = 0,y(x)],
[7219,(x^3+1)*diff(diff(y(x),x),x)+7*x^2*diff(y(x),x)+9*x*y(x) = 0,y(x)],
[7221,diff(diff(y(x),x),x)+x^6*diff(y(x),x)+7*x^5*y(x) = 0,y(x)],
[7223,diff(diff(y(x),x),x)+x^5*diff(y(x),x)+6*x^4*y(x) = 0,y(x)],
[7224,(3*x+1)*diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7225,(3*x^2+x+1)*diff(diff(y(x),x),x)+(2+15*x)*diff(y(x),x)+12*y(x) = 0,y(x)],
[7226,(x+2)*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)+3*y(x) = 0,y(x)],
[7227,(4+x)*diff(diff(y(x),x),x)+(x+2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[7228,(2*x^2+3*x)*diff(diff(y(x),x),x)+(10*x+10)*diff(y(x),x)+8*y(x) = 0,y(x)],
[7229,x^2*diff(diff(y(x),x),x)+(-6+7*x)*diff(y(x),x)+8*y(x) = 0,y(x)],
[7230,(2*x^2+x+1)*diff(diff(y(x),x),x)+(1+7*x)*diff(y(x),x)+2*y(x) = 0,y(x)],
[7231,(x+3)*diff(diff(y(x),x),x)+(2*x+1)*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[7232,diff(diff(y(x),x),x)+3*x*diff(y(x),x)+(2*x^2+4)*y(x) = 0,y(x)],
[7233,(2+4*x)*diff(diff(y(x),x),x)-4*diff(y(x),x)+(-4*x-6)*y(x) = 0,y(x)],
[7234,diff(diff(y(x),x),x)-3*x*diff(y(x),x)+(2*x^2+5)*y(x) = 0,y(x)],
[7235,2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)+(2*x^2+4)*y(x) = 0,y(x)],
[7236,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[7237,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[7239,3*x^2*diff(diff(y(x),x),x)+(-4*x^3+2*x^2+2*x)*diff(y(x),x)+(-8*x^2+2*x)*y(x) = 0,y(x)],
[7240,(12*x^3+12*x^2)*diff(diff(y(x),x),x)+(3*x^3+35*x^2+11*x)*diff(y(x),x)+(5*x^2+10*x-1)*y(x) = 0,y(x)],
[7241,diff(diff(y(x),x),x)+3*diff(y(x),x)+4*y(x) = 0,y(x)],
[7242,(18*x^3+18*x^2)*diff(diff(y(x),x),x)+(3*x^3+33*x^2+15*x)*diff(y(x),x)+(5*x^2+2*x-1)*y(x) = 0,y(x)],
[7243,2*x^2*diff(diff(y(x),x),x)+(2*x^2+3*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[7244,2*x^2*diff(diff(y(x),x),x)+(x^2+5*x)*diff(y(x),x)+(3*x-2)*y(x) = 0,y(x)],
[7245,3*x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)-y(x) = 0,y(x)],
[7246,2*x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+(1-2*x)*y(x) = 0,y(x)],
[7247,3*x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(-3*x-1)*y(x) = 0,y(x)],
[7248,(2*x^3+6*x^2)*diff(diff(y(x),x),x)+(5*x^2+x)*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[7249,(x^3+4*x^2)*diff(diff(y(x),x),x)+(3*x^2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[7250,2*x^2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[7251,6*x^2*diff(diff(y(x),x),x)+(-x^2+10*x)*diff(y(x),x)+(-2-x)*y(x) = 0,y(x)],
[7252,(4*x^3+3*x^2)*diff(diff(y(x),x),x)+(4*x^2+11*x)*diff(y(x),x)+(-4*x-3)*y(x) = 0,y(x)],
[7253,(6*x^3+4*x^2)*diff(diff(y(x),x),x)+(11*x^2+4*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[7254,(x^3+2*x^2)*diff(diff(y(x),x),x)+(-5*x^2+5*x)*diff(y(x),x)+(8*x-2)*y(x) = 0,y(x)],
[7255,(-8*x^4+8*x^2)*diff(diff(y(x),x),x)+(-26*x^3+2*x)*diff(y(x),x)+(-9*x^2+1)*y(x) = 0,y(x)],
[7256,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3-4*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[7257,(x^3+3*x)*diff(diff(y(x),x),x)+(-x^2+2)*diff(y(x),x)-8*x*y(x) = 0,y(x)],
[7258,(-4*x^4+4*x^2)*diff(diff(y(x),x),x)+(-19*x^3+7*x)*diff(y(x),x)+(-14*x^2-1)*y(x) = 0,y(x)],
[7259,(-3*x^4+6*x^2)*diff(diff(y(x),x),x)+(-11*x^3+x)*diff(y(x),x)+(-5*x^2+1)*y(x) = 0,y(x)],
[7260,(2*x^4+4*x^2)*diff(diff(y(x),x),x)+(7*x^3-12*x)*diff(y(x),x)+(3*x^2+7)*y(x) = 0,y(x)],
[7261,(2*x^4+4*x^2)*diff(diff(y(x),x),x)+(7*x^3+4*x)*diff(y(x),x)+(3*x^2-1)*y(x) = 0,y(x)],
[7262,(4*x^4+2*x^2)*diff(diff(y(x),x),x)+(30*x^3+5*x)*diff(y(x),x)+(40*x^2-2)*y(x) = 0,y(x)],
[7263,(x^3+x)*diff(diff(y(x),x),x)+(7*x^2+4)*diff(y(x),x)+8*x*y(x) = 0,y(x)],
[7264,(2*x^4+2*x^2)*diff(diff(y(x),x),x)+(8*x^3+3*x)*diff(y(x),x)+(4*x^2-3)*y(x) = 0,y(x)],
[7265,9*x^2*diff(diff(y(x),x),x)+(3*x^3+9*x)*diff(y(x),x)+(5*x^2-1)*y(x) = 0,y(x)],
[7266,6*x^2*diff(diff(y(x),x),x)+(6*x^3+x)*diff(y(x),x)+(9*x^2+1)*y(x) = 0,y(x)],
[7267,(9*x^4+9*x^2)*diff(diff(y(x),x),x)+(39*x^3+9*x)*diff(y(x),x)+(25*x^2-1)*y(x) = 0,y(x)],
[7268,(4*x^4+4*x^2)*diff(diff(y(x),x),x)+(24*x^3+4*x)*diff(y(x),x)+(25*x^2-1)*y(x) = 0,y(x)],
[7269,(16*x^4+8*x^2)*diff(diff(y(x),x),x)+(68*x^3+10*x)*diff(y(x),x)+(30*x^2-1)*y(x) = 0,y(x)],
[7270,(2*x^3+2*x^2)*diff(diff(y(x),x),x)+(3*x^2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[7271,(12*x^4+6*x^2)*diff(diff(y(x),x),x)+(50*x^3+x)*diff(y(x),x)+(30*x^2+1)*y(x) = 0,y(x)],
[7272,(-84*x^3+28*x^2)*diff(diff(y(x),x),x)+(-63*x^2-35*x)*diff(y(x),x)+(63*x+14)*y(x) = 0,y(x)],
[7273,(-8*x^4+16*x^2)*diff(diff(y(x),x),x)+(-42*x^3+20*x)*diff(y(x),x)+(-35*x^2-2)*y(x) = 0,y(x)],
[7274,(4*x^4+12*x^3+4*x^2)*diff(diff(y(x),x),x)+(12*x^3+12*x^2-4*x)*diff(y(x),x)+(3*x^2-3*x+3)*y(x) = 0,y(x)],
[7275,(3*x^4+6*x^3+3*x^2)*diff(diff(y(x),x),x)+(11*x^3+10*x^2-x)*diff(y(x),x)+(5*x^2+1)*y(x) = 0,y(x)],
[7276,(4*x^4+8*x^3+12*x^2)*diff(diff(y(x),x),x)+(15*x^3+14*x^2-3*x)*diff(y(x),x)+(7*x^2+3)*y(x) = 0,y(x)],
[7277,(x^4-2*x^3+x^2)*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+(4+x)*y(x) = 0,y(x)],
[7278,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+5*x^2*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[7279,(-x^4+2*x^2)*diff(diff(y(x),x),x)+(-4*x^3-2*x)*diff(y(x),x)+(-2*x^2+2)*y(x) = 0,y(x)],
[7280,x^2*diff(diff(y(x),x),x)+(x^2-5*x)*diff(y(x),x)+(9-4*x)*y(x) = 0,y(x)],
[7281,(4*x^4+4*x^3+4*x^2)*diff(diff(y(x),x),x)+(12*x^3+12*x^2)*diff(y(x),x)+(3*x^2+3*x+1)*y(x) = 0,y(x)],
[7282,(x^4+x^3+x^2)*diff(diff(y(x),x),x)+(2*x^3+4*x^2-x)*diff(y(x),x)+y(x) = 0,y(x)],
[7283,9*x^2*diff(diff(y(x),x),x)+(-6*x^3+9*x^2+15*x)*diff(y(x),x)+(-14*x^2+12*x+1)*y(x) = 0,y(x)],
[7284,(2*x^3+x^2)*diff(diff(y(x),x),x)+(3*x^3+14*x^2+5*x)*diff(y(x),x)+(12*x^2+18*x+4)*y(x) = 0,y(x)],
[7285,16*x^2*diff(diff(y(x),x),x)+(8*x^3+4*x^2+24*x)*diff(y(x),x)+(18*x^2+5*x+1)*y(x) = 0,y(x)],
[7286,(9*x^3+9*x^2)*diff(diff(y(x),x),x)+(-3*x^3+33*x^2+15*x)*diff(y(x),x)+(-7*x^2+16*x+1)*y(x) = 0,y(x)],
[7287,(-72*x^3+36*x^2)*diff(diff(y(x),x),x)+(-216*x^2+24*x)*diff(y(x),x)+(1-70*x)*y(x) = 0,y(x)],
[7288,(x^3+x^2)*diff(diff(y(x),x),x)+(x^2-3*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[7289,(-2*x^3+x^2)*diff(diff(y(x),x),x)+(4*x^2-5*x)*diff(y(x),x)+(9-4*x)*y(x) = 0,y(x)],
[7290,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+(1-x)*y(x) = 0,y(x)],
[7291,(2*x^3+2*x^2)*diff(diff(y(x),x),x)+(x^2-6*x)*diff(y(x),x)+(8-x)*y(x) = 0,y(x)],
[7292,(2*x^3+x^2)*diff(diff(y(x),x),x)+(9*x^2+5*x)*diff(y(x),x)+(4+3*x)*y(x) = 0,y(x)],
[7293,(-2*x^3+x^2)*diff(diff(y(x),x),x)+(-4*x^2-5*x)*diff(y(x),x)+(9+4*x)*y(x) = 0,y(x)],
[7294,(-x^3+x^2)*diff(diff(y(x),x),x)+(x^2+7*x)*diff(y(x),x)+(9-x)*y(x) = 0,y(x)],
[7295,x^2*diff(diff(y(x),x),x)+(x^3-x)*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[7296,(x^4+x^2)*diff(diff(y(x),x),x)+(3*x^3-3*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[7297,4*x^2*diff(diff(y(x),x),x)+2*x^3*diff(y(x),x)+(3*x^2+1)*y(x) = 0,y(x)],
[7298,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3-x)*diff(y(x),x)+y(x) = 0,y(x)],
[7299,(2*x^4+4*x^2)*diff(diff(y(x),x),x)+7*x^3*diff(y(x),x)+(3*x^2+1)*y(x) = 0,y(x)],
[7300,(x^4+x^2)*diff(diff(y(x),x),x)+(4*x^3-x)*diff(y(x),x)+(2*x^2+1)*y(x) = 0,y(x)],
[7301,(4*x^4+16*x^2)*diff(diff(y(x),x),x)+(9*x^3+24*x)*diff(y(x),x)+(-9*x^2+1)*y(x) = 0,y(x)],
[7302,(3*x^4+9*x^2)*diff(diff(y(x),x),x)+(11*x^3+3*x)*diff(y(x),x)+(5*x^2+1)*y(x) = 0,y(x)],
[7303,9*x^2*diff(diff(y(x),x),x)+(6*x^3-21*x)*diff(y(x),x)+(2*x^2+25)*y(x) = 0,y(x)],
[7304,x^2*diff(diff(y(x),x),x)+(x^3-x)*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[7305,(-2*x^3+x^2)*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+(4*x+1)*y(x) = 0,y(x)],
[7306,(x^2+x)*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)+y(x) = 0,y(x)],
[7307,(-x^3+x^2)*diff(diff(y(x),x),x)+(5*x^2-3*x)*diff(y(x),x)+(4-5*x)*y(x) = 0,y(x)],
[7308,(x^4+x^2)*diff(diff(y(x),x),x)+(-9*x^3-x)*diff(y(x),x)+(25*x^2+1)*y(x) = 0,y(x)],
[7309,9*x^2*diff(diff(y(x),x),x)+(-3*x^3+3*x)*diff(y(x),x)+(7*x^2+1)*y(x) = 0,y(x)],
[7310,(x^3+x)*diff(diff(y(x),x),x)+(-x^2+1)*diff(y(x),x)-8*x*y(x) = 0,y(x)],
[7311,4*x^2*diff(diff(y(x),x),x)+(-2*x^3+8*x)*diff(y(x),x)+(7*x^2+1)*y(x) = 0,y(x)],
[7312,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+8*x^2*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[7313,(9*x^3+27*x^2)*diff(diff(y(x),x),x)+(21*x^2+9*x)*diff(y(x),x)+(3+4*x)*y(x) = 0,y(x)],
[7314,(-x^4+2*x^2)*diff(diff(y(x),x),x)+(-3*x^3-2*x)*diff(y(x),x)+(-x^2+2)*y(x) = 0,y(x)],
[7315,(16*x^4+16*x^2)*diff(diff(y(x),x),x)+(72*x^3+8*x)*diff(y(x),x)+(49*x^2+1)*y(x) = 0,y(x)],
[7316,(3*x^3+4*x^2)*diff(diff(y(x),x),x)+(3*x^2-4*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[7317,(4*x^4+12*x^3+4*x^2)*diff(diff(y(x),x),x)+(16*x^3+24*x^2)*diff(y(x),x)+(9*x^2+3*x+1)*y(x) = 0,y(x)],
[7318,(x^4-2*x^3+x^2)*diff(diff(y(x),x),x)+(3*x^3-2*x^2-x)*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[7319,(9*x^4+9*x^3+9*x^2)*diff(diff(y(x),x),x)+(39*x^3+21*x^2+3*x)*diff(y(x),x)+(25*x^2+4*x+1)*y(x) = 0,y(x)],
[7320,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+(7*x^2-4*x)*diff(y(x),x)+(3*x-5)*y(x) = 0,y(x)],
[7321,(-2*x^3+x^2)*diff(diff(y(x),x),x)+(-9*x^2+8*x)*diff(y(x),x)+(6-3*x)*y(x) = 0,y(x)],
[7322,(x^4+x^2)*diff(diff(y(x),x),x)+(10*x^3+3*x)*diff(y(x),x)+(14*x^2-15)*y(x) = 0,y(x)],
[7323,(-2*x^4+x^2)*diff(diff(y(x),x),x)+(-13*x^3+7*x)*diff(y(x),x)-14*x^2*y(x) = 0,y(x)],
[7324,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+(8*x^2+4*x)*diff(y(x),x)+(-3*x-1)*y(x) = 0,y(x)],
[7325,(6*x^3+4*x^2)*diff(diff(y(x),x),x)+(21*x^2+4*x)*diff(y(x),x)+(9*x-1)*y(x) = 0,y(x)],
[7326,x^2*diff(diff(y(x),x),x)+(x^2+2*x)*diff(y(x),x)+(3*x-2)*y(x) = 0,y(x)],
[7327,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+(32*x^2+12*x)*diff(y(x),x)+(49*x-5)*y(x) = 0,y(x)],
[7329,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(-3*x-9)*y(x) = 0,y(x)],
[7330,(2*x^3+x^2)*diff(diff(y(x),x),x)+(13*x^2+9*x)*diff(y(x),x)+(7+5*x)*y(x) = 0,y(x)],
[7331,(8*x^3+4*x^2)*diff(diff(y(x),x),x)+(2*x^2-8*x)*diff(y(x),x)+(-5*x-7)*y(x) = 0,y(x)],
[7332,(3*x^3+9*x^2)*diff(diff(y(x),x),x)+(-x^2-15*x)*diff(y(x),x)-20*y(x) = 0,y(x)],
[7333,(x^3+x^2)*diff(diff(y(x),x),x)+(-10*x^2+x)*diff(y(x),x)+(10*x-9)*y(x) = 0,y(x)],
[7334,(x^3+x^2)*diff(diff(y(x),x),x)+3*x^2*diff(y(x),x)+(x-6)*y(x) = 0,y(x)],
[7335,(2*x^3+x^2)*diff(diff(y(x),x),x)+(-28*x^2-6*x)*diff(y(x),x)+(6+100*x)*y(x) = 0,y(x)],
[7336,(x^3+x^2)*diff(diff(y(x),x),x)+(-11*x^2-6*x)*diff(y(x),x)+(6+32*x)*y(x) = 0,y(x)],
[7337,(4*x^3+4*x^2)*diff(diff(y(x),x),x)+(16*x^2+4*x)*diff(y(x),x)+(-27*x-49)*y(x) = 0,y(x)],
[7338,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3-7*x)*diff(y(x),x)+12*y(x) = 0,y(x)],
[7339,x^2*diff(diff(y(x),x),x)+(x^3-7*x)*diff(y(x),x)+12*y(x) = 0,y(x)],
[7340,x^2*diff(diff(y(x),x),x)+(2*x^3+x)*diff(y(x),x)+(10*x^2-1)*y(x) = 0,y(x)],
[7341,x^2*diff(diff(y(x),x),x)+(-2*x^3+x)*diff(y(x),x)+(-8*x^2-4)*y(x) = 0,y(x)],
[7342,x^2*diff(diff(y(x),x),x)+(-3*x^3+x)*diff(y(x),x)+(12*x^2-4)*y(x) = 0,y(x)],
[7343,(x^4+x^2)*diff(diff(y(x),x),x)+(11*x^3+5*x)*diff(y(x),x)+24*x^2*y(x) = 0,y(x)],
[7344,(4*x^4+4*x^2)*diff(diff(y(x),x),x)+8*x*diff(y(x),x)+(x^2-35)*y(x) = 0,y(x)],
[7345,(x^4+x^2)*diff(diff(y(x),x),x)+(x^3-5*x)*diff(y(x),x)+(-25*x^2-7)*y(x) = 0,y(x)],
[7346,(x^4+x^2)*diff(diff(y(x),x),x)+(2*x^3+5*x)*diff(y(x),x)-21*y(x) = 0,y(x)],
[7347,(4*x^4+4*x^2)*diff(diff(y(x),x),x)+(4*x^3+8*x)*diff(y(x),x)+(-x^2-15)*y(x) = 0,y(x)],
[7348,diff(diff(y(t),t),t)+(-2/(t^2+2*t-1)*t-2/(t^2+2*t-1))*diff(y(t),t)+2/(t^2+2*t-1)*y(t) = 0,y(t)],
[7349,diff(diff(y(t),t),t)-4*t*diff(y(t),t)+(4*t^2-2)*y(t) = 0,y(t)],
[7350,(-t^2+1)*diff(diff(y(t),t),t)-2*t*diff(y(t),t)+2*y(t) = 0,y(t)],
[7351,(t^2+1)*diff(diff(y(t),t),t)-2*t*diff(y(t),t)+2*y(t) = 0,y(t)],
[7352,(-t^2+1)*diff(diff(y(t),t),t)-2*t*diff(y(t),t)+6*y(t) = 0,y(t)],
[7353,(2*t+1)*diff(diff(y(t),t),t)+(-4*t-4)*diff(y(t),t)+4*y(t) = 0,y(t)],
[7354,t^2*diff(diff(y(t),t),t)+t*diff(y(t),t)+(t^2-1/4)*y(t) = 0,y(t)],
[7355,diff(diff(y(t),t),t)-2*t/(t^2+1)*diff(y(t),t)+2/(t^2+1)*y(t) = 0,y(t)],
[7357,2*t*diff(diff(y(t),t),t)+(1-2*t)*diff(y(t),t)-y(t) = 0,y(t)],
[7358,2*t*diff(diff(y(t),t),t)+(t+1)*diff(y(t),t)-2*y(t) = 0,y(t)],
[7359,2*t^2*diff(diff(y(t),t),t)-t*diff(y(t),t)+(t+1)*y(t) = 0,y(t)],
[7360,2*t^2*diff(diff(y(t),t),t)+(t^2-t)*diff(y(t),t)+y(t) = 0,y(t)],
[7361,t^2*diff(diff(y(t),t),t)+(-t^2+t)*diff(y(t),t)-y(t) = 0,y(t)],
[7362,t*diff(diff(y(t),t),t)+(-t^2-2)*diff(y(t),t)+t*y(t) = 0,y(t)],
[7363,t^2*diff(diff(y(t),t),t)+(t^2+t)*diff(y(t),t)-y(t) = 0,y(t)],
[7364,t*diff(diff(y(t),t),t)+(-4-t)*diff(y(t),t)+2*y(t) = 0,y(t)],
[7365,t^2*diff(diff(y(t),t),t)+(t^2-3*t)*diff(y(t),t)+3*y(t) = 0,y(t)],
[7366,t*diff(diff(y(t),t),t)+t*diff(y(t),t)+2*y(t) = 0,y(t)],
[7367,t*diff(diff(y(t),t),t)+(-t^2+1)*diff(y(t),t)+4*t*y(t) = 0,y(t)],
[7368,t^2*diff(diff(y(t),t),t)+(-t^2-t)*diff(y(t),t)+y(t) = 0,y(t)],
[7369,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+6)*y(x) = 0,y(x)],
[7370,(-z^2+1)*diff(diff(y(z),z),z)-3*z*diff(y(z),z)+y(z) = 0,y(z)],
[7371,4*z*diff(diff(y(z),z),z)+(-2*z+2)*diff(y(z),z)-y(z) = 0,y(z)],
[7372,diff(diff(f(z),z),z)+(2*z-2)*diff(f(z),z)+4*f(z) = 0,f(z)],
[7373,z*diff(diff(y(z),z),z)-2*diff(y(z),z)+z*y(z) = 0,y(z)],
[7374,z*diff(diff(y(z),z),z)+(2*z-3)*diff(y(z),z)+4/z*y(z) = 0,y(z)],
[7375,x*diff(diff(y(x),x),x)+(1-2*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[7376,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[7377,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7378,4*x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2-1)*y(x) = 0,y(x)],
[7379,x*diff(diff(y(x),x),x)+(-2*x-1)*diff(y(x),x)+2*y(x) = 0,y(x)],
[7380,diff(diff(y(x),x),x)+2*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[7381,diff(diff(y(x),x),x)+x*diff(y(x),x)+3*y(x) = 0,y(x)],
[7382,diff(diff(y(x),x),x)-x^2*diff(y(x),x)-3*x*y(x) = 0,y(x)],
[7383,(-4*x^2+1)*diff(diff(y(x),x),x)-20*x*diff(y(x),x)-16*y(x) = 0,y(x)],
[7384,(x^2-1)*diff(diff(y(x),x),x)-6*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[7385,diff(diff(y(x),x),x)+x*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[7386,(2*x^2+1)*diff(diff(y(x),x),x)+7*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7387,4*diff(diff(y(x),x),x)+x*diff(y(x),x)+4*y(x) = 0,y(x)],
[7388,diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[7389,4*x*diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7390,6*x^2*diff(diff(y(x),x),x)+(18*x^2+x)*diff(y(x),x)+(1+12*x)*y(x) = 0,y(x)],
[7391,3*x^2*diff(diff(y(x),x),x)+(-x^2-8*x)*diff(y(x),x)+6*y(x) = 0,y(x)],
[7392,2*x^2*diff(diff(y(x),x),x)+(-2*x^2-x)*diff(y(x),x)+(8*x-2)*y(x) = 0,y(x)],
[7393,4*x^2*diff(diff(y(x),x),x)-4*x^2*diff(y(x),x)+(2*x+1)*y(x) = 0,y(x)],
[7394,x^2*diff(diff(y(x),x),x)+(-2*x^2+3*x)*diff(y(x),x)+(1-2*x)*y(x) = 0,y(x)],
[7395,x^2*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+(4-x)*y(x) = 0,y(x)],
[7396,x^2*diff(diff(y(x),x),x)+(-x^2+3*x)*diff(y(x),x)+y(x) = 0,y(x)],
[7397,x^2*diff(diff(y(x),x),x)+(-2*x*5^(1/2)+x)*diff(y(x),x)+(19/4-3*x^2)*y(x) = 0,y(x)],
[7398,x^2*diff(diff(y(x),x),x)+(x^2-3*x)*diff(y(x),x)+(4-x)*y(x) = 0,y(x)],
[7399,x^2*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+(-x-2)*y(x) = 0,y(x)],
[7400,x^2*diff(diff(y(x),x),x)+2*x^2*diff(y(x),x)+(x-3/4)*y(x) = 0,y(x)],
[7401,(x^3+x^2)*diff(diff(y(x),x),x)+x^2*diff(y(x),x)-2*y(x) = 0,y(x)],
[7402,x^2*diff(diff(y(x),x),x)+(x^3+6*x)*diff(y(x),x)+6*y(x) = 0,y(x)],
[7403,x^2*diff(diff(y(x),x),x)+(-x^2+x)*diff(y(x),x)-y(x) = 0,y(x)],
[7404,x^2*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[7405,x^2*diff(diff(y(x),x),x)-x^2*diff(y(x),x)-2*y(x) = 0,y(x)],
[7406,x^2*diff(diff(y(x),x),x)-x^2*diff(y(x),x)+(-3*x-2)*y(x) = 0,y(x)],
[7407,x^2*diff(diff(y(x),x),x)+(-x^2+5*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[7408,4*x^2*diff(diff(y(x),x),x)+(-4*x^2+4*x)*diff(y(x),x)+(2*x-9)*y(x) = 0,y(x)],
[7409,x^2*diff(diff(y(x),x),x)+(2*x^2+4*x)*diff(y(x),x)+(2*x+2)*y(x) = 0,y(x)],
[7410,x^2*diff(diff(y(x),x),x)+(x^2-x)*diff(y(x),x)+(1-x)*y(x) = 0,y(x)],
[7411,4*x^2*diff(diff(y(x),x),x)+(8*x^2+4*x)*diff(y(x),x)+(-1+4*x)*y(x) = 0,y(x)],
[7412,x^2*diff(diff(y(x),x),x)+(x^2+4*x)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[7413,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-9/4)*y(x) = 0,y(x)],
[7414,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[7415,2*x*diff(diff(y(x),x),x)+(-10*x+5)*diff(y(x),x)-5*y(x) = 0,y(x)],
[7416,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7418,x^4*diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[7419,x^2*diff(diff(y(x),x),x)+(2*x^2+x)*diff(y(x),x)-4*y(x) = 0,y(x)],
[7420,(4*x^3-14*x^2-2*x)*diff(diff(y(x),x),x)+(-6*x^2+7*x-1)*diff(y(x),x)+(6*x-1)*y(x) = 0,y(x)],
[7421,x^2*diff(diff(y(x),x),x)+x^2*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[7422,x^2*diff(diff(y(x),x),x)-x^2*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[7423,(-4*x^3+x^2)*diff(diff(y(x),x),x)+(-1/4*x-x^2)*diff(y(x),x)-5/16*x*y(x) = 0,y(x)],
[7424,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(x-9)*y(x) = 0,y(x)],
[7425,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(3*x-1)*y(x) = 0,y(x)],
[7426,x^2*diff(diff(y(x),x),x)+(-x^2-4*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[7427,2*x^2*diff(diff(y(x),x),x)+(-3*x-2)*diff(y(x),x)+(2-1/x)*y(x) = 0,y(x)],
[7428,(-x^2+x)*diff(diff(y(x),x),x)+(3/2-2*x)*diff(y(x),x)-1/4*y(x) = 0,y(x)],
[7429,(-2*x^2+2*x)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[7430,(-2*x^2+2*x)*diff(diff(y(x),x),x)+(1-11*x)*diff(y(x),x)-10*y(x) = 0,y(x)],
[7431,(-x^2+x)*diff(diff(y(x),x),x)+(-2/3*x+1/3)*diff(y(x),x)+20/9*y(x) = 0,y(x)],
[7432,4*diff(diff(y(x),x),x)+(-3/(-x^2+1)^2*x^2+6/(-x^2+1)^2)*y(x) = 0,y(x)],
[7440,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(-x^2-1/4)*y(x) = 0,y(x)],
[7442,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-25/4)*y(x) = 0,y(x)],
[7444,x*diff(diff(y(x),x),x)+3*diff(y(x),x)+4*x^3*y(x) = 0,y(x)],
[7445,(-x^3+2*x^2)*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-2*y(x) = 0,y(x)],
[7446,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7447,x*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[7448,3*x*diff(diff(y(x),x),x)+(-6*x+2)*diff(y(x),x)+(3*x-2)*y(x) = 0,y(x)],
[7449,(x^2+x)*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)+y(x) = 0,y(x)],
[7450,(x^2+2*x)*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[7451,(x^2+2*x)*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[7452,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7453,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7454,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-2)*y(x) = 0,y(x)],
[7455,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-2)*y(x) = 0,y(x)],
[7456,(2*x-3)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7457,diff(diff(y(x),x),x)-x*diff(y(x),x)-3*y(x) = 0,y(x)],
[7458,(x^2+1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7459,diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7460,(-x^2+1)*diff(diff(y(x),x),x)-diff(y(x),x)+y(x) = 0,y(x)],
[7461,(x^3+2*x^2+x)*diff(diff(y(x),x),x)+(-x^2+1)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[7462,2*x*diff(diff(y(x),x),x)-diff(y(x),x)+2*y(x) = 0,y(x)],
[7463,x*diff(diff(y(x),x),x)+x*diff(y(x),x)-2*y(x) = 0,y(x)],
[7464,(x^3-2*x^2+x)*diff(diff(y(x),x),x)-2*y(x) = 0,y(x)],
[7465,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+x^2*y(x) = 0,y(x)],
[7466,(-x^3+2*x)*diff(diff(y(x),x),x)+(x^3+3*x^2-2*x-2)*diff(y(x),x)+(-x^2-4*x-2)*y(x) = 0,y(x)],
[7467,(x^3+x^2)*diff(diff(y(x),x),x)+(-2*x^2-x)*diff(y(x),x)+(2*x+1)*y(x) = 0,y(x)],
[7468,(-2*x^3+4*x^2)*diff(diff(y(x),x),x)+(x^2-4*x)*diff(y(x),x)+(3-x)*y(x) = 0,y(x)],
[7469,(-x^3+x^2)*diff(diff(y(x),x),x)+(5*x^2-4*x)*diff(y(x),x)+(6-9*x)*y(x) = 0,y(x)],
[7470,x*diff(diff(y(x),x),x)+(4*x^2+1)*diff(y(x),x)+(4*x^3+4*x)*y(x) = 0,y(x)],
[7471,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[7472,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[7473,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+12*y(x) = 0,y(x)],
[7474,(x^2+2*x)*diff(diff(y(x),x),x)+(2*x+2)*diff(y(x),x)-2*y(x) = 0,y(x)],
[7475,(x^2+2*x)*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)-4*y(x) = 0,y(x)],
[7476,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7477,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7478,(x^2-2*x+10)*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[7479,(x^2-2*x+10)*diff(diff(y(x),x),x)+x*diff(y(x),x)-4*y(x) = 0,y(x)],
[7480,diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7481,(x+2)*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[7482,(x^2+1)*diff(diff(y(x),x),x)-6*y(x) = 0,y(x)],
[7483,(x^2+2)*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-y(x) = 0,y(x)],
[7484,(x-1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7485,diff(diff(y(x),x),x)-2*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[7486,x^2*diff(diff(y(x),x),x)+(5/3*x+x^2)*diff(y(x),x)-1/3*y(x) = 0,y(x)],
[7487,2*x*diff(diff(y(x),x),x)-diff(y(x),x)+2*y(x) = 0,y(x)],
[7488,2*x*diff(diff(y(x),x),x)+(-2*x-3)*diff(y(x),x)+y(x) = 0,y(x)],
[7489,2*x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+(2*x-1)*y(x) = 0,y(x)],
[7490,x*diff(diff(y(x),x),x)+2*diff(y(x),x)-x*y(x) = 0,y(x)],
[7491,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7492,x*diff(diff(y(x),x),x)+(x-6)*diff(y(x),x)-3*y(x) = 0,y(x)],
[7494,4*x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2-25)*y(x) = 0,y(x)],
[7495,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(36*x^2-1/4)*y(x) = 0,y(x)],
[7496,x^2*diff(diff(y(x),x),x)+(x^2-2)*y(x) = 0,y(x)],
[7497,x*diff(diff(y(x),x),x)+3*diff(y(x),x)+x^3*y(x) = 0,y(x)],
[7498,x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[7499,16*x^2*diff(diff(y(x),x),x)+32*x*diff(y(x),x)+(x^4-12)*y(x) = 0,y(x)],
[7500,diff(diff(y(x),x),x)-x^2*diff(y(x),x)+x*y(x) = 0,y(x)],
[7501,x*diff(diff(y(x),x),x)+(-x-2)*diff(y(x),x)+2*y(x) = 0,y(x)],
[7502,diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7503,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[7504,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-2)*y(x) = 0,y(x)],
[7505,(-x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+30*y(x) = 0,y(x)],
[7506,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[7507,x*diff(diff(y(x),x),x)+(2*x+1)*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[7508,(2*x^2-2*x)*diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[7509,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+4*x*y(x) = 0,y(x)],
[7510,x*diff(diff(y(x),x),x)+(-2*x+2)*diff(y(x),x)+(x-2)*y(x) = 0,y(x)],
[7511,x^2*diff(diff(y(x),x),x)+6*x*diff(y(x),x)+(4*x^2+6)*y(x) = 0,y(x)],
[7512,x*diff(diff(y(x),x),x)+(1-2*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[7513,(-x^2+x)*diff(diff(y(x),x),x)+(1/2+2*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[7514,(4*t^2-12*t+8)*diff(diff(y(t),t),t)-2*diff(y(t),t)+y(t) = 0,y(t)],
[7515,(2*t^2-10*t+12)*diff(diff(y(t),t),t)+(2*t-3)*diff(y(t),t)-8*y(t) = 0,y(t)],
[7516,(3*t^2+3*t)*diff(diff(y(t),t),t)+t*diff(y(t),t)-y(t) = 0,y(t)],
[7517,x^2*diff(diff(y(x),x),x)+(1/4*x+3/16)*y(x) = 0,y(x)],
[7518,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(1/4*x^2-1/4)*y(x) = 0,y(x)],
[7519,x*diff(diff(y(x),x),x)+(1-2*x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[7520,x*diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[7521,x*diff(diff(y(x),x),x)+3*diff(y(x),x)+4*x^3*y(x) = 0,y(x)],
[7522,(-x^4+x^2)*diff(diff(y(x),x),x)+(-2*x^3+2*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[7523,2*x*diff(diff(y(x),x),x)+(x-2)*diff(y(x),x)-y(x) = 0,y(x)],
[7524,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[7525,diff(diff(y(x),x),x)+2*x^2*diff(y(x),x)+(x^4+2*x-1)*y(x) = 0,y(x)],
[7526,diff(diff(u(x),x),x)+2*diff(u(x),x)+u(x) = 0,u(x)],
[7527,diff(diff(u(x),x),x)+(-2*x-1)*diff(u(x),x)+(x^2+x-1)*u(x) = 0,u(x)],
[7528,diff(diff(y(x),x),x)+2*diff(y(x),x)+(1+2/(3*x+1)^2)*y(x) = 0,y(x)],
[7529,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[7530,diff(diff(y(x),x),x)+2/x*diff(y(x),x)-2/(x+1)^2*y(x) = 0,y(x)],
[7531,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7532,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7533,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7534,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7535,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7536,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7537,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7538,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7539,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7540,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7541,diff(diff(y(x),x),x)-x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7542,x*diff(diff(y(x),x),x)+2*diff(y(x),x)+x*y(x) = 0,y(x)],
[7543,2*x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)-x*y(x) = 0,y(x)],
[7544,x^2*diff(diff(y(x),x),x)+(3*x^2+2*x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[7546,x*diff(diff(y(x),x),x)+(x+1)*diff(y(x),x)+2*y(x) = 0,y(x)],
[7547,(x^4-2*x^3+x^2)*diff(diff(y(x),x),x)+(-x^2-3*x)*diff(y(x),x)+(4+x)*y(x) = 0,y(x)],
[7548,(2*x^3+4*x^2)*diff(diff(y(x),x),x)+5*x^2*diff(y(x),x)+(x+1)*y(x) = 0,y(x)],
[7549,x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[7550,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7551,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+(-x^2-5/4)*y(x) = 0,y(x)],
[7552,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7553,x^2*diff(diff(y(x),x),x)+3*x*diff(y(x),x)+4*x^4*y(x) = 0,y(x)],
[7554,diff(diff(y(x),x),x)+(-x^2-3)*y(x) = 0,y(x)],
[7555,diff(diff(y(x),x),x)+2*x*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[7556,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)+(x^2-1/4)*y(x) = 0,y(x)],
[7557,4*x^2*diff(diff(y(x),x),x)+(-8*x^2+4*x)*diff(y(x),x)+(4*x^2-4*x-1)*y(x) = 0,y(x)],
[7558,diff(diff(y(x),x),x) = 0,y(x)],
[7559,diff(diff(y(x),x),x)-2*y(x)/x^2 = 0,y(x)],
[7560,diff(diff(y(x),x),x)-6*y(x)/x^2 = 0,y(x)],
[7561,diff(diff(y(x),x),x)+(3/16/x^2+2/9/(x-1)^2-3/16/x/(x-1))*y(x) = 0,y(x)],
[7562,diff(diff(y(x),x),x)-20*y(x)/x^2 = 0,y(x)],
[7563,diff(diff(y(x),x),x)-12*y(x)/x^2 = 0,y(x)],
[7564,diff(diff(y(x),x),x)-1/4*y(x)/x^2 = 0,y(x)],
[7565,x*diff(diff(y(x),x),x)+(-2*x-2)*diff(y(x),x)+(x+2)*y(x) = 0,y(x)],
[7566,diff(diff(y(x),x),x)+y(x)/x^2 = 0,y(x)],
[7567,(-x^2+1)*diff(diff(y(x),x),x)+diff(y(x),x)+y(x) = 0,y(x)],
[7568,(x^2-x)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[7569,(-x^4+2*x^2)*diff(diff(y(x),x),x)+(-4*x^3-3*x)*diff(y(x),x)+(-2*x^2+2)*y(x) = 0,y(x)],
[7570,diff(diff(y(x),x),x)+(-x^2+2*x-3-1/x-7/4/x^2+5/x^3-1/x^4)*y(x) = 0,y(x)],
[7571,diff(diff(y(x),x),x)+(-6/x^2+1)*y(x) = 0,y(x)],
[7572,diff(diff(y(x),x),x)+(-1/4*x^2+11/2)*y(x) = 0,y(x)],
[7573,diff(diff(y(x),x),x)+(-1/x+3/16/x^2)*y(x) = 0,y(x)],
[7574,diff(diff(y(x),x),x)+(3/16/x^2+2/9/(x-1)^2-3/16/x/(x-1))*y(x) = 0,y(x)],
[7575,diff(diff(y(x),x),x)+(5/36/(x^2-1)^2*x^2+3/4/(x^2-1)^2)*y(x) = 0,y(x)],
[7576,diff(diff(y(x),x),x)+1/4*y(x)/x^2 = 0,y(x)],
[7577,diff(diff(y(x),x),x)+(-x^2-3)*y(x) = 0,y(x)],
[7578,x^2*diff(diff(y(x),x),x)-2*y(x) = 0,y(x)],
[7579,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[7580,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[7581,(x^2-4*x+4)*diff(diff(y(x),x),x)+(-x+2)*diff(y(x),x)-3*y(x) = 0,y(x)],
[8581,diff(diff(y(x),x),x) = 0,y(x)],
[8582,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[8583,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[8584,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[8585,diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[8586,diff(diff(y(x),x),x)-y(x) = 0,y(x)],
[8587,diff(diff(y(x),x),x)-2*y(x) = 0,y(x)],
[8589,diff(diff(y(x),x),x)+l*y(x) = 0,y(x)],
[8591,diff(diff(y(x),x),x)+(-x^2-1)*y(x) = 0,y(x)],
[8619,diff(diff(y(x),x),x)+x*diff(y(x),x)+y(x) = 0,y(x)],
[8620,diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[8623,diff(diff(y(x),x),x)-x*diff(y(x),x)+2*y(x) = 0,y(x)],
[8625,diff(diff(y(x),x),x)-x*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[8627,diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(4*x^2+2)*y(x) = 0,y(x)],
[8629,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-1)*y(x) = 0,y(x)],
[8630,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-2)*y(x) = 0,y(x)],
[8631,diff(diff(y(x),x),x)-4*x*diff(y(x),x)+(4*x^2-3)*y(x) = 0,y(x)],
[8636,diff(diff(y(x),x),x)-x^2*diff(y(x),x)+x*y(x) = 0,y(x)],
[8637,diff(diff(y(x),x),x)-x^2*diff(y(x),x)+(-x^2-2*x-1)*y(x) = 0,y(x)],
[8638,diff(diff(y(x),x),x)+(-x^3-x^2)*diff(y(x),x)+(x^5-2*x)*y(x) = 0,y(x)],
[8639,diff(diff(y(x),x),x)+x^4*diff(y(x),x)-x^3*y(x) = 0,y(x)],
[8671,x*diff(diff(y(x),x),x)+x*y(x) = 0,y(x)],
[8673,x*diff(diff(y(x),x),x)+diff(y(x),x) = 0,y(x)],
[8680,x*diff(diff(y(x),x),x)+2*diff(y(x),x)-x*y(x) = 0,y(x)],
[8689,x*diff(diff(y(x),x),x)-x*diff(y(x),x)-y(x) = 0,y(x)],
[8691,x*diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[8692,x*diff(diff(y(x),x),x)+(-x-1)*diff(y(x),x)+(-2*x+2)*y(x) = 0,y(x)],
[8701,x*diff(diff(y(x),x),x)+(-x^2+x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[8702,x*diff(diff(y(x),x),x)+(-x^2+x+2)*diff(y(x),x)+(-x^2-3*x)*y(x) = 0,y(x)],
[8705,x*diff(diff(y(x),x),x)+(4*x^2-1)*diff(y(x),x)-4*x^3*y(x) = 0,y(x)],
[8709,(x-3)*diff(diff(y(x),x),x)+(-4*x+9)*diff(y(x),x)+(3*x-6)*y(x) = 0,y(x)],
[8713,(2*x-1)*diff(diff(y(x),x),x)+(-3*x+4)*diff(y(x),x)+(x-3)*y(x) = 0,y(x)],
[8715,4*x*diff(diff(y(x),x),x)+2*diff(y(x),x)-y(x) = 0,y(x)],
[8716,4*x*diff(diff(y(x),x),x)+4*diff(y(x),x)+(-x-2)*y(x) = 0,y(x)],
[8726,x^2*diff(diff(y(x),x),x)-6*y(x) = 0,y(x)],
[8727,x^2*diff(diff(y(x),x),x)-12*y(x) = 0,y(x)],
[8730,x^2*diff(diff(y(x),x),x)+(x^2-2)*y(x) = 0,y(x)],
[8739,x^2*diff(diff(y(x),x),x)+x*diff(y(x),x)-y(x) = 0,y(x)],
[8746,x^2*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[8748,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x) = 0,y(x)],
[8754,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[8755,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)-4*y(x) = 0,y(x)],
[8756,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[8757,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[8758,x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+(x^2+2)*y(x) = 0,y(x)],
[8761,x^2*diff(diff(y(x),x),x)+(3*x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[8762,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)+4*y(x) = 0,y(x)],
[8763,x^2*diff(diff(y(x),x),x)-3*x*diff(y(x),x)-5*y(x) = 0,y(x)],
[8764,x^2*diff(diff(y(x),x),x)-4*x*diff(y(x),x)+6*y(x) = 0,y(x)],
[8766,x^2*diff(diff(y(x),x),x)-5*x*diff(y(x),x)+8*y(x) = 0,y(x)],
[8771,x^2*diff(diff(y(x),x),x)+x^2*diff(y(x),x)-2*y(x) = 0,y(x)],
[8772,x^2*diff(diff(y(x),x),x)+(x^2-1)*diff(y(x),x)-y(x) = 0,y(x)],
[8773,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(x-9)*y(x) = 0,y(x)],
[8774,x^2*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)+(3*x-1)*y(x) = 0,y(x)],
[8776,x^2*diff(diff(y(x),x),x)+(-x^2+x)*diff(y(x),x)+(x-1)*y(x) = 0,y(x)],
[8778,x^2*diff(diff(y(x),x),x)+(-x^2+2*x)*diff(y(x),x)+(-3*x-2)*y(x) = 0,y(x)],
[8779,x^2*diff(diff(y(x),x),x)+(-x^2-4*x)*diff(y(x),x)+4*y(x) = 0,y(x)],
[8781,x^2*diff(diff(y(x),x),x)+(2*x^2+x)*diff(y(x),x)-4*y(x) = 0,y(x)],
[8782,x^2*diff(diff(y(x),x),x)+(-2*x^2-2*x)*diff(y(x),x)+(2*x+2)*y(x) = 0,y(x)],
[8788,x^2*diff(diff(y(x),x),x)+x^3*diff(y(x),x)+(x^2-2)*y(x) = 0,y(x)],
[8789,x^2*diff(diff(y(x),x),x)+(x^3+2*x)*diff(y(x),x)+(x^2-2)*y(x) = 0,y(x)],
[8791,x^2*diff(diff(y(x),x),x)+4*x^3*diff(y(x),x)+(4*x^4+2*x^2+1)*y(x) = 0,y(x)],
[8802,(x^2+1)*diff(diff(y(x),x),x)+x*diff(y(x),x)+2*y(x) = 0,y(x)],
[8803,(x^2+1)*diff(diff(y(x),x),x)+x*diff(y(x),x)-9*y(x) = 0,y(x)],
[8805,(x^2+1)*diff(diff(y(x),x),x)-x*diff(y(x),x)+y(x) = 0,y(x)],
[8807,(x^2+1)*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[8809,(x^2+1)*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[8814,(x^2-1)*diff(diff(y(x),x),x)+x*diff(y(x),x) = 0,y(x)],
[8817,(x^2-1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x) = 0,y(x)],
[8818,(x^2-1)*diff(diff(y(x),x),x)+2*x*diff(y(x),x) = 0,y(x)],
[8822,(x^2-1)*diff(diff(y(x),x),x)+(-3*x-1)*diff(y(x),x)+(-x^2+x)*y(x) = 0,y(x)],
[8823,(x^2-1)*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(x^2+1)*y(x) = 0,y(x)],
[8831,(x^2+x)*diff(diff(y(x),x),x)+(1-x)*diff(y(x),x)+y(x) = 0,y(x)],
[8833,(x^2+x)*diff(diff(y(x),x),x)+(3*x+2)*diff(y(x),x)+y(x) = 0,y(x)],
[8842,(x^2+2*x+1)*diff(diff(y(x),x),x)+(x^2+x-1)*diff(y(x),x)+(-x-2)*y(x) = 0,y(x)],
[8843,(x^2+3*x)*diff(diff(y(x),x),x)+(3*x-1)*diff(y(x),x)+y(x) = 0,y(x)],
[8844,(x^2+3*x+4)*diff(diff(y(x),x),x)+(x^2+x+1)*diff(y(x),x)+(-2*x-3)*y(x) = 0,y(x)],
[8846,(x^2-4*x+4)*diff(diff(y(x),x),x)+(-x+2)*diff(y(x),x)-3*y(x) = 0,y(x)],
[8847,2*x^2*diff(diff(y(x),x),x)+(-2*x^2-l+5*x)*diff(y(x),x)+(1-4*x)*y(x) = 0,y(x)],
[8850,(2*x^2+6*x+4)*diff(diff(y(x),x),x)+(10*x^2+21*x+8)*diff(y(x),x)+(12*x^2+17*x+8)*y(x) = 0,y(x)],
[8851,4*x^2*diff(diff(y(x),x),x)+y(x) = 0,y(x)],
[8856,4*x^2*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+(-4*x^2-1)*y(x) = 0,y(x)],
[8859,4*x^2*diff(diff(y(x),x),x)+5*x*diff(y(x),x)-y(x) = 0,y(x)],
[8860,4*x^2*diff(diff(y(x),x),x)+8*x*diff(y(x),x)+(-4*x^2-12*x-3)*y(x) = 0,y(x)],
[8861,4*x^2*diff(diff(y(x),x),x)+(-8*x^2+4*x)*diff(y(x),x)+(4*x^2-4*x-1)*y(x) = 0,y(x)],
[8862,4*x^2*diff(diff(y(x),x),x)+4*x^3*diff(y(x),x)+(x^4+2*x^2-24)*y(x) = 0,y(x)],
[8864,(4*x^2+4*x+1)*diff(diff(y(x),x),x)+(-4*x-2)*diff(y(x),x)-12*y(x) = 0,y(x)],
[8866,(9*x^2-6*x+1)*diff(diff(y(x),x),x)+(9*x-3)*diff(y(x),x)-9*y(x) = 0,y(x)],
[8867,(9*x^2-9*x)*diff(diff(y(x),x),x)+(6*x-3)*diff(y(x),x)-20*y(x) = 0,y(x)],
[8868,16*x^2*diff(diff(y(x),x),x)+(3+4*x)*y(x) = 0,y(x)],
[8869,16*x^2*diff(diff(y(x),x),x)+32*x*diff(y(x),x)+(-4*x-5)*y(x) = 0,y(x)],
[8870,(27*x^2+4)*diff(diff(y(x),x),x)+27*x*diff(y(x),x)-3*y(x) = 0,y(x)],
[8872,(50*x^2-50*x)*diff(diff(y(x),x),x)+(50*x-25)*diff(y(x),x)-2*y(x) = 0,y(x)],
[8884,x^3*diff(diff(y(x),x),x)+x*diff(y(x),x)+(-2*x-3)*y(x) = 0,y(x)],
[8887,x^3*diff(diff(y(x),x),x)+(x^2+x)*diff(y(x),x)-2*y(x) = 0,y(x)],
[8888,x^3*diff(diff(y(x),x),x)-x^2*diff(y(x),x)+x*y(x) = 0,y(x)],
[8890,x^3*diff(diff(y(x),x),x)+3*x^2*diff(y(x),x)+x*y(x) = 0,y(x)],
[8892,(x^3+x)*diff(diff(y(x),x),x)+(2*x^2-2)*diff(y(x),x)-2*x*y(x) = 0,y(x)],
[8899,(x^3+2*x)*diff(diff(y(x),x),x)-diff(y(x),x)-6*x*y(x) = 0,y(x)],
[8900,(x^3-2*x)*diff(diff(y(x),x),x)+(-x^3-3*x^2+2*x+2)*diff(y(x),x)+(x^2+4*x+2)*y(x) = 0,y(x)],
[8901,(x^3+x^2)*diff(diff(y(x),x),x)+(-2*x^2-x)*diff(y(x),x)+(2*x+1)*y(x) = 0,y(x)],
[8902,(x^3+x^2)*diff(diff(y(x),x),x)+(6*x^2+4*x)*diff(y(x),x) = 0,y(x)],
[8903,diff(diff(y(x),x),x)+(2/(x-1)-4/x/(x-1))*diff(y(x),x)+(-2/x/(x-1)-2/x^2/(x-1))*y(x) = 0,y(x)],
[8904,diff(diff(y(x),x),x)+(-5/(x-1)+4/x/(x-1))*diff(y(x),x)+(9/x/(x-1)-6/x^2/(x-1))*y(x) = 0,y(x)],
[8906,diff(diff(y(x),x),x)+1/(x+1)*diff(y(x),x)+1/x/(x+1)^2*y(x) = 0,y(x)],
[8908,diff(diff(y(x),x),x)-2*y(x)/x/(x-1)^2 = 0,y(x)],
[8911,diff(diff(y(x),x),x)+(-1/2/(x-2)+2/x/(x-2))*diff(y(x),x)+(1/2/x/(x-2)-3/2/x^2/(x-2))*y(x) = 0,y(x)],
[8912,diff(diff(y(x),x),x)-1/(x+1)*diff(y(x),x)+(3/4/x/(x+1)+1/4/x^2/(x+1))*y(x) = 0,y(x)],
[8916,diff(diff(y(x),x),x)+(-3/(x-1)/(2*x-1)^2*x+1/(x-1)/(2*x-1)^2)*y(x) = 0,y(x)],
[8918,diff(diff(y(x),x),x)+(-2/(x-2)+1/3/x/(x-2))*diff(y(x),x)-1/3/x^2/(x-2)*y(x) = 0,y(x)],
[8925,diff(diff(y(x),x),x)+1/x^3*diff(y(x),x)-2/x^4*y(x) = 0,y(x)],
[8931,diff(diff(y(x),x),x)+(2/x+1/x^3)*diff(y(x),x)-1/x^4*y(x) = 0,y(x)],
[8933,diff(diff(y(x),x),x)+(-2/x+1/x^3)*diff(y(x),x)+1/x^4*y(x) = 0,y(x)],
[8934,diff(diff(y(x),x),x)+(-2/x+1/x^3)*diff(y(x),x)+2/x^4*y(x) = 0,y(x)],
[8935,diff(diff(y(x),x),x)+(x^2/(x^3+1)-1/x/(x^3+1))*diff(y(x),x)-x/(x^3+1)*y(x) = 0,y(x)],
[8938,diff(diff(y(x),x),x)+(-x/(x^2-1)+2/x/(x^2-1))*diff(y(x),x)+(1/(x^2-1)-2/x^2/(x^2-1))*y(x) = 0,y(x)],
[8946,diff(diff(y(x),x),x)+2/(x^2+1)*x*diff(y(x),x)+1/(x^2+1)^2*y(x) = 0,y(x)],
[8958,diff(diff(y(x),x),x)+(2*x/(x-1)^2-2/x/(x-1)^2)*diff(y(x),x)+(-2/(x-1)^2+2/x/(x-1)^2+2/x^2/(x-1)^2)*y(x) = 0,y(x)],
[8959,diff(diff(y(x),x),x)-12/(x+1)^2/(x^2+2*x+3)*y(x) = 0,y(x)],
[8966,diff(diff(y(x),x),x)-18/(2*x+1)^2/(x^2+x+1)*y(x) = 0,y(x)],
[8967,diff(diff(y(x),x),x)-3/4/(x^2+x+1)^2*y(x) = 0,y(x)],
[8970,diff(diff(y(x),x),x)+3/16/x^2/(x-1)^2*y(x) = 0,y(x)],
[8977,diff(diff(y(x),x),x)+1/x^4*diff(y(x),x)-1/x^5*y(x) = 0,y(x)],
[8979,diff(diff(y(x),x),x)+(-3*x/(x-1)/(x+1)-1/(x-1)/(x+1))*diff(y(x),x)+(36/(x-1)^2/(3*x+5)^2*x^2+72/(x-1)^2/(3*x+5)^2*x+36/(x-1)^2/(3*x+5)^2)*y(x) = 0,y(x)],
[8984,diff(diff(y(x),x),x)+(2/x+1/x^3)*diff(y(x),x)+(-1/2/x^4+1/4/x^6)*y(x) = 0,y(x)],
[8986,diff(diff(y(x),x),x)+27/16*x/(x^3-1)^2*y(x) = 0,y(x)],
[9026,diff(diff(y(x),x),x)+1/x*diff(y(x),x)+(1/x^3-1/x^4)*y(x) = 0,y(x)],
[9027,diff(diff(y(x),x),x)+1/x*diff(y(x),x)+(-1/x^3-1/x^4)*y(x) = 0,y(x)],
[9044,-2*diff(diff(y(x),x),x)-3*diff(y(x),x)+10*y(x) = 0,y(x)],
[9055,-8*diff(diff(y(x),x),x)-11*diff(y(x),x)-3*y(x) = 0,y(x)],
[9061,(x^2-3)*diff(diff(y(x),x),x)+4*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[9065,(-x^2+2*x)*diff(diff(y(x),x),x)-2*diff(y(x),x)+2*y(x) = 0,y(x)],
[9067,(4+x)*diff(diff(y(x),x),x)+2*diff(y(x),x) = 0,y(x)],
[9070,-x*diff(diff(y(x),x),x)+(x^2+1)*diff(y(x),x) = 0,y(x)],
[9074,5*x*diff(diff(y(x),x),x)+4*diff(y(x),x) = 0,y(x)],
[9075,6*x*diff(diff(y(x),x),x)+6*diff(y(x),x) = 0,y(x)],
[9083,8*x*diff(diff(y(x),x),x)+10*diff(y(x),x) = 0,y(x)],
[9084,-2*x*diff(diff(y(x),x),x)+(x^2+2)*diff(y(x),x)-2*x*y(x) = 0,y(x)],
[9086,(x^2+14*x-1)*diff(diff(y(x),x),x)+(4*x+4)*diff(y(x),x)+2*y(x) = 0,y(x)],
[9091,3*x^2*diff(diff(y(x),x),x)-2*x*diff(y(x),x)+2*y(x) = 0,y(x)],
[9093,-4*x^2*diff(diff(y(x),x),x)+(x^3+8*x)*diff(y(x),x)+(-2*x^2-8)*y(x) = 0,y(x)],
[9096,(x^3+3*x^2)*diff(diff(y(x),x),x)+(5*x^2-30*x)*diff(y(x),x)+(4*x+30)*y(x) = 0,y(x)],
[9097,x^2*diff(diff(y(x),x),x)+2*x*diff(y(x),x)-y(x) = 0,y(x)],
[9098,(6*x^2+3)*diff(diff(y(x),x),x)-12*y(x) = 0,y(x)],
[9099,(-3*x^2-6*x)*diff(diff(y(x),x),x)+(6*x+6)*diff(y(x),x)-6*y(x) = 0,y(x)],
[9101,(-4*x^3-2*x^2)*diff(diff(y(x),x),x)+(10*x^2+4*x)*diff(y(x),x)+(-12*x-4)*y(x) = 0,y(x)],
[9102,-4*x^3*diff(diff(y(x),x),x)+4*x^2*diff(y(x),x) = 0,y(x)],
[9103,(-4*x^4-2*x^2)*diff(diff(y(x),x),x)+(10*x^3+4*x)*diff(y(x),x)+(-12*x^2-4)*y(x) = 0,y(x)],
[9104,x^2*diff(diff(y(x),x),x)-2*y(x) = 0,y(x)],
[9117,-12*diff(diff(y(x),x),x)+12*y(x) = 0,y(x)],
[9125,-3*diff(diff(y(x),x),x)-4*diff(y(x),x)+4*y(x) = 0,y(x)],
[9128,11*diff(diff(y(x),x),x)-3*diff(y(x),x) = 0,y(x)],
[9133,2*diff(diff(y(x),x),x) = 0,y(x)],
[9134,6*diff(diff(y(x),x),x) = 0,y(x)],
[9136,12*diff(diff(y(x),x),x) = 0,y(x)],
[9140,6*x*diff(diff(y(x),x),x) = 0,y(x)],
[9147,12*x^2*diff(diff(y(x),x),x) = 0,y(x)]];

print("main testing ");
for item in DATA do
    ODE := Object(nma:-ode_type,item[2],item[3],'hint'="kovacic");    
    ODE:-dsolve();
    sol := ODE:-solutions_found[1]:-sol;

    try 
        res_from_odetest := timelimit(60,odetest(sol,item[2]));
        if res_from_odetest <> 0 then
            number_failed := number_failed + 1;
            problems_failed ,= item[1];
            print(">>>>>>>>>>>>>>>>>Test ",item[1]," FAILED");
        else
            N:=N+1;
            print("Test ",item[1]," PASSED ");
        fi;
    catch:
         print("Test ",item[1]," TIMEDOUT on odetest");
    end try;
od;


print("Number of ode is ",N,"\nNumber failed = ",number_failed);
if number_failed>0 then
   print("ID of problems fails = ",convert(problems_failed,list));
fi;

end proc;

end module;


